@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.cc 11935 2011-09-25 16:09:38Z airwin $
+// $Id: plstream.cc 12885 2013-12-19 11:43:30Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -335,7 +335,7 @@ plstream::vect( const PLFLT * const *u, const PLFLT * const *v, PLINT nx, PLINT
 {
     set_stream();
 
-    plvect( (const PLFLT **) u, (const PLFLT **) v, nx, ny, scale, pltr, pltr_data );
+    plvect( u, v, nx, ny, scale, pltr, pltr_data );
 }
 
 void
@@ -502,7 +502,7 @@ void plstream::cont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT
 {
     set_stream();
 
-    plcont( (const PLFLT **) f, nx, ny, kx, lx, ky, ly, clevel, nlevel,
+    plcont( f, nx, ny, kx, lx, ky, ly, clevel, nlevel,
         pltr, pltr_data );
 }
 
@@ -995,13 +995,13 @@ void plstream::legend( PLFLT *p_legend_width, PLFLT *p_legend_height,
                        PLINT nlegend, const PLINT *opt_array,
                        PLFLT text_offset, PLFLT text_scale, PLFLT text_spacing,
                        PLFLT text_justification,
-                       const PLINT *text_colors, const char **text,
+                       const PLINT *text_colors, const char * const *text,
                        const PLINT *box_colors, const PLINT *box_patterns,
-                       const PLFLT *box_scales, const PLINT *box_line_widths,
+                       const PLFLT *box_scales, const PLFLT *box_line_widths,
                        const PLINT *line_colors, const PLINT *line_styles,
-                       const PLINT *line_widths,
+                       const PLFLT *line_widths,
                        const PLINT *symbol_colors, const PLFLT *symbol_scales,
-                       const PLINT *symbol_numbers, const char **symbols )
+                       const PLINT *symbol_numbers, const char * const *symbols )
 {
     set_stream();
 
@@ -1013,18 +1013,24 @@ void plstream::legend( PLFLT *p_legend_width, PLFLT *p_legend_height,
         symbol_colors, symbol_scales, symbol_numbers, symbols );
 }
 
-void plstream::colorbar( PLINT position, PLINT opt, PLFLT x, PLFLT y, PLFLT length, PLFLT width, PLINT cont_color, PLINT cont_width,
-                         PLFLT ticks, PLINT sub_ticks,
-                         const char *axis_opts, const char *label,
-                         PLINT n_colors, const PLFLT *colors, const PLFLT *values )
+void plstream::colorbar( PLFLT *p_colorbar_width, PLFLT *p_colorbar_height,
+                         PLINT opt, PLINT position, PLFLT x, PLFLT y,
+                         PLFLT x_length, PLFLT y_length,
+                         PLINT bg_color, PLINT bb_color, PLINT bb_style,
+                         PLFLT low_cap_color, PLFLT high_cap_color,
+                         PLINT cont_color, PLFLT cont_width,
+                         PLINT n_labels, PLINT *label_opts, const char * const *label,
+                         PLINT n_axes, const char * const *axis_opts,
+                         PLFLT *ticks, PLINT *sub_ticks,
+                         PLINT *n_values, const PLFLT * const *values )
 {
     set_stream();
 
-#if 0
-    plcolorbar( position, opt, x, y, length, width,
-        cont_color, cont_width, ticks, sub_ticks, axis_opts,
-        label, n_colors, colors, values );
-#endif
+    plcolorbar( p_colorbar_width, p_colorbar_height, opt, position, x, y,
+        x_length, y_length, bg_color, bb_color, bb_style,
+        low_cap_color, high_cap_color, cont_color, cont_width,
+        n_labels, label_opts, label, n_axes, axis_opts,
+        ticks, sub_ticks, n_values, values );
 }
 
 
@@ -1095,7 +1101,7 @@ void plstream::mesh( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLI
 {
     set_stream();
 
-    plmesh( x, y, (const PLFLT **) z, nx, ny, opt );
+    plmesh( x, y, z, nx, ny, opt );
 }
 
 // Plots a mesh representation of the function z[x][y] with contour.
@@ -1105,7 +1111,7 @@ void plstream::meshc( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PL
 {
     set_stream();
 
-    plmeshc( x, y, (const PLFLT **) z, nx, ny, opt, clevel, nlevel );
+    plmeshc( x, y, z, nx, ny, opt, clevel, nlevel );
 }
 
 //  Creates a new stream and makes it the default.
@@ -1145,7 +1151,7 @@ void plstream::surf3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 {
     set_stream();
 
-    plsurf3d( x, y, (const PLFLT **) z, nx, ny, opt, clevel, nlevel );
+    plsurf3d( x, y, z, nx, ny, opt, clevel, nlevel );
 }
 
 // Plots a 3-d shaded representation of the function z[x][y] with
@@ -1159,7 +1165,7 @@ void plstream::surf3dl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 {
     set_stream();
 
-    plsurf3dl( x, y, (const PLFLT **) z, nx, ny, opt, clevel, nlevel, ixstart, ixn,
+    plsurf3dl( x, y, z, nx, ny, opt, clevel, nlevel, ixstart, ixn,
         indexymin, indexymax );
 }
 
@@ -1170,7 +1176,7 @@ void plstream::plot3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 {
     set_stream();
 
-    ::plot3d( x, y, (const PLFLT **) z, nx, ny, opt, (PLBOOL) side );
+    ::plot3d( x, y, z, nx, ny, opt, (PLBOOL) side );
 }
 
 // Deprecated version using PLINT not bool
@@ -1179,7 +1185,7 @@ void plstream::plot3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 {
     set_stream();
 
-    ::plot3d( x, y, (const PLFLT **) z, nx, ny, opt, (PLBOOL) side );
+    ::plot3d( x, y, z, nx, ny, opt, (PLBOOL) side );
 }
 
 // Plots a 3-d representation of the function z[x][y] with contour.
@@ -1190,7 +1196,7 @@ void plstream::plot3dc( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 {
     set_stream();
 
-    ::plot3dc( x, y, (const PLFLT **) z, nx, ny, opt, clevel, nlevel );
+    ::plot3dc( x, y, z, nx, ny, opt, clevel, nlevel );
 }
 
 // Plots a 3-d representation of the function z[x][y] with contour
@@ -1204,7 +1210,7 @@ void plstream::plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 {
     set_stream();
 
-    ::plot3dcl( x, y, (const PLFLT **) z, nx, ny, opt, clevel, nlevel, ixstart, ixn,
+    ::plot3dcl( x, y, z, nx, ny, opt, clevel, nlevel, ixstart, ixn,
         indexymin, indexymax );
 }
 
@@ -1226,6 +1232,15 @@ void plstream::pat( PLINT nlin, const PLINT *inc, const PLINT *del )
     plpat( nlin, inc, del );
 }
 
+// Draw a line connecting two points, accounting for coordinate transforms
+
+void plstream::path( PLINT n, PLFLT x1, PLFLT y1, PLFLT x2, PLFLT y2 )
+{
+    set_stream();
+
+    plpath( n, x1, y1, x2, y2 );
+}
+
 // Plots array y against x for n points using ASCII code "code".
 
 void plstream::poin( PLINT n, const PLFLT *x, const PLFLT *y, PLINT code )
@@ -1377,6 +1392,24 @@ void plstream::scmap1n( PLINT ncol1 )
     plscmap1n( ncol1 );
 }
 
+// Set number of colors in cmap 1
+
+void plstream::scmap1_range( PLFLT min_color, PLFLT max_color )
+{
+    set_stream();
+
+    plscmap1_range( min_color, max_color );
+}
+
+// Set number of colors in cmap 1
+
+void plstream::gcmap1_range( PLFLT & min_color, PLFLT & max_color )
+{
+    set_stream();
+
+    plgcmap1_range( &min_color, &max_color );
+}
+
 // Set color map 0 colors by 8 bit RGB values
 
 void plstream::scmap0( const PLINT *r, const PLINT *g, const PLINT *b, PLINT ncol0 )
@@ -1418,24 +1451,24 @@ void plstream::scmap1a( const PLINT *r, const PLINT *g, const PLINT *b, const PL
 
 void plstream::scmap1l( bool itype, PLINT npts, const PLFLT *intensity,
                         const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3,
-                        const bool *rev )
+                        const bool *alt_hue_path )
 {
-    PLBOOL *loc_rev = NULL;
-    if ( rev != NULL )
+    PLBOOL *loc_alt_hue_path = NULL;
+    if ( alt_hue_path != NULL )
     {
-        loc_rev = new PLBOOL[npts - 1];
+        loc_alt_hue_path = new PLBOOL[npts - 1];
         for ( int i = 0; i < npts - 1; i++ )
         {
-            loc_rev[i] = (PLBOOL) rev[i];
+            loc_alt_hue_path[i] = (PLBOOL) alt_hue_path[i];
         }
     }
 
     set_stream();
 
-    plscmap1l( (PLBOOL) itype, npts, intensity, coord1, coord2, coord3, loc_rev );
+    plscmap1l( (PLBOOL) itype, npts, intensity, coord1, coord2, coord3, loc_alt_hue_path );
 
-    if ( loc_rev != NULL )
-        delete [] loc_rev;
+    if ( loc_alt_hue_path != NULL )
+        delete [] loc_alt_hue_path;
 }
 
 // Set color map 1 colors using a piece-wise linear relationship between
@@ -1444,25 +1477,25 @@ void plstream::scmap1l( bool itype, PLINT npts, const PLFLT *intensity,
 
 void plstream::scmap1la( bool itype, PLINT npts, const PLFLT *intensity,
                          const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3,
-                         const PLFLT *a, const bool *rev )
+                         const PLFLT *a, const bool *alt_hue_path )
 {
-    PLBOOL *loc_rev = NULL;
-    if ( rev != NULL )
+    PLBOOL *loc_alt_hue_path = NULL;
+    if ( alt_hue_path != NULL )
     {
-        loc_rev = new PLBOOL[npts - 1];
+        loc_alt_hue_path = new PLBOOL[npts - 1];
         for ( int i = 0; i < npts - 1; i++ )
         {
-            loc_rev[i] = (PLBOOL) rev[i];
+            loc_alt_hue_path[i] = (PLBOOL) alt_hue_path[i];
         }
     }
 
     set_stream();
 
     plscmap1la( (PLBOOL) itype, npts, intensity, coord1, coord2, coord3,
-        a, loc_rev );
+        a, loc_alt_hue_path );
 
-    if ( loc_rev != NULL )
-        delete [] loc_rev;
+    if ( loc_alt_hue_path != NULL )
+        delete [] loc_alt_hue_path;
 }
 
 //
@@ -1478,24 +1511,24 @@ void plstream::scmap1la( bool itype, PLINT npts, const PLFLT *intensity,
 // Deprecated version using PLINT instead of bool
 void plstream::scmap1l( PLINT itype, PLINT npts, const PLFLT *intensity,
                         const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3,
-                        const PLINT *rev )
+                        const PLINT *alt_hue_path )
 {
-    PLBOOL *loc_rev = NULL;
-    if ( rev != NULL )
+    PLBOOL *loc_alt_hue_path = NULL;
+    if ( alt_hue_path != NULL )
     {
-        loc_rev = new PLBOOL[npts - 1];
+        loc_alt_hue_path = new PLBOOL[npts - 1];
         for ( int i = 0; i < npts - 1; i++ )
         {
-            loc_rev[i] = (PLBOOL) rev[i];
+            loc_alt_hue_path[i] = (PLBOOL) alt_hue_path[i];
         }
     }
 
     set_stream();
 
-    plscmap1l( (PLBOOL) itype, npts, intensity, coord1, coord2, coord3, loc_rev );
+    plscmap1l( (PLBOOL) itype, npts, intensity, coord1, coord2, coord3, loc_alt_hue_path );
 
-    if ( loc_rev != NULL )
-        delete [] loc_rev;
+    if ( loc_alt_hue_path != NULL )
+        delete [] loc_alt_hue_path;
 }
 
 // Set a given color from color map 0 by 8 bit RGB value
@@ -1689,16 +1722,16 @@ plstream::shade( const PLFLT * const *a, PLINT nx, PLINT ny,
                  PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data )
 {
     set_stream();
 
-    plshade( (const PLFLT **) a, nx, ny, defined, left, right, bottom, top,
+    plshade( a, nx, ny, defined, left, right, bottom, top,
         shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
@@ -1711,16 +1744,16 @@ plstream::shade( const PLFLT * const *a, PLINT nx, PLINT ny,
                  PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data )
 {
     set_stream();
 
-    plshade( (const PLFLT **) a, nx, ny, defined, left, right, bottom, top,
+    plshade( a, nx, ny, defined, left, right, bottom, top,
         shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
@@ -1731,15 +1764,15 @@ void
 plstream::shades( const PLFLT * const *a, PLINT nx, PLINT ny,
                   PLINT ( *defined )( PLFLT, PLFLT ),
                   PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                  const PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-                  PLINT cont_color, PLINT cont_width,
+                  const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+                  PLINT cont_color, PLFLT cont_width,
                   void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                   void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                   PLPointer pltr_data )
 {
     set_stream();
 
-    plshades( (const PLFLT **) a, nx, ny, defined, xmin, xmax, ymin, ymax,
+    plshades( a, nx, ny, defined, xmin, xmax, ymin, ymax,
         clevel, nlevel, fill_width, cont_color, cont_width,
         fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
@@ -1749,15 +1782,15 @@ void
 plstream::shades( const PLFLT * const *a, PLINT nx, PLINT ny,
                   PLINT ( *defined )( PLFLT, PLFLT ),
                   PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                  const PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-                  PLINT cont_color, PLINT cont_width,
+                  const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+                  PLINT cont_color, PLFLT cont_width,
                   void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                   void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                   PLPointer pltr_data )
 {
     set_stream();
 
-    plshades( (const PLFLT **) a, nx, ny, defined, xmin, xmax, ymin, ymax,
+    plshades( a, nx, ny, defined, xmin, xmax, ymin, ymax,
         clevel, nlevel, fill_width, cont_color, cont_width,
         fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
@@ -1765,9 +1798,9 @@ plstream::shades( const PLFLT * const *a, PLINT nx, PLINT ny,
 void
 plstream::shade( Contourable_Data & d, PLFLT xmin, PLFLT xmax,
                  PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  bool rectangular,
                  Coord_Xformer *pcxf )
 {
@@ -1800,9 +1833,9 @@ plstream::shade( Contourable_Data & d, PLFLT xmin, PLFLT xmax,
 void
 plstream::shade( Contourable_Data & d, PLFLT xmin, PLFLT xmax,
                  PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  PLINT rectangular,
                  Coord_Xformer *pcxf )
 {
@@ -1826,9 +1859,9 @@ plstream::shade1( const PLFLT *a, PLINT nx, PLINT ny,
                   PLINT ( *defined )( PLFLT, PLFLT ),
                   PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                   PLFLT shade_min, PLFLT shade_max,
-                  PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                  PLINT min_color, PLINT min_width,
-                  PLINT max_color, PLINT max_width,
+                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                  PLINT min_color, PLFLT min_width,
+                  PLINT max_color, PLFLT max_width,
                   void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                   void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                   PLPointer pltr_data )
@@ -1849,9 +1882,9 @@ plstream::shade1( const PLFLT *a, PLINT nx, PLINT ny,
                   PLINT ( *defined )( PLFLT, PLFLT ),
                   PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                   PLFLT shade_min, PLFLT shade_max,
-                  PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                  PLINT min_color, PLINT min_width,
-                  PLINT max_color, PLINT max_width,
+                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                  PLINT min_color, PLFLT min_width,
+                  PLINT max_color, PLFLT max_width,
                   void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                   void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                   PLPointer pltr_data )
@@ -1874,9 +1907,9 @@ plstream::fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                   PLINT nx, PLINT ny,
                   PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                   PLFLT shade_min, PLFLT shade_max,
-                  PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                  PLINT min_color, PLINT min_width,
-                  PLINT max_color, PLINT max_width,
+                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                  PLINT min_color, PLFLT min_width,
+                  PLINT max_color, PLFLT max_width,
                   void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                   void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                   PLPointer pltr_data )
@@ -1901,9 +1934,9 @@ plstream::fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                   PLINT nx, PLINT ny,
                   PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                   PLFLT shade_min, PLFLT shade_max,
-                  PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                  PLINT min_color, PLINT min_width,
-                  PLINT max_color, PLINT max_width,
+                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                  PLINT min_color, PLFLT min_width,
+                  PLINT max_color, PLFLT max_width,
                   void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                   void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                   PLPointer pltr_data )
@@ -2161,7 +2194,7 @@ void plstream::image( const PLFLT * const *data, PLINT nx, PLINT ny,
 {
     set_stream();
 
-    plimage( (const PLFLT **) data, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
+    plimage( data, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
         Dxmin, Dxmax, Dymin, Dymax );
 }
 
@@ -2175,7 +2208,7 @@ void plstream::imagefr( const PLFLT * const *data, PLINT nx, PLINT ny, PLFLT xmi
 {
     set_stream();
 
-    plimagefr( (const PLFLT **) data, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
+    plimagefr( data, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax,
         valuemin, valuemax, pltr, pltr_data );
 }
 
@@ -2314,11 +2347,11 @@ void plstream::w3d( PLFLT basex, PLFLT basey, PLFLT height, PLFLT xmin0,
 
 // Set pen width.
 
-void plstream::wid( PLINT width )
+void plstream::width( PLFLT width )
 {
     set_stream();
 
-    plwid( width );
+    plwidth( width );
 }
 
 // Set up world coordinates of the viewport boundaries (2d plots).
@@ -2690,7 +2723,7 @@ void plstream::MinMax2dGrid( const PLFLT * const *f, PLINT nx, PLINT ny,
 {
     set_stream();
 
-    ::plMinMax2dGrid( (const PLFLT **) f, nx, ny, fmax, fmin );
+    ::plMinMax2dGrid( f, nx, ny, fmax, fmin );
 }
 
 // Functions for converting between HLS and RGB color space
