@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.h 11915 2011-09-07 11:45:29Z andrewross $
+// $Id: plstream.h 12885 2013-12-19 11:43:30Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -97,10 +97,10 @@ private:
     plstream& operator=( const plstream& );
 
 protected:
-    virtual void set_stream() { ::c_plsstrm( stream ); }
+    virtual void set_stream( void ) { ::c_plsstrm( stream ); }
 
 public:
-    plstream();
+    plstream( void );
     plstream( plstream * pls );
     plstream( PLS::stream_id sid, PLINT strm = 0 );
     plstream( PLINT _stream ) : stream( _stream ) {}
@@ -109,7 +109,7 @@ public:
     plstream( PLINT nx /*=1*/, PLINT ny /*=1*/, PLINT r, PLINT g, PLINT b,
               const char *driver = NULL, const char *file = NULL );
 
-    virtual ~plstream();
+    virtual ~plstream( void );
 
 // Now start miroring the PLplot C API.
 
@@ -135,7 +135,7 @@ public:
                PLPointer pltr_data );
 
 // Set the arrow style
-    void svect( const PLFLT *arrow_x, const PLFLT *arrow_y, PLINT npts, bool fill );
+    void svect( const PLFLT *arrow_x = NULL, const PLFLT *arrow_y = NULL, PLINT npts = 0, bool fill = false );
 
 // This functions similarly to plbox() except that the origin of the axes is
 // placed at the user-specified point (x0, y0).
@@ -149,7 +149,7 @@ public:
 
 // Start new page.  Should only be used with pleop().
 
-    void bop();
+    void bop( void );
 
 // This draws a box around the current viewport.
 
@@ -173,7 +173,7 @@ public:
 
 // Clear the current subpage.
 
-    void clear();
+    void clear( void );
 
 // Set color, map 0.  Argument is integer between 0 and 15.
 
@@ -260,7 +260,7 @@ public:
 
 // End current page.  Should only be used with plbop().
 
-    void eop();
+    void eop( void );
 
 // Plot horizontal error bars (xmin(i),y(i)) to (xmax(i),y(i)).
 
@@ -272,7 +272,7 @@ public:
 
 // Advance to the next family file on the next new page.
 
-    void famadv();
+    void famadv( void );
 
 // Pattern fills the polygon bounded by the input points.
 
@@ -284,7 +284,7 @@ public:
 
 // Flushes the output stream.  Use sparingly, if at all.
 
-    void flush();
+    void flush( void );
 
 // Sets the global font flag to 'ifont'.
 
@@ -357,7 +357,7 @@ public:
 
 // Switches to graphics screen.
 
-    void gra();
+    void gra( void );
 
 // Draw gradient in polygon.
 
@@ -416,7 +416,7 @@ public:
 
 // Initializes PLplot, using preset or default options
 
-    void init();
+    void init( void );
 
 // Draws a line segment from (x1, y1) to (x2, y2).
 
@@ -434,19 +434,24 @@ public:
                  PLINT nlegend, const PLINT *opt_array,
                  PLFLT text_offset, PLFLT text_scale, PLFLT text_spacing,
                  PLFLT text_justification,
-                 const PLINT *text_colors, const char **text,
+                 const PLINT *text_colors, const char * const *text,
                  const PLINT *box_colors, const PLINT *box_patterns,
-                 const PLFLT *box_scales, const PLINT *box_line_widths,
+                 const PLFLT *box_scales, const PLFLT *box_line_widths,
                  const PLINT *line_colors, const PLINT *line_styles,
-                 const PLINT *line_widths,
+                 const PLFLT *line_widths,
                  const PLINT *symbol_colors, const PLFLT *symbol_scales,
-                 const PLINT *symbol_numbers, const char **symbols );
-
-    void colorbar( PLINT position, PLINT opt, PLFLT x, PLFLT y, PLFLT length, PLFLT width, PLINT cont_color, PLINT cont_width,
-                   PLFLT ticks, PLINT sub_ticks,
-                   const char *axis_opts, const char *label,
-                   PLINT n_colors, const PLFLT *colors, const PLFLT *values );
+                 const PLINT *symbol_numbers, const char * const *symbols );
 
+    void colorbar( PLFLT *p_colorbar_width, PLFLT *p_colorbar_height,
+                   PLINT opt, PLINT position, PLFLT x, PLFLT y,
+                   PLFLT x_length, PLFLT y_length,
+                   PLINT bg_color, PLINT bb_color, PLINT bb_style,
+                   PLFLT low_cap_color, PLFLT high_cap_color,
+                   PLINT cont_color, PLFLT cont_width,
+                   PLINT n_labels, PLINT *label_opts, const char * const *label,
+                   PLINT n_axes, const char * const *axis_opts,
+                   PLFLT *ticks, PLINT *sub_ticks,
+                   PLINT *n_values, const PLFLT * const *values );
 
 // Sets position of the light source
 
@@ -542,6 +547,10 @@ public:
 
     void pat( PLINT nlin, const PLINT *inc, const PLINT *del );
 
+// Draw a line connecting two points, accounting for coordinate transforms
+
+    void path( PLINT n, PLFLT x1, PLFLT y1, PLFLT x2, PLFLT y2 );
+
 // Plots array y against x for n points using ASCII code "code".
 
     void poin( PLINT n, const PLFLT *x, const PLFLT *y, PLINT code );
@@ -574,7 +583,7 @@ public:
 
 // Replays contents of plot buffer to current device/file.
 
-    void replot();
+    void replot( void );
 
 // Set line color by red, green, blue from  0. to 1.
 
@@ -600,6 +609,14 @@ public:
 
     void scmap1n( PLINT ncol1 );
 
+// Set the color map 1 range used in continuous plots
+
+    void scmap1_range( PLFLT min_color, PLFLT max_color );
+
+// Get the color map 1 range used in continuous plots
+
+    void gcmap1_range( PLFLT &min_color, PLFLT &max_color );
+
 // Set color map 0 colors by 8 bit RGB values
 
     void scmap0( const PLINT *r, const PLINT *g, const PLINT *b, PLINT ncol0 );
@@ -620,7 +637,7 @@ public:
 // intensity [0,1] (cmap 1 index) and position in HLS or RGB color space.
 
     void scmap1l( bool itype, PLINT npts, const PLFLT *intensity,
-                  const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const bool *rev = NULL );
+                  const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const bool *alt_hue_path = NULL );
 
 //    void scmap1l( bool itype, PLINT npts, PLFLT *intensity,
 //                PLFLT *coord1, PLFLT *coord2, PLFLT *coord3 );
@@ -631,7 +648,7 @@ public:
 
     void scmap1la( bool itype, PLINT npts, const PLFLT *intensity,
                    const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLFLT *a,
-                   const bool *rev = NULL );
+                   const bool *alt_hue_path = NULL );
 
 // Set a given color from color map 0 by 8 bit RGB value
 
@@ -723,9 +740,9 @@ public:
                 PLINT ( *defined )( PLFLT, PLFLT ),
                 PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                 PLFLT shade_min, PLFLT shade_max,
-                PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                PLINT min_color, PLINT min_width,
-                PLINT max_color, PLINT max_width,
+                PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                PLINT min_color, PLFLT min_width,
+                PLINT max_color, PLFLT max_width,
                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                 PLPointer pltr_data );
@@ -733,8 +750,8 @@ public:
     void shades( const PLFLT * const *a, PLINT nx, PLINT ny,
                  PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                 const PLFLT * clevel, PLINT nlevel, PLINT fill_width,
-                 PLINT cont_color, PLINT cont_width,
+                 const PLFLT * clevel, PLINT nlevel, PLFLT fill_width,
+                 PLINT cont_color, PLFLT cont_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data );
@@ -745,9 +762,9 @@ public:
 
     void shade( Contourable_Data& d, PLFLT xmin, PLFLT xmax,
                 PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max,
-                PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                PLINT min_color, PLINT min_width,
-                PLINT max_color, PLINT max_width,
+                PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                PLINT min_color, PLFLT min_width,
+                PLINT max_color, PLFLT max_width,
                 bool rectangular,
                 Coord_Xformer *pcxf );
 
@@ -755,9 +772,9 @@ public:
                  PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data );
@@ -769,9 +786,9 @@ public:
                  PLINT nx, PLINT ny,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data );
@@ -921,7 +938,7 @@ public:
 
 // Switches to text screen.
 
-    void text();
+    void text( void );
 
 // Set the format for date / time labels
 
@@ -944,7 +961,7 @@ public:
 // Defines a "standard" viewport with seven character heights for
 // the left margin and four character heights everywhere else.
 
-    void vsta();
+    void vsta( void );
 
 // Set up a window for three-dimensional plotting.
 
@@ -954,7 +971,7 @@ public:
 
 // Set pen width.
 
-    void wid( PLINT width );
+    void width( PLFLT width );
 
 // Set up world coordinates of the viewport boundaries (2d plots).
 
@@ -1055,11 +1072,11 @@ public:
 
 // Clear internal option table info structure.
 
-    void ClearOpts();
+    void ClearOpts( void );
 
 // Reset internal option table info structure.
 
-    void ResetOpts();
+    void ResetOpts( void );
 
 // Merge user option table into internal info structure.
 
@@ -1083,7 +1100,7 @@ public:
 
 // Print usage & syntax message.
 
-    void OptUsage();
+    void OptUsage( void );
 
     // Miscellaneous
 
@@ -1156,15 +1173,15 @@ public:
                  PLINT nx, PLINT ny, PLINT opt, PLINT side );
     void poly3( PLINT n, const PLFLT *x, const PLFLT *y, const PLFLT *z, const PLINT *draw, PLINT ifcc );
     void scmap1l( PLINT itype, PLINT npts, const PLFLT *intensity,
-                  const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLINT *rev );
+                  const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLINT *alt_hue_path );
 
     void shade( const PLFLT * const *a, PLINT nx, PLINT ny,
                 PLINT ( *defined )( PLFLT, PLFLT ),
                 PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                 PLFLT shade_min, PLFLT shade_max,
-                PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                PLINT min_color, PLINT min_width,
-                PLINT max_color, PLINT max_width,
+                PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                PLINT min_color, PLFLT min_width,
+                PLINT max_color, PLFLT max_width,
                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                 PLPointer pltr_data );
@@ -1172,17 +1189,17 @@ public:
     void shades( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT,
                                                                                  PLFLT ),
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                 const PLFLT * clevel, PLINT nlevel, PLINT fill_width,
-                 PLINT cont_color, PLINT cont_width,
+                 const PLFLT * clevel, PLINT nlevel, PLFLT fill_width,
+                 PLINT cont_color, PLFLT cont_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data );
 
     void shade( Contourable_Data& d, PLFLT xmin, PLFLT xmax,
                 PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max,
-                PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                PLINT min_color, PLINT min_width,
-                PLINT max_color, PLINT max_width,
+                PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                PLINT min_color, PLFLT min_width,
+                PLINT max_color, PLFLT max_width,
                 PLINT rectangular,
                 Coord_Xformer *pcxf );
 
@@ -1190,9 +1207,9 @@ public:
                  PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data );
@@ -1204,9 +1221,9 @@ public:
                  PLINT nx, PLINT ny,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data );
