@@ -1,4 +1,4 @@
-// $Id: plstubs.h 11915 2011-09-07 11:45:29Z andrewross $
+// $Id: plstubs.h 12750 2013-11-25 23:29:30Z andrewross $
 //
 // Maurice LeBrun
 // IFS, University of Texas
@@ -157,9 +157,9 @@
 // Each stub must have an entry here.
 //--------------------------------------------------------------------------
 
-// N.B. By default the g77 compiler appends second underscore to name if
+// N.B. By default the gfortran compiler appends second underscore to name if
 // the original name contains any underscore at all.  According to info
-// g77, "This is done to ensure compatibility with code produced by many
+// gfortran, "This is done to ensure compatibility with code produced by many
 // UNIX Fortran compilers."  However, other fortran compilers do not have
 // this default naming scheme so to avoid trouble I have #defined two
 // variations of the embedded underscore names, one with and one without
@@ -174,7 +174,7 @@
 #define    PLADV                     FNAME( PLADV, pladv )
 #define    PLARC                     FNAME( PLARC, plarc )
 #define    PLAXES7                   FNAME( PLAXES7, plaxes7 )
-#define    PLBIN                     FNAME( PLBINF77, plbinf77 )
+#define    PLBIN                     FNAME( PLBINF95, plbinf95 )
 #define    PLBOP                     FNAME( PLBOP, plbop )
 #define    PLBOX37                   FNAME( PLBOX37, plbox37 )
 #define    PLBOX7                    FNAME( PLBOX7, plbox7 )
@@ -185,27 +185,30 @@
 #define    PLCLR                     FNAME( PLCLR, plclr )
 #define    PLCOL0                    FNAME( PLCOL0, plcol0 )
 #define    PLCOL1                    FNAME( PLCOL1, plcol1 )
+#define    PLCOLORBAR_CNV_TEXT       FNAME( PLCOLORBAR07_CNV_TEXT, plcolorbar07_cnv_text )
+#define    PLCOLORBAR                FNAME( PLCOLORBAR07, plcolorbar07 )
 #define    PLCONFIGTIME              FNAME( PLCONFIGTIME, plconfigtime )
 #define    PLCON07                   FNAME( PLCON07, plcon07 )
 #define    PLCON17                   FNAME( PLCON17, plcon17 )
 #define    PLCON27                   FNAME( PLCON27, plcon27 )
 #define    PLCONT7                   FNAME( PLCONT7, plcont7 )
-#define    PLCPSTRM                  FNAME( PLCPSTRMF77, plcpstrmf77 )
+#define    PLCPSTRM                  FNAME( PLCPSTRMF95, plcpstrmf95 )
 #define    PLCTIME                   FNAME( PLCTIME, plctime )
 #define    PLEND                     FNAME( PLEND, plend )
 #define    PLEND1                    FNAME( PLEND1, plend1 )
 #define    PLENV                     FNAME( PLENV, plenv )
 #define    PLENV0                    FNAME( PLENV0, plenv0 )
 #define    PLEOP                     FNAME( PLEOP, pleop )
-#define    PLERRX                    FNAME( PLERRXF77, plerrxf77 )
-#define    PLERRY                    FNAME( PLERRYF77, plerryf77 )
+#define    PLERRX                    FNAME( PLERRXF95, plerrxf95 )
+#define    PLERRY                    FNAME( PLERRYF95, plerryf95 )
 #define    PLFAMADV                  FNAME( PLFAMADV, plfamadv )
-#define    PLFILL                    FNAME( PLFILLF77, plfillf77 )
-#define    PLFILL3                   FNAME( PLFILL3F77, plfill3f77 )
+#define    PLFILL                    FNAME( PLFILLF95, plfillf95 )
+#define    PLFILL3                   FNAME( PLFILL3F95, plfill3f95 )
 #define    PLFLUSH                   FNAME( PLFLUSH, plflush )
 #define    PLFONT                    FNAME( PLFONT, plfont )
 #define    PLFONTLD                  FNAME( PLFONTLD, plfontld )
 #define    PLGCHR                    FNAME( PLGCHR, plgchr )
+#define    PLGCMAP1_RANGE            FNAME( PLGCMAP1_RANGE, plgcmap1_range )
 #define    PLGCOL0                   FNAME( PLGCOL0, plgcol0 )
 #define    PLGCOL0A                  FNAME( PLGCOL0A, plgcol0a )
 #define    PLGCOLBG                  FNAME( PLGCOLBG, plgcolbg )
@@ -223,8 +226,8 @@
 #define    PLGLEVEL                  FNAME( PLGLEVEL, plglevel )
 #define    PLGPAGE                   FNAME( PLGPAGE, plgpage )
 #define    PLGRA                     FNAME( PLGRA, plgra )
-#define    PLGRADIENT                FNAME( PLGRADIENTF77, plgradientf77 )
-#define    PLGRIDDATA                FNAME( PLGRIDDATAF77, plgriddataf77 )
+#define    PLGRADIENT                FNAME( PLGRADIENTF95, plgradientf95 )
+#define    PLGRIDDATA                FNAME( PLGRIDDATAF95, plgriddataf95 )
 #define    PLGSPA                    FNAME( PLGSPA, plgspa )
 #define    PLGSTRM                   FNAME( PLGSTRM, plgstrm )
 #define    PLGVER7                   FNAME( PLGVER7, plgver7 )
@@ -233,9 +236,9 @@
 #define    PLGXAX                    FNAME( PLGXAX, plgxax )
 #define    PLGYAX                    FNAME( PLGYAX, plgyax )
 #define    PLGZAX                    FNAME( PLGZAX, plgzax )
-#define    PLHIST                    FNAME( PLHISTF77, plhistf77 )
+#define    PLHIST                    FNAME( PLHISTF95, plhistf95 )
 #define    PLHLSRGB                  FNAME( PLHLSRGB, plhlsrgb )
-#define    PLIMAGE                   FNAME( PLIMAGEF77, plimagef77 )
+#define    PLIMAGE                   FNAME( PLIMAGEF95, plimagef95 )
 #define    PLIMAGEFR07               FNAME( PLIMAGEFR07, plimagefr07 )
 #define    PLIMAGEFR17               FNAME( PLIMAGEFR17, plimagefr17 )
 #define    PLIMAGEFR27               FNAME( PLIMAGEFR27, plimagefr27 )
@@ -246,50 +249,52 @@
 #define    PLLEGEND_CNV_TEXT         FNAME( PLLEGEND07_CNV_TEXT, pllegend07_cnv_text )
 #define    PLLEGEND                  FNAME( PLLEGEND07, pllegend07 )
 #define    PLLIGHTSOURCE             FNAME( PLLIGHTSOURCE, pllightsource )
-#define    PLLINE                    FNAME( PLLINEF77, pllinef77 )
-#define    PLLINE3                   FNAME( PLLINE3F77, plline3f77 )
+#define    PLLINE                    FNAME( PLLINEF95, pllinef95 )
+#define    PLLINE3                   FNAME( PLLINE3F95, plline3f95 )
 #define    PLLSTY                    FNAME( PLLSTY, pllsty )
 #define    PLMAP7                    FNAME( PLMAP7, plmap7 )
 #define    PLMERIDIANS7              FNAME( PLMERIDIANS7, plmeridians7 )
-#define    PLMESH                    FNAME( PLMESHF77, plmeshf77 )
-#define    PLMESHC                   FNAME( PLMESHCF77, plmeshcf77 )
+#define    PLMESH                    FNAME( PLMESHF95, plmeshf95 )
+#define    PLMESHC                   FNAME( PLMESHCF95, plmeshcf95 )
 #define    PLMKSTRM                  FNAME( PLMKSTRM, plmkstrm )
 #define    PLMTEX7                   FNAME( PLMTEX7, plmtex7 )
 #define    PLMTEX37                  FNAME( PLMTEX37, plmtex37 )
-#define    PLOT3D                    FNAME( PLOT3DF77, plot3df77 )
-#define    PLOT3DC                   FNAME( PLOT3DCF77, plot3dcf77 )
+#define    PLOT3D                    FNAME( PLOT3DF95, plot3df95 )
+#define    PLOT3DC                   FNAME( PLOT3DCF95, plot3dcf95 )
 
 #if STUB_LINKAGE == STUB_STDCALL || STUB_LINKAGE == STUB_FORTRAN
-#define    CALL_PLOT3DC              PLOT3DCF77
+#define    CALL_PLOT3DC              PLOT3DCF95
 #elif  STUB_LINKAGE == STUB_LAU
-#define    CALL_PLOT3DC              plot3dcf77_
+#define    CALL_PLOT3DC              plot3dcf95_
 #else
 #define    CALL_PLOT3DC              PLOT3DC
 #endif
 
 #define    PLPARSEOPTS7              FNAME( PLPARSEOPTS7, plparseopts7 )
 #define    PLPAT                     FNAME( PLPAT, plpat )
-#define    PLPOIN                    FNAME( PLPOINF77, plpoinf77 )
-#define    PLPOIN3                   FNAME( PLPOIN3F77, plpoin3f77 )
-#define    PLPOLY3                   FNAME( PLPOLY3F77, plpoly3f77 )
+#define    PLPATH                    FNAME( PLPATH, plpath )
+#define    PLPOIN                    FNAME( PLPOINF95, plpoinf95 )
+#define    PLPOIN3                   FNAME( PLPOIN3F95, plpoin3f95 )
+#define    PLPOLY3                   FNAME( PLPOLY3F95, plpoly3f95 )
 #define    PLPREC                    FNAME( PLPREC, plprec )
 #define    PLPSTY                    FNAME( PLPSTY, plpsty )
 #define    PLPTEX7                   FNAME( PLPTEX7, plptex7 )
 #define    PLPTEX37                  FNAME( PLPTEX37, plptex37 )
-#define    PLRANDD                   FNAME( PLRANDDF77, plranddf77 )
+#define    PLRANDD                   FNAME( PLRANDDF95, plranddf95 )
 #define    PLREPLOT                  FNAME( PLREPLOT, plreplot )
 #define    PLRGBHLS                  FNAME( PLRGBHLS, plrgbhls )
 #define    PLSCHR                    FNAME( PLSCHR, plschr )
-#define    PLSCMAP0                  FNAME( PLSCMAP0F77, plscmap0f77 )
-#define    PLSCMAP0A                 FNAME( PLSCMAP0AF77, plscmap0af77 )
+#define    PLSCMAP0                  FNAME( PLSCMAP0F95, plscmap0f95 )
+#define    PLSCMAP0A                 FNAME( PLSCMAP0AF95, plscmap0af95 )
 #define    PLSCMAP0N                 FNAME( PLSCMAP0N, plscmap0n )
-#define    PLSCMAP1                  FNAME( PLSCMAP1F77, plscmap1f77 )
-#define    PLSCMAP1A                 FNAME( PLSCMAP1AF77, plscmap1af77 )
-#define    PLSCMAP1L                 FNAME( PLSCMAP1LF77, plscmap1lf77 )
-#define    PLSCMAP1L2                FNAME( PLSCMAP1L2F77, plscmap1l2f77 )
-#define    PLSCMAP1LA                FNAME( PLSCMAP1LAF77, plscmap1laf77 )
-#define    PLSCMAP1LA2               FNAME( PLSCMAP1LA2F77, plscmap1la2f77 )
+#define    PLSCMAP1                  FNAME( PLSCMAP1F95, plscmap1f95 )
+#define    PLSCMAP1A                 FNAME( PLSCMAP1AF95, plscmap1af95 )
+#define    PLSCMAP1L                 FNAME( PLSCMAP1LF95, plscmap1lf95 )
+#define    PLSCMAP1L2                FNAME( PLSCMAP1L2F95, plscmap1l2f95 )
+#define    PLSCMAP1LA                FNAME( PLSCMAP1LAF95, plscmap1laf95 )
+#define    PLSCMAP1LA2               FNAME( PLSCMAP1LA2F95, plscmap1la2f95 )
 #define    PLSCMAP1N                 FNAME( PLSCMAP1N, plscmap1n )
+#define    PLSCMAP1_RANGE            FNAME( PLSCMAP1_RANGE, plscmap1_range )
 #define    PLSCOL0                   FNAME( PLSCOL0, plscol0 )
 #define    PLSCOL0A                  FNAME( PLSCOL0A, plscol0a )
 #define    PLSCOLBG                  FNAME( PLSCOLBG, plscolbg )
@@ -331,7 +336,7 @@
 #define    PLSPAGE                   FNAME( PLSPAGE, plspage )
 #define    PLSPAL07                  FNAME( PLSPAL07, plspal07 )
 #define    PLSPAL17                  FNAME( PLSPAL17, plspal17 )
-#define    PLSPAUSE                  FNAME( PLSPAUSEF77, plspausef77 )
+#define    PLSPAUSE                  FNAME( PLSPAUSEF95, plspausef95 )
 #define    PLSSTRM                   FNAME( PLSSTRM, plsstrm )
 #define    PLSSUB                    FNAME( PLSSUB, plssub )
 #define    PLSSYM                    FNAME( PLSSYM, plssym )
@@ -343,15 +348,16 @@
 #define    PLSTRING7                 FNAME( PLSTRING7, plstring7 )
 #define    PLSTRING37                FNAME( PLSTRING37, plstring37 )
 #define    PLSTRIPA                  FNAME( PLSTRIPA, plstripa )
-#define    PLSTRIPC                  FNAME( PLSTRIPCF77, plstripcf77 )
+#define    PLSTRIPC                  FNAME( PLSTRIPCF95, plstripcf95 )
 #define    PLSTRIPD                  FNAME( PLSTRIPD, plstripd )
 #define    PLSTYL                    FNAME( PLSTYL, plstyl )
-#define    PLSURF3D                  FNAME( PLSURF3DF77, plsurf3df77 )
-#define    PLSVECT                   FNAME( PLSVECTF77, plsvectf77 )
+#define    PLSURF3D                  FNAME( PLSURF3DF95, plsurf3df95 )
+#define    PLSVECT1                  FNAME( PLSVECT1F95, plsvect1f95 )
+#define    PLSVECT2                  FNAME( PLSVECT2, plsvect2 )
 #define    PLSVPA                    FNAME( PLSVPA, plsvpa )
 #define    PLSXAX                    FNAME( PLSXAX, plsxax )
 #define    PLSYAX                    FNAME( PLSYAX, plsyax )
-#define    PLSYM                     FNAME( PLSYMF77, plsymf77 )
+#define    PLSYM                     FNAME( PLSYMF95, plsymf95 )
 #define    PLSZAX                    FNAME( PLSZAX, plszax )
 #define    PLTEXT                    FNAME( PLTEXT, pltext )
 #define    PLTIMEFMT7                FNAME( PLTIMEFMT7, pltimefmt7 )
@@ -364,9 +370,9 @@
 #define    PLVPOR                    FNAME( PLVPOR, plvpor )
 #define    PLVSTA                    FNAME( PLVSTA, plvsta )
 #define    PLW3D                     FNAME( PLW3D, plw3d )
-#define    PLWID                     FNAME( PLWID, plwid )
+#define    PLWIDTH                   FNAME( PLWIDTH, plwidth )
 #define    PLWIND                    FNAME( PLWIND, plwind )
-#define    PLXORMOD                  FNAME( PLXORMODF77, plxormodf77 )
+#define    PLXORMOD                  FNAME( PLXORMODF95, plxormodf95 )
 
 #ifdef PL_DEPRECATE
 #define    PLRGB                     FNAME( PLRGB, plrgb )
