@@ -1,4 +1,4 @@
-// $Id: sc3d.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: sc3d.c 12095 2011-12-03 08:56:15Z andrewross $
 //
 //      Stub routines for 3d plots.
 //
@@ -24,6 +24,24 @@
 
 #include "plstubs.h"
 
+// Function prototypes
+void PLOT3DC__( PLFLT *x, PLFLT *y, PLFLT *z,
+                PLINT *nx, PLINT *ny, PLINT *opt,
+                PLFLT *clevel, PLINT *nlevel, PLINT *lx );
+void PLOT3DC( PLFLT *x, PLFLT *y, PLFLT *z,
+              PLINT *nx, PLINT *ny, PLINT *opt,
+              PLFLT *clevel, PLINT *nlevel, PLINT *lx );
+void PLSURF3D( PLFLT *x, PLFLT *y, PLFLT *z,
+               PLINT *nx, PLINT *ny, PLINT *opt,
+               PLFLT *clevel, PLINT *nlevel, PLINT *lx );
+void PLMESH( PLFLT *x, PLFLT *y, PLFLT *z,
+             PLINT *nx, PLINT *ny, PLINT *opt, PLINT *lx );
+void PLMESHC( PLFLT *x, PLFLT *y, PLFLT *z,
+              PLINT *nx, PLINT *ny, PLINT *opt,
+              PLFLT *clevel, PLINT *nlevel, PLINT *lx );
+void PLOT3D( PLFLT *x, PLFLT *y, PLFLT *z,
+             PLINT *nx, PLINT *ny, PLINT *opt, PLBOOL *side, PLINT *lx );
+
 void
 PLOT3DC__( PLFLT *x, PLFLT *y, PLFLT *z,
            PLINT *nx, PLINT *ny, PLINT *opt,
@@ -42,7 +60,7 @@ PLOT3DC__( PLFLT *x, PLFLT *y, PLFLT *z,
         }
     }
 
-    c_plot3dc( x, y, (const PLFLT **) a, *nx, *ny, *opt, clevel, *nlevel );
+    c_plot3dc( x, y, (const PLFLT * const *) a, *nx, *ny, *opt, clevel, *nlevel );
 
 // Clean up memory allocated for a
     plFree2dGrid( a, *nx, *ny );
@@ -93,7 +111,7 @@ PLSURF3D( PLFLT *x, PLFLT *y, PLFLT *z,
         for ( j = 0; j < *ny; j++ )
             temp[i][j] = *( z + j * *lx + i );
 
-    c_plsurf3d( x, y, (const PLFLT **) temp, *nx, *ny, *opt, clevel, *nlevel );
+    c_plsurf3d( x, y, (const PLFLT * const *) temp, *nx, *ny, *opt, clevel, *nlevel );
 
     for ( i = 0; i < *nx; i++ )
         free( (void *) temp[i] );
