@@ -1,4 +1,4 @@
-// $Id: sccont.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: sccont.c 12836 2013-12-09 19:33:53Z arjenmarkus $
 //
 //      Contour plotter front-ends for Fortran.
 //
@@ -24,6 +24,93 @@
 
 #include "plstubs.h"
 
+// Function prototypes
+void pltr0f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data );
+void PLCON07( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
+              PLINT *ky, PLINT *ly, PLFLT *clevel, PLINT *nlevel );
+void PLCON17( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
+              PLINT *ky, PLINT *ly, PLFLT *clevel, PLINT *nlevel,
+              PLFLT *xg, PLFLT *yg );
+void PLCON27( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
+              PLINT *ky, PLINT *ly, PLFLT *clevel, PLINT *nlevel,
+              PLFLT *xg, PLFLT *yg );
+void PLVEC07( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale );
+void PLVEC17( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
+              PLFLT *xg, PLFLT *yg );
+void PLVEC27( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
+              PLFLT *xg, PLFLT *yg );
+static void pltr( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data );
+void PLCONT7( PLFLT *z, PLINT *nx, PLINT *ny, PLINT *kx, PLINT *lx,
+              PLINT *ky, PLINT *ly, PLFLT *clevel, PLINT *nlevel, PLFLT *ftr );
+void PLVECT7( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
+              PLFLT *ftr );
+void PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                PLFLT *shade_min, PLFLT *shade_max,
+                PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+                PLINT *min_color, PLFLT *min_width,
+                PLINT *max_color, PLFLT *max_width, PLINT *lx );
+void PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                PLFLT *shade_min, PLFLT *shade_max,
+                PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+                PLINT *min_color, PLFLT *min_width,
+                PLINT *max_color, PLFLT *max_width,
+                PLFLT *xg1, PLFLT *yg1, PLINT *lx );
+void PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                PLFLT *shade_min, PLFLT *shade_max,
+                PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+                PLINT *min_color, PLFLT *min_width,
+                PLINT *max_color, PLFLT *max_width,
+                PLFLT *xg2, PLFLT *yg2, PLINT *lx );
+void PLSHADE7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+               PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+               PLFLT *shade_min, PLFLT *shade_max,
+               PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+               PLINT *min_color, PLFLT *min_width,
+               PLINT *max_color, PLFLT *max_width, PLFLT *ftr, PLINT *lx );
+void PLSHADES07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                 PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                 PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+                 PLINT *cont_color, PLFLT *cont_width, PLINT *lx, PLINT *rect );
+void PLSHADES17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                 PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                 PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+                 PLINT *cont_color, PLFLT *cont_width,
+                 PLFLT *xg1, PLFLT *yg1, PLINT *lx, PLINT *rect );
+void PLSHADES27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                 PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                 PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+                 PLINT *cont_color, PLFLT *cont_width,
+                 PLFLT *xg2, PLFLT *yg2, PLINT *lx, PLINT *rect );
+void PLSHADES7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+                PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+                PLINT *cont_color, PLFLT *cont_width, PLFLT *ftr, PLINT *lx, PLINT *rect );
+void PLGRIDDATA( PLFLT *x, PLFLT *y, PLFLT *z, PLINT *npts, PLFLT *xg,
+                 PLINT *nx, PLFLT *yg, PLINT *ny, PLFLT *zg, PLINT *type,
+                 PLFLT *data );
+void PLIMAGEFR07( PLFLT *idata, PLINT *nx, PLINT *ny,
+                  PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                  PLFLT *zmin, PLFLT *zmax, PLFLT *valuemin, PLFLT *valuemax,
+                  PLINT *lx );
+void PLIMAGEFR17( PLFLT *idata, PLINT *nx, PLINT *ny,
+                  PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                  PLFLT *zmin, PLFLT *zmax, PLFLT *valuemin, PLFLT *valuemax,
+                  PLFLT *xg, PLFLT *yg, PLINT *lx );
+void PLIMAGEFR27( PLFLT *idata, PLINT *nx, PLINT *ny,
+                  PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                  PLFLT *zmin, PLFLT *zmax, PLFLT *valuemin, PLFLT *valuemax,
+                  PLFLT *xg, PLFLT *yg, PLINT *lx );
+void PLIMAGEFR7( PLFLT *idata, PLINT *nx, PLINT *ny,
+                 PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
+                 PLFLT *zmin, PLFLT *zmax, PLFLT *valuemin, PLFLT *valuemax,
+                 PLFLT *ftr, PLINT *lx );
+
+
+
+
 //--------------------------------------------------------------------------
 // pltr0f()
 //
@@ -33,7 +120,7 @@
 //--------------------------------------------------------------------------
 
 void
-pltr0f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data )
+pltr0f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *PL_UNUSED( pltr_data ) )
 {
     *tx = x + 1.0;
     *ty = y + 1.0;
@@ -266,12 +353,12 @@ PLVECT7( PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
 //--------------------------------------------------------------------------
 
 void
-PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *PL_UNUSED( defined ),
            PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
            PLFLT *shade_min, PLFLT *shade_max,
-           PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
-           PLINT *min_color, PLINT *min_width,
-           PLINT *max_color, PLINT *max_width, PLINT *lx )
+           PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+           PLINT *min_color, PLFLT *min_width,
+           PLINT *max_color, PLFLT *max_width, PLINT *lx )
 {
     PLINT rect = 1;
     PLFLT ** a;
@@ -287,7 +374,7 @@ PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
         }
     }
 
-    c_plshade( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshade( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
@@ -302,12 +389,12 @@ PLSHADE07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 // 1-d transformation
 
 void
-PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
            PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
            PLFLT *shade_min, PLFLT *shade_max,
-           PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
-           PLINT *min_color, PLINT *min_width,
-           PLINT *max_color, PLINT *max_width,
+           PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+           PLINT *min_color, PLFLT *min_width,
+           PLINT *max_color, PLFLT *max_width,
            PLFLT *xg1, PLFLT *yg1, PLINT *lx )
 {
     PLINT   rect = 1;
@@ -329,7 +416,7 @@ PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
     cgrid.ny = *ny;
     cgrid.xg = xg1;
     cgrid.yg = yg1;
-    c_plshade( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshade( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
@@ -343,12 +430,12 @@ PLSHADE17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 // 2-d transformation
 
 void
-PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
            PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
            PLFLT *shade_min, PLFLT *shade_max,
-           PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
-           PLINT *min_color, PLINT *min_width,
-           PLINT *max_color, PLINT *max_width,
+           PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+           PLINT *min_color, PLFLT *min_width,
+           PLINT *max_color, PLFLT *max_width,
            PLFLT *xg2, PLFLT *yg2, PLINT *lx )
 {
     PLINT    rect = 0;
@@ -372,7 +459,7 @@ PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
         }
     }
 
-    c_plshade( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshade( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
@@ -386,12 +473,12 @@ PLSHADE27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 }
 
 void
-PLSHADE7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADE7( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
           PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
           PLFLT *shade_min, PLFLT *shade_max,
-          PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
-          PLINT *min_color, PLINT *min_width,
-          PLINT *max_color, PLINT *max_width, PLFLT *ftr, PLINT *lx )
+          PLINT *sh_cmap, PLFLT *sh_color, PLFLT *sh_width,
+          PLINT *min_color, PLFLT *min_width,
+          PLINT *max_color, PLFLT *max_width, PLFLT *ftr, PLINT *lx )
 {
     PLINT rect = 1;
     PLFLT ** a;
@@ -407,7 +494,7 @@ PLSHADE7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
         }
     }
 
-    c_plshade( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshade( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         *shade_min, *shade_max,
         *sh_cmap, *sh_color, *sh_width,
@@ -429,12 +516,11 @@ PLSHADE7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 //--------------------------------------------------------------------------
 
 void
-PLSHADES07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADES07( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
             PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
-            PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
-            PLINT *cont_color, PLINT *cont_width, PLINT *lx )
+            PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+            PLINT *cont_color, PLFLT *cont_width, PLINT *lx, PLINT *rect )
 {
-    PLINT rect = 1;
     PLFLT ** a;
     int   i, j;
 
@@ -448,24 +534,23 @@ PLSHADES07( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
         }
     }
 
-    c_plshades( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshades( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
-        c_plfill, rect, NULL, NULL );
+        c_plfill, *rect, NULL, NULL );
 
 // Clean up memory allocated for a
     plFree2dGrid( a, *nx, *ny );
 }
 
 void
-PLSHADES17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADES17( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
             PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
-            PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
-            PLINT *cont_color, PLINT *cont_width,
-            PLFLT *xg1, PLFLT *yg1, PLINT *lx )
+            PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+            PLINT *cont_color, PLFLT *cont_width,
+            PLFLT *xg1, PLFLT *yg1, PLINT *lx, PLINT *rect )
 {
-    PLINT   rect = 1;
     PLFLT   ** a;
     int     i, j;
     PLcGrid cgrid;
@@ -485,24 +570,23 @@ PLSHADES17( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
     cgrid.xg = xg1;
     cgrid.yg = yg1;
 
-    c_plshades( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshades( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
-        c_plfill, rect, pltr1, ( PLPointer ) & cgrid );
+        c_plfill, *rect, pltr1, ( PLPointer ) & cgrid );
 
 // Clean up memory allocated for a
     plFree2dGrid( a, *nx, *ny );
 }
 
 void
-PLSHADES27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADES27( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
             PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
-            PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
-            PLINT *cont_color, PLINT *cont_width,
-            PLFLT *xg2, PLFLT *yg2, PLINT *lx )
+            PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+            PLINT *cont_color, PLFLT *cont_width,
+            PLFLT *xg2, PLFLT *yg2, PLINT *lx, PLINT *rect )
 {
-    PLINT    rect = 0;
     PLFLT    **a;
     int      i, j;
     PLcGrid2 cgrid2;
@@ -523,11 +607,11 @@ PLSHADES27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
         }
     }
 
-    c_plshades( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshades( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
-        c_plfill, rect, pltr2, (void *) &cgrid2 );
+        c_plfill, *rect, pltr2, (void *) &cgrid2 );
 
 // Clean up allocated memory
     plFree2dGrid( a, *nx, *ny );
@@ -536,12 +620,11 @@ PLSHADES27( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 }
 
 void
-PLSHADES7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
+PLSHADES7( PLFLT *z, PLINT *nx, PLINT *ny, const char * PL_UNUSED( defined ),
            PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
-           PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
-           PLINT *cont_color, PLINT *cont_width, PLFLT *ftr, PLINT *lx )
+           PLFLT *clevel, PLINT *nlevel, PLFLT *fill_width,
+           PLINT *cont_color, PLFLT *cont_width, PLFLT *ftr, PLINT *lx, PLINT *rect )
 {
-    PLINT rect = 1;
     PLFLT ** a;
     int   i, j;
 
@@ -555,11 +638,11 @@ PLSHADES7( PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
         }
     }
 
-    c_plshades( (const PLFLT **) a, *nx, *ny, NULL,
+    c_plshades( (const PLFLT * const *) a, *nx, *ny, NULL,
         *xmin, *xmax, *ymin, *ymax,
         clevel, *nlevel, *fill_width,
         *cont_color, *cont_width,
-        c_plfill, rect, pltr, (void *) ftr );
+        c_plfill, *rect, pltr, (void *) ftr );
 
 // Clean up memory allocated for a
     plFree2dGrid( a, *nx, *ny );
@@ -608,7 +691,7 @@ PLIMAGEFR07( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT * const *) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr0, NULL );
 
@@ -640,7 +723,7 @@ PLIMAGEFR17( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT * const *) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr1, (void *) &cgrid );
 
@@ -680,7 +763,7 @@ PLIMAGEFR27( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT * const *) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr2, (void *) &cgrid2 );
 
@@ -708,7 +791,7 @@ PLIMAGEFR7( PLFLT *idata, PLINT *nx, PLINT *ny,
         }
     }
 
-    c_plimagefr( (const PLFLT **) pidata, *nx, *ny,
+    c_plimagefr( (const PLFLT * const *) pidata, *nx, *ny,
         *xmin, *xmax, *ymin, *ymax, *zmin, *zmax,
         *valuemin, *valuemax, pltr, (void *) ftr );
 
