@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubs.f90 11680 2011-03-27 17:57:51Z airwin $
+!  $Id: sfstubs.f90 12836 2013-12-09 19:33:53Z arjenmarkus $
 !  sfstubs.f
 !
 !  Copyright (C) 2004  Alan W. Irwin
@@ -41,10 +41,8 @@
       implicit none
       character*(*) opt, optarg
 
-      include 'sfstubs.h'
-
-      call plstrf2c(opt, string1, maxlen)
-      call plstrf2c(optarg, string2, maxlen)
+      call plstrf2c(opt, string1)
+      call plstrf2c(optarg, string2)
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
       call plsetopt7(s1, s2)
@@ -58,9 +56,7 @@
       implicit none
       character*(*) text
 
-      include 'sfstubs.h'
-
-      call plstrf2c(text, string1, maxlen)
+      call plstrf2c(text, string1)
       s1 = transfer( string1, s1 )
       call plabort7(s1)
 
@@ -73,9 +69,7 @@
       implicit none
       character*(*) dnam
 
-      include 'sfstubs.h'
-
-      call plstrf2c(dnam, string1, maxlen)
+      call plstrf2c(dnam, string1)
       s1 = transfer( string1, s1 )
       call plsdev7(s1)
 
@@ -88,8 +82,6 @@
       implicit none
       character*(*) dnam
 
-      include 'sfstubs.h'
-
       call plgdev7(string1)
       call plstrc2f(string1, dnam)
 
@@ -102,9 +94,7 @@
       implicit none
       character*(*) fnam
 
-      include 'sfstubs.h'
-
-      call plstrf2c(fnam, string1, maxlen)
+      call plstrf2c(fnam, string1)
       s1 = transfer( string1, s1 )
       call plsfnam7(s1)
 
@@ -117,8 +107,6 @@
       implicit none
       character*(*) fnam
 
-      include 'sfstubs.h'
-
       call plgfnam7(string1)
       call plstrc2f(string1, fnam)
 
@@ -131,8 +119,6 @@
       implicit none
       character*(*) ver
 
-      include 'sfstubs.h'
-
       call plgver7(s1)
       string1 = transfer( s1, string1 )
       call plstrc2f(string1, ver)
@@ -148,10 +134,8 @@
       integer nxsub, nysub
       character*(*) xopt,yopt
 
-      include 'sfstubs.h'
-
-      call plstrf2c(xopt, string1, maxlen)
-      call plstrf2c(yopt, string2, maxlen)
+      call plstrf2c(xopt, string1)
+      call plstrf2c(yopt, string2)
 
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
@@ -168,10 +152,8 @@
       integer nxsub, nysub
       character*(*) xopt,yopt
 
-      include 'sfstubs.h'
-
-      call plstrf2c(xopt, string1, maxlen)
-      call plstrf2c(yopt, string2, maxlen)
+      call plstrf2c(xopt, string1)
+      call plstrf2c(yopt, string2)
 
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
@@ -189,14 +171,12 @@
       character*(*) xopt,xlabel,yopt,ylabel,zopt,zlabel
       integer nxsub, nysub, nzsub
 
-      include 'sfstubs.h'
-
-      call plstrf2c(xopt, string1, maxlen)
-      call plstrf2c(xlabel, string2, maxlen)
-      call plstrf2c(yopt, string3, maxlen)
-      call plstrf2c(ylabel, string4, maxlen)
-      call plstrf2c(zopt, string5, maxlen)
-      call plstrf2c(zlabel, string6, maxlen)
+      call plstrf2c(xopt, string1)
+      call plstrf2c(xlabel, string2)
+      call plstrf2c(yopt, string3)
+      call plstrf2c(ylabel, string4)
+      call plstrf2c(zopt, string5)
+      call plstrf2c(zlabel, string6)
 
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
@@ -332,13 +312,11 @@
       real(kind=plflt) x(:), y(:)
       character(len=*) string
 
-      include 'sfstubs.h'
-
       integer n
 
       n = size(x)
 
-      call plstrf2c(string, string1, maxlen)
+      call plstrf2c(string, string1)
       s1 = transfer( string1, s1 )
       call plstring7(n,x,y,s1)
 
@@ -352,13 +330,11 @@
       real(kind=plflt) x(:), y(:), z(:)
       character(len=*) string
 
-      include 'sfstubs.h'
-
       integer n
 
       n = size(x)
 
-      call plstrf2c(string, string1, maxlen)
+      call plstrf2c(string, string1)
       s1 = transfer( string1, s1 )
       call plstring37(n,x,y,z,s1)
 
@@ -420,14 +396,13 @@
 
       implicit none
       character defined*(*)
-      integer sh_cmap, sh_width
-      integer min_color, min_width, max_color, max_width
+      integer sh_cmap
+      integer min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
       real(kind=plflt) shade_min, shade_max, sh_color
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax
 
-      include 'sfstubs.h'
-
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
 
       s1 = transfer( string1, s1 )
       call plshade07(z, size(z,1), size(z,2), s1, &
@@ -449,14 +424,13 @@
 
       implicit none
       character defined*(*)
-      integer sh_cmap, sh_width
-      integer min_color, min_width, max_color, max_width
+      integer sh_cmap
+      integer min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
       real(kind=plflt) shade_min, shade_max, sh_color
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax, xg(:), yg(:)
 
-      include 'sfstubs.h'
-
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
 
       s1 = transfer( string1, s1 )
       call plshade17(z, size(z,1), size(z,2), s1, &
@@ -479,14 +453,13 @@
 
       implicit none
       character defined*(*)
-      integer sh_cmap, sh_width
-      integer min_color, min_width, max_color, max_width
+      integer sh_cmap
+      integer min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
       real(kind=plflt) shade_min, shade_max, sh_color
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax, xg(:,:), yg(:,:)
 
-      include 'sfstubs.h'
-
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
 
       s1 = transfer( string1, s1 )
       call plshade27(z, size(z,1), size(z,2), s1, &
@@ -508,14 +481,13 @@
 
       implicit none
       character(len=*) defined
-      integer sh_cmap, sh_width
-      integer min_color, min_width, max_color, max_width
+      integer sh_cmap
+      integer min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
       real(kind=plflt) shade_min, shade_max, sh_color
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax
       real(kind=plflt) tr(6)
 
-      include 'sfstubs.h'
-
       s1 = transfer( string1, s1 )
       call plshade7(z, size(z,1), size(z,2), s1, &
         xmin, xmax, ymin, ymax, &
@@ -530,23 +502,30 @@
       subroutine plshades_multiple_0(z, defined, &
         xmin, xmax, ymin, ymax, &
         clevel, fill_width, &
-        cont_color, cont_width )
+        cont_color, cont_width, rectangular)
 
       implicit none
       character defined*(*)
-      integer fill_width, cont_color, cont_width
+      integer cont_color
+      logical, optional :: rectangular
+      real(kind=plflt) fill_width, cont_width
       real(kind=plflt) clevel(:)
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax
 
-      include 'sfstubs.h'
+      integer rect
 
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
+
+      rect = 1
+      if ( present(rectangular) ) then
+          rect = merge( 1, 0, rectangular )
+      endif
 
       s1 = transfer( string1, s1 )
       call plshades07(z, size(z,1), size(z,2), s1, &
         xmin, xmax, ymin, ymax, &
         clevel, size(clevel), fill_width, &
-        cont_color, cont_width, size(z,1))
+        cont_color, cont_width, size(z,1), rect)
 
       end subroutine
 
@@ -559,20 +538,53 @@
 
       implicit none
       character defined*(*)
-      integer fill_width, cont_color, cont_width
+      integer cont_color
+      real(kind=plflt) fill_width, cont_width
       real(kind=plflt) clevel(:)
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax, &
                        xg1(:), yg1(:)
 
-      include 'sfstubs.h'
+      integer rect
 
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
+
+      rect = 1
 
       s1 = transfer( string1, s1 )
       call plshades17(z, size(z,1), size(z,2), s1, &
         xmin, xmax, ymin, ymax, &
         clevel, size(clevel), fill_width, &
-        cont_color, cont_width, xg1, yg1, size(z,1))
+        cont_color, cont_width, xg1, yg1, size(z,1), rect)
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plshades_multiple_1r(z, defined, &
+        xmin, xmax, ymin, ymax, &
+        clevel, fill_width, &
+        cont_color, cont_width, rectangular, xg1, yg1)
+
+      implicit none
+      character defined*(*)
+      integer cont_color
+      logical rectangular
+      real(kind=plflt) fill_width, cont_width
+      real(kind=plflt) clevel(:)
+      real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax, &
+                       xg1(:), yg1(:)
+
+      integer rect
+
+!	call plstrf2c(dnam, string1)
+
+      rect = merge( 1, 0, rectangular )
+
+      s1 = transfer( string1, s1 )
+      call plshades17(z, size(z,1), size(z,2), s1, &
+        xmin, xmax, ymin, ymax, &
+        clevel, size(clevel), fill_width, &
+        cont_color, cont_width, xg1, yg1, size(z,1), rect)
 
       end subroutine
 
@@ -585,14 +597,47 @@
 
       implicit none
       character defined*(*)
-      integer fill_width, cont_color, cont_width
+      integer cont_color
+      real(kind=plflt)fill_width, cont_width
       real(kind=plflt) clevel(:)
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax, &
         xg2(:,:), yg2(:,:)
 
-      include 'sfstubs.h'
+      integer rect
 
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
+
+      rect = 0
+
+      s1 = transfer( string1, s1 )
+      call plshades27(z, size(z,1), size(z,2), s1, &
+        xmin, xmax, ymin, ymax, &
+        clevel, size(clevel), fill_width, &
+        cont_color, cont_width, xg2, yg2, size(z,1), rect)
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plshades_multiple_2r(z, defined, &
+        xmin, xmax, ymin, ymax, &
+        clevel, fill_width, &
+        cont_color, cont_width, rectangular, xg2, yg2)
+
+      implicit none
+      character defined*(*)
+      integer cont_color
+      logical rectangular
+      real(kind=plflt)fill_width, cont_width
+      real(kind=plflt) clevel(:)
+      real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax, &
+        xg2(:,:), yg2(:,:)
+
+      integer rect
+
+      rect = merge( 1, 0, rectangular )
+
+!	call plstrf2c(dnam, string1)
 
       s1 = transfer( string1, s1 )
       call plshades27(z, size(z,1), size(z,2), s1, &
@@ -611,20 +656,53 @@
 
       implicit none
       character defined*(*)
-      integer fill_width, cont_color, cont_width
+      integer cont_color
+      real(kind=plflt) fill_width, cont_width
       real(kind=plflt) clevel(:)
       real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax
       real(kind=plflt) tr(6)
 
-      include 'sfstubs.h'
+      integer rect
 
-!	call plstrf2c(dnam, string1, maxlen)
+!	call plstrf2c(dnam, string1)
+
+      rect = 0
 
       s1 = transfer( string1, s1 )
       call plshades7(z, size(z,1), size(z,2), s1, &
         xmin, xmax, ymin, ymax, &
         clevel, size(clevel), fill_width, &
-        cont_color, cont_width, tr, size(z,1))
+        cont_color, cont_width, tr, size(z,1), rect)
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plshades_multiple_trr(z, defined, &
+        xmin, xmax, ymin, ymax, &
+        clevel, fill_width, &
+        cont_color, cont_width, rectangular, tr)
+
+      implicit none
+      character defined*(*)
+      integer cont_color
+      logical rectangular
+      real(kind=plflt) fill_width, cont_width
+      real(kind=plflt) clevel(:)
+      real(kind=plflt) z(:,:), xmin, xmax, ymin, ymax
+      real(kind=plflt) tr(6)
+
+      integer rect
+
+!	call plstrf2c(dnam, string1)
+
+      rect = merge(1, 0, rectangular)
+
+      s1 = transfer( string1, s1 )
+      call plshades7(z, size(z,1), size(z,2), s1, &
+        xmin, xmax, ymin, ymax, &
+        clevel, size(clevel), fill_width, &
+        cont_color, cont_width, tr, size(z,1), rect)
 
       end subroutine
 
@@ -634,7 +712,6 @@
            valuemin,valuemax)
 
       implicit none
-      integer nx, ny, lx
       real(kind=plflt) z(:,:)
       real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
 
@@ -649,7 +726,6 @@
            valuemin,valuemax,xg,yg)
 
       implicit none
-      integer nx, ny, lx
       real(kind=plflt) z(:,:), xg(:), yg(:)
       real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
 
@@ -664,7 +740,6 @@
            valuemin,valuemax,xg,yg)
 
       implicit none
-      integer nx, ny, lx
       real(kind=plflt) z(:,:), xg(:,:), yg(:,:)
       real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
 
@@ -679,7 +754,6 @@
            valuemin,valuemax,tr)
 
       implicit none
-      integer nx, ny, lx
       real(kind=plflt) z(:,:)
       real(kind=plflt) xmin, xmax, ymin, ymax, zmin, zmax, valuemin, valuemax
       real(kind=plflt) tr(6)
@@ -696,11 +770,9 @@
       implicit none
       character*(*) xlab,ylab,title
 
-      include 'sfstubs.h'
-
-      call plstrf2c(xlab, string1, maxlen)
-      call plstrf2c(ylab, string2, maxlen)
-      call plstrf2c(title, string3, maxlen)
+      call plstrf2c(xlab, string1)
+      call plstrf2c(ylab, string2)
+      call plstrf2c(title, string3)
 
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
@@ -716,9 +788,7 @@
       implicit none
       character*(*) filename
 
-      include 'sfstubs.h'
-
-      call plstrf2c(filename, string1, maxlen)
+      call plstrf2c(filename, string1)
 
       s1 = transfer( string1, s1 )
       call plspal07(s1)
@@ -733,9 +803,7 @@
       character*(*) filename
       integer interpolate
 
-      include 'sfstubs.h'
-
-      call plstrf2c(filename, string1, maxlen)
+      call plstrf2c(filename, string1)
 
       s1 = transfer( string1, s1 )
       call plspal17(s1,interpolate)
@@ -750,10 +818,8 @@
       real(kind=plflt) disp, pos, xjust
       character*(*) side, text
 
-      include 'sfstubs.h'
-
-      call plstrf2c(side, string1, maxlen)
-      call plstrf2c(text, string2, maxlen)
+      call plstrf2c(side, string1)
+      call plstrf2c(text, string2)
 
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
@@ -769,10 +835,8 @@
       real(kind=plflt) disp, pos, xjust
       character*(*) side, text
 
-      include 'sfstubs.h'
-
-      call plstrf2c(side, string1, maxlen)
-      call plstrf2c(text, string2, maxlen)
+      call plstrf2c(side, string1)
+      call plstrf2c(text, string2)
 
       s1 = transfer( string1, s1 )
       s2 = transfer( string2, s2 )
@@ -788,9 +852,7 @@
       real(kind=plflt) x, y, dx, dy, xjust
       character*(*) text
 
-      include 'sfstubs.h'
-
-      call plstrf2c(text, string1, maxlen)
+      call plstrf2c(text, string1)
 
       s1 = transfer( string1, s1 )
       call plptex7(x,y,dx,dy,xjust,s1)
@@ -805,9 +867,7 @@
       real(kind=plflt) x, y, z, dx, dy, dz, sx, sy, sz, xjust
       character*(*) text
 
-      include 'sfstubs.h'
-
-      call plstrf2c(text, string1, maxlen)
+      call plstrf2c(text, string1)
 
       s1 = transfer( string1, s1 )
       call plptex37(x,y,z,dx,dy,dz,sx,sy,sz,xjust,s1)
@@ -822,9 +882,7 @@
       character*(*) devname
       integer nx, ny
 
-      include 'sfstubs.h'
-
-      call plstrf2c(devname, string1, maxlen)
+      call plstrf2c(devname, string1)
 
       s1 = transfer( string1, s1 )
       call plstart7(s1, nx, ny)
@@ -838,9 +896,7 @@
       implicit none
       character*(*) fmt
 
-      include 'sfstubs.h'
-
-      call plstrf2c(fmt, string1, maxlen)
+      call plstrf2c(fmt, string1)
       s1 = transfer( string1, s1 )
       call pltimefmt7(s1)
 
