@@ -536,9 +536,9 @@ public class PLStream implements plplotjavacConstants {
                         double text_spacing, double text_justification,
                         int[] text_colors, String[] text,
                         int[] box_colors, int[] box_patterns,
-                        double[] box_scales, int[] box_line_widths,
+                        double[] box_scales, double[] box_line_widths,
                         int[] line_colors, int[] line_styles,
-                        int[] line_widths,
+                        double[] line_widths,
                         int[] symbol_colors, double[] symbol_scales,
                         int[] symbol_numbers, String[] symbols )
     {
@@ -554,17 +554,30 @@ public class PLStream implements plplotjavacConstants {
             symbol_numbers, symbols );
     }
 
-    //
-//      public void colorbar( int opt, double x, double y, double length,
-//                            double width, double ticks, double subticks,
-//                            String axis_opts, String label,
-//                            double[] colors, double[] values )
-//      {
-//          if ( set_stream() == -1 ) return;
-//          plplotjavac.plcolorbar( opt, x, y, length, width, ticks, subticks,
-//              axis_opts, label, colors, values );
-//      }
-//
+
+    public void colorbar( double[] p_colorbar_width,
+                          double[] p_colorbar_height,
+                          int opt, int position, double x, double y,
+                          double x_length, double y_length,
+                          int bg_color, int bb_color, int bb_style,
+                          double low_cap_color, double high_cap_color,
+                          int cont_color, double cont_width,
+                          int[] label_opts, String[] labels,
+                          String[] axis_opts,
+                          double[] ticks, int[] sub_ticks,
+                          int[] n_values, double[][] values )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plcolorbar( p_colorbar_width, p_colorbar_height,
+            opt, position, x, y, x_length, y_length,
+            bg_color, bb_color, bb_style,
+            low_cap_color, high_cap_color,
+            cont_color, cont_width,
+            label_opts, labels, axis_opts,
+            ticks, sub_ticks,
+            n_values, values );
+    }
+
 
     public void lightsource( double x, double y, double z )
     {
@@ -682,6 +695,12 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.plpat( inc, del );
     }
 
+    public void path( int n, double x1, double y1, double x2, double y2 )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plpath( n, x1, y1, x2, y2 );
+    }
+
     public void poin( double[] x, double[] y, int code )
     {
         if ( set_stream() == -1 ) return;
@@ -773,10 +792,10 @@ public class PLStream implements plplotjavacConstants {
     }
 
     public void scmap1l( boolean itype, double[] intensity, double[] coord1,
-                         double[] coord2, double[] coord3, boolean[] rev )
+                         double[] coord2, double[] coord3, boolean[] alt_hue_path )
     {
         if ( set_stream() == -1 ) return;
-        plplotjavac.plscmap1l( itype, intensity, coord1, coord2, coord3, rev );
+        plplotjavac.plscmap1l( itype, intensity, coord1, coord2, coord3, alt_hue_path );
     }
 
     public void scmap1l( boolean itype, double[] intensity, double[] coord1,
@@ -787,10 +806,10 @@ public class PLStream implements plplotjavacConstants {
     }
 
     public void scmap1la( boolean itype, double[] intensity, double[] coord1,
-                          double[] coord2, double[] coord3, double[] a, boolean[] rev )
+                          double[] coord2, double[] coord3, double[] a, boolean[] alt_hue_path )
     {
         if ( set_stream() == -1 ) return;
-        plplotjavac.plscmap1la( itype, intensity, coord1, coord2, coord3, a, rev );
+        plplotjavac.plscmap1la( itype, intensity, coord1, coord2, coord3, a, alt_hue_path );
     }
 
     public void scmap1la( boolean itype, double[] intensity, double[] coord1,
@@ -806,6 +825,18 @@ public class PLStream implements plplotjavacConstants {
         plplotjavac.plscmap1n( ncol1 );
     }
 
+    public void scmap1_range( double min_color, double max_color )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plscmap1_range( min_color, max_color );
+    }
+
+    public void gcmap1_range( double[] min_color, double[] max_color )
+    {
+        if ( set_stream() == -1 ) return;
+        plplotjavac.plgcmap1_range( min_color, max_color );
+    }
+
     public void scol0( int icol0, int r, int g, int b )
     {
         if ( set_stream() == -1 ) return;
@@ -922,8 +953,8 @@ public class PLStream implements plplotjavacConstants {
     }
 
     public void shades( double[][] a, double xmin, double xmax, double ymin,
-                        double ymax, double[] clevel, int fill_width, int cont_color,
-                        int cont_width, boolean rectangular,
+                        double ymax, double[] clevel, double fill_width, int cont_color,
+                        double cont_width, boolean rectangular,
                         double[][] pltr, double[][] OBJECT_DATA )
     {
         if ( set_stream() == -1 ) return;
@@ -933,8 +964,8 @@ public class PLStream implements plplotjavacConstants {
 
     public void shade( double[][] a, double left, double right, double bottom,
                        double top, double shade_min, double shade_max, int sh_cmap,
-                       double sh_color, int sh_width, int min_color, int min_width,
-                       int max_color, int max_width, boolean rectangular,
+                       double sh_color, double sh_width, int min_color, double min_width,
+                       int max_color, double max_width, boolean rectangular,
                        double[][] pltr, double[][] OBJECT_DATA )
     {
         if ( set_stream() == -1 ) return;
@@ -1163,10 +1194,10 @@ public class PLStream implements plplotjavacConstants {
             zmin0, zmax0, alt, az );
     }
 
-    public void wid( int width )
+    public void width( int width )
     {
         if ( set_stream() == -1 ) return;
-        plplotjavac.plwid( width );
+        plplotjavac.plwidth( width );
     }
 
     public void wind( double xmin, double xmax, double ymin, double ymax )
@@ -1243,24 +1274,24 @@ public class PLStream implements plplotjavacConstants {
     }
 
     public void scmap1l( int itype, double[] intensity, double[] coord1,
-                         double[] coord2, double[] coord3, int[] rev )
+                         double[] coord2, double[] coord3, int[] alt_hue_path )
     {
         if ( set_stream() == -1 ) return;
-        boolean [] loc_rev = null;
-        if ( rev != null )
+        boolean [] loc_alt_hue_path = null;
+        if ( alt_hue_path != null )
         {
-            loc_rev = new boolean[rev.length];
-            for ( int i = 0; i < rev.length; i++ )
+            loc_alt_hue_path = new boolean[alt_hue_path.length];
+            for ( int i = 0; i < alt_hue_path.length; i++ )
             {
-                loc_rev[i] = ( rev[i] != 0 );
+                loc_alt_hue_path[i] = ( alt_hue_path[i] != 0 );
             }
         }
-        plplotjavac.plscmap1l( itype != 0, intensity, coord1, coord2, coord3, loc_rev );
+        plplotjavac.plscmap1l( itype != 0, intensity, coord1, coord2, coord3, loc_alt_hue_path );
     }
 
     public void shades( double[][] a, double xmin, double xmax, double ymin,
-                        double ymax, double[] clevel, int fill_width, int cont_color,
-                        int cont_width, int rectangular,
+                        double ymax, double[] clevel, double fill_width, int cont_color,
+                        double cont_width, int rectangular,
                         double[][] pltr, double[][] OBJECT_DATA )
     {
         if ( set_stream() == -1 ) return;
@@ -1270,8 +1301,8 @@ public class PLStream implements plplotjavacConstants {
 
     public void shade( double[][] a, double left, double right, double bottom,
                        double top, double shade_min, double shade_max, int sh_cmap,
-                       double sh_color, int sh_width, int min_color, int min_width,
-                       int max_color, int max_width, int rectangular,
+                       double sh_color, double sh_width, int min_color, double min_width,
+                       int max_color, double max_width, int rectangular,
                        double[][] pltr, double[][] OBJECT_DATA )
     {
         if ( set_stream() == -1 ) return;
