@@ -410,9 +410,9 @@ void ml_plcont( const PLFLT **f, PLINT nx, PLINT ny,
 void ml_plshade( const PLFLT **a, PLINT nx, PLINT ny,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  PLBOOL rectangular )
 {
     c_plshade( a, nx, ny,
@@ -449,8 +449,8 @@ void ml_plshade( const PLFLT **a, PLINT nx, PLINT ny,
 //
 void ml_plshades( const PLFLT **a, PLINT nx, PLINT ny,
                   PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                  PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-                  PLINT cont_color, PLINT cont_width,
+                  PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+                  PLINT cont_color, PLFLT cont_width,
                   PLBOOL rectangular )
 {
     c_plshades( a, nx, ny,
@@ -497,6 +497,14 @@ void ml_plvect( const PLFLT **u, const PLFLT **v, PLINT nx, PLINT ny, PLFLT scal
         (void *) 1 );
 }
 
+//
+// Wrapper to reset vector rendering
+//
+void ml_plsvect_reset()
+{
+    c_plsvect( NULL, NULL, 0, 0 );
+}
+
 //
 // void
 // c_plmap( void (*mapform)(PLINT, PLFLT *, PLFLT *), const char *type,
@@ -654,6 +662,16 @@ int translate_parse_option( int parse_option )
     int c_ ## o[o ## _length];      \
     for ( i = 0; i < ( o ## _length ); i++ ) { ( c_ ## o )[i] = Int_val( Field( ( o ), i ) ); }
 
+// Copy an int array, o, of n element to the C array c
+#define INIT_INT_ARRAYS( o )                   \
+    int o ## _length, o ## _inner;             \
+    o ## _length = Wosize_val( o );            \
+    int *c_ ## o[o ## _length];                \
+    for ( i = 0; i < ( o ## _length ); i++ ) { \
+        INIT_INT_ARRAY( o ## _subarray );      \
+        ( c_ ## o )[i] = c_ ## o ## _subarray; \
+    }
+
 int lor_ml_list( value list, ML_VARIANT_FUNC variant_f )
 {
     CAMLparam1( list );
@@ -753,6 +771,33 @@ int translate_legend_option( int legend_option )
     return translated_option;
 }
 
+int translate_colorbar_option( int colorbar_option )
+{
+    int translated_option;
+    switch ( colorbar_option )
+    {
+    case 0: translated_option  = PL_COLORBAR_LABEL_LEFT; break;
+    case 1: translated_option  = PL_COLORBAR_LABEL_RIGHT; break;
+    case 2: translated_option  = PL_COLORBAR_LABEL_TOP; break;
+    case 3: translated_option  = PL_COLORBAR_LABEL_BOTTOM; break;
+    case 4: translated_option  = PL_COLORBAR_IMAGE; break;
+    case 5: translated_option  = PL_COLORBAR_SHADE; break;
+    case 6: translated_option  = PL_COLORBAR_GRADIENT; break;
+    case 7: translated_option  = PL_COLORBAR_CAP_NONE; break;
+    case 8: translated_option  = PL_COLORBAR_CAP_LOW; break;
+    case 9: translated_option  = PL_COLORBAR_CAP_HIGH; break;
+    case 10: translated_option = PL_COLORBAR_SHADE_LABEL; break;
+    case 11: translated_option = PL_COLORBAR_ORIENT_RIGHT; break;
+    case 12: translated_option = PL_COLORBAR_ORIENT_TOP; break;
+    case 13: translated_option = PL_COLORBAR_ORIENT_LEFT; break;
+    case 14: translated_option = PL_COLORBAR_ORIENT_BOTTOM; break;
+    case 15: translated_option = PL_COLORBAR_BACKGROUND; break;
+    case 16: translated_option = PL_COLORBAR_BOUNDING_BOX; break;
+    default: translated_option = -1;
+    }
+    return translated_option;
+}
+
 int translate_position_option( int position_option )
 {
     int translated_option;
@@ -811,10 +856,8 @@ value ml_pllegend( value opt, value position, value x, value y, value plot_width
     INIT_INT_ARRAY( text_colors )
     INIT_INT_ARRAY( box_colors )
     INIT_INT_ARRAY( box_patterns )
-    INIT_INT_ARRAY( box_line_widths )
     INIT_INT_ARRAY( line_colors )
     INIT_INT_ARRAY( line_styles )
-    INIT_INT_ARRAY( line_widths )
     INIT_INT_ARRAY( symbol_colors )
     INIT_INT_ARRAY( symbol_numbers )
     INIT_STRING_ARRAY( symbols )
@@ -842,8 +885,8 @@ value ml_pllegend( value opt, value position, value x, value y, value plot_width
         Double_val( text_justification ),
         c_text_colors, c_text,
         c_box_colors, c_box_patterns, (double *) box_scales,
-        c_box_line_widths,
-        c_line_colors, c_line_styles, c_line_widths,
+        (double *) box_line_widths,
+        c_line_colors, c_line_styles, (double *) line_widths,
         c_symbol_colors, (double *) symbol_scales, c_symbol_numbers,
         c_symbols );
 
@@ -864,6 +907,93 @@ value ml_pllegend_byte( value* argv, int argn )
         argv[25], argv[26], argv[27] );
 }
 
+value ml_plcolorbar( value opt, value position, value x, value y,
+                     value x_length, value y_length,
+                     value bg_color, value bb_color, value bb_style,
+                     value low_cap_color, value high_cap_color,
+                     value cont_color, value cont_width,
+                     value label_opts, value label,
+                     value axis_opts,
+                     value ticks, value sub_ticks,
+                     value values )
+{
+    CAMLparam5( opt, position, x, y, x_length );
+    CAMLxparam5( y_length, bg_color, bb_color, bb_style, low_cap_color );
+    CAMLxparam5( high_cap_color, cont_color, cont_width, label_opts, label );
+    CAMLxparam4( axis_opts, ticks, sub_ticks, values );
+    CAMLlocal1( result );
+    result = caml_alloc( 2, 0 );
+
+    // Counter
+    int i;
+    // General colorbar options
+    int c_opt, c_position;
+    // Number of labels
+    int n_labels;
+    n_labels = Wosize_val( label_opts );
+    // Number of axes and value ranges
+    int n_axes;
+    n_axes = Wosize_val( axis_opts );
+
+    // Translate configuration options
+    c_opt      = lor_ml_list( opt, translate_colorbar_option );
+    c_position = lor_ml_list( position, translate_position_option );
+
+    // Assume that the dimensions all line up on the OCaml side, so we don't
+    // need to do any further dimension checks.
+
+    // Define and initialize all of the C arrays to pass into plcolorbar
+    INIT_STRING_ARRAY( label )
+    INIT_STRING_ARRAY( axis_opts )
+    INIT_INT_ARRAY( sub_ticks );
+
+    // Label options
+    int c_label_opts[ n_labels ];
+    for ( i = 0; i < n_labels; i++ )
+    {
+        c_label_opts[i] = lor_ml_list( Field( label_opts, i ), translate_colorbar_option );
+    }
+
+    // Copy the axis/range values
+    double **c_values;
+    int    n_values[ n_axes ];
+    c_values = malloc( n_axes * sizeof ( double * ) );
+    // TODO: Add allocation failure check
+    for ( i = 0; i < n_axes; i++ )
+    {
+        c_values[i] = (double *) Field( values, i );
+        n_values[i] = Wosize_val( Field( values, i ) ) / Double_wosize;
+    }
+
+    // Return values
+    PLFLT width, height;
+
+    plcolorbar( &width, &height,
+        c_opt, c_position, Double_val( x ), Double_val( y ),
+        Double_val( x_length ), Double_val( y_length ),
+        Int_val( bg_color ), Int_val( bb_color ), Int_val( bb_style ),
+        Double_val( low_cap_color ), Double_val( high_cap_color ),
+        Int_val( cont_color ), Double_val( cont_width ),
+        n_labels, c_label_opts, c_label,
+        n_axes, c_axis_opts,
+        (double *) ticks, c_sub_ticks,
+        n_values, (const PLFLT * const *) c_values );
+
+    // Return a tuple with the colorbar's size
+    Store_field( result, 0, caml_copy_double( width ) );
+    Store_field( result, 1, caml_copy_double( height ) );
+
+    CAMLreturn( result );
+}
+
+value ml_plcolorbar_byte( value *argv, int argn )
+{
+    return ml_plcolorbar( argv[0], argv[1], argv[2], argv[3], argv[4],
+        argv[5], argv[6], argv[7], argv[8], argv[9],
+        argv[10], argv[11], argv[12], argv[13], argv[14],
+        argv[15], argv[16], argv[17], argv[18] );
+}
+
 // pltr* function implementations
 void ml_pltr0( double x, double y, double* tx, double* ty )
 {
@@ -951,14 +1081,14 @@ int plg_current_col0( void )
 }
 
 // Get the current color map 1 color index
-float plg_current_col1( void )
+PLFLT plg_current_col1( void )
 {
     return plsc->icol1;
 }
 
 // Get the current pen width. TODO: Remove this, as I think this information
 // can be retrieved from another proper PLplot function.
-int plgwid( void )
+PLFLT plgwidth( void )
 {
     return plsc->width;
 }
@@ -966,7 +1096,7 @@ int plgwid( void )
 // Get the current character (text) height in mm.  TODO: Remove this, as I
 // think this information can be retrieved from another proper PLplot
 // function
-float plgchrht( void )
+PLFLT plgchrht( void )
 {
     return plsc->chrht;
 }
