@@ -40,6 +40,7 @@
 function text = title (text)
 
   global __pl
+  global pl_automatic_replot
 
   strm = __pl_init;
 
@@ -57,8 +58,8 @@ function text = title (text)
     __pl.tlabel = __pl_matstr(__pl.tlabel, text, strm);
   endif
 
-  if (exist("automatic_replot"))
-    if (automatic_replot)
+  if (exist("pl_automatic_replot"))
+    if (pl_automatic_replot)
       __pl_plotit;
     endif
   endif
