@@ -23,16 +23,21 @@
 if ! exist ("use_plplot_state")
   global use_plplot_state
   use_plplot_state = "on";
+  global default_shadow_warning
+  default_shadow_warning = warning("query","Octave:shadowed-function");
+  warning("off","Octave:shadowed-function");
 else
   if strcmp (use_plplot_state, "on")
     use_plplot_state = "off";
+    warning(default_shadow_warning.state,"Octave:shadowed-function");
   else
     use_plplot_state = "on";
+    warning("off","Octave:shadowed-function");
   endif
 endif
 
 use_plplot_path = plplot_octave_path;
-plplot_path_to_remove = split(genpath(use_plplot_path),pathsep);
+plplot_path_to_remove = char(strsplit(genpath(use_plplot_path),pathsep));
 for use_plplot_i=1:size(plplot_path_to_remove)(1)
   if (findstr(path,deblank(plplot_path_to_remove(use_plplot_i,:))) > 0)
     rmpath(deblank(plplot_path_to_remove(use_plplot_i,:)));
