@@ -52,9 +52,6 @@ class Plframe(Widget):
 ## on the Numeric extensions cannot work this way, so for those we
 ## call straight to the Python compiled interface to the PLplot API.
 
-    def plcol(s,c):
-	s.cmd( 'plcol', c )
-
     def plenv( s, xmin, xmax, ymin, ymax, i, j ):
 	s.cmd( 'plenv', xmin, xmax, ymin, ymax, i, j )
 
@@ -1101,11 +1098,8 @@ class PlXframe(Frame):
                yopt, ylabel, ytick, nsuby,
                zopt, zlabel, ztick, nsubz )
 
-    def plcol(s,c):
-        s.cmd( 'plcol', c )
-
     def plcol0( s, col0 ):
-	s.plcol( col0 )
+	s.cmd( 'plcol0', col0 )
 
     def plcol1( s, col1 ):
         s.cmd( 'plcol1', col1 )
@@ -1249,6 +1243,10 @@ class PlXframe(Frame):
 ##		 min_col, min_wid, max_col, max_wid, rect,
 ##		 pltr, xg, yg, wrap )
 
+# Only works for special conditions so comment it out for now.
+#    def plsmem( ny, ny, plotmem ):
+#        s.cmd('plsmem', nx, ny plotmem )
+
     def plssub( s, nx, ny ):
 	s.cmd( 'plssub', nx, ny )
 
