@@ -1,20 +1,21 @@
 // C code to create dynamically loaded library to implement plplot_widget module
 
+#define NPY_NO_DEPRECATED_API    NPY_1_7_API_VERSION
 #include <Python.h>
-// Change this to the recommended
-// #include <Numeric/arrayobject.h>
-//  once we no longer support python1.5
 #include <arrayobject.h>
 #include "plplot.h"
 #include "plplotP.h"
 
-#ifdef ENABLE_tk
+#ifdef ENABLE_tkX
 #include <tcl.h>
+#include "pltk.h"
 #endif
 
+void initplplot_widget( void );
+
 #define TRY( E )    if ( !( E ) ) return NULL
 
-#ifdef ENABLE_tk
+#ifdef ENABLE_tkX
 static char doc_Pltk_init[] = "Initialize the Pltk Tcl extension.";
 
 //--------------------------------------------------------------------------
@@ -23,7 +24,7 @@ static char doc_Pltk_init[] = "Initialize the Pltk Tcl extension.";
 // the Tcl interpreter into which the Pltk extension is to be injected.
 //--------------------------------------------------------------------------
 
-static PyObject *pl_Pltk_init( PyObject *self, PyObject *args )
+static PyObject *pl_Pltk_init( PyObject * PL_UNUSED( self ), PyObject *args )
 {
     printf( "in pl_Pltk_init()\n" );
     long x = 0;
@@ -43,7 +44,7 @@ static PyObject *pl_Pltk_init( PyObject *self, PyObject *args )
 
     if ( Pltk_Init( interp ) == TCL_ERROR )
     {
-        printf( "Initizlization of Pltk Tcl extension failed!\n" );
+        printf( "Initialization of Pltk Tcl extension failed!\n" );
         return NULL;
     }
 
@@ -58,7 +59,7 @@ static PyObject *pl_Pltk_init( PyObject *self, PyObject *args )
 //--------------------------------------------------------------------------
 
 static PyMethodDef plplot_widget_methods[] = {
-#ifdef ENABLE_tk
+#ifdef ENABLE_tkX
     { "Pltk_init", pl_Pltk_init, METH_VARARGS, doc_Pltk_init },
 #endif
 
@@ -68,13 +69,13 @@ static PyMethodDef plplot_widget_methods[] = {
 PLDLLIMPEXP_PLPLOT_WIDGETMODULE void initplplot_widget( void )
 {
     PyObject *m;
-    PyObject *d;
+    //PyObject *d;
 
     import_array();
 
     // Create the module and add the functions
     m = Py_InitModule( "plplot_widget", plplot_widget_methods );
-    d = PyModule_GetDict( m );
+    PyModule_GetDict( m );
 
     // Check for errors
     if ( PyErr_Occurred() )
