@@ -452,13 +452,13 @@ void QtPLDriver::setGradient( int x1, int x2, int y1, int y2,
     m_painterP->setBrush( linear_gradient );
 }
 
-void QtPLDriver::setWidth( PLINT w )
+void QtPLDriver::setWidthF( PLFLT w )
 {
     if ( !m_painterP->isActive() )
         return;
 
     QPen p = m_painterP->pen();
-    p.setWidth( w );
+    p.setWidthF( w );
     m_painterP->setPen( p );
 }
 
@@ -928,11 +928,11 @@ void QtPLWidget::setBackgroundColor( int r, int g, int b, double alpha )
     redrawFromLastFlush = true;
 }
 
-void QtPLWidget::setWidth( PLINT w )
+void QtPLWidget::setWidthF( PLFLT w )
 {
     BufferElement el;
     el.Element       = SET_WIDTH;
-    el.Data.intParam = w;
+    el.Data.fltParam = w;
     m_listBuffer.append( el );
 //     redrawFromLastFlush=true;
 }
@@ -1046,6 +1046,8 @@ void QtPLWidget::lookupButtonEvent( QMouseEvent * event )
     case Qt::RightButton:
         gin.button = 3;
         break;
+    default:
+        break;
     }
 
     // Map Qt button and key states to the (X windows) values used
@@ -1116,21 +1118,20 @@ void QtPLWidget::mousePressEvent( QMouseEvent * event )
     mouseEvent( event );
 }
 
-void QtPLWidget::mouseReleaseEvent( QMouseEvent * event )
+void QtPLWidget::mouseReleaseEvent( QMouseEvent * PL_UNUSED( event ) )
 {
-    mouseEvent( event );
+    //mouseEvent( event );
 }
 
-void QtPLWidget::mouseMoveEvent( QMouseEvent * event )
+void QtPLWidget::mouseMoveEvent( QMouseEvent * PL_UNUSED( event ) )
 {
-    mouseEvent( event );
+    //mouseEvent( event );
 }
 
 void QtPLWidget::keyPressEvent( QKeyEvent* event )
 {
     if ( locate_mode )
     {
-        Qt::KeyboardModifiers modifiers = event->modifiers();
         QPoint p = QCursor::pos();
         gin.pX = p.x();
         gin.pY = height() - p.y();
@@ -1266,8 +1267,7 @@ void QtPLWidget::paintEvent( QPaintEvent * )
         painter->begin( m_pixPixmap );
 
         // Draw the margins and the background
-        painter->fillRect( 0, 0, width(), height(), QBrush( Qt::white ) );
-        painter->fillRect( 0, 0, width(), height(), QBrush( Qt::gray, Qt::Dense4Pattern ) );
+        painter->fillRect( 0, 0, width(), height(), QColor( bgColour.r, bgColour.g, bgColour.b ) );
 
         // Re-initialise pens etc.
         resetPensAndBrushes( painter );
@@ -1412,7 +1412,7 @@ void QtPLWidget::doPlot( QPainter* p, double x_fact, double y_fact, double x_off
             break;
 
         case SET_WIDTH:
-            SolidPen.setWidthF( i->Data.intParam );
+            SolidPen.setWidthF( i->Data.fltParam );
             if ( hasPen )
             {
                 p->setPen( SolidPen );
@@ -1561,7 +1561,7 @@ void QtExtWidget::mouseMoveEvent( QMouseEvent* event )
     update();
 }
 
-void QtExtWidget::mousePressEvent( QMouseEvent* event )
+void QtExtWidget::mousePressEvent( QMouseEvent*  /* event */ )
 {
 }
 
