@@ -1,5 +1,5 @@
 #!/usr/local/bin/tclsh
-# $Id: pltclgen.tcl 10774 2010-01-29 09:10:37Z arjenmarkus $
+# $Id: pltclgen.tcl 12007 2011-10-28 12:02:58Z andrewross $
 #
 # Arjen Markus
 # - translation of the original Perl script
@@ -187,7 +187,7 @@ proc process_pltclcmd {cmd rtype} {
                             puts $GENFILE "    $argname($i) = atoi(argv\[1+$i\]);"
                         }
                         "PLUNICODE" {
-                            puts $GENFILE "    $argname($i) = strtoul(argv\[1+$i\],NULL,10);"
+                            puts $GENFILE "    $argname($i) = (PLUNICODE) strtoul(argv\[1+$i\],NULL,10);"
                         }
                         "unsigned int" {
                             puts $GENFILE "    $argname($i) = (unsigned int) strtoul(argv\[1+$i\],NULL,10);"
