@@ -1,5 +1,5 @@
 // -*-C++-*-
-// $Id: tclMatrix.h 11295 2010-11-01 22:19:45Z airwin $
+// $Id: tclMatrix.h 12078 2011-11-30 22:09:07Z andrewross $
 //
 //  Copyright 1994, 1995
 //  Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -353,7 +353,7 @@ typedef struct tclMatrixXtnsnDescr
     struct tclMatrixXtnsnDescr *next;
 } tclMatrixXtnsnDescr;
 
-int PLDLLIMPEXP_TCLMAT Tcl_MatrixInstallXtnsn( char *cmd, tclMatrixXtnsnProc proc );
+int PLDLLIMPEXP_TCLMAT Tcl_MatrixInstallXtnsn( const char *cmd, tclMatrixXtnsnProc proc );
 
 #ifdef __cplusplus
 }
