@@ -1,4 +1,4 @@
-// $Id: Plplotter_Init.c 11760 2011-06-01 19:29:11Z airwin $
+// $Id: Plplotter_Init.c 12688 2013-11-13 06:30:19Z airwin $
 //
 // Copyright (C) 2004  Joao Cardoso
 //
@@ -52,27 +52,25 @@
 // the Plbasicinit function called from here.
 //--------------------------------------------------------------------------
 
-EXTERN int
+PLDLLIMPEXP_DRIVER EXTERN int
 Plplotter_Init( Tcl_Interp *interp )
 {
-#ifdef USE_TCL_STUBS
-    //
-    // We hard-wire 8.1 here, rather than TCL_VERSION, TK_VERSION because
-    // we really don't mind which version of Tcl, Tk we use as long as it
-    // is 8.1 or newer.  Otherwise if we compiled against 8.2, we couldn't
-    // be loaded into 8.1
-    //
-    Tcl_InitStubs( interp, "8.1", 0 );
-#endif
-#ifdef USE_TK_STUBS
-    Tk_InitStubs( interp, "8.1", 0 );
-#endif
     // This must be before any other Tcl related calls
     if ( PlbasicInit( interp ) != TCL_OK )
     {
         return TCL_ERROR;
     }
 
+#ifdef USE_TK_STUBS
+    //
+    // We hard-wire 8.1 here (as is done for the USE_TCL_STUBS case in
+    // PlbasisInit above) rather than TK_VERSION because we really don't
+    // mind which version of Tcl, Tk we use as long as it is 8.1 or
+    // newer.  Otherwise if we compiled against 8.2, we couldn't be
+    // loaded into 8.1
+    //
+    Tk_InitStubs( interp, "8.1", 0 );
+#endif
     //
     // Note, the old technique of:
     //    main = Tk_MainWindow(interp);
@@ -90,7 +88,7 @@ Plplotter_Init( Tcl_Interp *interp )
     Tcl_CreateCommand( interp, "plframe", (Tcl_CmdProc *) plPlotterCmd,
         (ClientData) NULL, (Tcl_CmdDeleteProc *) NULL );
 
-    Tcl_PkgProvide( interp, "Plplotter", VERSION );
+    Tcl_PkgProvide( interp, "Plplotter", PLPLOT_VERSION );
     return TCL_OK;
 }
 
