@@ -1,5 +1,5 @@
 ## -*-Tcl-*-
- # $Id: Pltkwin.tcl 6382 2005-10-31 22:31:27Z mlebrun $
+ # $Id: Pltkwin.tcl 12678 2013-11-12 03:22:18Z airwin $
  # ###################################################################
  # 
  #  FILE: "Pltkwin.tcl"
@@ -36,9 +36,7 @@
 # We don't need	version	numbers	because	we use the first versions
 # which	actually use the 'package' mechanism.
 package	require	Pltk
-package	require	Itcl
-package	require	Itk
-package require Iwidgets
+eval package require $pl_iwidgets_package_name
 
 itcl::class Pltkwin {
     inherit PLWin
