@@ -1,4 +1,4 @@
-# $Id: plcolor.tcl 6169 2005-04-05 06:25:28Z mlebrun $
+# $Id: plcolor.tcl 12678 2013-11-12 03:22:18Z airwin $
 
 #----------------------------------------------------------------------------
 # Color palette editors in iTcl for PLPlot.
@@ -69,7 +69,7 @@ proc plfile_open {op} {
 
 set colorSpace hsl
 
-package require Itcl 
+eval package require $pl_itcl_package_name
 
 itcl::class ColorEditor {
     private variable r 255
