@@ -1,4 +1,4 @@
-// $Id: plr.c 11682 2011-03-31 02:55:49Z airwin $
+// $Id: plr.c 12288 2013-01-30 04:40:35Z airwin $
 //
 //  Copyright 1993, 1994, 1995
 //  Maurice LeBrun
@@ -47,10 +47,14 @@
 
 // Some wrapper macros to return (-1) on error
 
-#define plr_rd( code )                                                            \
-    if ( code ) { fprintf( stderr,                                                \
-                      "Unable to read from %s in %s at line %d, bytecount %ld\n", \
-                      plr->iodev->typeName, __FILE__, __LINE__, plr->pdfs->bp );  \
+// Note we use %lu and an explicit cast to unsigned long to print size_t pointers.
+// C99 adds %zd as an explicit format specifier for size_t but this is not yet
+// fully adopted.
+
+#define plr_rd( code )                                                                           \
+    if ( code ) { fprintf( stderr,                                                               \
+                      "Unable to read from %s in %s at line %d, bytecount %lu\n",                \
+                      plr->iodev->typeName, __FILE__, __LINE__, (unsigned long) plr->pdfs->bp ); \
                   return -1; }
 
 #define plr_cmd( code ) \
@@ -59,8 +63,8 @@
 // Error termination
 
 #define barf( msg )                                               \
-    { fprintf( stderr, "%s\nCommand code: %d, byte count: %ld\n", \
-          msg, csave, plr->pdfs->bp ); return -1; }
+    { fprintf( stderr, "%s\nCommand code: %d, byte count: %lu\n", \
+          msg, csave, (unsigned long) plr->pdfs->bp ); return -1; }
 
 // Static function prototypes.
 
@@ -116,7 +120,7 @@ plr_process( PLRDev *plr )
 
     dbug_enter( "plr_process" );
 
-    while ( plr->pdfs->bp < plr->nbytes )
+    while ( plr->pdfs->bp < (size_t) plr->nbytes )
     {
         plr_cmd( c = plr_get( plr ) );
         csave = c;
@@ -217,35 +221,35 @@ plr_init( PLRDev *plr )
         if ( !strcmp( tag, "xmin" ) )
         {
             plr_rd( pdf_rd_2bytes( plr->pdfs, &dum_ushort ) );
-            plr->xmin = dum_ushort;
+            plr->xmin = (short) dum_ushort;
             continue;
         }
 
         if ( !strcmp( tag, "xmax" ) )
         {
             plr_rd( pdf_rd_2bytes( plr->pdfs, &dum_ushort ) );
-            plr->xmax = dum_ushort;
+            plr->xmax = (short) dum_ushort;
             continue;
         }
 
         if ( !strcmp( tag, "ymin" ) )
         {
             plr_rd( pdf_rd_2bytes( plr->pdfs, &dum_ushort ) );
-            plr->ymin = dum_ushort;
+            plr->ymin = (short) dum_ushort;
             continue;
         }
 
         if ( !strcmp( tag, "ymax" ) )
         {
             plr_rd( pdf_rd_2bytes( plr->pdfs, &dum_ushort ) );
-            plr->ymax = dum_ushort;
+            plr->ymax = (short) dum_ushort;
             continue;
         }
 
         if ( !strcmp( tag, "width" ) )
         {
             plr_rd( pdf_rd_1byte( plr->pdfs, &dum_uchar ) );
-            plwid( dum_uchar );
+            plwidth( dum_uchar );
             continue;
         }
 
@@ -290,7 +294,7 @@ plr_line( PLRDev *plr, int c )
             plr_cmd( get_ncoords( plr, x + npts, y + npts, 1 ) );
 
             npts++;
-            if ( npts == PL_MAXPOLY || ( plr->pdfs->bp == plr->nbytes ) )
+            if ( npts == PL_MAXPOLY || ( plr->pdfs->bp == (size_t) plr->nbytes ) )
                 break;
 
             plr_cmd( c1 = plr_get( plr ) );
@@ -337,8 +341,8 @@ get_ncoords( PLRDev *plr, PLFLT *x, PLFLT *y, PLINT n )
 
     if ( n > PL_MAXPOLY )
     {
-        xs = (short *) malloc( sizeof ( short ) * n );
-        ys = (short *) malloc( sizeof ( short ) * n );
+        xs = (short *) malloc( sizeof ( short ) * (size_t) n );
+        ys = (short *) malloc( sizeof ( short ) * (size_t) n );
     }
     else
     {
@@ -371,7 +375,7 @@ get_ncoords( PLRDev *plr, PLFLT *x, PLFLT *y, PLINT n )
 //--------------------------------------------------------------------------
 
 static int
-plr_eop( PLRDev *plr )
+plr_eop( PLRDev * PL_UNUSED( plr ) )
 {
     dbug_enter( "plr_eop" );
 
@@ -421,14 +425,14 @@ plr_state( PLRDev *plr )
 
         plr_rd( pdf_rd_2bytes( plr->pdfs, &width ) );
 
-        plwid( width );
+        plwidth( width );
         break;
     }
 
     case PLSTATE_COLOR0: {
         short icol0;
 
-        plr_rd( pdf_rd_2bytes( plr->pdfs, &icol0 ) );
+        plr_rd( pdf_rd_2bytes( plr->pdfs, (unsigned short *) &icol0 ) );
 
         if ( icol0 == PL_RGB_COLOR )
         {
@@ -501,10 +505,10 @@ plr_state( PLRDev *plr )
             plr_rd( pdf_rd_ieeef( plr->pdfs, &s ) );
             plr_rd( pdf_rd_1byte( plr->pdfs, &rev ) );
 
-            plsc->cmap1cp[i].h   = h;
-            plsc->cmap1cp[i].l   = l;
-            plsc->cmap1cp[i].s   = s;
-            plsc->cmap1cp[i].rev = rev;
+            plsc->cmap1cp[i].h            = h;
+            plsc->cmap1cp[i].l            = l;
+            plsc->cmap1cp[i].s            = s;
+            plsc->cmap1cp[i].alt_hue_path = rev;
         }
         plP_state( PLSTATE_CMAP1 );
         break;
