@@ -1,4 +1,4 @@
-// $Id: plserver.c 11760 2011-06-01 19:29:11Z airwin $
+// $Id: plserver.c 12990 2014-02-09 20:52:02Z airwin $
 //
 //  Copyright 1993, 1994, 1995
 //  Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -74,7 +74,7 @@ plExitCmd( ClientData clientData, Tcl_Interp *interp, int argc, char **argv );
 // Evals the specified command, aborting on an error.
 
 static void
-tcl_cmd( Tcl_Interp *interp, char *cmd );
+tcl_cmd( Tcl_Interp *interp, const char *cmd );
 
 // Application-specific startup
 
@@ -96,9 +96,9 @@ int
 main( int argc, const char **argv )
 {
     int        i, myargc = argc;
-    const char *myargv[20];
+    const char **myargv;
     Tcl_Interp *interp;
-    char       *helpmsg = "Command-specific options:";
+    const char *helpmsg = "Command-specific options:";
 
 #ifdef DEBUG
     fprintf( stderr, "Program %s called with arguments :\n", argv[0] );
@@ -113,27 +113,41 @@ main( int argc, const char **argv )
 
     interp = Tcl_CreateInterp();
 
-// Save arglist to get around tk_ParseArgv limitations
+// Save arglist to get around Tk_ParseArgv limitations
 
+#ifdef DEBUG
+    fprintf( stderr, "Before myargv\n" );
+#endif
+
+    myargv = (const char **) malloc( argc * sizeof ( char * ) );
     for ( i = 0; i < argc; i++ )
     {
         myargv[i] = argv[i];
     }
 
+#ifdef DEBUG
+    fprintf( stderr, "After myargv\n" );
+#endif
+
 // Parse args
 // Examine the result string to see if an error return is really an error
 
     if ( Tk_ParseArgv( interp, (Tk_Window) NULL, &argc, argv,
              argTable, TK_ARGV_NO_DEFAULTS ) != TCL_OK )
     {
-        fprintf( stderr, "\n(plserver) %s\n\n", interp->result );
+        fprintf( stderr, "Error in Tk_ParseArgv\n" );
+        fprintf( stderr, "\n(plserver) %s\n\n", Tcl_GetStringResult( interp ) );
         fprintf( stderr, "\
 The client_<xxx> and -child options should not be used except via the\n\
 PLplot/Tk driver.\n\n(wish) " );
-        if ( strncmp( interp->result, helpmsg, strlen( helpmsg ) ) )
-            exit( 1 );
+        fprintf( stderr, "Before Tcl_SetResult\n" );
+        Tcl_SetResult( interp, (char *) helpmsg, TCL_VOLATILE );
     }
 
+#ifdef DEBUG
+    fprintf( stderr, "After Tk_ParseArgv\n" );
+#endif
+
 // No longer need interpreter
 
 #if TCL_MAJOR_VERSION < 7 || ( TCL_MAJOR_VERSION == 7 && TCL_MINOR_VERSION < 5 )
@@ -225,7 +239,7 @@ AppInit( Tcl_Interp *interp )
     if ( auto_path != NULL )
     {
         Tcl_SetVar( interp, "dir", auto_path, 0 );
-        tcl_cmd( interp, "set auto_path [list $dir $auto_path]" );
+        tcl_cmd( interp, "lappend auto_path $dir" );
     }
 
 // Rename "exit" to "tkexit", and insert custom exit handler
@@ -235,10 +249,6 @@ AppInit( Tcl_Interp *interp )
     Tcl_CreateCommand( interp, "exit", (Tcl_CmdProc *) plExitCmd,
         (ClientData) mainWindow, (Tcl_CmdDeleteProc *) NULL );
 
-// Define the flags as variables in the PLPLOT namespace
-
-    set_plplot_parameters( interp );
-
     return TCL_OK;
 }
 
@@ -251,14 +261,16 @@ AppInit( Tcl_Interp *interp )
 //--------------------------------------------------------------------------
 
 static int
-plExitCmd( ClientData clientData, Tcl_Interp *interp, int argc, char **argv )
+plExitCmd( ClientData PL_UNUSED( clientData ), Tcl_Interp *interp, int argc, char **argv )
 {
-    int value = 0;
+    int        value = 0;
+    const char *res;
 
 // Print error message if one given
 
-    if ( interp->result != NULL && interp->result[0] != '\0' )
-        fprintf( stderr, "%s\n", interp->result );
+    res = Tcl_GetStringResult( interp );
+    if ( res[0] != '\0' )
+        fprintf( stderr, "%s\n", res );
 
 // Best to check the syntax before proceeding
 
@@ -280,8 +292,17 @@ plExitCmd( ClientData clientData, Tcl_Interp *interp, int argc, char **argv )
     Tcl_VarEval( interp, "plserver_link_end", (char **) NULL );
 
 // Now really exit
+// (Note: this function is actually deprecated, but as it is only used here
+// at the end of the program, let's leave it.)
 
-    return Tcl_VarEval( interp, "tkexit", argv[1], (char **) NULL );
+    if ( argc == 1 )
+    {
+        return Tcl_VarEval( interp, "tkexit", (char **) NULL );
+    }
+    else
+    {
+        return Tcl_VarEval( interp, "tkexit", argv[1], (char **) NULL );
+    }
 }
 
 //--------------------------------------------------------------------------
@@ -291,7 +312,7 @@ plExitCmd( ClientData clientData, Tcl_Interp *interp, int argc, char **argv )
 //--------------------------------------------------------------------------
 
 static void
-tcl_cmd( Tcl_Interp *interp, char *cmd )
+tcl_cmd( Tcl_Interp *interp, const char *cmd )
 {
     int result;
 
