@@ -1,4 +1,4 @@
-// $Id: pltkd.h 11295 2010-11-01 22:19:45Z airwin $
+// $Id: pltkd.h 12933 2014-01-12 02:53:54Z airwin $
 //
 //      Holds system header includes, prototypes of TK driver
 //      utility functions, and definition of the state structure.
@@ -21,6 +21,12 @@
 #include <dp.h>
 #endif
 
+// typedef the type pid_t - a dummy for the moment - for MS Windows
+// platforms other than those (e.g., MinGW) that typedef it already.
+#if defined ( __WIN32__ ) && !defined ( __MINGW32__ )
+typedef unsigned int   pid_t;
+#endif
+
 // One of these holds the TK driver state information
 
 typedef struct
@@ -32,9 +38,9 @@ typedef struct
     int          exit_eventloop;        // Break out of event loop
     int          pass_thru;             // Skip normal error termination
     char         *cmdbuf;               // Command buffer
-    int          cmdbuf_len;            // and its length
+    size_t       cmdbuf_len;            // and its length
     PLiodev      *iodev;                // I/O device info
-    char         *updatecmd;            // Name of update command
+    const char   *updatecmd;            // Name of update command
     pid_t        child_pid;             // PID for child process
     int          instr;                 // Instruction timer
     int          max_instr;             // Limit before issuing an update
