@@ -1,4 +1,4 @@
-# $Id: pltools.tcl 8312 2008-03-22 16:23:58Z mlebrun $
+# $Id: pltools.tcl 12681 2013-11-12 06:03:11Z airwin $
 
 #----------------------------------------------------------------------------
 # PLPLOT TK/TCL graphics renderer support procs
@@ -256,9 +256,10 @@ proc max {args} {
 #----------------------------------------------------------------------------
 
 proc fileSelect {{filter {}}} {
+    global pl_iwidgets_package_name
 
     # Use the Iwidgets file selector if available
-    if ![catch {package require Iwidgets}] {
+    if ![catch {eval package require $pl_iwidgets_package_name}] {
 	if {![winfo exist .fs]} {
 	    iwidgets::fileselectiondialog .fs -modality application
 	}
