@@ -1,4 +1,4 @@
-// $Id: tcpip.h 11295 2010-11-01 22:19:45Z airwin $
+// $Id: tcpip.h 11975 2011-10-19 11:05:10Z andrewross $
 //
 // Maurice LeBrun
 // 31-May-95
@@ -16,13 +16,11 @@
 // Modified version of the "Tdp_PacketSend" command.
 
 PLDLLIMPEXP_TCLTK int
-pl_PacketSend           PLARGS( ( Tcl_Interp * interp, PLiodev * iodev,
-                                  PDFstrm * pdfs ) );
+pl_PacketSend( Tcl_Interp * interp, PLiodev * iodev, PDFstrm * pdfs );
 
 // Modified version of the "Tdp_PacketReceive" command.
 
 PLDLLIMPEXP_TCLTK int
-pl_PacketReceive        PLARGS( ( Tcl_Interp * interp, PLiodev * iodev,
-                                  PDFstrm * pdfs ) );
+pl_PacketReceive( Tcl_Interp * interp, PLiodev * iodev, PDFstrm * pdfs );
 
 #endif  // __TCPIP_H__
