@@ -1,4 +1,4 @@
-// $Id: tkMain.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: tkMain.c 12881 2013-12-19 01:25:14Z airwin $
 //
 // Modified version of tkMain.c, from Tk 3.6.
 // Maurice LeBrun
@@ -85,7 +85,8 @@ EXTERN int Itk_Init _ANSI_ARGS_( ( Tcl_Interp * interp ) );
 
 // From tclIntDecls.h
 
-#ifndef Tcl_Import_TCL_DECLARED
+//#ifndef Tcl_Import_TCL_DECLARED
+#if 0
 EXTERN int Tcl_Import _ANSI_ARGS_( ( Tcl_Interp * interp,
                                      Tcl_Namespace * nsPtr, char * pattern,
                                      int allowOverwrite ) );
@@ -107,7 +108,12 @@ EXTERN Tcl_Namespace * Tcl_GetGlobalNamespace _ANSI_ARGS_( (
 // extern int		isatty _ANSI_ARGS_((int fd));
 // extern int		read _ANSI_ARGS_((int fd, char *buf, size_t size));
 //
+#if !defined ( __WIN32__ )
 extern char *           strrchr _ANSI_ARGS_( ( CONST char *string, int c ) );
+#else
+// On Windows we do not have a convenient console to work with
+#define isatty( a )    0
+#endif
 
 //
 // Global variables used by the main program:
@@ -153,7 +159,7 @@ static Tk_ArgvInfo argTable[] = {
 // Forward declarations for procedures defined later in this file:
 //
 
-static void Prompt _ANSI_ARGS_( ( Tcl_Interp * interp, int partial ) );
+static void Prompt _ANSI_ARGS_( ( Tcl_Interp * interploc, int partial ) );
 static void StdinProc _ANSI_ARGS_( ( ClientData clientData,
                                      int mask ) );
 
@@ -180,8 +186,8 @@ int
 pltkMain( int argc, const char **argv, char *RcFileName,
           int ( *AppInit )( Tcl_Interp *interp ) )
 {
-    char       *args, *msg;
-    const char *p;
+    char       *args;
+    const char *msg, *p;
     char       buf[20];
     int        code;
 
@@ -198,13 +204,15 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     //
     // Parse command-line arguments.
     //
+    //fprintf( stderr, "Before Tk_ParseArgv\n" );
 
     if ( Tk_ParseArgv( interp, (Tk_Window) NULL, &argc, argv, argTable, 0 )
          != TCL_OK )
     {
-        fprintf( stderr, "%s\n", interp->result );
+        fprintf( stderr, "%s\n", Tcl_GetStringResult( interp ) );
         exit( 1 );
     }
+    //fprintf( stderr, "After Tk_ParseArgv\n" );
     if ( name == NULL )
     {
         if ( fileName != NULL )
@@ -250,21 +258,25 @@ pltkMain( int argc, const char **argv, char *RcFileName,
 
     if ( Tcl_Init( interp ) == TCL_ERROR )
     {
+        fprintf( stderr, "Tcl initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
     if ( Tk_Init( interp ) == TCL_ERROR )
     {
+        fprintf( stderr, "Tk initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
 #ifdef HAVE_ITCL
     if ( Itcl_Init( interp ) == TCL_ERROR )
     {
+        fprintf( stderr, "Itcl initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
 #endif
 #ifdef HAVE_ITK
     if ( Itk_Init( interp ) == TCL_ERROR )
     {
+        fprintf( stderr, "Itk initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
 
@@ -280,17 +292,20 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     if ( Tcl_Import( interp, Tcl_GetGlobalNamespace( interp ),
              "::itk::*", /* allowOverwrite */ 1 ) != TCL_OK )
     {
+        fprintf( stderr, "Itk initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
 
     if ( Tcl_Import( interp, Tcl_GetGlobalNamespace( interp ),
              "::itcl::*", /* allowOverwrite */ 1 ) != TCL_OK )
     {
+        fprintf( stderr, "Itk initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
 
     if ( Tcl_Eval( interp, "auto_mkindex_parser::slavehook { _%@namespace import -force ::itcl::* ::itk::* }" ) != TCL_OK )
     {
+        fprintf( stderr, "Itk initialisation failed: %s\n", Tcl_GetStringResult( interp ) );
         return TCL_ERROR;
     }
 #endif
@@ -300,6 +315,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     // and "argv".  Also set the "geometry" variable from the geometry
     // specified on the command line.
     //
+    //fprintf( stderr, "Before Tcl_Merge\n" );
 
     args = Tcl_Merge( argc - 1, ( CONST char * CONST * )argv + 1 );
     Tcl_SetVar( interp, "argv", args, TCL_GLOBAL_ONLY );
@@ -307,6 +323,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     sprintf( buf, "%d", argc - 1 );
     Tcl_SetVar( interp, "argc", buf, TCL_GLOBAL_ONLY );
 
+    //fprintf( stderr, "After Tcl_Merge\n" );
     if ( geometry != NULL )
     {
         Tcl_SetVar( interp, "geometry", geometry, TCL_GLOBAL_ONLY );
@@ -328,10 +345,12 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     //
     // Invoke application-specific initialization.
     //
+    //fprintf( stderr, "Before AppInit\n" );
 
     if ( ( *AppInit )( interp ) != TCL_OK )
     {
-        fprintf( stderr, "(*AppInit) failed: %s\n", interp->result );
+        fprintf( stderr, "(*AppInit) failed: %s\n", Tcl_GetStringResult( interp ) );
+        return TCL_ERROR;
     }
 
     //
@@ -343,13 +362,14 @@ pltkMain( int argc, const char **argv, char *RcFileName,
         code = Tcl_VarEval( interp, "wm geometry . ", geometry, (char *) NULL );
         if ( code != TCL_OK )
         {
-            fprintf( stderr, "%s\n", interp->result );
+            fprintf( stderr, "%s\n", Tcl_GetStringResult( interp ) );
         }
     }
 
     //
     // Process the startup script, if any.
     //
+    //fprintf( stderr, "Before startup\n" );
 
     if ( script != NULL )
     {
@@ -364,6 +384,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     //
     // Invoke the script specified on the command line, if any.
     //
+    //fprintf( stderr, "Before source\n" );
 
     if ( fileName != NULL )
     {
@@ -393,7 +414,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
             fullName = Tcl_TildeSubst( interp, RcFileName, &buffer );
             if ( fullName == NULL )
             {
-                fprintf( stderr, "%s\n", interp->result );
+                fprintf( stderr, "%s\n", Tcl_GetStringResult( interp ) );
             }
             else
             {
@@ -403,7 +424,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
                     code = Tcl_EvalFile( interp, fullName );
                     if ( code != TCL_OK )
                     {
-                        fprintf( stderr, "%s\n", interp->result );
+                        fprintf( stderr, "%s\n", Tcl_GetStringResult( interp ) );
                     }
                     fclose( f );
                 }
@@ -411,7 +432,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
             Tcl_DStringFree( &buffer );
         }
 // Exclude UNIX-only feature
-#if !defined ( MAC_TCL ) && !defined ( __WIN32__ ) && !defined ( __CYGWIN__ )
+#if !defined ( MAC_TCL ) && !defined ( __WIN32__ )
         Tk_CreateFileHandler( 0, TK_READABLE, StdinProc, (ClientData) 0 );
 #endif
         if ( tty )
@@ -427,6 +448,7 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     // are no windows left, Tk_MainLoop returns and we exit.
     //
 
+    //fprintf( stderr, "Before Tk_MainLoop\n" );
     Tk_MainLoop();
 
     //
@@ -439,10 +461,10 @@ pltkMain( int argc, const char **argv, char *RcFileName,
     exit( 1 );
 
 error:
-    msg = (char *) Tcl_GetVar( interp, "errorInfo", TCL_GLOBAL_ONLY );
+    msg = Tcl_GetVar( interp, "errorInfo", TCL_GLOBAL_ONLY );
     if ( msg == NULL )
     {
-        msg = interp->result;
+        msg = Tcl_GetStringResult( interp );
     }
     fprintf( stderr, "%s\n", msg );
     Tcl_Eval( interp, errorExitCmd );
@@ -471,17 +493,20 @@ error:
 
 // ARGSUSED
 static void
-StdinProc( clientData, mask )
-ClientData clientData;                  // Not used.
-int mask;                               // Not used.
+StdinProc( ClientData PL_UNUSED( clientData ), int PL_UNUSED( mask ) )
 {
 #define BUFFER_SIZE    4000
     char       input[BUFFER_SIZE + 1];
     static int gotPartial = 0;
     char       *cmd;
     int        code, count;
+    const char *res;
 
-    count = read( fileno( stdin ), input, BUFFER_SIZE );
+#if !defined ( __WIN32__ )
+    count = (int) read( fileno( stdin ), input, BUFFER_SIZE );
+#else
+    count = fread( input, BUFFER_SIZE, sizeof ( char ), stdin );
+#endif
     if ( count <= 0 )
     {
         if ( !gotPartial )
@@ -493,7 +518,7 @@ int mask;                               // Not used.
             }
             else
             {
-#if !defined ( MAC_TCL ) && !defined ( __WIN32__ ) && !defined ( __CYGWIN__ )
+#if !defined ( MAC_TCL ) && !defined ( __WIN32__ )
                 Tk_DeleteFileHandler( 0 );
 #endif
             }
@@ -527,19 +552,20 @@ int mask;                               // Not used.
     // finished.  Among other things, this will trash the text of the
     // command being evaluated.
     //
-#if !defined ( MAC_TCL ) && !defined ( __WIN32__ ) && !defined ( __CYGWIN__ )
+#if !defined ( MAC_TCL ) && !defined ( __WIN32__ )
     Tk_CreateFileHandler( 0, 0, StdinProc, (ClientData) 0 );
 #endif
     code = Tcl_RecordAndEval( interp, cmd, 0 );
-#if !defined ( MAC_TCL ) && !defined ( __WIN32__ ) && !defined ( __CYGWIN__ )
+#if !defined ( MAC_TCL ) && !defined ( __WIN32__ )
     Tk_CreateFileHandler( 0, TK_READABLE, StdinProc, (ClientData) 0 );
 #endif
     Tcl_DStringFree( &command );
-    if ( *interp->result != 0 )
+    res = Tcl_GetStringResult( interp );
+    if ( *res != 0 )
     {
         if ( ( code != TCL_OK ) || ( tty ) )
         {
-            printf( "%s\n", interp->result );
+            printf( "%s\n", res );
         }
     }
 
@@ -573,16 +599,16 @@ prompt:
 //
 
 static void
-Prompt( interp, partial )
-Tcl_Interp * interp;                    // Interpreter to use for prompting.
-int partial;                            // Non-zero means there already
-                                        // exists a partial command, so use
-                                        // the secondary prompt.
+Prompt( interploc, partial )
+Tcl_Interp * interploc;               // Interpreter to use for prompting.
+int partial;                          // Non-zero means there already
+                                      // exists a partial command, so use
+                                      // the secondary prompt.
 {
-    char *promptCmd;
-    int  code;
+    const char *promptCmd;
+    int        code;
 
-    promptCmd = (char *) Tcl_GetVar( interp,
+    promptCmd = Tcl_GetVar( interploc,
         partial ? "tcl_prompt2" : "tcl_prompt1", TCL_GLOBAL_ONLY );
     if ( promptCmd == NULL )
     {
@@ -594,12 +620,12 @@ defaultPrompt:
     }
     else
     {
-        code = Tcl_Eval( interp, promptCmd );
+        code = Tcl_Eval( interploc, promptCmd );
         if ( code != TCL_OK )
         {
-            Tcl_AddErrorInfo( interp,
+            Tcl_AddErrorInfo( interploc,
                 "\n    (script that generates prompt)" );
-            fprintf( stderr, "%s\n", interp->result );
+            fprintf( stderr, "%s\n", Tcl_GetStringResult( interploc ) );
             goto defaultPrompt;
         }
     }
