@@ -1,7 +1,7 @@
-/* $Id: dg300.c 10785 2010-01-31 20:05:17Z hezekiahcarty $
- *
- *      PLplot dg300 device driver.
- */
+// $Id: dg300.c 11282 2010-10-28 16:26:09Z airwin $
+//
+//      PLplot dg300 device driver.
+//
 #include "plDevs.h"
 
 #ifdef PLD_dg300
@@ -9,7 +9,7 @@
 #include "plplotP.h"
 #include "drivers.h"
 
-/* Device info */
+// Device info
 PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_dg300 = "dg300:DG300 Terminal:0:dg300:25:dg300\n";
 
 void plD_dispatch_init_dg( PLDispatchTable *pdt );
@@ -23,7 +23,7 @@ void plD_tidy_dg( PLStream * );
 void plD_state_dg( PLStream *, PLINT );
 void plD_esc_dg( PLStream *, PLINT, void * );
 
-/* top level declarations */
+// top level declarations
 
 #define  DGX    639
 #define  DGY    239
@@ -55,45 +55,46 @@ void plD_dispatch_init_dg( PLDispatchTable *pdt )
     pdt->pl_esc      = (plD_esc_fp) plD_esc_dg;
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_init_dg()
- *
- * Initialize device.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_init_dg()
+//
+// Initialize device.
+//--------------------------------------------------------------------------
 
 void
 plD_init_dg( PLStream *pls )
 {
-/* Request terminal configuration report */
+// Request terminal configuration report
 
     printf( "\n\036\107\051\n" );
     scanf( "%s", (char *) &termattr );
-    while ( getchar() != '\n' ) ;
+    while ( getchar() != '\n' )
+        ;
     if ( !strncmp( (char *) &termattr.ram[0], "0000", 4 ) )
     {
         printf( "Please wait while graphics interpreter is downloaded.\n" );
 
-        /* Need to download graphics interpreter. */
+        // Need to download graphics interpreter.
 
         system( "cat  /usr/local/src/g300/g300gci110.tx" );
     }
 
-/* Clear screen, Set pen color to green, Absolute positioning */
+// Clear screen, Set pen color to green, Absolute positioning
 
     printf( "\036\107\063\060\n\036\107\155\061\n\036\107\151\060\n" );
     printf( "\036\107\042\061\n" );
 
-    pls->termin = 1;            /* Is an interactive device */
+    pls->termin = 1;            // Is an interactive device
 
     plP_setpxl( (PLFLT) ( 3.316 * 16 ), (PLFLT) ( 1.655 * 16 ) );
     plP_setphy( 0, DGX * 16, 0, DGY * 16 );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_line_dg()
- *
- * Draw a line in the current color from (x1,y1) to (x2,y2).
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_line_dg()
+//
+// Draw a line in the current color from (x1,y1) to (x2,y2).
+//--------------------------------------------------------------------------
 
 void
 plD_line_dg( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
@@ -103,11 +104,11 @@ plD_line_dg( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
     printf( "LINE %d %d %d %d\n", x1 >> 4, y1 >> 3, x2 >> 4, y2 >> 3 );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_polyline_dg()
- *
- * Draw a polyline in the current color.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_polyline_dg()
+//
+// Draw a polyline in the current color.
+//--------------------------------------------------------------------------
 
 void
 plD_polyline_dg( PLStream *pls, short *xa, short *ya, PLINT npts )
@@ -118,26 +119,27 @@ plD_polyline_dg( PLStream *pls, short *xa, short *ya, PLINT npts )
         plD_line_dg( pls, xa[i], ya[i], xa[i + 1], ya[i + 1] );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_eop_dg()
- *
- * End of page.  User must hit a <CR> to continue.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_eop_dg()
+//
+// End of page.  User must hit a <CR> to continue.
+//--------------------------------------------------------------------------
 
 void
 plD_eop_dg( PLStream *pls )
 {
     putchar( '\007' );
     fflush( stdout );
-    while ( getchar() != '\n' ) ;
+    while ( getchar() != '\n' )
+        ;
     printf( "ERASE\n" );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_bop_dg()
- *
- * Set up for the next page.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_bop_dg()
+//
+// Set up for the next page.
+//--------------------------------------------------------------------------
 
 void
 plD_bop_dg( PLStream *pls )
@@ -145,11 +147,11 @@ plD_bop_dg( PLStream *pls )
     pls->page++;
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_tidy_dg()
- *
- * Close graphics file
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_tidy_dg()
+//
+// Close graphics file
+//--------------------------------------------------------------------------
 
 void
 plD_tidy_dg( PLStream *pls )
@@ -158,22 +160,22 @@ plD_tidy_dg( PLStream *pls )
     fflush( stdout );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_state_dg()
- *
- * Handle change in PLStream state (color, pen width, fill attribute, etc).
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_state_dg()
+//
+// Handle change in PLStream state (color, pen width, fill attribute, etc).
+//--------------------------------------------------------------------------
 
 void
 plD_state_dg( PLStream *pls, PLINT op )
 {
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_esc_dg()
- *
- * Escape function.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_esc_dg()
+//
+// Escape function.
+//--------------------------------------------------------------------------
 
 void
 plD_esc_dg( PLStream *pls, PLINT op, void *ptr )
@@ -187,4 +189,4 @@ pldummy_dg300()
     return 0;
 }
 
-#endif                          /* PLD_dg300 */
+#endif                          // PLD_dg300
