@@ -1,11 +1,11 @@
-/* $Id: ljii.c 11047 2010-06-01 08:49:36Z andrewross $
- *
- *      PLplot Laser Jet II device driver.
- *
- *      Note only the 150 dpi mode is supported.  The others (75,100,300)
- *      should work by just changing the value of DPI and changing the
- *      values passed to plP_setphy().
- */
+// $Id: ljii.c 11282 2010-10-28 16:26:09Z airwin $
+//
+//      PLplot Laser Jet II device driver.
+//
+//      Note only the 150 dpi mode is supported.  The others (75,100,300)
+//      should work by just changing the value of DPI and changing the
+//      values passed to plP_setphy().
+//
 #include "plDevs.h"
 
 #ifdef PLD_ljii
@@ -15,17 +15,17 @@
 #include <math.h>
 #include <string.h>
 
-#ifdef __GO32__                 /* dos386/djgpp */
+#ifdef __GO32__                 // dos386/djgpp
 #ifdef MSDOS
 #undef MSDOS
 #endif
 #endif
 
-/* Device info */
+// Device info
 PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_ljii =
     "ljii:LaserJet II Bitmap File (150 dpi):0:ljii:33:ljii\n";
 
-/* Function prototypes */
+// Function prototypes
 
 void plD_dispatch_init_ljii( PLDispatchTable *pdt );
 
@@ -40,21 +40,21 @@ void plD_esc_ljii( PLStream *, PLINT, void * );
 
 static void setpoint( PLINT, PLINT );
 
-/* top level declarations */
+// top level declarations
 
 #define JETX      1103
 #define JETY      1409
 
 #define OF        pls->OutFile
-#define DPI       150           /* Resolution Dots per Inch */
+#define DPI       150           // Resolution Dots per Inch
 #define CURX      51
 #define CURY      61
-#define XDOTS     1104L         /* # dots across */
-#define YDOTS     1410L         /* # dots down	 */
-#define BPROW     XDOTS / 8L    /* # bytes across */
-#define NBYTES    BPROW * YDOTS /* total number of bytes */
+#define XDOTS     1104L         // # dots across
+#define YDOTS     1410L         // # dots down
+#define BPROW     XDOTS / 8L    // # bytes across
+#define NBYTES    BPROW * YDOTS // total number of bytes
 
-/* Graphics control characters. */
+// Graphics control characters.
 
 #define ESC    0x1b
 #define FF     0x0c
@@ -68,7 +68,7 @@ static char mask[8] =
 #define _HUGE    _huge
 #endif
 
-static char _HUGE *bitmap;      /* points to memory area NBYTES in size */
+static char _HUGE *bitmap;      // points to memory area NBYTES in size
 
 void plD_dispatch_init_ljii( PLDispatchTable *pdt )
 {
@@ -88,26 +88,26 @@ void plD_dispatch_init_ljii( PLDispatchTable *pdt )
     pdt->pl_esc      = (plD_esc_fp) plD_esc_ljii;
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_init_ljii()
- *
- * Initialize device.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_init_ljii()
+//
+// Initialize device.
+//--------------------------------------------------------------------------
 
 void
 plD_init_ljii( PLStream *pls )
 {
     PLDev *dev;
 
-/* Initialize family file info */
+// Initialize family file info
 
     plFamInit( pls );
 
-/* Prompt for a file name if not already set */
+// Prompt for a file name if not already set
 
     plOpenFile( pls );
 
-/* Allocate and initialize device-specific data */
+// Allocate and initialize device-specific data
 
     dev = plAllocDev( pls );
 
@@ -118,7 +118,7 @@ plD_init_ljii( PLStream *pls )
 
     plP_setpxl( (PLFLT) 5.905, (PLFLT) 5.905 );
 
-/* Rotate by 90 degrees since portrait mode addressing is used */
+// Rotate by 90 degrees since portrait mode addressing is used
 
     dev->xmin = 0;
     dev->ymin = 0;
@@ -129,12 +129,12 @@ plD_init_ljii( PLStream *pls )
 
     plP_setphy( dev->xmin, dev->xmax, dev->ymin, dev->ymax );
 
-/* If portrait mode is specified, then set up an additional rotation
- * transformation with aspect ratio allowed to adjust via freeaspect.
- * Default orientation is landscape (ORIENTATION == 3 or 90 deg rotation
- * counter-clockwise from portrait).  (Legacy PLplot used seascape
- * which was equivalent to ORIENTATION == 1 or 90 deg clockwise rotation
- * from portrait.) */
+// If portrait mode is specified, then set up an additional rotation
+// transformation with aspect ratio allowed to adjust via freeaspect.
+// Default orientation is landscape (ORIENTATION == 3 or 90 deg rotation
+// counter-clockwise from portrait).  (Legacy PLplot used seascape
+// which was equivalent to ORIENTATION == 1 or 90 deg clockwise rotation
+// from portrait.)
 
     if ( pls->portrait )
     {
@@ -142,7 +142,7 @@ plD_init_ljii( PLStream *pls )
         pls->freeaspect = 1;
     }
 
-/* Allocate storage for bit map matrix */
+// Allocate storage for bit map matrix
 
 #ifdef MSDOS
     if ( ( bitmap = (char _HUGE *) halloc( (long) NBYTES, sizeof ( char ) ) ) == NULL )
@@ -152,16 +152,16 @@ plD_init_ljii( PLStream *pls )
         plexit( "Out of memory in call to calloc" );
 #endif
 
-/* Reset Printer */
+// Reset Printer
 
     fprintf( OF, "%cE", ESC );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_line_ljii()
- *
- * Draw a line in the current color from (x1,y1) to (x2,y2).
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_line_ljii()
+//
+// Draw a line in the current color from (x1,y1) to (x2,y2).
+//--------------------------------------------------------------------------
 
 void
 plD_line_ljii( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
@@ -172,12 +172,12 @@ plD_line_ljii( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
     PLINT x1b, y1b, x2b, y2b;
     PLFLT length, fx, fy, dx, dy;
 
-/* Take mirror image, since PCL expects (0,0) to be at top left */
+// Take mirror image, since PCL expects (0,0) to be at top left
 
     y1 = dev->ymax - ( y1 - dev->ymin );
     y2 = dev->ymax - ( y2 - dev->ymin );
 
-/* Rotate by 90 degrees */
+// Rotate by 90 degrees
 
     plRotPhy( ORIENTATION, dev->xmin, dev->ymin, dev->xmax, dev->ymax, &x1, &y1 );
     plRotPhy( ORIENTATION, dev->xmin, dev->ymin, dev->xmax, dev->ymax, &x2, &y2 );
@@ -200,11 +200,11 @@ plD_line_ljii( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
         setpoint( (PLINT) ( fx += dx ), (PLINT) ( fy += dy ) );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_polyline_ljii()
- *
- * Draw a polyline in the current color.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_polyline_ljii()
+//
+// Draw a polyline in the current color.
+//--------------------------------------------------------------------------
 
 void
 plD_polyline_ljii( PLStream *pls, short *xa, short *ya, PLINT npts )
@@ -215,28 +215,28 @@ plD_polyline_ljii( PLStream *pls, short *xa, short *ya, PLINT npts )
         plD_line_ljii( pls, xa[i], ya[i], xa[i + 1], ya[i + 1] );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_eop_ljii()
- *
- * End of page.(prints it here).
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_eop_ljii()
+//
+// End of page.(prints it here).
+//--------------------------------------------------------------------------
 
 void
 plD_eop_ljii( PLStream *pls )
 {
     PLINT i, j;
 
-/* First move cursor to origin */
+// First move cursor to origin
 
     fprintf( OF, "%c*p%dX", ESC, CURX );
     fprintf( OF, "%c*p%dY", ESC, CURY );
 
-/* Then put Laser Printer in 150 dpi mode */
+// Then put Laser Printer in 150 dpi mode
 
     fprintf( OF, "%c*t%dR", ESC, DPI );
     fprintf( OF, "%c*r1A", ESC );
 
-/* Write out raster data */
+// Write out raster data
 
     for ( j = 0; j < YDOTS; j++ )
     {
@@ -246,22 +246,22 @@ plD_eop_ljii( PLStream *pls )
     }
     pls->bytecnt += NBYTES;
 
-/* End raster graphics and send Form Feed */
+// End raster graphics and send Form Feed
 
     fprintf( OF, "%c*rB", ESC );
     fprintf( OF, "%c", FF );
 
-/* Finally, clear out bitmap storage area */
+// Finally, clear out bitmap storage area
 
     memset( bitmap, '\0', NBYTES );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_bop_ljii()
- *
- * Set up for the next page.
- * Advance to next family file if necessary (file output).
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_bop_ljii()
+//
+// Set up for the next page.
+// Advance to next family file if necessary (file output).
+//--------------------------------------------------------------------------
 
 void
 plD_bop_ljii( PLStream *pls )
@@ -272,49 +272,49 @@ plD_bop_ljii( PLStream *pls )
     pls->page++;
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_tidy_ljii()
- *
- * Close graphics file or otherwise clean up.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_tidy_ljii()
+//
+// Close graphics file or otherwise clean up.
+//--------------------------------------------------------------------------
 
 void
 plD_tidy_ljii( PLStream *pls )
 {
-/* Reset Printer */
+// Reset Printer
 
     fprintf( OF, "%cE", ESC );
     plCloseFile( pls );
     free( (void *) bitmap );
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_state_ljii()
- *
- * Handle change in PLStream state (color, pen width, fill attribute, etc).
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_state_ljii()
+//
+// Handle change in PLStream state (color, pen width, fill attribute, etc).
+//--------------------------------------------------------------------------
 
 void
 plD_state_ljii( PLStream *pls, PLINT op )
 {
 }
 
-/*--------------------------------------------------------------------------*\
- * plD_esc_ljii()
- *
- * Escape function.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// plD_esc_ljii()
+//
+// Escape function.
+//--------------------------------------------------------------------------
 
 void
 plD_esc_ljii( PLStream *pls, PLINT op, void *ptr )
 {
 }
 
-/*--------------------------------------------------------------------------*\
- * setpoint()
- *
- * Sets a bit in the bitmap.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// setpoint()
+//
+// Sets a bit in the bitmap.
+//--------------------------------------------------------------------------
 
 static void
 setpoint( PLINT x, PLINT y )
@@ -331,4 +331,4 @@ pldummy_ljii()
     return 0;
 }
 
-#endif                          /* PLD_ljii */
+#endif                          // PLD_ljii
