@@ -1,5 +1,5 @@
 //
-// $Id: mem.c 11282 2010-10-28 16:26:09Z airwin $
+// $Id: mem.c 12008 2011-10-28 12:50:46Z andrewross $
 //
 // PLplot MEM (in user-supplied memory) device driver.
 // The idea here is that the user will specify the Y by X by RGB
@@ -161,25 +161,25 @@ plD_eop_mem( PLStream *pls )
 }
 
 void
-plD_bop_mem( PLStream *pls )
+plD_bop_mem( PLStream * PL_UNUSED( pls ) )
 {
 // Nothing to do here
 }
 
 void
-plD_tidy_mem( PLStream *pls )
+plD_tidy_mem( PLStream * PL_UNUSED( pls ) )
 {
 // Nothing to do here
 }
 
 void
-plD_state_mem( PLStream *pls, PLINT op )
+plD_state_mem( PLStream * PL_UNUSED( pls ), PLINT PL_UNUSED( op ) )
 {
 // Nothing to do here
 }
 
 void
-plD_esc_mem( PLStream *pls, PLINT op, void *ptr )
+plD_esc_mem( PLStream *PL_UNUSED( pls ), PLINT PL_UNUSED( op ), void * PL_UNUSED( ptr ) )
 {
 // Nothing to do here
 }
