@@ -1,4 +1,4 @@
-// $Id: ntk.c 11282 2010-10-28 16:26:09Z airwin $
+// $Id: ntk.c 12932 2014-01-12 02:18:40Z airwin $
 //
 // Experimental tk driver using a plain "wish"
 //
@@ -77,10 +77,14 @@ static Tcl_Interp *interp = NULL; // tcl interpreter
 static Tk_Window  mainw;          // tk main window
 
 static char       curcolor[80];   // current color in #rrggbb notation
-static char       cmd[10000];     // buffer to build command to interp
-static int        ccanv = 0;      // current canvas number
-static char       base[80];       // name of frame that contains the canvas
-static char       dash[80];       // dash string, as <mark space>*
+
+// 12000 is large enough to satisfy example 27 needs without
+// erroring out in plD_polyline_ntk.  Quadruple that to be conservative.
+#define PLPLOT_NTK_CMD_SIZE    48000
+static char cmd[PLPLOT_NTK_CMD_SIZE]; // buffer to build command to interp
+static int  ccanv = 0;                // current canvas number
+static char base[80];                 // name of frame that contains the canvas
+static char dash[80];                 // dash string, as <mark space>*
 
 // line buffering
 #define NPTS    1000
@@ -101,35 +105,38 @@ static PLINT ymax = YPIXELS;
 static PLGraphicsIn gin;
 
 static void
-tk_cmd( char *cmd )
+tk_cmd( const char *gcmd )
 {
-    static char scmd[10000];
+    static char scmd[PLPLOT_NTK_CMD_SIZE];
 
     if ( local )
-        Tcl_Eval( interp, cmd );
+        Tcl_Eval( interp, gcmd );
     else
     {
         // the -async option makes it block, some times! but is *much* faster!
         // and was working OK till now :(
         // sprintf(scmd, "send -async %s {%s}", rem_interp, cmd);
         //
-        sprintf( scmd, "send %s {%s}", rem_interp, cmd ); // mess! make it more efficient
+        sprintf( scmd, "send %s {%s}", rem_interp, gcmd ); // mess! make it more efficient
         if ( Tcl_Eval( interp, scmd ) != TCL_OK )
-            fprintf( stderr, "%s\n", interp->result );
+            fprintf( stderr, "%s\n", Tcl_GetStringResult( interp ) );
     }
 }
 
 static void
 create_canvas( PLStream *pls )
 {
+    int columnbreak;
+
     ccanv++;
+    columnbreak = ( ccanv % 30 == 0 );
 
     // create new canvas
     sprintf( cmd, "set ccanv %d; canvas $plf.f2.c$ccanv -width $xmax -height $ymax -background #%02x%02x%02x -xscrollcommand \"$hs set\" -yscrollcommand \"$vs set\" -scrollregion \"0 0 $xmax $ymax\"", ccanv, pls->cmap0[0].r, pls->cmap0[0].g, pls->cmap0[0].b );
     tk_cmd( cmd );
 
     // add new canvas to option menu
-    sprintf( cmd, "$plf.f1.mb.menu add command -label \"Page $ccanv\" -command {\n"
+    sprintf( cmd, "$plf.f1.mb.menu add command -label \"Page $ccanv\" -columnbreak %d -command {\n"
         "set w $plf.f2.c%d;\n"
         "$hs configure -command \"$w xview\";\n"
         "$vs configure -command \"$w yview\";\n"
@@ -141,7 +148,7 @@ create_canvas( PLStream *pls )
         "$hs set $i $j;\n"
         "scan [$w yview] \"%%f %%f\" i j;\n"
         "$vs set $i $j;}",
-        ccanv, ccanv, ccanv );
+        columnbreak, ccanv, ccanv, ccanv );
     tk_cmd( cmd );
 
     sprintf( cmd, "set item(%d) 0", ccanv );
@@ -239,10 +246,10 @@ plD_init_ntk( PLStream *pls )
     if ( pls->geometry != NULL )
         sscanf( pls->geometry, "%dx%d", &xmax, &ymax );
 
-    if ( pls->plwindow != NULL )
-        strcpy( base, pls->plwindow );
-    else
-        strcpy( base, ".plf" ); // default frame containing the canvas
+//  if ( pls->plwindow != NULL )
+//        strcpy( base, pls->plwindow );
+//    else
+    strcpy( base, ".plf" );     // default frame containing the canvas
 
     interp = Tcl_CreateInterp();
 
@@ -264,7 +271,7 @@ plD_init_ntk( PLStream *pls )
         sprintf( cmd, "send %s \"set client [tk appname]; wm deiconify .\"", rem_interp );
         if ( Tcl_Eval( interp, cmd ) != TCL_OK )
         {
-            fprintf( stderr, "%s\n", interp->result );
+            fprintf( stderr, "%s\n", Tcl_GetStringResult( interp ) );
             plexit( "No such tk server." );
         }
     }
@@ -301,9 +308,11 @@ plD_init_ntk( PLStream *pls )
     // Set up device parameters
 
     Tcl_Eval( interp, "tk scaling" ); // pixels per mm
-    ppm = (PLFLT) atof( interp->result ) / ( 25.4 / 72. );
+    ppm = (PLFLT) atof( Tcl_GetStringResult( interp ) ) / ( 25.4 / 72. );
     plP_setpxl( ppm, ppm );
-    plP_setphy( xmin, xmax * scale, ymin, ymax * scale );
+    plP_setphy( xmin, (PLINT) ( xmax * scale ), ymin, (PLINT) ( ymax * scale ) );
+
+    tk_cmd( "update" );
 }
 
 static void
@@ -333,21 +342,27 @@ plD_line_ntk( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
 
     if ( curpts == NPTS )
     {
-        fprintf( stderr, "\nflush: %d ", curpts );
+        //fprintf( stderr, "\nflush: %d ", curpts );
         flushbuffer( pls );
     }
 }
 
 void
-plD_polyline_ntk( PLStream *pls, short *xa, short *ya, PLINT npts )
+plD_polyline_ntk( PLStream * PL_UNUSED( pls ), short *xa, short *ya, PLINT npts )
 {
     PLINT i, j;
 
     // there must exist a way to code this using the tk C API
     j = sprintf( cmd, "$plf.f2.c%d create line ", ccanv );
     for ( i = 0; i < npts; i++ )
+    {
+        // To be completely safe, assume 5 characters to the left of the
+        // decimal point ==> 2*(5+3) characters written per sprintf
+        // call.
+        if ( ( j + 16 ) > PLPLOT_NTK_CMD_SIZE )
+            plexit( "plD_polyline_ntk: too many x, y values to hold in static cmd array" );
         j += sprintf( &cmd[j], "%.1f %.1f ", xa[i] / scale, ymax - ya[i] / scale );
-
+    }
     j += sprintf( &cmd[j], " -fill %s", curcolor );
     if ( dash[0] == '-' )
         j += sprintf( &cmd[j], " %s", dash );
@@ -358,7 +373,7 @@ plD_polyline_ntk( PLStream *pls, short *xa, short *ya, PLINT npts )
 // an event loop has to be designed, getcursor() and waitforpage() are just experimental
 
 static void
-waitforpage( PLStream *pls )
+waitforpage( PLStream * PL_UNUSED( pls ) )
 {
     int key = 0, st = 0;
     // why can't I bind to the canvas? or even any frame?
@@ -371,11 +386,11 @@ waitforpage( PLStream *pls )
         {
             tk_cmd( "update" );
             tk_cmd( "info exists keypress" );
-            sscanf( interp->result, "%d", &st );
+            sscanf( Tcl_GetStringResult( interp ), "%d", &st );
         }
 
         tk_cmd( "set keypress" );
-        sscanf( interp->result, "%d", &key );
+        sscanf( Tcl_GetStringResult( interp ), "%d", &key );
 //fprintf(stderr,"\n%d\n", key);fflush(stderr);
         tk_cmd( "unset keypress" );
         st = 0;
@@ -421,7 +436,7 @@ plD_state_ntk( PLStream *pls, PLINT op )
 }
 
 static void
-getcursor( PLStream *pls, PLGraphicsIn *ptr )
+getcursor( PLStream * PL_UNUSED( pls ), PLGraphicsIn *ptr )
 {
     int st = 0;
 
@@ -433,7 +448,7 @@ getcursor( PLStream *pls, PLGraphicsIn *ptr )
         {
             tk_cmd( "update" );
             tk_cmd( "winfo exists $plf.f2.c$ccanv" );
-            sscanf( interp->result, "%d", &st );
+            sscanf( Tcl_GetStringResult( interp ), "%d", &st );
         }
         st = 0;
         // this give a "Segmentation fault", even after checking for the canvas!
@@ -450,16 +465,16 @@ getcursor( PLStream *pls, PLGraphicsIn *ptr )
     {
         tk_cmd( "update" );
         tk_cmd( "info exists xloc" );
-        sscanf( interp->result, "%d", &st );
+        sscanf( Tcl_GetStringResult( interp ), "%d", &st );
     }
     tk_cmd( "set xloc" );
-    sscanf( interp->result, "%d", &gin.pX );
+    sscanf( Tcl_GetStringResult( interp ), "%d", &gin.pX );
     tk_cmd( "set yloc" );
-    sscanf( interp->result, "%d", &gin.pY );
+    sscanf( Tcl_GetStringResult( interp ), "%d", &gin.pY );
     tk_cmd( "set bloc" );
-    sscanf( interp->result, "%d", &gin.button );
+    sscanf( Tcl_GetStringResult( interp ), "%ud", &gin.button );
     tk_cmd( "set sloc" );
-    sscanf( interp->result, "%d", &gin.state );
+    sscanf( Tcl_GetStringResult( interp ), "%ud", &gin.state );
 
     gin.dX = (PLFLT) gin.pX / xmax;
     gin.dY = 1. - (PLFLT) gin.pY / ymax;
@@ -479,10 +494,10 @@ getcursor( PLStream *pls, PLGraphicsIn *ptr )
 void
 plD_esc_ntk( PLStream *pls, PLINT op, void *ptr )
 {
-    PLINT  i, j;
-    short                *xa, *ya;
-    Pixmap bitmap;
-    static unsigned char bit_pat[] = {
+    PLINT i, j;
+    short *xa, *ya;
+    //Pixmap bitmap;
+    static const unsigned char bit_pat[] = {
         0x24, 0x01, 0x92, 0x00, 0x49, 0x00, 0x24, 0x00, 0x12, 0x00, 0x09, 0x00,
         0x04, 0x00, 0x02, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
         0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff
@@ -491,8 +506,8 @@ plD_esc_ntk( PLStream *pls, PLINT op, void *ptr )
     switch ( op )
     {
     case PLESC_DASH:
-        xa = (short *) malloc( sizeof ( short ) * pls->dev_npts );
-        ya = (short *) malloc( sizeof ( short ) * pls->dev_npts );
+        xa = (short *) malloc( sizeof ( short ) * (size_t) pls->dev_npts );
+        ya = (short *) malloc( sizeof ( short ) * (size_t) pls->dev_npts );
         for ( i = 0; i < pls->dev_npts; i++ )
         {
             xa[i] = pls->dev_x[i];
@@ -521,7 +536,7 @@ plD_esc_ntk( PLStream *pls, PLINT op, void *ptr )
     case PLESC_FILL:
         if ( pls->patt != 0 )
         {
-            // this is a hack! The real solution is in the if(0) bellow
+            // this is a hack! The real solution is in the if(0) below
             pls->xpmm *= scale;
             pls->ypmm *= scale;
             plfill_soft( pls->dev_x, pls->dev_y, pls->dev_npts );
@@ -542,8 +557,8 @@ plD_esc_ntk( PLStream *pls, PLINT op, void *ptr )
         {
             if ( pls->patt != 0 )
             {
-                Tk_DefineBitmap( interp, Tk_GetUid( "foo" ), bit_pat, 16, 16 );
-                bitmap = Tk_GetBitmap( interp, mainw, Tk_GetUid( "patt" ) );
+                Tk_DefineBitmap( interp, Tk_GetUid( "foo" ), (const char *) bit_pat, 16, 16 );
+                //bitmap = Tk_GetBitmap( interp, mainw, Tk_GetUid( "patt" ) );
             }
             j = sprintf( cmd, "$plf.f2.c%d create polygon ", ccanv );
             for ( i = 0; i < pls->dev_npts; i++ )
