@@ -1,4 +1,4 @@
-// $Id: psttf.cc 11795 2011-07-06 02:28:50Z airwin $
+// $Id: psttf.cc 12874 2013-12-17 05:32:16Z airwin $
 //
 //        PLplot PostScript device driver using LASi to provide fonts
 //        based on original ps.c PostScript driver
@@ -31,11 +31,9 @@
 
 #include "plDevs.h"
 
-#define DEBUG
-
 #if defined ( PLD_psttf )
 
-#define NEED_PLDEBUG
+//#define NEED_PLDEBUG
 #include "plplotP.h"
 #include "drivers.h"
 #include "ps.h"
@@ -70,7 +68,7 @@ static char  *ps_getdate( void );
 static void  ps_init( PLStream * );
 static void  fill_polygon( PLStream *pls );
 static void  proc_str( PLStream *, EscText * );
-static void  esc_purge( char *, char * );
+//static void  esc_purge( char *, char * );
 
 #define OUTBUF_LEN    128
 static char outbuf[OUTBUF_LEN];
@@ -127,8 +125,11 @@ static void psttf_dispatch_init_helper( PLDispatchTable *pdt,
                                         int type, int seq, plD_init_fp init )
 {
 #ifndef ENABLE_DYNDRIVERS
-    pdt->pl_MenuStr = menustr;
-    pdt->pl_DevName = devnam;
+    pdt->pl_MenuStr = (char *) menustr;
+    pdt->pl_DevName = (char *) devnam;
+#else
+    (void) menustr;   // Cast to void to silence compiler warnings about unused parameters
+    (void) devnam;
 #endif
     pdt->pl_type     = type;
     pdt->pl_seq      = seq;
@@ -318,7 +319,7 @@ writeHeader( PLStream *pls )
     doc->osHeader() << "%%%%%%%%%%%%%%%%%%%%%%%%%%%\n";
 
     doc->osHeader() << "%%Title: PLplot Graph\n";
-    doc->osHeader() << "%%Creator: PLplot Version " << VERSION << "\n";
+    doc->osHeader() << "%%Creator: PLplot Version " << PLPLOT_VERSION << "\n";
     doc->osHeader() << "%%CreationDate: " << ps_getdate() << "\n";
     doc->osHeader() << "%%Pages: (atend)\n";
     doc->osHeader() << "%%EndComments\n\n";
@@ -450,7 +451,7 @@ writeHeader( PLStream *pls )
 
     doc->osHeader() << "PSDict begin\n";
     doc->osHeader() << "@start\n";
-    doc->osHeader() << "%d @copies\n", COPIES;
+    doc->osHeader() << COPIES << " @copies\n";
     doc->osHeader() << "@line\n";
     doc->osHeader() << YSIZE << " @hsize\n";
     doc->osHeader() << XSIZE << " @vsize\n";
@@ -669,9 +670,9 @@ plD_state_psttf( PLStream *pls, PLINT op )
     switch ( op )
     {
     case PLSTATE_WIDTH: {
-        int width =
+        int width = (int) (
             ( pls->width < MIN_WIDTH ) ? DEF_WIDTH :
-            ( pls->width > MAX_WIDTH ) ? MAX_WIDTH : pls->width;
+            ( pls->width > MAX_WIDTH ) ? MAX_WIDTH : pls->width );
 
         doc->osBody() << " S\n" << width << " W";
 
@@ -847,23 +848,20 @@ proc_str( PLStream *pls, EscText *args )
     // Be generous.  Used to store lots of font changes which take
     // 3 characters per change.
   #define PROC_STR_STRING_LENGTH    1000
-    char    *strp, str[PROC_STR_STRING_LENGTH], *cur_strp,
-             cur_str[PROC_STR_STRING_LENGTH];
-    float   font_factor = 1.4;
-    PLINT   clxmin, clxmax, clymin, clymax; // Clip limits
-    PLINT   clipx[4], clipy[4];             // Current clip limits
+    char   *strp, str[PROC_STR_STRING_LENGTH], *cur_strp,
+            cur_str[PROC_STR_STRING_LENGTH];
+    float  font_factor = 1.4;
+    PLINT  clxmin, clxmax, clymin, clymax;  // Clip limits
+    PLINT  clipx[4], clipy[4];              // Current clip limits
 
-    PLFLT   scale = 1., up = 0.;            // Font scaling and shifting parameters
+    PLFLT  scale = 1., up = 0.;             // Font scaling and shifting parameters
 
-    double  lineSpacing, xAdvance, ymintmp, ymaxtmp, ymin, ymax, xmin, xmax;
-    PLINT   xx[4], yy[4];
-
-    FT_Data *FT;
+    double lineSpacing, xAdvance, ymintmp, ymaxtmp, ymin, ymax, xmin, xmax;
+    PLINT  xx[4], yy[4];
 
     // unicode only! so test for it.
     if ( args->unicode_array_len > 0 )
     {
-        FT = (FT_Data *) pls->FT;
         int             j, s, f;
         char            *fonts[PROC_STR_STRING_LENGTH];
         FontStyle       styles[PROC_STR_STRING_LENGTH];
@@ -1274,43 +1272,43 @@ proc_str( PLStream *pls, EscText *args )
     }
 }
 
-static void
-esc_purge( char *dstr, char *sstr )
-{
-    char esc;
-
-    plgesc( &esc );
-
-    while ( *sstr )
-    {
-        if ( *sstr != esc )
-        {
-            *dstr++ = *sstr++;
-            continue;
-        }
-
-        sstr++;
-        if ( *sstr == esc )
-        {
-            *dstr++ = *sstr++;
-            continue;
-        }
-
-        else
-        {
-            switch ( *sstr++ )
-            {
-            case 'f':
-                sstr++;
-                break; // two chars sequence
-
-            default:
-                break; // single char escape
-            }
-        }
-    }
-    *dstr = '\0';
-}
+//static void
+//esc_purge( char *dstr, char *sstr )
+//{
+//    char esc;
+//
+//    plgesc( &esc );
+//
+//    while ( *sstr )
+//    {
+//        if ( *sstr != esc )
+//        {
+//            *dstr++ = *sstr++;
+//            continue;
+//        }
+//
+//        sstr++;
+//        if ( *sstr == esc )
+//        {
+//            *dstr++ = *sstr++;
+//            continue;
+//        }
+//
+//        else
+//        {
+//            switch ( *sstr++ )
+//            {
+//            case 'f':
+//                sstr++;
+//                break; // two chars sequence
+//
+//            default:
+//                break; // single char escape
+//            }
+//        }
+//    }
+//    *dstr = '\0';
+//}
 
 #else
 int
