@@ -1,4 +1,4 @@
-// $Id: tk.c 11760 2011-06-01 19:29:11Z airwin $
+// $Id: tk.c 12965 2014-01-28 20:23:52Z arjenmarkus $
 //
 //	PLplot Tcl/Tk and Tcl-DP device drivers.
 //	Should be broken up somewhat better to allow use of DP w/o X.
@@ -39,12 +39,12 @@
 
 #define NEED_PLDEBUG
 #include "pltkd.h"
-#include "plxwd.h"
 #include "pltcl.h"
 #include "tcpip.h"
 #include "drivers.h"
 #include "metadefs.h"
 #include "plevent.h"
+#include <X11/keysym.h>
 
 #if PL_HAVE_UNISTD_H
 # include <unistd.h>
@@ -102,6 +102,7 @@ void plD_bop_tk( PLStream * );
 void plD_tidy_tk( PLStream * );
 void plD_state_tk( PLStream *, PLINT );
 void plD_esc_tk( PLStream *, PLINT, void * );
+void plD_init_dp( PLStream *pls );
 
 // various
 
@@ -128,11 +129,11 @@ static int   pltkdriver_Init( PLStream *pls );
 
 // Tcl/TK utility commands
 
-static void  tk_wait( PLStream *pls, char * );
-static void  abort_session( PLStream *pls, char * );
-static void  server_cmd( PLStream *pls, char *, int );
-static void  tcl_cmd( PLStream *pls, char * );
-static void  copybuf( PLStream *pls, char *cmd );
+static void  tk_wait( PLStream *pls, const char * );
+static void  abort_session( PLStream *pls, const char * );
+static void  server_cmd( PLStream *pls, const char *, int );
+static void  tcl_cmd( PLStream *pls, const char * );
+static void  copybuf( PLStream *pls, const char *cmd );
 static int   pltk_toplevel( Tk_Window *w, Tcl_Interp *interp );
 
 static void  ProcessKey( PLStream *pls );
@@ -206,7 +207,7 @@ plD_init_dp( PLStream *pls )
 }
 
 static void
-tk_wr_header( PLStream *pls, char *header )
+tk_wr_header( PLStream *pls, const char *header )
 {
     tk_wr( pdf_wr_header( pls->pdfs, header ) );
 }
@@ -267,7 +268,7 @@ init( PLStream *pls )
     if ( dev->iodev == NULL )
         plexit( "plD_init_tk: Out of memory." );
 
-    dev->exit_eventloop = 0;
+    dev->exit_eventloop = FALSE;
 
 // Variables used in querying plserver for events
 
@@ -347,8 +348,8 @@ plD_line_tk( PLStream *pls, short x1, short y1, short x2, short y2 )
         c = (U_CHAR) LINETO;
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
 
-        xy[0] = x2;
-        xy[1] = y2;
+        xy[0] = (U_SHORT) x2;
+        xy[1] = (U_SHORT) y2;
         tk_wr( pdf_wr_2nbytes( pls->pdfs, xy, 2 ) );
     }
     else
@@ -356,16 +357,16 @@ plD_line_tk( PLStream *pls, short x1, short y1, short x2, short y2 )
         c = (U_CHAR) LINE;
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
 
-        xy[0] = x1;
-        xy[1] = y1;
-        xy[2] = x2;
-        xy[3] = y2;
+        xy[0] = (U_SHORT) x1;
+        xy[1] = (U_SHORT) y1;
+        xy[2] = (U_SHORT) x2;
+        xy[3] = (U_SHORT) y2;
         tk_wr( pdf_wr_2nbytes( pls->pdfs, xy, 4 ) );
     }
     dev->xold = x2;
     dev->yold = y2;
 
-    if ( pls->pdfs->bp > pls->bufmax )
+    if ( pls->pdfs->bp > (size_t) pls->bufmax )
         flush_output( pls );
 }
 
@@ -392,7 +393,7 @@ plD_polyline_tk( PLStream *pls, short *xa, short *ya, PLINT npts )
     dev->xold = xa[npts - 1];
     dev->yold = ya[npts - 1];
 
-    if ( pls->pdfs->bp > pls->bufmax )
+    if ( pls->pdfs->bp > (size_t) pls->bufmax )
         flush_output( pls );
 }
 
@@ -468,7 +469,7 @@ plD_state_tk( PLStream *pls, PLINT op )
     dbug_enter( "plD_state_tk" );
 
     tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
-    tk_wr( pdf_wr_1byte( pls->pdfs, op ) );
+    tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) op ) );
 
     switch ( op )
     {
@@ -477,7 +478,7 @@ plD_state_tk( PLStream *pls, PLINT op )
         break;
 
     case PLSTATE_COLOR0:
-        tk_wr( pdf_wr_2bytes( pls->pdfs, (short) pls->icol0 ) );
+        tk_wr( pdf_wr_2bytes( pls->pdfs, (U_SHORT) pls->icol0 ) );
 
         if ( pls->icol0 == PL_RGB_COLOR )
         {
@@ -517,15 +518,15 @@ plD_state_tk( PLStream *pls, PLINT op )
         tk_wr( pdf_wr_2bytes( pls->pdfs, (U_SHORT) pls->ncp1 ) );
         for ( i = 0; i < pls->ncp1; i++ )
         {
-            tk_wr( pdf_wr_ieeef( pls->pdfs, pls->cmap1cp[i].h ) );
-            tk_wr( pdf_wr_ieeef( pls->pdfs, pls->cmap1cp[i].l ) );
-            tk_wr( pdf_wr_ieeef( pls->pdfs, pls->cmap1cp[i].s ) );
-            tk_wr( pdf_wr_1byte( pls->pdfs, pls->cmap1cp[i].rev ) );
+            tk_wr( pdf_wr_ieeef( pls->pdfs, (float) pls->cmap1cp[i].h ) );
+            tk_wr( pdf_wr_ieeef( pls->pdfs, (float) pls->cmap1cp[i].l ) );
+            tk_wr( pdf_wr_ieeef( pls->pdfs, (float) pls->cmap1cp[i].s ) );
+            tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) pls->cmap1cp[i].alt_hue_path ) );
         }
         break;
     }
 
-    if ( pls->pdfs->bp > pls->bufmax )
+    if ( pls->pdfs->bp > (size_t) pls->bufmax )
         flush_output( pls );
 }
 
@@ -556,25 +557,25 @@ plD_esc_tk( PLStream *pls, PLINT op, void *ptr )
     {
     case PLESC_DI:
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
-        tk_wr( pdf_wr_1byte( pls->pdfs, op ) );
+        tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) op ) );
         tk_di( pls );
         break;
 
     case PLESC_EH:
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
-        tk_wr( pdf_wr_1byte( pls->pdfs, op ) );
+        tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) op ) );
         HandleEvents( pls );
         break;
 
     case PLESC_FLUSH:
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
-        tk_wr( pdf_wr_1byte( pls->pdfs, op ) );
+        tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) op ) );
         flush_output( pls );
         break;
 
     case PLESC_FILL:
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
-        tk_wr( pdf_wr_1byte( pls->pdfs, op ) );
+        tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) op ) );
         tk_fill( pls );
         break;
 
@@ -588,7 +589,7 @@ plD_esc_tk( PLStream *pls, PLINT op, void *ptr )
 
     default:
         tk_wr( pdf_wr_1byte( pls->pdfs, c ) );
-        tk_wr( pdf_wr_1byte( pls->pdfs, op ) );
+        tk_wr( pdf_wr_1byte( pls->pdfs, (U_CHAR) op ) );
     }
 }
 
@@ -764,7 +765,7 @@ tk_start( PLStream *pls )
 
     if ( Tcl_Init( dev->interp ) != TCL_OK )
     {
-        fprintf( stderr, "%s\n", dev->interp->result );
+        fprintf( stderr, "%s\n", Tcl_GetStringResult( dev->interp ) );
         abort_session( pls, "Unable to initialize Tcl" );
     }
 
@@ -901,7 +902,7 @@ tk_stop( PLStream *pls )
 //--------------------------------------------------------------------------
 
 static void
-abort_session( PLStream *pls, char *msg )
+abort_session( PLStream *pls, const char *msg )
 {
     TkDev *dev = (TkDev *) pls->dev;
 
@@ -1134,9 +1135,11 @@ init_server( PLStream *pls )
 static void
 launch_server( PLStream *pls )
 {
-    TkDev *dev = (TkDev *) pls->dev;
-    char  * argv[20], *plserver_exec = NULL, *ptr, *tmp = NULL;
-    int   i;
+    TkDev      *dev = (TkDev *) pls->dev;
+    const char *argv[20];
+    char       *plserver_exec = NULL, *ptr;
+    char       *tmp           = NULL;
+    int        i;
 
     dbug_enter( "launch_server" );
 
@@ -1196,7 +1199,7 @@ launch_server( PLStream *pls )
 
     if ( pls->plwindow != NULL )
     {
-        char *t, *tmp;
+        char *t;
         argv[i++] = "-name";                       // plserver name
         tmp       = plstrdup( pls->plwindow + 1 ); // get rid of the initial dot
         argv[i++] = tmp;
@@ -1206,7 +1209,7 @@ launch_server( PLStream *pls )
     else
     {
         argv[i++] = "-name";            // plserver name
-        argv[i++] = (char *) pls->program;
+        argv[i++] = pls->program;
     }
 
     if ( pls->auto_path != NULL )
@@ -1227,10 +1230,10 @@ launch_server( PLStream *pls )
     if ( pls->dp )
     {
         argv[i++] = "-client_host";
-        argv[i++] = (char *) Tcl_GetVar( dev->interp, "client_host", TCL_GLOBAL_ONLY );
+        argv[i++] = Tcl_GetVar( dev->interp, "client_host", TCL_GLOBAL_ONLY );
 
         argv[i++] = "-client_port";
-        argv[i++] = (char *) Tcl_GetVar( dev->interp, "client_port", TCL_GLOBAL_ONLY );
+        argv[i++] = Tcl_GetVar( dev->interp, "client_port", TCL_GLOBAL_ONLY );
 
         if ( pls->user != NULL )
         {
@@ -1241,7 +1244,7 @@ launch_server( PLStream *pls )
     else
     {
         argv[i++] = "-client_name";
-        argv[i++] = (char *) Tcl_GetVar( dev->interp, "client_name", TCL_GLOBAL_ONLY );
+        argv[i++] = Tcl_GetVar( dev->interp, "client_name", TCL_GLOBAL_ONLY );
     }
 
 // The display absolutely must be set if invoking a remote server (by rsh)
@@ -1280,7 +1283,7 @@ launch_server( PLStream *pls )
 
     if ( pls->dp && pls->server_host != NULL )
     {
-        if ( ( dev->child_pid = vfork() ) < 0 )
+        if ( ( dev->child_pid = fork() ) < 0 )
         {
             abort_session( pls, "Unable to fork server process" );
         }
@@ -1289,7 +1292,7 @@ launch_server( PLStream *pls )
             fprintf( stderr, "Starting up %s on node %s\n", pls->plserver,
                 pls->server_host );
 
-            if ( execvp( "rsh", argv ) )
+            if ( execvp( "rsh", (char * const *) argv ) )
             {
                 perror( "Unable to exec server process" );
                 _exit( 1 );
@@ -1302,7 +1305,7 @@ launch_server( PLStream *pls )
     else
     {
         plserver_exec = plFindCommand( pls->plserver );
-        if ( ( plserver_exec == NULL ) || ( dev->child_pid = vfork() ) < 0 )
+        if ( ( plserver_exec == NULL ) || ( dev->child_pid = fork() ) < 0 )
         {
             abort_session( pls, "Unable to fork server process" );
         }
@@ -1320,7 +1323,7 @@ launch_server( PLStream *pls )
             }
 
             pldebug( "launch_server", "Starting up %s\n", plserver_exec );
-            if ( execv( plserver_exec, argv ) )
+            if ( execv( plserver_exec, (char * const *) argv ) )
             {
                 fprintf( stderr, "Unable to exec server process.\n" );
                 _exit( 1 );
@@ -1383,8 +1386,8 @@ plwindow_init( PLStream *pls )
     // and with ' ' replaced by '_' and all other '.' by '_' to avoid
     // quoting and bad window name problems. Also avoid name starting with
     // an upper case letter.
-    n   = strlen( pls->plwindow ) + 1;
-    tmp = (char *) malloc( sizeof ( char ) * ( n + 1 ) );
+    n   = (int) strlen( pls->plwindow ) + 1;
+    tmp = (char *) malloc( sizeof ( char ) * (size_t) ( n + 1 ) );
     sprintf( tmp, ".%s", pls->plwindow );
     for ( i = 1; i < n; i++ )
     {
@@ -1409,7 +1412,7 @@ plwindow_init( PLStream *pls )
 // Configure background color if anything other than black
 // The default color is handled from a resource setting in plconfig.tcl
 
-    bg = pls->cmap0[0].b | ( pls->cmap0[0].g << 8 ) | ( pls->cmap0[0].r << 16 );
+    bg = (unsigned int) ( pls->cmap0[0].b | ( pls->cmap0[0].g << 8 ) | ( pls->cmap0[0].r << 16 ) );
     if ( bg > 0 )
     {
         snprintf( command, CMD_LEN, "$plwidget configure -plbg #%06x", bg );
@@ -1461,7 +1464,8 @@ static void
 set_windowname( PLStream *pls )
 {
     const char *pname;
-    int        i, maxlen;
+    int        i;
+    size_t     maxlen;
 
     // Set to "plclient" if not initialized via plargs or otherwise
 
@@ -1514,9 +1518,10 @@ set_windowname( PLStream *pls )
 static void
 link_init( PLStream *pls )
 {
-    TkDev   *dev   = (TkDev *) pls->dev;
-    PLiodev *iodev = (PLiodev *) dev->iodev;
-    long    bufmax = pls->bufmax * 1.2;
+    TkDev      *dev     = (TkDev *) pls->dev;
+    PLiodev    *iodev   = (PLiodev *) dev->iodev;
+    size_t     bufmax   = (size_t) ( pls->bufmax * 1.2 );
+    const char *dirname = NULL;
 
     dbug_enter( "link_init" );
 
@@ -1524,11 +1529,11 @@ link_init( PLStream *pls )
 
     if ( !pls->dp )
     {
-        // This of tmpnam should (?) be safe since mkfifo
-        // will fail if the filename already exists
-        iodev->fileName = (char *) tmpnam( NULL );
-        if ( mkfifo( iodev->fileName,
-                 S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH ) < 0 )
+        // This uses the pl_create_tempfifo function to create
+        // the fifo in a safe manner by first creating a private
+        // temporary directory.
+        iodev->fileName = pl_create_tempfifo( (const char **) &iodev->fileName, &dirname );
+        if ( dirname == NULL || iodev->fileName == NULL )
             abort_session( pls, "mkfifo error" );
 
         // Tell plframe widget to open FIFO (for reading).
@@ -1553,6 +1558,11 @@ link_init( PLStream *pls )
 
         if ( unlink( iodev->fileName ) == -1 )
             abort_session( pls, "Error removing fifo" );
+        free( (void *) iodev->fileName );
+        iodev->fileName = NULL;
+        if ( rmdir( dirname ) == -1 )
+            abort_session( pls, "Error removing temporary directory" );
+        free( (void *) dirname );
     }
 
 // Create socket for data transfer to the plframe widget
@@ -1562,13 +1572,13 @@ link_init( PLStream *pls )
         iodev->type     = 1;
         iodev->typeName = "socket";
         tcl_cmd( pls, "plclient_dp_init" );
-        iodev->fileHandle = (char *) Tcl_GetVar( dev->interp, "data_sock", 0 );
+        iodev->fileHandle = Tcl_GetVar( dev->interp, "data_sock", 0 );
 
         if ( Tcl_GetOpenFile( dev->interp, iodev->fileHandle,
                  0, 1, ( ClientData ) & iodev->file ) != TCL_OK )
         {
             fprintf( stderr, "Cannot get file info:\n\t %s\n",
-                dev->interp->result );
+                Tcl_GetStringResult( dev->interp ) );
             abort_session( pls, "" );
         }
         iodev->fd = fileno( iodev->file );
@@ -1576,7 +1586,7 @@ link_init( PLStream *pls )
 
 // Create data buffer
 
-    pls->pdfs = pdf_bopen( NULL, bufmax );
+    pls->pdfs = pdf_bopen( NULL, (size_t) bufmax );
 }
 
 //--------------------------------------------------------------------------
@@ -1673,7 +1683,7 @@ flush_output( PLStream *pls )
         if ( pl_PacketSend( dev->interp, dev->iodev, pls->pdfs ) )
         {
             fprintf( stderr, "Packet send failed:\n\t %s\n",
-                dev->interp->result );
+                Tcl_GetStringResult( dev->interp ) );
             abort_session( pls, "" );
         }
         pdfs->bp = 0;
@@ -1687,7 +1697,7 @@ flush_output( PLStream *pls )
 //--------------------------------------------------------------------------
 
 static int
-Abort( ClientData clientData, Tcl_Interp *interp, int argc, char **argv )
+Abort( ClientData clientData, Tcl_Interp *PL_UNUSED( interp ), int PL_UNUSED( argc ), char **PL_UNUSED( argv ) )
 {
     PLStream *pls = (PLStream *) clientData;
 
@@ -1721,8 +1731,8 @@ Plfinfo( ClientData clientData, Tcl_Interp *interp, int argc, char **argv )
     }
     else
     {
-        dev->width  = atoi( argv[1] );
-        dev->height = atoi( argv[2] );
+        dev->width  = (unsigned int) atoi( argv[1] );
+        dev->height = (unsigned int) atoi( argv[2] );
 #if PHYSICAL
         {
             PLFLT pxlx = (double) PIXELS_X / dev->width * DPMM;
@@ -1825,10 +1835,10 @@ LookupTkKeyEvent( PLStream *pls, Tcl_Interp *interp, int argc, char **argv )
         return TCL_ERROR;
     }
 
-    gin->keysym = atol( argv[1] );
-    gin->state  = atol( argv[2] );
-    gin->pX     = atol( argv[3] );
-    gin->pY     = atol( argv[4] );
+    gin->keysym = (unsigned int) atol( argv[1] );
+    gin->state  = (unsigned int) atol( argv[2] );
+    gin->pX     = atoi( argv[3] );
+    gin->pY     = atoi( argv[4] );
     gin->dX     = atof( argv[5] );
     gin->dY     = atof( argv[6] );
 
@@ -1892,10 +1902,10 @@ LookupTkButtonEvent( PLStream *pls, Tcl_Interp *interp, int argc, char **argv )
         return TCL_ERROR;
     }
 
-    gin->button = atol( argv[1] );
-    gin->state  = atol( argv[2] );
-    gin->pX     = atof( argv[3] );
-    gin->pY     = atof( argv[4] );
+    gin->button = (unsigned int) atol( argv[1] );
+    gin->state  = (unsigned int) atol( argv[2] );
+    gin->pX     = atoi( argv[3] );
+    gin->pY     = atoi( argv[4] );
     gin->dX     = atof( argv[5] );
     gin->dY     = atof( argv[6] );
     gin->keysym = 0x20;
@@ -2123,7 +2133,7 @@ Locate( PLStream *pls )
 //--------------------------------------------------------------------------
 
 static int
-pltk_toplevel( Tk_Window *w, Tcl_Interp *interp )
+pltk_toplevel( Tk_Window *PL_UNUSED( w ), Tcl_Interp *interp )
 {
     static char wcmd[] = "wm withdraw .";
 
@@ -2131,7 +2141,7 @@ pltk_toplevel( Tk_Window *w, Tcl_Interp *interp )
 
     if ( Tk_Init( interp ) )
     {
-        fprintf( stderr, "tk_init:%s\n", interp->result );
+        fprintf( stderr, "tk_init:%s\n", Tcl_GetStringResult( interp ) );
         return 1;
     }
 
@@ -2152,7 +2162,7 @@ pltk_toplevel( Tk_Window *w, Tcl_Interp *interp )
 //--------------------------------------------------------------------------
 
 static void
-tk_wait( PLStream *pls, char *cmd )
+tk_wait( PLStream *pls, const char *cmd )
 {
     TkDev *dev   = (TkDev *) pls->dev;
     int   result = 0;
@@ -2165,7 +2175,7 @@ tk_wait( PLStream *pls, char *cmd )
         if ( Tcl_ExprBoolean( dev->interp, dev->cmdbuf, &result ) )
         {
             fprintf( stderr, "tk_wait command \"%s\" failed:\n\t %s\n",
-                cmd, dev->interp->result );
+                cmd, Tcl_GetStringResult( dev->interp ) );
             break;
         }
         if ( result )
@@ -2191,7 +2201,7 @@ tk_wait( PLStream *pls, char *cmd )
 //--------------------------------------------------------------------------
 
 static void
-server_cmd( PLStream *pls, char *cmd, int nowait )
+server_cmd( PLStream *pls, const char *cmd, int nowait )
 {
     TkDev       *dev          = (TkDev *) pls->dev;
     static char dpsend_cmd0[] = "dp_RPC $server ";
@@ -2225,7 +2235,7 @@ server_cmd( PLStream *pls, char *cmd, int nowait )
     if ( result != TCL_OK )
     {
         fprintf( stderr, "Server command \"%s\" failed:\n\t %s\n",
-            cmd, dev->interp->result );
+            cmd, Tcl_GetStringResult( dev->interp ) );
         abort_session( pls, "" );
     }
 }
@@ -2237,7 +2247,7 @@ server_cmd( PLStream *pls, char *cmd, int nowait )
 //--------------------------------------------------------------------------
 
 static void
-tcl_cmd( PLStream *pls, char *cmd )
+tcl_cmd( PLStream *pls, const char *cmd )
 {
     TkDev *dev = (TkDev *) pls->dev;
 
@@ -2247,7 +2257,7 @@ tcl_cmd( PLStream *pls, char *cmd )
     if ( Tcl_VarEval( dev->interp, cmd, (char **) NULL ) != TCL_OK )
     {
         fprintf( stderr, "TCL command \"%s\" failed:\n\t %s\n",
-            cmd, dev->interp->result );
+            cmd, Tcl_GetStringResult( dev->interp ) );
         abort_session( pls, "" );
     }
 }
@@ -2260,7 +2270,7 @@ tcl_cmd( PLStream *pls, char *cmd )
 //--------------------------------------------------------------------------
 
 static void
-copybuf( PLStream *pls, char *cmd )
+copybuf( PLStream *pls, const char *cmd )
 {
     TkDev *dev = (TkDev *) pls->dev;
 
@@ -2270,7 +2280,7 @@ copybuf( PLStream *pls, char *cmd )
         dev->cmdbuf     = (char *) malloc( dev->cmdbuf_len );
     }
 
-    if ( (int) strlen( cmd ) >= dev->cmdbuf_len )
+    if ( strlen( cmd ) >= dev->cmdbuf_len )
     {
         free( (void *) dev->cmdbuf );
         dev->cmdbuf_len = strlen( cmd ) + 20;
