@@ -1,4 +1,4 @@
-// $Id: wingcc.c 11760 2011-06-01 19:29:11Z airwin $
+// $Id: wingcc.c 12965 2014-01-28 20:23:52Z arjenmarkus $
 //
 //      PLplot WIN32 under GCC device driver.
 //
@@ -27,6 +27,12 @@
 
 #include <string.h>
 #include <windows.h>
+#if !defined ( __CYGWIN__ )
+#include <tchar.h>
+#else
+#include <winnt.h>
+#define _T( a )    __TEXT( a )
+#endif
 #ifdef _WIN64
 #define GWL_USERDATA    GWLP_USERDATA
 #define GCL_HCURSOR     GCLP_HCURSOR
@@ -36,7 +42,7 @@
 #include "drivers.h"
 #include "plevent.h"
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 //
 //  Freetype support has been added to the wingcc driver using the
@@ -45,7 +51,7 @@
 //  "PLESC_HAS_TEXT" command for rendering within the driver.
 //
 //  Freetype support is turned on/off at compile time by defining
-//  "HAVE_FREETYPE".
+//  "PL_HAVE_FREETYPE".
 //
 //  To give the user some level of control over the fonts that are used,
 //  environmental variables can be set to over-ride the definitions used by
@@ -128,7 +134,7 @@ void plD_tidy_wingcc( PLStream * );
 void plD_state_wingcc( PLStream *, PLINT );
 void plD_esc_wingcc( PLStream *, PLINT, void * );
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 static void plD_pixel_wingcc( PLStream *pls, short x, short y );
 static void plD_pixelV_wingcc( PLStream *pls, short x, short y );
@@ -145,8 +151,8 @@ static void init_freetype_lv2( PLStream *pls );
 //  Local Function definitions and function-like defines
 //--------------------------------------------------------------------------
 
-static int GetRegValue( char *key_name, char *key_word, char *buffer, int size );
-static int SetRegValue( char *key_name, char *key_word, char *buffer, int dwType, int size );
+static int GetRegValue( TCHAR *key_name, TCHAR *key_word, char *buffer, int size );
+static int SetRegValue( TCHAR *key_name, TCHAR *key_word, char *buffer, int dwType, int size );
 static void Resize( PLStream *pls );
 static void plD_fill_polygon_wingcc( PLStream *pls );
 static void CopySCRtoBMP( PLStream *pls );
@@ -193,14 +199,14 @@ static void UpdatePageMetrics( PLStream *pls, char flag );
         SetClassLong( dev->hwnd, GCL_HCURSOR, (long) dev->cursor ); \
         SetCursor( dev->cursor ); } while ( 0 )
 
-#define NormalCursor()       do {                                   \
-        dev->cursor = LoadCursor( NULL, IDC_ARROW );                \
-        SetClassLong( dev->hwnd, GCL_HCURSOR, (long) dev->cursor ); \
+#define NormalCursor()       do {                                          \
+        dev->cursor = LoadCursor( NULL, IDC_ARROW );                       \
+        SetClassLongPtr( dev->hwnd, GCL_HCURSOR, (LONG_PTR) dev->cursor ); \
         SetCursor( dev->cursor ); } while ( 0 )
 
-#define BusyCursor()         do {                                   \
-        dev->cursor = LoadCursor( NULL, IDC_WAIT );                 \
-        SetClassLong( dev->hwnd, GCL_HCURSOR, (long) dev->cursor ); \
+#define BusyCursor()         do {                                          \
+        dev->cursor = LoadCursor( NULL, IDC_WAIT );                        \
+        SetClassLongPtr( dev->hwnd, GCL_HCURSOR, (LONG_PTR) dev->cursor ); \
         SetCursor( dev->cursor ); } while ( 0 )
 
 #define PopupPrint       0x08A1
@@ -226,7 +232,7 @@ void plD_dispatch_init_wingcc( PLDispatchTable *pdt )
     pdt->pl_esc      = (plD_esc_fp) plD_esc_wingcc;
 }
 
-static char* szWndClass = "PlplotWin";
+static TCHAR* szWndClass = _T( "PlplotWin" );
 
 
 //--------------------------------------------------------------------------
@@ -257,6 +263,7 @@ LRESULT CALLBACK PlplotWndProc( HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
     else
     {
 #ifndef _WIN64
+#undef GetWindowLongPtr
 #define GetWindowLongPtr    GetWindowLong
 #endif
         pls = (PLStream *) GetWindowLongPtr( hwnd, GWL_USERDATA ); // Try to get the address to pls for this window
@@ -301,7 +308,7 @@ LRESULT CALLBACK PlplotWndProc( HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
                     if ( dev->ps.fErase )
                     {
                         dev->oldcolour = SetBkColor( dev->hdc, RGB( pls->cmap0[0].r, pls->cmap0[0].g, pls->cmap0[0].b ) );
-                        ExtTextOut( dev->hdc, 0, 0, ETO_OPAQUE, &dev->rect, "", 0, 0 );
+                        ExtTextOut( dev->hdc, 0, 0, ETO_OPAQUE, &dev->rect, _T( "" ), 0, 0 );
                         SetBkColor( dev->hdc, dev->oldcolour );
                     }
 
@@ -372,7 +379,7 @@ LRESULT CALLBACK PlplotWndProc( HWND hwnd, UINT nMsg, WPARAM wParam, LPARAM lPar
                 //
 
                 dev->oldcolour = SetBkColor( dev->hdc, RGB( pls->cmap0[0].r, pls->cmap0[0].g, pls->cmap0[0].b ) );
-                ExtTextOut( dev->hdc, 0, 0, ETO_OPAQUE, &dev->rect, "", 0, 0 );
+                ExtTextOut( dev->hdc, 0, 0, ETO_OPAQUE, &dev->rect, _T( "" ), 0, 0 );
                 SetBkColor( dev->hdc, dev->oldcolour );
 
                 dev->already_erased = 1;
@@ -406,7 +413,7 @@ plD_init_wingcc( PLStream *pls )
 {
     wingcc_Dev *dev;
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     static int freetype    = 0;
     static int smooth_text = 0;
     static int save_reg    = 0;
@@ -416,13 +423,13 @@ plD_init_wingcc( PLStream *pls )
 //  Variables used for reading the registary keys
 //  might eventually add a user defined pallette here, but for now it just does freetype
 //
-    char key_name[]       = "Software\\PLplot\\wingcc";
-    char Keyword_text[]   = "freetype";
-    char Keyword_smooth[] = "smooth";
+    TCHAR key_name[]       = _T( "Software\\PLplot\\wingcc" );
+    TCHAR Keyword_text[]   = _T( "freetype" );
+    TCHAR Keyword_smooth[] = _T( "smooth" );
 #endif
 
     DrvOpt wingcc_options[] = {
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
         { "text",   DRV_INT, &freetype,    "Use driver text (FreeType)"            },
         { "smooth", DRV_INT, &smooth_text, "Turn text smoothing on (1) or off (0)" },
         { "save",   DRV_INT, &save_reg,    "Save defaults to registary"            },
@@ -431,6 +438,12 @@ plD_init_wingcc( PLStream *pls )
         { NULL,     DRV_INT, NULL,         NULL                                    }
     };
 
+//
+// Variable for storing the program name
+//
+    TCHAR *program;
+    int   programlength;
+
 // Allocate and initialize device-specific data
 
     if ( pls->dev != NULL )
@@ -456,7 +469,7 @@ plD_init_wingcc( PLStream *pls )
         pls->color = 1;
 
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 //
 //  Read registry to see if the user has set up default values
@@ -474,7 +487,7 @@ plD_init_wingcc( PLStream *pls )
 
     plParseDrvOpts( wingcc_options );
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 //
 //  We will now save the settings to the registary if the user wants
@@ -539,13 +552,24 @@ plD_init_wingcc( PLStream *pls )
 
     RegisterClassEx( &dev->wndclass );
 
+    //
+    //convert the program name to wide char if needed
+    //
 
+#ifdef UNICODE
+    printf( pls->program );
+    programlength = strlen( pls->program ) + 1;
+    program       = malloc( programlength * sizeof ( TCHAR ) );
+    MultiByteToWideChar( CP_UTF8, 0, pls->program, programlength, program, programlength );
+#else
+    program = pls->program;
+#endif
     //
     // Create our main window using that window class.
     //
     dev->hwnd = CreateWindowEx( WS_EX_WINDOWEDGE + WS_EX_LEFT,
         szWndClass,                                         // Class name
-        pls->program,                                       // Caption
+        program,                                            // Caption
         WS_OVERLAPPEDWINDOW,                                // Style
         pls->xoffset,                                       // Initial x (use default)
         pls->yoffset,                                       // Initial y (use default)
@@ -557,6 +581,9 @@ plD_init_wingcc( PLStream *pls )
         NULL                                                // Creation parameters
         );
 
+#ifdef UNICODE
+    free( program );
+#endif
 
 //
 // Attach a pointer to the stream to the window's user area
@@ -577,11 +604,11 @@ plD_init_wingcc( PLStream *pls )
 //
 
     dev->PopupMenu = CreatePopupMenu();
-    AppendMenu( dev->PopupMenu, MF_STRING, PopupPrint, "Print" );
-    AppendMenu( dev->PopupMenu, MF_STRING, PopupNextPage, "Next Page" );
-    AppendMenu( dev->PopupMenu, MF_STRING, PopupQuit, "Quit" );
+    AppendMenu( dev->PopupMenu, MF_STRING, PopupPrint, _T( "Print" ) );
+    AppendMenu( dev->PopupMenu, MF_STRING, PopupNextPage, _T( "Next Page" ) );
+    AppendMenu( dev->PopupMenu, MF_STRING, PopupQuit, _T( "Quit" ) );
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
     if ( freetype )
     {
@@ -652,7 +679,7 @@ plD_init_wingcc( PLStream *pls )
     else
         SetPolyFillMode( dev->hdc, WINDING );
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     if ( pls->dev_text )
     {
         init_freetype_lv2( pls );
@@ -878,7 +905,7 @@ void
 plD_bop_wingcc( PLStream *pls )
 {
     wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     FT_Data    *FT = (FT_Data *) pls->FT;
 #endif
     Debug( "Start of Page\t" );
@@ -900,7 +927,7 @@ plD_tidy_wingcc( PLStream *pls )
 {
     wingcc_Dev *dev = NULL;
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     if ( pls->dev_text )
     {
         FT_Data *FT = (FT_Data *) pls->FT;
@@ -954,8 +981,6 @@ plD_state_wingcc( PLStream *pls, PLINT op )
     case PLSTATE_CMAP0:
     case PLSTATE_CMAP1:
         dev->colour = RGB( pls->curcolor.r, pls->curcolor.g, pls->curcolor.b );
-
-
         break;
     }
 
@@ -988,7 +1013,7 @@ plD_esc_wingcc( PLStream *pls, PLINT op, void *ptr )
             SetROP2( dev->hdc, R2_XORPEN );
         break;
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     case PLESC_HAS_TEXT:
         plD_render_freetype_text( pls, (EscText *) ptr );
         break;
@@ -1017,7 +1042,7 @@ plD_esc_wingcc( PLStream *pls, PLINT op, void *ptr )
 static void Resize( PLStream *pls )
 {
     wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     FT_Data    *FT = (FT_Data *) pls->FT;
 #endif
     Debug( "Resizing" );
@@ -1044,7 +1069,7 @@ static void Resize( PLStream *pls )
                     dev->scale = (PLFLT) PIXELS_Y / dev->height;
                 }
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
                 if ( FT )
                 {
                     FT->scale = dev->scale;
@@ -1070,7 +1095,7 @@ static void Resize( PLStream *pls )
 //  that is is there !
 //--------------------------------------------------------------------------
 
-static int SetRegValue( char *key_name, char *key_word, char *buffer, int dwType, int size )
+static int SetRegValue( TCHAR *key_name, TCHAR *key_word, char *buffer, int dwType, int size )
 {
     int   j = 0;
 
@@ -1106,7 +1131,7 @@ static int SetRegValue( char *key_name, char *key_word, char *buffer, int dwType
 //  Return code is 1 for success, and 0 for failure.
 //--------------------------------------------------------------------------
 
-static int GetRegValue( char *key_name, char *key_word, char *buffer, int size )
+static int GetRegValue( TCHAR *key_name, TCHAR *key_word, char *buffer, int size )
 {
     int  ret = 0;
     HKEY hKey;
@@ -1124,7 +1149,7 @@ static int GetRegValue( char *key_name, char *key_word, char *buffer, int size )
     return ( ret );
 }
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 //--------------------------------------------------------------------------
 //  void plD_pixel_wingcc (PLStream *pls, short x, short y)
@@ -1308,7 +1333,7 @@ static void init_freetype_lv2( PLStream *pls )
 static void UpdatePageMetrics( PLStream *pls, char flag )
 {
     wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
-  #ifdef HAVE_FREETYPE
+  #ifdef PL_HAVE_FREETYPE
     FT_Data    *FT = (FT_Data *) pls->FT;
   #endif
 
@@ -1333,7 +1358,7 @@ static void UpdatePageMetrics( PLStream *pls, char flag )
         dev->scale = (PLFLT) PIXELS_Y / dev->height;
     }
 
-  #ifdef HAVE_FREETYPE
+  #ifdef PL_HAVE_FREETYPE
     if ( FT )           // If we are using freetype, then set it up next
     {
         FT->scale = dev->scale;
@@ -1362,7 +1387,7 @@ static void UpdatePageMetrics( PLStream *pls, char flag )
 static void PrintPage( PLStream *pls )
 {
     wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
-  #ifdef HAVE_FREETYPE
+  #ifdef PL_HAVE_FREETYPE
     FT_Data    *FT = (FT_Data *) pls->FT;
   #endif
     PRINTDLG   Printer;
@@ -1375,7 +1400,7 @@ static void PrintPage( PLStream *pls )
 
     ZeroMemory( &docinfo, sizeof ( docinfo ) );
     docinfo.cbSize      = sizeof ( docinfo );
-    docinfo.lpszDocName = "Plplot Page";
+    docinfo.lpszDocName = _T( "Plplot Page" );
 
     //
     //   Reset out printer structure to zero and initialise it
@@ -1413,7 +1438,7 @@ static void PrintPage( PLStream *pls )
 
             UpdatePageMetrics( pls, 1 );
 
-          #ifdef HAVE_FREETYPE
+          #ifdef PL_HAVE_FREETYPE
             if ( FT )                                  // If we are using freetype, then set it up next
             {
                 dev->FT_smooth_text = FT->smooth_text; // When printing, we don't want smoothing
@@ -1436,7 +1461,7 @@ static void PrintPage( PLStream *pls )
             dev->hdc = dev->SCRN_hdc;  // Reset the screen HDC to the default
             UpdatePageMetrics( pls, 0 );
 
-          #ifdef HAVE_FREETYPE
+          #ifdef PL_HAVE_FREETYPE
             if ( FT )           // If we are using freetype, then set it up next
             {
                 FT->smooth_text = dev->FT_smooth_text;
