@@ -1,4 +1,4 @@
-// $Id: wxwidgets.cpp 11760 2011-06-01 19:29:11Z airwin $
+// $Id: wxwidgets.cpp 12334 2013-05-04 16:43:33Z airwin $
 //
 // Copyright (C) 2005  Werner Smekal, Sjaak Verdoold
 // Copyright (C) 2005  Germain Carrera Corraleche
@@ -41,6 +41,21 @@
 
 #include "wxwidgets.h"
 
+// Static function prototypes
+#ifdef PL_HAVE_FREETYPE
+static void plD_pixel_wxwidgets( PLStream *pls, short x, short y );
+static PLINT plD_read_pixel_wxwidgets( PLStream *pls, short x, short y );
+static void plD_set_pixel_wxwidgets( PLStream *pls, short x, short y, PLINT colour );
+static void init_freetype_lv1( PLStream *pls );
+static void init_freetype_lv2( PLStream *pls );
+#endif
+
+// private functions needed by the wxwidgets Driver
+static void install_buffer( PLStream *pls );
+static void wxRunApp( PLStream *pls, bool runonce = false );
+static void GetCursorCmd( PLStream *pls, PLGraphicsIn *ptr );
+static void fill_polygon( PLStream *pls );
+
 #ifdef __WXMAC__
         #include <Carbon/Carbon.h>
 extern "C" { void CPSEnableForegroundOperation( ProcessSerialNumber* psn ); }
@@ -63,6 +78,8 @@ void Log_Verbose( const char *fmt, ... )
     fprintf( stderr, "\n" );
     va_end( args );
     fflush( stderr );
+#else
+    (void) fmt;        // Cast to void to silence compiler warnings about unused paraemeter
 #endif
 }
 
@@ -82,6 +99,8 @@ void Log_Debug( const char *fmt, ... )
     fprintf( stderr, "\n" );
     va_end( args );
     fflush( stderr );
+#else
+    (void) fmt;        // Cast to void to silence compiler warnings about unused paraemeter
 #endif
 }
 
@@ -157,6 +176,8 @@ wxPLDevBase::wxPLDevBase( int bcknd ) : backend( bcknd )
     devDesc = (const char **) malloc( NDEV * sizeof ( char** ) );
     memset( devDesc, '\0', NDEV * sizeof ( char** ) );
     ndev = NDEV;
+
+    lineSpacing = 1.0;
 }
 
 
@@ -215,14 +236,11 @@ void wxPLDevBase::PSDrawText( PLUNICODE* ucs4, int ucs4Len, bool drawText )
     char plplotEsc;
     plgesc( &plplotEsc );
 
-    // Get the curent font
-    fontScale = 1.0;
-    yOffset   = 0.0;
-    PLUNICODE fci;
-    plgfci( &fci );
-    PSSetFont( fci );
-    textWidth  = 0;
-    textHeight = 0;
+    //Reset the size metrics
+    textWidth         = 0;
+    textHeight        = 0;
+    superscriptHeight = 0;
+    subscriptDepth    = 0;
 
     while ( i < ucs4Len )
     {
@@ -231,7 +249,8 @@ void wxPLDevBase::PSDrawText( PLUNICODE* ucs4, int ucs4Len, bool drawText )
             if ( ucs4[i] != (PLUNICODE) plplotEsc ) // a character to display
             {
                 ucs4_to_utf8( ucs4[i], utf8 );
-                strncat( utf8_string, utf8, max_string_length );
+                strncat( utf8_string, utf8,
+                    sizeof ( utf8_string ) - strlen( utf8_string ) - 1 );
                 i++;
                 continue;
             }
@@ -239,7 +258,8 @@ void wxPLDevBase::PSDrawText( PLUNICODE* ucs4, int ucs4Len, bool drawText )
             if ( ucs4[i] == (PLUNICODE) plplotEsc ) // a escape character to display
             {
                 ucs4_to_utf8( ucs4[i], utf8 );
-                strncat( utf8_string, utf8, max_string_length );
+                strncat( utf8_string, utf8,
+                    sizeof ( utf8_string ) - strlen( utf8_string ) - 1 );
                 i++;
                 continue;
             }
@@ -311,6 +331,7 @@ wxPLDevBase* common_init( PLStream *pls )
     // Log_Verbose( "common_init()" );
 
     wxPLDevBase* dev;
+    PLFLT      downscale, downscale2;
 
     // default options
     static PLINT freetype    = -1;
@@ -331,7 +352,7 @@ wxPLDevBase* common_init( PLStream *pls )
         #endif
 
     DrvOpt wx_options[] = {
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
         { "freetype", DRV_INT, &freetype,    "Use FreeType library"                                                             },
         { "smooth",   DRV_INT, &smooth_text, "Turn text smoothing on (1) or off (0)"                                            },
 #endif
@@ -373,10 +394,12 @@ wxPLDevBase* common_init( PLStream *pls )
         dev = new wxPLDevDC;
         // by default the own text routines are used for wxDC
         if ( text == -1 )
+        {
             if ( freetype != 1 )
                 text = 1;
             else
                 text = 0;
+        }
         if ( freetype == -1 )
             freetype = 0;
         break;
@@ -408,7 +431,7 @@ wxPLDevBase* common_init( PLStream *pls )
             pls->dev_hrshsym = 1;
     }
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     // own text routines have higher priority over freetype
     // if text and freetype option are set to 1
     if ( !text )
@@ -458,8 +481,12 @@ wxPLDevBase* common_init( PLStream *pls )
     plP_setpxl( (PLFLT) VIRTUAL_PIXELS_PER_MM, (PLFLT) VIRTUAL_PIXELS_PER_MM );
 
     // Set up physical limits of plotting device (in drawing units)
-    plP_setphy( (PLINT) 0, (PLINT) ( CANVAS_WIDTH * VIRTUAL_PIXELS_PER_IN ),
-        (PLINT) 0, (PLINT) ( CANVAS_HEIGHT * VIRTUAL_PIXELS_PER_IN ) );
+    downscale  = (double) dev->width / (double) ( PIXELS_X - 1 );
+    downscale2 = (double) dev->height / (double) PIXELS_Y;
+    if ( downscale < downscale2 )
+        downscale = downscale2;
+    plP_setphy( (PLINT) 0, (PLINT) ( dev->width / downscale ),
+        (PLINT) 0, (PLINT) ( dev->height / downscale ) );
 
     // get physical device limits coordinates
     plP_gphy( &dev->xmin, &dev->xmax, &dev->ymin, &dev->ymax );
@@ -471,7 +498,7 @@ wxPLDevBase* common_init( PLStream *pls )
     // set dpi
     plspage( VIRTUAL_PIXELS_PER_IN / dev->scalex, VIRTUAL_PIXELS_PER_IN / dev->scaley, 0, 0, 0, 0 );
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     if ( dev->freetype )
         init_freetype_lv2( pls );
 #endif
@@ -675,10 +702,12 @@ void plD_eop_wxwidgets( PLStream *pls )
     }
 
     if ( dev->ownGUI )
+    {
         if ( pls->nopause || !dev->showGUI )
             wxRunApp( pls, true );
         else
             wxRunApp( pls );
+    }
 }
 
 
@@ -752,7 +781,7 @@ void plD_tidy_wxwidgets( PLStream *pls )
 
     wxPLDevBase* dev = (wxPLDevBase *) pls->dev;
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     if ( dev->freetype )
     {
         FT_Data *FT = (FT_Data *) pls->FT;
@@ -857,7 +886,7 @@ void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
 
         if ( dev->freetype )
         {
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
             plD_render_freetype_text( pls, (EscText *) ptr );
 #endif
         }
@@ -972,7 +1001,7 @@ void wx_set_size( PLStream* pls, int width, int height )
     }
 
     // freetype parameters must also be changed
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     if ( dev->freetype )
     {
         FT_Data *FT = (FT_Data *) pls->FT;
@@ -1020,7 +1049,7 @@ void plD_erroraborthandler_wxwidgets( const char *errormessage )
 
 
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 //--------------------------------------------------------------------------
 //  static void plD_pixel_wxwidgets( PLStream *pls, short x, short y )
@@ -1111,8 +1140,6 @@ static void init_freetype_lv1( PLStream *pls )
 {
     // Log_Verbose( "init_freetype_lv1" );
 
-    wxPLDevBase *dev = (wxPLDevBase *) pls->dev;
-
     plD_FreeType_init( pls );
 
     FT_Data *FT = (FT_Data *) pls->FT;
