@@ -1,4 +1,4 @@
-// $Id: wxwidgets.h 11680 2011-03-27 17:57:51Z airwin $
+// $Id: wxwidgets.h 12334 2013-05-04 16:43:33Z airwin $
 //
 // Copyright (C) 2008  Werner Smekal
 //
@@ -26,14 +26,8 @@
 #include <wx/spinctrl.h>
 
 // freetype headers and macros
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
   #include "plfreetype.h"
-
-static void plD_pixel_wxwidgets( PLStream *pls, short x, short y );
-static PLINT plD_read_pixel_wxwidgets( PLStream *pls, short x, short y );
-static void plD_set_pixel_wxwidgets( PLStream *pls, short x, short y, PLINT colour );
-static void init_freetype_lv1( PLStream *pls );
-static void init_freetype_lv2( PLStream *pls );
 #endif
 
 #ifndef max_number_of_grey_levels_used_in_text_smoothing
@@ -46,25 +40,27 @@ static void init_freetype_lv2( PLStream *pls );
 // Physical dimension constants used by the driver
 
 // Virtual coordinate scaling parameter, used to do calculations at
-// higher resolution.  Chosen to be 32 for consistency with the PLplot
-// metafile (see plplotP.h).
+// higher resolution.  Chosen so that maximum plP_setphy coordinate
+// is 32000 which is close to but still less than the maximum possible
+// which is 32767.
 //
 // The trick here is to do everything in device coordinates on the driver
 // side, but report/receive everything in virtual coordinates to/from the
 // PLplot core.
 //
-#define VSCALE                       ( 32. )
+#define VSCALE                   ( 40. )
+
+// pixels per inch
+#define DEVICE_PIXELS_PER_IN     ( 80. )
+#define VIRTUAL_PIXELS_PER_IN    ( DEVICE_PIXELS_PER_IN * VSCALE )
 
-// pixels per mm
-#define DEVICE_PIXELS_PER_MM         ( 3.14961 )
-#define VIRTUAL_PIXELS_PER_MM        ( DEVICE_PIXELS_PER_MM * VSCALE )
 
 // mm per inch
 #define MM_PER_IN                    ( 25.4 )
 
-// pixels per inch
-#define DEVICE_PIXELS_PER_IN         ( DEVICE_PIXELS_PER_MM * MM_PER_IN )
-#define VIRTUAL_PIXELS_PER_IN        ( VIRTUAL_PIXELS_PER_MM * MM_PER_IN )
+// pixels per mm
+#define DEVICE_PIXELS_PER_MM         ( DEVICE_PIXELS_PER_IN / MM_PER_IN )
+#define VIRTUAL_PIXELS_PER_MM        ( VIRTUAL_PIXELS_PER_IN / MM_PER_IN )
 
 // Default dimensions of the canvas (in inches)
 #define CANVAS_WIDTH                 ( 10.0 )
@@ -104,11 +100,11 @@ public: // methods
     virtual void SetColor0( PLStream *pls )        = 0;
     virtual void SetColor1( PLStream *pls )        = 0;
     virtual void SetExternalBuffer( void* buffer ) = 0;
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     virtual void PutPixel( short x, short y, PLINT color ) = 0;
     virtual void PutPixel( short x, short y )  = 0;
     virtual PLINT GetPixel( short x, short y ) = 0;
-#endif // HAVE_FREETYPE
+#endif // PL_HAVE_FREETYPE
     virtual void ProcessString( PLStream* pls, EscText* args ) = 0;
     virtual void PSDrawText( PLUNICODE* ucs4, int ucs4Len, bool drawText );
     virtual void PSDrawTextToDC( char* utf8_string, bool drawText ) = 0;
@@ -169,6 +165,10 @@ public: // variables
     double           fontSize;
     double           fontScale;
     wxCoord          textWidth, textHeight, textDescent, textLeading;
+    PLUNICODE        fci;
+    //the distance between the superscript top and subscript base from the baseline
+    wxCoord          superscriptHeight, subscriptDepth;
+    double           lineSpacing;
     double           yOffset;
     PLINT            posX, posY;
     PLFLT            rotation, cos_rot, sin_rot;
@@ -193,11 +193,11 @@ public: // methods
     void SetColor0( PLStream *pls );
     void SetColor1( PLStream *pls );
     void SetExternalBuffer( void* buffer );
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     void PutPixel( short x, short y, PLINT color );
     void PutPixel( short x, short y );
     PLINT GetPixel( short x, short y );
-#endif // HAVE_FREETYPE
+#endif // PL_HAVE_FREETYPE
     void ProcessString( PLStream* pls, EscText* args );
     void PSDrawTextToDC( char* utf8_string, bool drawText );
     void PSSetFont( PLUNICODE fci );
@@ -256,11 +256,11 @@ public: // methods
     void SetColor0( PLStream *pls );
     void SetColor1( PLStream *pls );
     void SetExternalBuffer( void* buffer );
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     void PutPixel( short x, short y, PLINT color );
     void PutPixel( short x, short y );
     PLINT GetPixel( short x, short y );
-#endif // HAVE_FREETYPE
+#endif // PL_HAVE_FREETYPE
     void ProcessString( PLStream* pls, EscText* args );
     void PSDrawTextToDC( char* utf8_string, bool drawText );
     void PSSetFont( PLUNICODE fci );
@@ -324,11 +324,11 @@ public: // methods
     void SetColor0( PLStream *pls );
     void SetColor1( PLStream *pls );
     void SetExternalBuffer( void* buffer );
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
     void PutPixel( short x, short y, PLINT color );
     void PutPixel( short x, short y );
     PLINT GetPixel( short x, short y );
-#endif // HAVE_FREETYPE
+#endif // PL_HAVE_FREETYPE
     void ProcessString( PLStream* pls, EscText* args );
     void PSDrawTextToDC( char* utf8_string, bool drawText );
     void PSSetFont( PLUNICODE fci );
@@ -471,16 +471,16 @@ private:
 
 // Use this macro if you want to define your own main() or WinMain() function
 // and call wxEntry() from there.
-#define IMPLEMENT_PLAPP_NO_MAIN( appname )                           \
-    wxAppConsole * wxPLCreateApp()                                   \
-    {                                                                \
-        wxAppConsole::CheckBuildOptions( WX_BUILD_OPTIONS_SIGNATURE, \
-            "your program" );                                        \
-        return new appname;                                          \
-    }                                                                \
-    wxAppInitializer                                                 \
-    wxAppInitializer( (wxAppInitializerFunction) wxPLCreateApp );    \
-    DECLARE_PLAPP( appname )                                         \
+#define IMPLEMENT_PLAPP_NO_MAIN( appname )                                                                                                        \
+    wxAppConsole * wxPLCreateApp()                                                                                                                \
+    {                                                                                                                                             \
+        wxAppConsole::CheckBuildOptions( WX_BUILD_OPTIONS_SIGNATURE,                                                                              \
+            "your program" );                                                                                                                     \
+        return new appname;                                                                                                                       \
+    }                                                                                                                                             \
+    wxAppInitializer                                                                                                                              \
+    wxAppInitializer( (wxAppInitializerFunction) ( wxApp::GetInitializerFunction() == NULL ? wxPLCreateApp : wxApp::GetInitializerFunction() ) ); \
+    DECLARE_PLAPP( appname )                                                                                                                      \
     appname & wxPLGetApp() { return *wx_static_cast( appname *, wxApp::GetInstance() ); }
 
 #define DECLARE_PLAPP( appname )    extern appname &wxPLGetApp();
@@ -491,11 +491,6 @@ static inline void Use( void * )
 }
 #define WX_SUPPRESS_UNUSED_WARN( x )    Use( &x )
 
-// private functions needed by the wxwidgets Driver
-static void install_buffer( PLStream *pls );
-static void wxRunApp( PLStream *pls, bool runonce = false );
-static void GetCursorCmd( PLStream *pls, PLGraphicsIn *ptr );
-
 
 //--------------------------------------------------------------------------
 //  Declarations for the device.
@@ -511,7 +506,6 @@ void plD_tidy_wxwidgets( PLStream * );
 void plD_state_wxwidgets( PLStream *, PLINT );
 void plD_esc_wxwidgets( PLStream *, PLINT, void * );
 
-static void fill_polygon( PLStream *pls );
 void wx_set_dc( PLStream* pls, wxDC* dc );
 void wx_set_buffer( PLStream* pls, wxImage* buffer );
 void wx_set_size( PLStream* pls, int width, int height );
