@@ -1,4 +1,4 @@
-// $Id: wxwidgets_agg.cpp 11760 2011-06-01 19:29:11Z airwin $
+// $Id: wxwidgets_agg.cpp 12334 2013-05-04 16:43:33Z airwin $
 //
 // Copyright (C) 2008  Werner Smekal
 //
@@ -399,10 +399,10 @@ void wxPLDevAGG::SetWidth( PLStream *pls )
 //--------------------------------------------------------------------------
 void wxPLDevAGG::SetColor0( PLStream *pls )
 {
-    mColorRedStroke   = pls->cmap0[pls->icol0].r;
-    mColorGreenStroke = pls->cmap0[pls->icol0].g;
-    mColorBlueStroke  = pls->cmap0[pls->icol0].b;
-    mStrokeOpacity    = (wxUint8) ( pls->cmap0[pls->icol0].a * 255 );
+    mColorRedStroke   = pls->curcolor.r;
+    mColorGreenStroke = pls->curcolor.g;
+    mColorBlueStroke  = pls->curcolor.b;
+    mStrokeOpacity    = (wxUint8) ( pls->curcolor.a * 255 );
 }
 
 
@@ -442,7 +442,7 @@ void wxPLDevAGG::SetExternalBuffer( void* image )
 }
 
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 //--------------------------------------------------------------------------
 //  void wxPLDevAGG::PutPixel( short x, short y, PLINT color )
@@ -478,7 +478,7 @@ PLINT wxPLDevAGG::GetPixel( short x, short y )
     return RGB( mBuffer->GetRed( x, y ), mBuffer->GetGreen( x, y ), mBuffer->GetBlue( x, y ) );
 }
 
-#endif // HAVE_FREETYPE
+#endif // PL_HAVE_FREETYPE
 
 
 void wxPLDevAGG::PSDrawTextToDC( char* utf8_string, bool drawText )
@@ -493,7 +493,7 @@ void wxPLDevAGG::PSDrawTextToDC( char* utf8_string, bool drawText )
     //size_t len=wxConvUTF8.ToWChar( str, 512, utf8_string );
     size_t len   = strlen( utf8_string );
     char   * str = utf8_string;
-    printf( "len=%d\n", len );
+    printf( "len=%lu\n", (unsigned long) len );
 
     const agg::glyph_cache* glyph;
     if ( !drawText )
