@@ -1,4 +1,4 @@
-// $Id: wxwidgets_app.cpp 11760 2011-06-01 19:29:11Z airwin $
+// $Id: wxwidgets_app.cpp 12009 2011-10-28 13:06:27Z andrewross $
 //
 // Copyright (C) 2008  Werner Smekal
 //
@@ -300,7 +300,7 @@ void wxPLplotFrame::OnMenu( wxCommandEvent& event )
     }
 
     size_t index = event.GetId() - wxPL_Save;
-    if ( ( index >= 0 ) && ( index < sizeof ( dev_entries ) / sizeof ( dev_entry ) ) )
+    if ( ( event.GetId() >= wxPL_Save ) && ( index < sizeof ( dev_entries ) / sizeof ( dev_entry ) ) )
     {
         int  width   = 800;
         int  height  = 600;
@@ -345,7 +345,7 @@ void wxPLplotFrame::OnMenu( wxCommandEvent& event )
 //
 //  Event method, which is called if user
 //--------------------------------------------------------------------------
-void wxPLplotFrame::OnClose( wxCloseEvent& event )
+void wxPLplotFrame::OnClose( wxCloseEvent& /* event */ )
 {
     // Log_Verbose( "wxPLplotFrame::OnClose" );
 
@@ -412,6 +412,8 @@ bool wxPLplotFrame::SavePlot( const char* filename, const char* devname, int wid
         else if ( !strcmp( devname, "wxpnm" ) )
             type = wxBITMAP_TYPE_PNM;
 #endif
+        else
+            type = wxBITMAP_TYPE_BMP;
         bool status = bitmap.SaveFile( wxString( filename, *wxConvCurrent ), type );
 
         if ( !status )
@@ -802,10 +804,12 @@ void wxPLplotWindow::Locate( void )
             // If invoked by the API, we're done
             // Otherwise send report to stdout
             if ( m_dev->locate_mode == LOCATE_INVOKED_VIA_DRIVER )
+            {
                 if ( gin->keysym < 0xFF && isprint( gin->keysym ) )
                     printf( "%f %f %c\n", gin->wX, gin->wY, gin->keysym );
                 else
                     printf( "%f %f 0x%02x\n", gin->wX, gin->wY, gin->keysym );
+            }
         }
         else
         {
