@@ -1,4 +1,4 @@
-// $Id: xfig.c 11405 2010-12-30 08:41:03Z arjenmarkus $
+// $Id: xfig.c 12626 2013-10-24 23:01:26Z andrewross $
 //
 //      PLplot xfig device driver.
 //
@@ -123,7 +123,7 @@ plD_init_xfig( PLStream *pls )
 
     dev = (xfig_Dev *) pls->dev;
 
-    dev->curwid    = pls->width < 1 ? 1 : pls->width;
+    dev->curwid    = pls->width < 1 ? 1 : (int) pls->width;
     dev->firstline = 1;
 
     dev->xold       = PL_UNDEFINED;
@@ -166,7 +166,7 @@ plD_init_xfig( PLStream *pls )
     stcmap1( pls );
 
     dev->bufflen = 2 * BSIZE;
-    dev->buffptr = (int *) malloc( sizeof ( int ) * dev->bufflen );
+    dev->buffptr = (int *) malloc( sizeof ( int ) * (size_t) ( dev->bufflen ) );
     if ( dev->buffptr == NULL )
         plexit( "plD_init_xfig: Out of memory!" );
 }
@@ -265,7 +265,7 @@ plD_line_xfig( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
         {
             dev->bufflen += 2 * BSIZE;
             tempptr       = (int *)
-                            realloc( (void *) dev->buffptr, dev->bufflen * sizeof ( int ) );
+                            realloc( (void *) dev->buffptr, (size_t) ( dev->bufflen ) * sizeof ( int ) );
             if ( tempptr == NULL )
             {
                 free( (void *) dev->buffptr );
@@ -390,7 +390,7 @@ plD_state_xfig( PLStream *pls, PLINT op )
     case PLSTATE_WIDTH:
         flushbuffer( pls );
         dev->firstline = 1;
-        dev->curwid    = pls->width < 1 ? 1 : pls->width;
+        dev->curwid    = pls->width < 1 ? 1 : (int) pls->width;
         break;
 
     case PLSTATE_COLOR0:
