@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x02.cc 11297 2010-11-02 03:31:14Z airwin $
+// $Id: x02.cc 12288 2013-01-30 04:40:35Z airwin $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
@@ -148,14 +148,14 @@ x02::draw_windows( int nw, int cmap0_offset )
         vmax = 0.9;
         for ( j = 0; j <= 2; j++ )
         {
-            pls->wid( j + 1 );
+            pls->width( j + 1 );
             pls->vpor( vmin, vmax, vmin, vmax );
             pls->wind( 0.0, 1.0, 0.0, 1.0 );
             pls->box( "bc", 0.0, 0, "bc", 0.0, 0 );
             vmin = vmin + 0.1;
             vmax = vmax - 0.1;
         }
-        pls->wid( 1 );
+        pls->width( 1 );
         pls->ptex( 0.5, 0.5, 1.0, 0.0, 0.5, text );
     }
 }
