@@ -1,9 +1,9 @@
 //--------------------------------------------------------------------------
-// $Id: x15.cc 11760 2011-06-01 19:29:11Z airwin $
+// $Id: x15.cc 12372 2013-06-06 21:44:33Z andrewross $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
-// Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
+// Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
 // This file is part of PLplot.
@@ -41,22 +41,14 @@ public:
 
 private:
     // Class data
-    plstream           *pls;
+    plstream         *pls;
 
-    const static int   XPTS;
-    const static int   YPTS;
-    // calculated constants and array that depends on them
-    const static PLFLT XSPA;
-    const static PLFLT YSPA;
-    const static PLFLT tr[];
+    const static int XPTS;
+    const static int YPTS;
 };
 
-const int   x15::  XPTS = 35;
-const int   x15::  YPTS = 46;
-// calculated constants and array that depends on them
-const PLFLT x15::XSPA = 2. / ( XPTS - 1 );
-const PLFLT x15::YSPA = 2. / ( YPTS - 1 );
-const PLFLT x15::tr[] = { XSPA, 0.0, -1.0, 0.0, YSPA, -1.0 };
+const int x15::  XPTS = 35;
+const int x15::  YPTS = 46;
 
 
 x15::x15( int argc, const char ** argv )
@@ -65,8 +57,6 @@ x15::x15( int argc, const char ** argv )
 
     PLFLT xx;
     PLFLT yy;
-    PLFLT x;
-    PLFLT y;
     PLFLT **z;
     PLFLT zmin, zmax;
 
@@ -93,8 +83,6 @@ x15::x15( int argc, const char ** argv )
         {
             yy      = ( (PLFLT) ( j - ( YPTS / 2 ) ) / (PLFLT) ( YPTS / 2 ) ) - 1.;
             z[i][j] = xx * xx - yy * yy + ( xx - yy ) / ( xx * xx + yy * yy + 0.1 );
-            x       = tr[0] * i + tr[1] * j + tr[2];
-            y       = tr[3] * i + tr[4] * j + tr[5];
         }
     }
 
@@ -117,8 +105,10 @@ x15::x15( int argc, const char ** argv )
 void x15::plot1( PLFLT **z, PLFLT zmin, PLFLT zmax )
 {
     PLFLT shade_min, shade_max, sh_color;
-    int   sh_cmap   = 0, sh_width;
-    int   min_color = 0, min_width = 0, max_color = 0, max_width = 0;
+    int   sh_cmap = 0;
+    PLFLT sh_width;
+    int   min_color = 0, max_color = 0;
+    PLFLT min_width = 0.0, max_width = 0.0;
 
     pls->adv( 0 );
     pls->vpor( 0.1, 0.9, 0.1, 0.9 );
@@ -129,11 +119,11 @@ void x15::plot1( PLFLT **z, PLFLT zmin, PLFLT zmax )
     shade_min = zmin + ( zmax - zmin ) * 0.4;
     shade_max = zmin + ( zmax - zmin ) * 0.6;
     sh_color  = 7;
-    sh_width  = 2;
+    sh_width  = 2.0;
     min_color = 9;
     max_color = 2;
-    min_width = 2;
-    max_width = 2;
+    min_width = 2.0;
+    max_width = 2.0;
 
     pls->psty( 8 );
 
@@ -155,8 +145,10 @@ void x15::plot1( PLFLT **z, PLFLT zmin, PLFLT zmax )
 void x15::plot2( PLFLT **z, PLFLT zmin, PLFLT zmax )
 {
     PLFLT        shade_min, shade_max, sh_color;
-    int          sh_cmap   = 0, sh_width;
-    int          min_color = 0, min_width = 0, max_color = 0, max_width = 0;
+    int          sh_cmap = 0;
+    PLFLT        sh_width;
+    int          min_color = 0, max_color = 0;
+    PLFLT        min_width = 0.0, max_width = 0.0;
     int          i;
     static PLINT nlin[10]   = { 1, 1, 1, 1, 1, 2, 2, 2, 2, 2 };
     static PLINT inc[10][2] = { { 450,    0 }, { -450,    0 }, { 0,   0 }, { 900,   0 },
@@ -166,7 +158,7 @@ void x15::plot2( PLFLT **z, PLFLT zmin, PLFLT zmax )
                                 { 2000, 2000 }, { 2000, 2000 }, { 2000, 2000 },
                                 { 2000, 2000 }, { 2000, 2000 }, { 4000, 4000 },
                                 { 4000, 2000 } };
-    sh_width = 2;
+    sh_width = 2.0;
 
     pls->adv( 0 );
     pls->vpor( 0.1, 0.9, 0.1, 0.9 );
