@@ -1,9 +1,9 @@
 //--------------------------------------------------------------------------
-// $Id: x16.cc 11760 2011-06-01 19:29:11Z airwin $
+// $Id: x16.cc 12626 2013-10-24 23:01:26Z andrewross $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
-// Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
+// Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
 // This file is part of PLplot.
@@ -46,6 +46,7 @@ private:
     static int           nx;
     static int           ny;
     static int           exclude;
+    static int           colorbar;
     const static int     PERIMETERPTS;
 public:
     static PLFLT         tr[];
@@ -54,11 +55,12 @@ public:
     static const char    *notes[];
 };
 
-int       x16::      ns      = 20;
-int       x16::      nx      = 35;
-int       x16::      ny      = 46;
-int       x16::      exclude = 0;
-const int x16::PERIMETERPTS  = 100;
+int       x16::      ns       = 20;
+int       x16::      nx       = 35;
+int       x16::      ny       = 46;
+int       x16::      exclude  = 0;
+int       x16::      colorbar = 1;
+const int x16::PERIMETERPTS   = 100;
 
 PLFLT     x16::    tr[] = { 2. / ( nx - 1 ), 0.0, -1.0, 0.0, 2. / ( ny - 1 ), -1.0 };
 
@@ -122,7 +124,7 @@ const char    *x16::  notes[] = {
 
 // Transformation function
 
-static void mypltr( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data )
+static void mypltr( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void * /* pltr_data */ )
 {
     *tx = x16::tr[0] * x + x16::tr[1] * y + x16::tr[2];
     *ty = x16::tr[3] * x + x16::tr[4] * y + x16::tr[5];
@@ -137,20 +139,43 @@ PLINT zdefined( PLFLT x, PLFLT y )
 
 x16::x16( int argc, const char ** argv )
 {
-    int       i, j;
-    PLFLT     x, y, argx, argy, distort, r, t, zmin, zmax;
-    PLFLT     *px  = new PLFLT[PERIMETERPTS];
-    PLFLT     *py  = new PLFLT[PERIMETERPTS];
-    PLFLT     *xg1 = new PLFLT[nx];
-    PLFLT     *yg1 = new PLFLT[ny];
-    PLFLT     **z;
-    PLFLT     **w;
-    PLcGrid   cgrid1;
-    PLcGrid2  cgrid2;
-    PLFLT     *clevel    = new PLFLT[ns];
-    PLFLT     *shedge    = new PLFLT[ns + 1];
-    const int fill_width = 2, cont_color = 0, cont_width = 0;
+    int         i, j;
+    PLFLT       x, y, argx, argy, distort, r, t, zmin, zmax;
+    PLFLT       *px  = new PLFLT[PERIMETERPTS];
+    PLFLT       *py  = new PLFLT[PERIMETERPTS];
+    PLFLT       *xg1 = new PLFLT[nx];
+    PLFLT       *yg1 = new PLFLT[ny];
+    PLFLT       **z;
+    PLFLT       **w;
+    PLcGrid     cgrid1;
+    PLcGrid2    cgrid2;
+    PLFLT       *clevel    = new PLFLT[ns];
+    PLFLT       *shedge    = new PLFLT[ns + 1];
+    const int   cont_color = 0;
+    const PLFLT fill_width = 2.0, cont_width = 0.0;
+    PLFLT       colorbar_width, colorbar_height;
 
+#define NUM_AXES    1
+    PLINT      n_axis_opts  = NUM_AXES;
+    const char *axis_opts[] = {
+        "bcvtm",
+    };
+    PLINT      num_values[NUM_AXES];
+    PLFLT      *values[NUM_AXES];
+    PLFLT      axis_ticks[NUM_AXES] = {
+        0.0,
+    };
+    PLINT      axis_subticks[NUM_AXES] = {
+        0,
+    };
+#define NUM_LABELS    1
+    PLINT      n_labels     = NUM_LABELS;
+    PLINT      label_opts[] = {
+        PL_COLORBAR_LABEL_BOTTOM,
+    };
+    const char *labels[] = {
+        "Magnitude",
+    };
 
     // plplot initialization
 
@@ -240,6 +265,31 @@ x16::x16( int argc, const char ** argv )
         cont_color, cont_width,
         plstream::fill, true, NULL, NULL );
 
+    if ( colorbar )
+    {
+        // Smaller text
+        pls->schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls->smaj( 0.0, 0.5 );
+        pls->smin( 0.0, 0.5 );
+
+        num_values[0] = ns + 1;
+        values[0]     = shedge;
+        pls->colorbar( &colorbar_width, &colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            n_labels, label_opts, labels,
+            n_axis_opts, axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, (const PLFLT * const *) values );
+
+        // Reset text and tick sizes
+        pls->schr( 0.0, 1.0 );
+        pls->smaj( 0.0, 1.0 );
+        pls->smin( 0.0, 1.0 );
+    }
+
     pls->col0( 1 );
     pls->box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
     pls->col0( 2 );
@@ -262,6 +312,31 @@ x16::x16( int argc, const char ** argv )
         cont_color, cont_width,
         plstream::fill, true, plstream::tr1, (void *) &cgrid1 );
 
+    if ( colorbar )
+    {
+        // Smaller text
+        pls->schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls->smaj( 0.0, 0.5 );
+        pls->smin( 0.0, 0.5 );
+
+        num_values[0] = ns + 1;
+        values[0]     = shedge;
+        pls->colorbar( &colorbar_width, &colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            n_labels, label_opts, labels,
+            n_axis_opts, axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, (const PLFLT * const *) values );
+
+        // Reset text and tick sizes
+        pls->schr( 0.0, 1.0 );
+        pls->smaj( 0.0, 1.0 );
+        pls->smin( 0.0, 1.0 );
+    }
+
     pls->col0( 1 );
     pls->box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
     pls->col0( 2 );
@@ -285,6 +360,31 @@ x16::x16( int argc, const char ** argv )
         cont_color, cont_width,
         plstream::fill, false, plstream::tr2, (void *) &cgrid2 );
 
+    if ( colorbar )
+    {
+        // Smaller text
+        pls->schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls->smaj( 0.0, 0.5 );
+        pls->smin( 0.0, 0.5 );
+
+        num_values[0] = ns + 1;
+        values[0]     = shedge;
+        pls->colorbar( &colorbar_width, &colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            n_labels, label_opts, labels,
+            n_axis_opts, axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, (const PLFLT * const *) values );
+
+        // Reset text and tick sizes
+        pls->schr( 0.0, 1.0 );
+        pls->smaj( 0.0, 1.0 );
+        pls->smin( 0.0, 1.0 );
+    }
+
     pls->col0( 1 );
     pls->box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
     pls->col0( 2 );
@@ -306,9 +406,34 @@ x16::x16( int argc, const char ** argv )
 
     pls->shades( z, nx, ny, NULL, -1., 1., -1., 1.,
         shedge, ns + 1, fill_width,
-        2, 3,
+        2, 3.0,
         plstream::fill, false, plstream::tr2, (void *) &cgrid2 );
 
+    if ( colorbar )
+    {
+        // Smaller text
+        pls->schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls->smaj( 0.0, 0.5 );
+        pls->smin( 0.0, 0.5 );
+
+        num_values[0] = ns + 1;
+        values[0]     = shedge;
+        pls->colorbar( &colorbar_width, &colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            2, 3,
+            n_labels, label_opts, labels,
+            n_axis_opts, axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, (const PLFLT * const *) values );
+
+        // Reset text and tick sizes
+        pls->schr( 0.0, 1.0 );
+        pls->smaj( 0.0, 1.0 );
+        pls->smin( 0.0, 1.0 );
+    }
+
     pls->col0( 1 );
     pls->box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
     pls->col0( 2 );
@@ -379,6 +504,31 @@ x16::x16( int argc, const char ** argv )
         cont_color, cont_width,
         plstream::fill, false, plstream::tr2, (void *) &cgrid2 );
 
+    if ( colorbar )
+    {
+        // Smaller text
+        pls->schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls->smaj( 0.0, 0.5 );
+        pls->smin( 0.0, 0.5 );
+
+        num_values[0] = ns + 1;
+        values[0]     = shedge;
+        pls->colorbar( &colorbar_width, &colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            n_labels, label_opts, labels,
+            n_axis_opts, axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, (const PLFLT * const *) values );
+
+        // Reset text and tick sizes
+        pls->schr( 0.0, 1.0 );
+        pls->smaj( 0.0, 1.0 );
+        pls->smin( 0.0, 1.0 );
+    }
+
     // Now we can draw the perimeter.  (If do before, shade stuff may overlap.)
     for ( i = 0; i < PERIMETERPTS; i++ )
     {
