@@ -1,9 +1,9 @@
 //--------------------------------------------------------------------------
-// $Id: x17.cc 11760 2011-06-01 19:29:11Z airwin $
+// $Id: x17.cc 12832 2013-12-09 14:39:59Z andrewross $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
-// Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
+// Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
 // This file is part of PLplot.
@@ -27,6 +27,9 @@
 //--------------------------------------------------------------------------
 
 #include "plc++demos.h"
+#ifdef PL_HAVE_NANOSLEEP
+# include <time.h>
+#endif
 #ifdef PL_HAVE_UNISTD_H
 # include <unistd.h>
 #else
@@ -57,12 +60,15 @@ char  x17:: errmsg[160] = "";
 
 x17::x17( int argc, const char ** argv )
 {
-    PLINT      id1, n, nsteps = 1000;
-    bool       autoy, acc;
-    PLFLT      y1, y2, y3, y4, ymin, ymax, xlab, ylab;
-    PLFLT      t, tmin, tmax, tjump, dt, noise;
-    PLINT      colbox, collab, colline[4], styline[4];
-    const char *legline[4];
+    PLINT           id1, n, nsteps = 1000;
+    bool            autoy, acc;
+    PLFLT           y1, y2, y3, y4, ymin, ymax, xlab, ylab;
+    PLFLT           t, tmin, tmax, tjump, dt, noise;
+    PLINT           colbox, collab, colline[4], styline[4];
+    const char      *legline[4];
+#ifdef PL_HAVE_NANOSLEEP
+    struct timespec ts;
+#endif
 
     // plplot initialization
 
@@ -149,10 +155,14 @@ x17::x17( int argc, const char ** argv )
     y1 = y2 = y3 = y4 = 0.0;
     dt = 0.1;
 
+#ifdef PL_HAVE_NANOSLEEP
+    ts.tv_sec  = 0;
+    ts.tv_nsec = 10000000;
+#endif
     for ( n = 0; n < nsteps; n++ )
     {
-#ifdef PL_HAVE_USLEEP
-        usleep( 10000 ); // wait a little (10 ms) to simulate time elapsing
+#ifdef PL_HAVE_NANOSLEEP
+        nanosleep( &ts, NULL ); // wait a little (10 ms) to simulate time elapsing
 #else
 # ifdef PL_HAVE_POLL
         poll( 0, 0, 10 );
@@ -163,7 +173,7 @@ x17::x17( int argc, const char ** argv )
 # endif
 #endif
         t     = (double) n * dt;
-        noise = plrandd() - 0.5;
+        noise = pls->randd() - 0.5;
         y1    = y1 + noise;
         y2    = sin( t * M_PI / 18. );
         y3    = y2 * noise;
