@@ -1,9 +1,9 @@
 //--------------------------------------------------------------------------
-// $Id: x19.cc 11297 2010-11-02 03:31:14Z airwin $
+// $Id: x19.cc 12532 2013-09-26 15:18:37Z andrewross $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
-// Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
+// Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
 // This file is part of PLplot.
@@ -42,7 +42,7 @@ private:
 };
 
 void
-map_transform( PLFLT x, PLFLT y, PLFLT *xt, PLFLT *yt, PLPointer data )
+map_transform( PLFLT x, PLFLT y, PLFLT *xt, PLFLT *yt, PLPointer /* data */ )
 {
     double radius;
 
@@ -100,10 +100,10 @@ normalize_longitude( PLFLT lon )
 
 // A custom axis labeling function for longitudes and latitudes.
 void
-geolocation_labeler( PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data )
+geolocation_labeler( PLINT axis, PLFLT value, char *label, PLINT length, PLPointer /* data */ )
 {
-    const char *direction_label;
-    PLFLT      label_val;
+    const char *direction_label = "";
+    PLFLT      label_val        = 0.0;
 
     if ( axis == PL_Y_AXIS )
     {
@@ -170,8 +170,8 @@ x19::x19( int argc, const char ** argv )
     // Cartesian plots
     // Most of world
 
-    minx = 190;
-    maxx = 190 + 360;
+    minx = -170;
+    maxx = minx + 360;
 
     // Setup a custom latitude and longitude-based scaling function.
     pls->slabelfunc( geolocation_labeler, NULL );
