@@ -1,9 +1,9 @@
 //--------------------------------------------------------------------------
-// $Id: x20.cc 11760 2011-06-01 19:29:11Z airwin $
+// $Id: x20.cc 12176 2012-02-24 20:33:39Z andrewross $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
-// Copyright (C) 2004  Andrew Ross <andrewr@coriolis.greenend.org.uk>
+// Copyright (C) 2004  Andrew Ross
 // Copyright (C) 2004  Alan W. Irwin
 //
 // This file is part of PLplot.
@@ -335,7 +335,7 @@ x20::x20( int argc, const char ** argv )
         }
     }
 
-    pls->imagefr( img_f, width, height, 0., width, 0., height, 0., 0., img_min, img_max, pltr2, &cgrid2 );
+    pls->imagefr( img_f, width, height, 0., width, 0., height, 0., 0., img_min, img_max, pls->tr2, &cgrid2 );
 
     pls->Free2dGrid( cgrid2.xg, width + 1, height + 1 );
     pls->Free2dGrid( cgrid2.yg, width + 1, height + 1 );
