@@ -1,10 +1,10 @@
 //--------------------------------------------------------------------------
-// $Id: x22.cc 11629 2011-03-16 09:32:29Z andrewross $
+// $Id: x22.cc 12840 2013-12-10 23:52:18Z andrewross $
 //    Simple vector plot example
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
-// Copyright (C) 2004  Andrew Ross <andrewross@users.sourceforge.net>
+// Copyright (C) 2004  Andrew Ross
 //
 // This file is part of PLplot.
 //
@@ -32,13 +32,32 @@
 using namespace std;
 #endif
 
+//
+// Global transform function for a constriction using data passed in
+// This is the same transformation used in constriction.
+//
+void
+transform( PLFLT x, PLFLT y, PLFLT *xt, PLFLT *yt, PLPointer data )
+{
+    PLFLT *trdata;
+    PLFLT xmax;
+
+    trdata = (PLFLT *) data;
+    xmax   = *trdata;
+
+    *xt = x;
+    *yt = y / 4.0 * ( 3 - cos( M_PI * x / xmax ) );
+}
+
+
 class x22 {
 public:
     x22( int, const char ** );
 
 private:
     void circulation();
-    void constriction();
+    void constriction( int astyle );
+    void constriction2();
     void potential();
     void f2mnmx( PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmin, PLFLT *fmax );
 
@@ -49,7 +68,7 @@ private:
 
     PLFLT    **u, **v;
     PLcGrid2 cgrid2;
-    int      nx, ny;
+    int      nx, ny, nc, nseg;
 };
 
 // Vector plot of the circulation about the origin
@@ -93,12 +112,13 @@ x22::circulation()
 
 // Vector plot of flow through a constricted pipe
 void
-x22::constriction()
+x22::constriction( int astyle )
 {
     int   i, j;
     PLFLT dx, dy, x, y;
     PLFLT xmin, xmax, ymin, ymax;
     PLFLT Q, b, dbdx;
+    char  title[80];
 
     dx = 1.0;
     dy = 1.0;
@@ -111,17 +131,17 @@ x22::constriction()
     Q = 2.0;
     for ( i = 0; i < nx; i++ )
     {
+        x = ( i - nx / 2 + 0.5 ) * dx;
         for ( j = 0; j < ny; j++ )
         {
-            x = ( i - nx / 2 + 0.5 ) * dx;
             y = ( j - ny / 2 + 0.5 ) * dy;
             cgrid2.xg[i][j] = x;
             cgrid2.yg[i][j] = y;
-            b = ymax / 4.0 * ( 3 - cos( M_PI * x / xmax ) );
+            b = ymax / 4.0 * ( 3.0 - cos( M_PI * x / xmax ) );
             if ( fabs( y ) < b )
             {
                 dbdx = ymax / 4.0 * sin( M_PI * x / xmax ) *
-                       y / b;
+                       M_PI / xmax * y / b;
                 u[i][j] = Q * ymax / b;
                 v[i][j] = dbdx * u[i][j];
             }
@@ -134,12 +154,74 @@ x22::constriction()
     }
 
     pls->env( xmin, xmax, ymin, ymax, 0, 0 );
-    pls->lab( "(x)", "(y)", "#frPLplot Example 22 - constriction" );
+    sprintf( title, "#frPLplot Example 22 - constriction (arrow style %d)", astyle );
+    pls->lab( "(x)", "(y)", title );
     pls->col0( 2 );
-    pls->vect( u, v, nx, ny, -0.5, plstream::tr2, (void *) &cgrid2 );
+    pls->vect( u, v, nx, ny, -1.0, plstream::tr2, (void *) &cgrid2 );
     pls->col0( 1 );
 }
 
+//
+// Vector plot of flow through a constricted pipe
+// with a coordinate transform
+//
+void
+x22::constriction2( void )
+{
+    int   i, j;
+    PLFLT dx, dy, x, y;
+    PLFLT xmin, xmax, ymin, ymax;
+    PLFLT Q, b;
+#define NC    11
+    int   nc = NC;
+    PLFLT clev[NC];
+
+    dx = 1.0;
+    dy = 1.0;
+
+    xmin = -nx / 2 * dx;
+    xmax = nx / 2 * dx;
+    ymin = -ny / 2 * dy;
+    ymax = ny / 2 * dy;
+
+    pls->stransform( transform, ( PLPointer ) & xmax );
+
+    Q = 2.0;
+    for ( i = 0; i < nx; i++ )
+    {
+        x = ( i - nx / 2 + 0.5 ) * dx;
+        for ( j = 0; j < ny; j++ )
+        {
+            y = ( j - ny / 2 + 0.5 ) * dy;
+            cgrid2.xg[i][j] = x;
+            cgrid2.yg[i][j] = y;
+            b       = ymax / 4.0 * ( 3 - cos( M_PI * x / xmax ) );
+            u[i][j] = Q * ymax / b;
+            v[i][j] = 0.0;
+        }
+    }
+
+    for ( i = 0; i < nc; i++ )
+    {
+        clev[i] = Q + i * Q / ( nc - 1 );
+    }
+
+    pls->env( xmin, xmax, ymin, ymax, 0, 0 );
+    pls->lab( "(x)", "(y)", "#frPLplot Example 22 - constriction with plstransform" );
+    pls->col0( 2 );
+    pls->shades( (const PLFLT * const *) u, nx, ny, NULL,
+        xmin + dx / 2, xmax - dx / 2, ymin + dy / 2, ymax - dy / 2,
+        clev, nc, 0, 1, 1.0, plstream::fill, 0, NULL, NULL );
+    pls->vect( (const PLFLT * const *) u, (const PLFLT * const *) v, nx, ny,
+        -1.0, plstream::tr2, (void *) &cgrid2 );
+    // Plot edges using plpath (which accounts for coordinate transformation) rather than plline
+    pls->path( nseg, xmin, ymax, xmax, ymax );
+    pls->path( nseg, xmin, ymin, xmax, ymin );
+    pls->col0( 1 );
+
+    pls->stransform( NULL, NULL );
+}
+
 // Vector plot of the gradient of a shielded potential (see example 9)
 void
 x22::potential()
@@ -268,7 +350,6 @@ x22::x22( int argc, const char ** argv )
     PLFLT arrow2_x[6] = { -0.5, 0.3, 0.3, 0.5, 0.3, 0.3 };
     PLFLT arrow2_y[6] = { 0.0, 0.0, 0.2, 0.0, -0.2, 0.0 };
 
-
     // Create new plstream
     pls = new plstream();
 
@@ -280,8 +361,10 @@ x22::x22( int argc, const char ** argv )
 
     pls->init();
 
-    nx = 20;
-    ny = 20;
+    nx   = 20;
+    ny   = 20;
+    nc   = 11;
+    nseg = 20;
 
     // Allocate arrays
     pls->Alloc2dGrid( &cgrid2.xg, nx, ny );
@@ -300,13 +383,19 @@ x22::x22( int argc, const char ** argv )
     // Set arrow style using arrow_x and arrow_y then
     // plot using these arrows.
     pls->svect( arrow_x, arrow_y, narr, fill );
-    constriction();
+    constriction( 1 );
 
     // Set arrow style using arrow2_x and arrow2_y then
     // plot using these filled arrows.
     fill = true;
     pls->svect( arrow2_x, arrow2_y, narr, fill );
-    constriction();
+    constriction( 2 );
+
+    constriction2();
+
+    // Reset arrow style to the default by passing two
+    // NULL arrays (this are the default arguments)
+    pls->svect( );
 
     potential();
 
@@ -316,7 +405,6 @@ x22::x22( int argc, const char ** argv )
     pls->Free2dGrid( v, nx, ny );
 
     delete pls;
-    exit( 0 );
 }
 
 int main( int argc, const char ** argv )
