@@ -1,7 +1,7 @@
 // -*- coding: utf-8; -*-
 //
 //--------------------------------------------------------------------------
-// $Id: x26.cc 11717 2011-04-21 00:47:06Z airwin $
+// $Id: x26.cc 12336 2013-05-10 19:01:13Z andrewross $
 // Multi-lingual version of the first page of example 4.
 //--------------------------------------------------------------------------
 //
@@ -163,7 +163,7 @@ void x26::plot1( int type, const char *x_label, const char *y_label,
     PLINT      text_colors[2];
     PLINT      line_colors[2];
     PLINT      line_styles[2];
-    PLINT      line_widths[2];
+    PLFLT      line_widths[2];
     PLINT      symbol_numbers[2], symbol_colors[2];
     PLFLT      symbol_scales[2];
     const char *symbols[2];
@@ -234,7 +234,7 @@ void x26::plot1( int type, const char *x_label, const char *y_label,
     text_colors[0] = 2;
     line_colors[0] = 2;
     line_styles[0] = 1;
-    line_widths[0] = 1;
+    line_widths[0] = 1.0;
     // note from the above opt_array the first symbol (and box) indices
     // do not have to be specified
 
@@ -243,7 +243,7 @@ void x26::plot1( int type, const char *x_label, const char *y_label,
     text_colors[1]    = 3;
     line_colors[1]    = 3;
     line_styles[1]    = 1;
-    line_widths[1]    = 1;
+    line_widths[1]    = 1.0;
     symbol_colors[1]  = 3;
     symbol_scales[1]  = 1.;
     symbol_numbers[1] = 4;
@@ -258,7 +258,7 @@ void x26::plot1( int type, const char *x_label, const char *y_label,
         1, 1, 0, 0,
         nlegend, opt_array,
         1.0, 1.0, 2.0,
-        1., text_colors, (const char **) legend_text,
+        1., text_colors, (const char * const *) legend_text,
         NULL, NULL, NULL, NULL,
         line_colors, line_styles, line_widths,
         symbol_colors, symbol_scales, symbol_numbers,
