@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x27.cc 11935 2011-09-25 16:09:38Z airwin $
+// $Id: x27.cc 11992 2011-10-20 22:54:16Z andrewross $
 // Drawing "spirograph" curves - epitrochoids, cycolids, roulettes
 //--------------------------------------------------------------------------
 //
@@ -60,15 +60,15 @@ x27::x27( int argc, const char ** argv )
     // N.B. N is just a place holder since it is no longer used
     // (because we now have proper termination of the angle loop).
     PLFLT params[9][4] = {
-        21.0,   7.0,  7.0,  3.0, // Deltoid
-        21.0,   7.0, 10.0,  3.0,
-        21.0,  -7.0, 10.0,  3.0,
-        20.0,   3.0,  7.0, 20.0,
-        20.0,   3.0, 10.0, 20.0,
-        20.0,  -3.0, 10.0, 20.0,
-        20.0,  13.0,  7.0, 20.0,
-        20.0,  13.0, 20.0, 20.0,
-        20.0, -13.0, 20.0, 20.0
+        { 21.0,   7.0,  7.0,  3.0 }, // Deltoid
+        { 21.0,   7.0, 10.0,  3.0 },
+        { 21.0,  -7.0, 10.0,  3.0 },
+        { 20.0,   3.0,  7.0, 20.0 },
+        { 20.0,   3.0, 10.0, 20.0 },
+        { 20.0,  -3.0, 10.0, 20.0 },
+        { 20.0,  13.0,  7.0, 20.0 },
+        { 20.0,  13.0, 20.0, 20.0 },
+        { 20.0, -13.0, 20.0, 20.0 }
     };
 
     int   i;
@@ -170,11 +170,11 @@ x27::spiro( PLFLT params[], int fill )
     PLFLT        phi;
     PLFLT        phiw;
     PLFLT        dphi;
-    PLFLT        xmin;
-    PLFLT        xmax;
+    PLFLT        xmin = 0.0;
+    PLFLT        xmax = 0.0;
     PLFLT        xrange_adjust;
-    PLFLT        ymin;
-    PLFLT        ymax;
+    PLFLT        ymin = 0.0;
+    PLFLT        ymax = 0.0;
     PLFLT        yrange_adjust;
 
     // Fill the coordinates
