@@ -1,4 +1,4 @@
-// $Id: x20c.c 11623 2011-03-14 03:24:23Z airwin $
+// $Id: x20c.c 12095 2011-12-03 08:56:15Z andrewross $
 //
 //      plimage demo
 //
@@ -13,7 +13,7 @@
 
 void save_plot( char * );
 void gray_cmap( PLINT );
-int read_img( char *, PLFLT ***, int *, int *, int * );
+int read_img( const char *, PLFLT ***, int *, int *, int * );
 int get_clip( PLFLT *, PLFLT *, PLFLT *, PLFLT * );
 
 int  dbg           = 0;
@@ -140,7 +140,7 @@ main( int argc, const char *argv[] )
 
         pllab( "...around a blue square.", " ", "A red border should appear..." );
 
-        plimage( (const PLFLT **) z, XDIM, YDIM,
+        plimage( (const PLFLT * const *) z, XDIM, YDIM,
             1., (PLFLT) XDIM, 1., (PLFLT) YDIM, 0., 0.,
             1., (PLFLT) XDIM, 1., (PLFLT) YDIM );
     }
@@ -166,7 +166,7 @@ main( int argc, const char *argv[] )
 
         pllab( "No, an amplitude clipped \"sombrero\"", "", "Saturn?" );
         plptex( 2., 2., 3., 4., 0., "Transparent image" );
-        plimage( (const PLFLT **) z, XDIM, YDIM, 0., 2. * M_PI, 0., 3. * M_PI, 0.05, 1.,
+        plimage( (const PLFLT * const *) z, XDIM, YDIM, 0., 2. * M_PI, 0., 3. * M_PI, 0.05, 1.,
             0., 2. * M_PI, 0., 3. * M_PI );
         plFree2dGrid( r, XDIM, YDIM );
 
@@ -201,7 +201,7 @@ main( int argc, const char *argv[] )
     else
         pllab( "", " ", "Lena..." );
 
-    plimage( (const PLFLT **) img_f, width, height, 1., width, 1., height, 0., 0.,
+    plimage( (const PLFLT * const *) img_f, width, height, 1., width, 1., height, 0., 0.,
         1., width, 1., height );
 
     // plend();exit(0);
@@ -242,24 +242,24 @@ main( int argc, const char *argv[] )
         pladv( 0 );
 
         // display selection only
-        plimage( (const PLFLT **) img_f, width, height, 1., width, 1., height, 0., 0., xi, xe, ye, yi );
+        plimage( (const PLFLT * const *) img_f, width, height, 1., width, 1., height, 0., 0., xi, xe, ye, yi );
 
         plspause( 1 );
 
         // zoom in selection
         plenv( xi, xe, ye, yi, 1, -1 );
-        plimage( (const PLFLT **) img_f, width, height, 1., width, 1., height, 0., 0., xi, xe, ye, yi );
+        plimage( (const PLFLT * const *) img_f, width, height, 1., width, 1., height, 0., 0., xi, xe, ye, yi );
     }
 
     // Base the dynamic range on the image contents.
-    plMinMax2dGrid( (const PLFLT **) img_f, width, height, &img_max, &img_min );
+    plMinMax2dGrid( (const PLFLT * const *) img_f, width, height, &img_max, &img_min );
 
     // Draw a saturated version of the original image.  Only use the middle 50%
     // of the image's full dynamic range.
     plcol0( 2 );
     plenv( 0, width, 0, height, 1, -1 );
     pllab( "", "", "Reduced dynamic range image example" );
-    plimagefr( (const PLFLT **) img_f, width, height, 0., width, 0., height, 0., 0., img_min + img_max * 0.25, img_max - img_max * 0.25, NULL, NULL );
+    plimagefr( (const PLFLT * const *) img_f, width, height, 0., width, 0., height, 0., 0., img_min + img_max * 0.25, img_max - img_max * 0.25, NULL, NULL );
 
     // Draw a distorted version of the original image, showing its full dynamic range.
     plenv( 0, width, 0, height, 1, -1 );
@@ -292,7 +292,7 @@ main( int argc, const char *argv[] )
         }
     }
 
-    plimagefr( (const PLFLT **) img_f, width, height, 0., width, 0., height, 0., 0., img_min, img_max, pltr2, &cgrid2 );
+    plimagefr( (const PLFLT * const *) img_f, width, height, 0., width, 0., height, 0., 0., img_min, img_max, pltr2, &cgrid2 );
 
     plFree2dGrid( cgrid2.xg, width + 1, height + 1 );
     plFree2dGrid( cgrid2.yg, width + 1, height + 1 );
@@ -303,7 +303,7 @@ main( int argc, const char *argv[] )
 }
 
 // read image from file in binary ppm format
-int read_img( char *fname, PLFLT ***img_f, int *width, int *height, int *num_col )
+int read_img( const char *fname, PLFLT ***img_f, int *width, int *height, int *num_col )
 {
     FILE          *fp;
     unsigned char *img;
@@ -346,10 +346,10 @@ int read_img( char *fname, PLFLT ***img_f, int *width, int *height, int *num_col
     }
     // printf("width=%d height=%d num_col=%d\n", w, h, *num_col);
 
-    img = (unsigned char *) malloc( w * h * sizeof ( char ) );
+    img = (unsigned char *) malloc( (size_t) ( w * h ) * sizeof ( char ) );
     plAlloc2dGrid( &imf, w, h );
 
-    if ( fread( img, sizeof ( char ), w * h, fp ) != w * h )
+    if ( (int) fread( img, sizeof ( char ), (size_t) ( w * h ), fp ) != w * h )
     {
         fclose( fp );
         free( img );
