@@ -1,28 +1,28 @@
-/* $Id: x32c.c 10785 2010-01-31 20:05:17Z hezekiahcarty $
- *
- *      Box plot demo.
- *
- * Copyright (C) 2008 by FLLL <http://www.flll.jku.at>
- * Author: Robert Pollak <robert.pollak@jku.at>
- * Copyright (C) 2009 Andrew Ross
- *
- * This file is part of PLplot.
- *
- *  PLplot is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Library Public License as published
- * by the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * PLplot is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with PLplot; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- *
- */
+// $Id: x32c.c 11680 2011-03-27 17:57:51Z airwin $
+//
+//      Box plot demo.
+//
+// Copyright (C) 2008 by FLLL <http://www.flll.jku.at>
+// Author: Robert Pollak <robert.pollak@jku.at>
+// Copyright (C) 2009 Andrew Ross
+//
+// This file is part of PLplot.
+//
+//  PLplot is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Library General Public License as published
+// by the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// PLplot is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Library General Public License for more details.
+//
+// You should have received a copy of the GNU Library General Public License
+// along with PLplot; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+//
+//
 
 #include "plcdemos.h"
 
@@ -31,11 +31,11 @@ plfbox( PLFLT x, PLFLT y25, PLFLT y50, PLFLT y75, PLFLT lw, PLFLT uw );
 void
 plcircle( PLFLT x, PLFLT y );
 
-/*--------------------------------------------------------------------------*\
- * main
- *
- * Does a box plot.
- \*--------------------------------------------------------------------------*/
+//--------------------------------------------------------------------------
+// main
+//
+// Does a box plot.
+//--------------------------------------------------------------------------
 
 int
 main( int argc, const char *argv[] )
@@ -43,7 +43,7 @@ main( int argc, const char *argv[] )
     int          i;
     char         string[20];
     PLFLT        x0;
-    /* quartiles */
+    // quartiles
     static PLFLT y25[] = { 0.984, 0.980, 0.976, 0.975, 0.973,
                            0.967, 0.974, 0.954, 0.987, 0.991 };
     static PLFLT y50[] = { 0.994, 0.999, 1.035, 0.995, 1.002,
@@ -51,27 +51,27 @@ main( int argc, const char *argv[] )
     static PLFLT y75[] = { 1.054, 1.040, 1.066, 1.025, 1.043,
                            1.017, 1.054, 1.004, 1.047, 1.031 };
 
-    /* lower and upper whisker */
+    // lower and upper whisker
     static PLFLT lw[] = { 0.964, 0.950, 0.926, 0.955, 0.963,
                           0.937, 0.944, 0.924, 0.967, 0.941 };
 
     static PLFLT uw[] = { 1.071, 1.062, 1.093, 1.045, 1.072,
                           1.067, 1.085, 1.024, 1.057, 1.071 };
 
-    /* outliers */
+    // outliers
     static PLFLT outx[] = { 3.5, 6.5 };
     static PLFLT outy[] = { 0.89, 1.09 };
-/*
- *  static PLFLT pos[] = {0.0, 0.25, 0.5, 0.75, 1.0};
- *  static PLFLT red[] = {0.0, 0.25, 0.5, 1.0, 1.0};
- *  static PLFLT green[] = {1.0, 0.5, 0.5, 0.5, 1.0};
- *  static PLFLT blue[] = {1.0, 1.0, 0.5, 0.25, 0.0};
- */
-/* Parse and process command line arguments */
+//
+//  static PLFLT pos[] = {0.0, 0.25, 0.5, 0.75, 1.0};
+//  static PLFLT red[] = {0.0, 0.25, 0.5, 1.0, 1.0};
+//  static PLFLT green[] = {1.0, 0.5, 0.5, 0.5, 1.0};
+//  static PLFLT blue[] = {1.0, 1.0, 0.5, 0.25, 0.0};
+//
+// Parse and process command line arguments
 
     (void) plparseopts( &argc, argv, PL_PARSE_FULL );
 
-/* Initialize plplot */
+// Initialize plplot
 
     plinit();
 
@@ -84,7 +84,7 @@ main( int argc, const char *argv[] )
     plbox( "bc", 1.0, 0, "bcgnst", 0, 0 );
     pllab( "Group", "Value", "#frPLplot Example 32" );
 
-    /* plscmap1l(1,5,pos,red,green,blue,NULL); */
+    // plscmap1l(1,5,pos,red,green,blue,NULL);
 
     for ( i = 0; i < 10; i++ )
     {
@@ -95,11 +95,11 @@ main( int argc, const char *argv[] )
         plmtex( "b", 1.0, ( ( i + 1 ) * .1 - .05 ), 0.5, string );
     }
 
-    /* some outliers plotted with intermediate-sized circles, see PLplot
-     * example 06 for other possibilities.*/
+    // some outliers plotted with intermediate-sized circles, see PLplot
+    // example 06 for other possibilities.
     plpoin( 2, outx, outy, 22 );
 
-/* Don't forget to call plend() to finish off! */
+// Don't forget to call plend() to finish off!
 
     plend();
     exit( 0 );
@@ -113,12 +113,12 @@ plfbox( PLFLT x, PLFLT y25, PLFLT y50, PLFLT y75, PLFLT lw, PLFLT uw )
     PLFLT xmin, xmax;
     PLFLT xmid, xwidth;
 
-    spacing = .4; /* in x axis units */
+    spacing = .4; // in x axis units
 
     xmin = x + spacing / 2.;
     xmax = x + 1. - spacing / 2.;
 
-    /* box */
+    // box
 
     px[0] = xmin;
     py[0] = y25;
@@ -138,7 +138,7 @@ plfbox( PLFLT x, PLFLT y25, PLFLT y50, PLFLT y75, PLFLT lw, PLFLT uw )
     plline( 5, px, py );
 
 
-    /* median */
+    // median
 
     mx[0] = xmin;
     my[0] = y50;
@@ -148,7 +148,7 @@ plfbox( PLFLT x, PLFLT y25, PLFLT y50, PLFLT y75, PLFLT lw, PLFLT uw )
     pllsty( 1 );
     plline( 2, mx, my );
 
-    /* lower whisker */
+    // lower whisker
 
     xmid   = ( xmin + xmax ) / 2.;
     xwidth = xmax - xmin;
@@ -157,7 +157,7 @@ plfbox( PLFLT x, PLFLT y25, PLFLT y50, PLFLT y75, PLFLT lw, PLFLT uw )
     wx[1]  = xmid;
     wy[1]  = y25;
 
-    pllsty( 2 ); /* short dashes and gaps */
+    pllsty( 2 ); // short dashes and gaps
     plline( 2, wx, wy );
 
     barx[0] = xmid - xwidth / 4.;
@@ -168,14 +168,14 @@ plfbox( PLFLT x, PLFLT y25, PLFLT y50, PLFLT y75, PLFLT lw, PLFLT uw )
     pllsty( 1 );
     plline( 2, barx, bary );
 
-    /* upper whisker */
+    // upper whisker
 
     xmid   = ( xmin + xmax ) / 2.;
     xwidth = xmax - xmin;
     wy[0]  = y75;
     wy[1]  = uw;
 
-    pllsty( 2 ); /* short dashes and gaps */
+    pllsty( 2 ); // short dashes and gaps
     plline( 2, wx, wy );
 
     bary[0] = uw;
