@@ -1,4 +1,4 @@
-!      $Id: x15f.f90 11680 2011-03-27 17:57:51Z airwin $
+!      $Id: x15f.f90 12320 2013-05-02 01:20:31Z arjenmarkus $
 !      Shade plot demo.
 !      Does a variety of shade plots.
 !
@@ -158,10 +158,11 @@
       integer xdim, XPTS, YPTS
       real(kind=plflt)  z(xdim,YPTS), zmin, zmax
 
-      character*1 undefined
+      character(len=1) undefined
       real(kind=plflt)  shade_min, shade_max, sh_color
-      integer sh_cmap, sh_width
-      integer min_color, min_width, max_color, max_width
+      integer sh_cmap
+      integer min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
 
       sh_cmap   = 0
       min_color = 0
@@ -214,24 +215,25 @@
       integer xdim, XPTS, YPTS
       real(kind=plflt)  z(xdim,YPTS), zmin, zmax
 
-      character*1 undefined
+      character(len=1) undefined
       real(kind=plflt)  shade_min, shade_max, sh_color
-      integer sh_cmap, sh_width
-      integer min_color, min_width, max_color, max_width
+      integer sh_cmap
+      integer min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
       integer i, j
 
       integer nlin(10), inc(2,10), del(2,10)
       data nlin /1, 1, 1, 1, 1, 2, 2, 2, 2, 2/
       data ( (inc(i,j), i=1,2), j=1,10) / &
            450, 0, -450, 0, 0, 0, 900, 0, &
-           300, 0, 450,-450, 0, 900, 0, 450, & 
+           300, 0, 450,-450, 0, 900, 0, 450, &
            450, -450, 0, 900/
       data ( (del(i,j), i=1,2), j=1,10) / &
            2000, 2000, 2000, 2000, 2000, 2000, &
            2000, 2000, 2000, 2000, 2000, 2000, &
            2000, 2000, 2000, 2000, 4000, 4000, &
            4000, 2000/
-      
+
       sh_cmap   = 0
       min_color = 0
       min_width = 0
@@ -267,8 +269,8 @@
 !--------------------------------------------------------------------------
 !     plot3
 !
-!     Illustrates shaded regions in 3d, using a different fill pattern for 
-!     each region.  
+!     Illustrates shaded regions in 3d, using a different fill pattern for
+!     each region.
 !--------------------------------------------------------------------------
 
       subroutine plot3
@@ -289,8 +291,8 @@
       call plw3d(1._plflt, 1._plflt, 1._plflt, -1.0_plflt, 1.0_plflt, &
            -1.0_plflt, 1.0_plflt, 0.0_plflt,1.5_plflt, 30._plflt, -40._plflt)
 
-!     Plot using identity transform 
-    
+!     Plot using identity transform
+
       call plcol0(1)
       call plbox3("bntu", "X", 0.0_plflt, 0, "bntu", "Y", 0.0_plflt, 0, &
            "bcdfntu", "Z", 0.5_plflt, 0)
