@@ -1,4 +1,4 @@
-!      $Id: x16af.f90 11680 2011-03-27 17:57:51Z airwin $
+!      $Id: x16af.f90 12320 2013-05-02 01:20:31Z arjenmarkus $
 !      Demonstration of plshade plotting
 !      Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display
 !
@@ -57,8 +57,9 @@
       real(kind=plflt)    z(xdim, ydim), w(xdim, ydim), clevel(NCONTR)
       real(kind=plflt)    xmin, xmax, ymin, ymax, zmin, zmax, x, y
       real(kind=plflt)    shade_min, shade_max, sh_color
-      integer   i, j, sh_cmap, sh_width
-      integer   min_color, min_width, max_color, max_width
+      integer   i, j, sh_cmap
+      integer   min_color, max_color
+      real(kind=plflt)    sh_width, min_width, max_width
 
       xmin = -1._plflt
       ymin = -1._plflt
@@ -145,9 +146,10 @@
       integer   nxsub, nysub
       integer   ncolbox, ncollab
       integer   i, j, kx, lx, ky, ly
-      integer   sh_cmap, sh_width
-      integer   min_color, min_width, max_color, max_width
-      character*8 xopt, yopt
+      integer   sh_cmap
+      integer   min_color, max_color
+      real(kind=plflt) sh_width, min_width, max_width
+      character(len=8) xopt, yopt
 
 !      Set up for plshade call
 
