@@ -1,4 +1,4 @@
-! $Id: x20f.f90 11680 2011-03-27 17:57:51Z airwin $
+! $Id: x20f.f90 12725 2013-11-20 22:58:00Z airwin $
 !
 !      Copyright (C) 2004  Alan W. Irwin
 !      Copyright (C) 2008  Andrew Ross
@@ -97,7 +97,7 @@
       logical dbg
       logical nosombrero
       logical nointeractive
-      character*80 f_name
+      character(len=80) f_name
 
 !
 !     Bugs in plimage():
@@ -144,7 +144,7 @@
               z(XDIM,i) = 1._plflt
           enddo
 
-          call pllab('...around a blue square.',' ', &
+          call pllab('...around a blue square.',' '//PL_END_OF_STRING, &
               'A red border should appear...')
 
           call plimage(z, 1._plflt, XDIMR, 1._plflt, YDIMR, 0._plflt, 0._plflt, &
@@ -207,9 +207,9 @@
 
       if (.not. nointeractive) then
           call pllab('Set and drag Button 1 to (re)set selection, Butto'// &
-               'n 2 to finish.',' ','Lena...')
+               'n 2 to finish.',' '//PL_END_OF_STRING,'Lena...')
       else
-          call pllab('',' ','Lena...')
+          call pllab('',' '//PL_END_OF_STRING,'Lena...')
       endif
 
       call plimage(img_f, 1._plflt, width_r, 1._plflt, &
@@ -224,7 +224,7 @@
 
           if (get_clip(xi, xe, yi, ye)) then
               call plend()
-              call myexit(0)
+              stop
           endif
 
 !
@@ -295,7 +295,7 @@
       deallocate( img_f, xg, yg )
 
       call plend()
-      call myexit(0)
+      stop
 
       contains
 
@@ -304,7 +304,7 @@
       implicit none
       integer     bytes
 
-      character*8 string
+      character(len=8) string
       integer     i
       integer     ierr
 
@@ -330,17 +330,17 @@
 
       character, dimension(8) :: img
       character(len=80), dimension(2) :: ver
-      integer      i, j, k, w, h, b
+      integer ::  i, j, w, h, b
 
-      integer      ierr
-      integer      count
-      integer      record
+      integer :: ierr
+      integer ::  count
+      integer ::  record
 
-      integer      bytes
-      integer      lastlf
-      integer      first
-      integer      last
-      integer      pixel
+      integer ::  bytes = 0
+      integer ::  lastlf = 0
+      integer ::  first
+      integer ::  last
+      integer ::  pixel
 
 !     Naive grayscale binary ppm reading. If you know how to, improve it
 
@@ -379,11 +379,6 @@
       enddo
 
 !     Found the line with the sizes, copy this one and the next
-!     Note (AM):
-!     For reasons I have not been able to determine the original
-!     method (copied from the F77 example) did not work on my
-!     MinGW+gfortran platform - it caused an end-of-file error.
-!     So, instead use an internal read.
 
       count = count + 1
       read( 10, '(a)', iostat = ierr ) ver(2)
@@ -499,7 +494,9 @@
       real(kind=plflt) sx(5), sy(5)
 
       integer PLK_Return
-      parameter(PLK_Return = Z'0D')
+      data PLK_Return / Z'0D' /
+      integer hex100
+      data hex100 / Z'100' /
 
       xxi = xi
       yyi = yi
@@ -534,7 +531,7 @@
                sy(5) = yyi
             endif
 
-            if (iand(gin%state,Z'100').ne.0) then
+            if (iand(gin%state,hex100).ne.0) then
                xxe = gin%wX
                yye = gin%wY
                if (start) then
@@ -640,12 +637,3 @@
       enddo
       end
 
-!----------------------------------------------------------------------------
-!      Subroutine myexit
-!      Just calls exit - works around bug in gfortran <= 4.1
-      subroutine myexit(icode)
-      implicit none
-      integer icode
-
-      call exit(icode)
-      end
