@@ -1,4 +1,4 @@
-!     $Id: x24f.f90 11680 2011-03-27 17:57:51Z airwin $  
+!     $Id: x24f.f90 11984 2011-10-19 23:26:23Z andrewross $  
 !
 !   Unicode Pace Flag
 !
@@ -59,7 +59,7 @@ program x24f
   real(kind=plflt)  sx(12)
   real(kind=plflt)  sy(12)
   
-  character*30 peace(12)
+  character(len=30) peace(12)
   
   data (red(i) ,i=1,7)   / 240, 204, 204, 204,   0,  39, 125 /
   data (green(i) ,i=1,7) / 240,   0, 125, 204, 204,  80,   0 /
