@@ -1,6 +1,6 @@
 !  -*- coding: utf-8; -*-
 !
-!  $Id: x26f.f90 11717 2011-04-21 00:47:06Z airwin $
+!  $Id: x26f.f90 12320 2013-05-02 01:20:31Z arjenmarkus $
 !
 !  Multi-lingual version of the first page of example 4.
 !
@@ -77,12 +77,12 @@ program x26f
   integer, parameter :: nolangs = 2
   integer, parameter :: nlegend = 2
 
-  character*80 x_label(nolangs)
-  character*80 y_label(nolangs)
-  character*80 legend_text(2,nolangs)
-  character*80 alty_label(nolangs)
-  character*80 title_label(nolangs)
-  character*80 line_label(nolangs)
+  character(len=80) x_label(nolangs)
+  character(len=80) y_label(nolangs)
+  character(len=80) legend_text(2,nolangs)
+  character(len=80) alty_label(nolangs)
+  character(len=80) title_label(nolangs)
+  character(len=80) line_label(nolangs)
 
   integer      i, j
 
@@ -155,13 +155,13 @@ end program x26f
     integer          text_colors(nlegend)
     integer          line_colors(nlegend)
     integer          line_styles(nlegend)
-    integer          line_widths(nlegend)
+    real(kind=plflt) line_widths(nlegend)
     integer          symbol_numbers(nlegend)
     integer          symbol_colors(nlegend)
     real(kind=plflt) symbol_scales(nlegend)
-    character*20     symbols(nlegend)
-    integer          box_colors(0), box_patterns(0), box_line_widths(0)
-    real(kind=plflt) box_scales(0)
+    character(len=20) symbols(nlegend)
+    integer          box_colors(0), box_patterns(0)
+    real(kind=plflt) box_scales(0), box_line_widths(0)
     real(kind=plflt) legend_width, legend_height
 
     call pladv(0)
