@@ -1,4 +1,4 @@
-! $Id: x27f.f90 11851 2011-08-04 08:58:52Z andrewross $
+! $Id: x27f.f90 12626 2013-10-24 23:01:26Z andrewross $
 !
 !  Drawing "spirograph" curves - epitrochoids, cycolids, roulettes
 !
@@ -173,6 +173,12 @@ subroutine spiro( params, fill )
 
   n = windings*steps+1
 
+  ! Initialize variables to prevent compiler warnings
+  xmin = 0.0
+  xmax = 0.0
+  ymin = 0.0
+  ymax = 0.0
+
   do i = 1,n
      phi       = dble(i-1) * dphi
      phiw      = (params(1)-params(2))/params(2)*phi
