@@ -1,4 +1,4 @@
-!  $Id: x28f.f90 11680 2011-03-27 17:57:51Z airwin $
+!  $Id: x28f.f90 12164 2012-02-01 10:11:21Z andrewross $
 !
 !   Demonstrates plotting text in 3D (plmtex3, plptex3)
 !
@@ -57,7 +57,9 @@
    integer     :: i, j
    real(PLFLT) :: radius, pitch, xpos, ypos, zpos
 
-   character(len=1)  :: p1string = "O"
+   ! N.B. Need to append PL_END_OF_STRING so spaces get
+   ! properly plotted.
+   character(len=2)  :: p1string = "O"//PL_END_OF_STRING
    character(len=80) :: pstring  = &
      "The future of our civilization depends on software freedom."
 
@@ -343,7 +345,7 @@
       x_shear = 0.
       y_shear = 0.
       z_shear = 1.
-      p1string = pstring(i:i)
+      p1string(1:1) = pstring(i:i)
       call plptex3( &
          xpos, ypos, zpos, &
          x_inclination, y_inclination, z_inclination, &
