@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x01.java 11301 2010-11-02 17:21:08Z airwin $
+// $Id: x01.java 12288 2013-01-30 04:40:35Z airwin $
 //--------------------------------------------------------------------------
 
 //--------------------------------------------------------------------------
@@ -32,6 +32,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.lang.Math;
 
@@ -58,7 +59,7 @@ class x01 {
         // Parse and process command line arguments.
 
 //         plMergeOpts(options, "x01c options", notes);
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
 // Print out version number.
 
@@ -234,9 +235,9 @@ class x01 {
         // Draw the line.
 
         pls.col0( 3 );
-        pls.wid( 2 );
+        pls.width( 2 );
         pls.line( x, y );
-        pls.wid( 1 );
+        pls.width( 1 );
     }
 
     void plot3()
