@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x02.java 11301 2010-11-02 17:21:08Z airwin $
+// $Id: x02.java 12288 2013-01-30 04:40:35Z airwin $
 //--------------------------------------------------------------------------
 
 //--------------------------------------------------------------------------
@@ -30,6 +30,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.text.*;
 
@@ -47,7 +48,7 @@ class x02 {
 
         // Parse and process command line arguments.
 
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         // Initialize plplot.
 
@@ -164,14 +165,14 @@ class x02 {
             vmax = 0.9;
             for ( j = 0; j <= 2; j++ )
             {
-                pls.wid( j + 1 );
+                pls.width( j + 1 );
                 pls.vpor( vmin, vmax, vmin, vmax );
                 pls.wind( 0.0, 1.0, 0.0, 1.0 );
                 pls.box( "bc", 0.0, 0, "bc", 0.0, 0 );
                 vmin = vmin + 0.1;
                 vmax = vmax - 0.1;
             }
-            pls.wid( 1 );
+            pls.width( 1 );
             pls.ptex( 0.5, 0.5, 1.0, 0.0, 0.5, text );
         }
     }
