@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x04.java 11717 2011-04-21 00:47:06Z airwin $
+// $Id: x04.java 12329 2013-05-02 22:44:50Z airwin $
 //--------------------------------------------------------------------------
 
 //--------------------------------------------------------------------------
@@ -30,6 +30,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.lang.Math;
 
@@ -45,7 +46,7 @@ class x04 {
     {
         // Parse and process command line arguments.
 
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         // Initialize plplot.
 
@@ -76,7 +77,7 @@ class x04 {
         int[] text_colors;
         int[] line_colors;
         int[] line_styles;
-        int[] line_widths;
+        double[] line_widths;
         int[] symbol_numbers;
         int[] symbol_colors;
         double[] symbol_scales;
@@ -149,19 +150,19 @@ class x04 {
         text_colors    = new int[nlegend];
         line_colors    = new int[nlegend];
         line_styles    = new int[nlegend];
-        line_widths    = new int[nlegend];
+        line_widths    = new double[nlegend];
         symbol_numbers = new int[nlegend];
         symbol_colors  = new int[nlegend];
         symbol_scales  = new double[nlegend];
 
         // Draw a legend
         // First legend entry.
-        opt_array[0]   = PLStream.PL_LEGEND_LINE;
+        opt_array[0]   = PL_LEGEND_LINE;
         text_colors[0] = 2;
         text[0]        = "Amplitude";
         line_colors[0] = 2;
         line_styles[0] = 1;
-        line_widths[0] = 1;
+        line_widths[0] = 1.;
         // note from the above opt_array the first symbol (and box) indices
         // do not have to be specified EXCEPT for symbols.
         // Although this is unused, it can't be undefined as the String
@@ -171,12 +172,12 @@ class x04 {
         // Second legend entry.
         if ( nlegend == 2 )
         {
-            opt_array[1]      = PLStream.PL_LEGEND_LINE | PLStream.PL_LEGEND_SYMBOL;
+            opt_array[1]      = PL_LEGEND_LINE | PL_LEGEND_SYMBOL;
             text_colors[1]    = 3;
             text[1]           = "Phase shift";
             line_colors[1]    = 3;
             line_styles[1]    = 1;
-            line_widths[1]    = 1;
+            line_widths[1]    = 1.;
             symbol_colors[1]  = 3;
             symbol_scales[1]  = 1.;
             symbol_numbers[1] = 4;
@@ -188,7 +189,7 @@ class x04 {
 
         pls.scol0a( 15, 32, 32, 32, 0.70 );
         pls.legend( legend_width, legend_height,
-            PLStream.PL_LEGEND_BACKGROUND | PLStream.PL_LEGEND_BOUNDING_BOX, 0,
+            PL_LEGEND_BACKGROUND | PL_LEGEND_BOUNDING_BOX, 0,
             0.0, 0.0, 0.1, 15,
             1, 1, 0, 0, opt_array,
             1.0, 1.0, 2.0,
