@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x14.java 11301 2010-11-02 17:21:08Z airwin $
+// $Id: x14.java 12240 2012-10-04 22:10:12Z andrewross $
 //--------------------------------------------------------------------------
 
 //--------------------------------------------------------------------------
@@ -31,6 +31,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.lang.Math;
 import java.text.*;
@@ -61,7 +62,7 @@ class x14 {
 
         // Parse and process command line arguments.
 
-        pls1.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls1.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         //      If valid geometry specified on command line, use it for both streams.
 
