@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x16.java 11301 2010-11-02 17:21:08Z airwin $
+// $Id: x16.java 12372 2013-06-06 21:44:33Z andrewross $
 //--------------------------------------------------------------------------
 
 //--------------------------------------------------------------------------
@@ -30,6 +30,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.lang.Math;
 
@@ -39,6 +40,8 @@ class x16 {
     static final int XPTS         = 35;
     static final int YPTS         = 46;
     static final int PERIMETERPTS = 100;
+    static final int NUM_AXES     = 1;
+    static final int NUM_LABELS   = 1;
 
     // calculated constants and array that depends on them
     static final double XSPA = 2. / ( XPTS - 1 );
@@ -87,10 +90,25 @@ class x16 {
         double[][] yg2  = new double[XPTS][YPTS];
         double[] clevel = new double[NSHADES];
         double[] shedge = new double[NSHADES + 1];
-        final int fill_width = 2, cont_color = 0, cont_width = 0;
+        final int    cont_color = 0;
+        final double fill_width = 2., cont_width = 0.;
+        double[] colorbar_width  = new double[1];
+        double[] colorbar_height = new double[1];
+
+        int n_axis_opts = NUM_AXES;
+        int[] num_values  = new int[NUM_AXES];
+        double[][] values = new double[NUM_AXES][NSHADES + 1];
+        String axis_opts[]     = { "bcvtm" };
+        double axis_ticks[]    = { 0.0 };
+        int    axis_subticks[] = { 0 };
+        double filler_values[] = { 0.0, 1.0 };
+
+        int    n_labels     = NUM_LABELS;
+        int    label_opts[] = { PL_COLORBAR_LABEL_BOTTOM };
+        String labels[]     = { "Magnitude" };
 
         // Parse and process command line arguments.
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         // Load colour palettes
         pls.spal0( "cmap0_black_on_white.pal" );
@@ -121,10 +139,10 @@ class x16 {
         zmax = fmax;
 
         for ( i = 0; i < NSHADES; i++ )
-            clevel[i] = zmin + ( zmax - zmin ) * ( i + 0.5 ) / (double) NSHADES;
+            clevel[i] = zmin + ( zmax - zmin ) * ( i + 0.5 ) / NSHADES;
 
         for ( i = 0; i < NSHADES + 1; i++ )
-            shedge[i] = zmin + ( zmax - zmin ) * (double) i / (double) NSHADES;
+            shedge[i] = zmin + ( zmax - zmin ) * i / NSHADES;
 
         for ( i = 0; i < XPTS; i++ )
         {
@@ -166,6 +184,31 @@ class x16 {
             cont_color, cont_width,
             true, xg0, yg0 );
 
+        // Smaller text
+        pls.schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls.smaj( 0.0, 0.5 );
+        pls.smin( 0.0, 0.5 );
+
+        num_values[0] = NSHADES + 1;
+        for ( i = 0; i < NSHADES + 1; i++ )
+        {
+            values[0][i] = shedge[i];
+        }
+        pls.colorbar( colorbar_width, colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            label_opts, labels,
+            axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, values );
+
+        // Reset text and tick sizes
+        pls.schr( 0.0, 1.0 );
+        pls.smaj( 0.0, 1.0 );
+        pls.smin( 0.0, 1.0 );
+
         pls.col0( 1 );
         pls.box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
         pls.col0( 2 );
@@ -191,6 +234,31 @@ class x16 {
             cont_color, cont_width,
             true, xg1, yg1 );
 
+        // Smaller text
+        pls.schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls.smaj( 0.0, 0.5 );
+        pls.smin( 0.0, 0.5 );
+
+        num_values[0] = NSHADES + 1;
+        for ( i = 0; i < NSHADES + 1; i++ )
+        {
+            values[0][i] = shedge[i];
+        }
+        pls.colorbar( colorbar_width, colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            label_opts, labels,
+            axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, values );
+
+        // Reset text and tick sizes
+        pls.schr( 0.0, 1.0 );
+        pls.smaj( 0.0, 1.0 );
+        pls.smin( 0.0, 1.0 );
+
         pls.col0( 1 );
         pls.box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
         pls.col0( 2 );
@@ -217,6 +285,31 @@ class x16 {
             cont_color, cont_width,
             false, xg2, yg2 );
 
+        // Smaller text
+        pls.schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls.smaj( 0.0, 0.5 );
+        pls.smin( 0.0, 0.5 );
+
+        num_values[0] = NSHADES + 1;
+        for ( i = 0; i < NSHADES + 1; i++ )
+        {
+            values[0][i] = shedge[i];
+        }
+        pls.colorbar( colorbar_width, colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            label_opts, labels,
+            axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, values );
+
+        // Reset text and tick sizes
+        pls.schr( 0.0, 1.0 );
+        pls.smaj( 0.0, 1.0 );
+        pls.smin( 0.0, 1.0 );
+
         pls.col0( 1 );
         pls.box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
         pls.col0( 2 );
@@ -241,9 +334,34 @@ class x16 {
 
         pls.shades( z, -1., 1., -1., 1.,
             shedge, fill_width,
-            2, 3,
+            2, 3.,
             false, xg2, yg2 );
 
+        // Smaller text
+        pls.schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls.smaj( 0.0, 0.5 );
+        pls.smin( 0.0, 0.5 );
+
+        num_values[0] = NSHADES + 1;
+        for ( i = 0; i < NSHADES + 1; i++ )
+        {
+            values[0][i] = shedge[i];
+        }
+        pls.colorbar( colorbar_width, colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            2, 3.0,
+            label_opts, labels,
+            axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, values );
+
+        // Reset text and tick sizes
+        pls.schr( 0.0, 1.0 );
+        pls.smaj( 0.0, 1.0 );
+        pls.smin( 0.0, 1.0 );
+
         pls.col0( 1 );
         pls.box( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 );
         pls.col0( 2 );
@@ -290,17 +408,42 @@ class x16 {
         zmax = fmax;
 
         for ( i = 0; i < NSHADES + 1; i++ )
-            shedge[i] = zmin + ( zmax - zmin ) * (double) i / (double) NSHADES;
+            shedge[i] = zmin + ( zmax - zmin ) * i / NSHADES;
 
         pls.shades( z, -1., 1., -1., 1.,
             shedge, fill_width,
             cont_color, cont_width,
             false, xg2, yg2 );
 
+        // Smaller text
+        pls.schr( 0.0, 0.75 );
+        // Small ticks on the vertical axis
+        pls.smaj( 0.0, 0.5 );
+        pls.smin( 0.0, 0.5 );
+
+        num_values[0] = NSHADES + 1;
+        for ( i = 0; i < NSHADES + 1; i++ )
+        {
+            values[0][i] = shedge[i];
+        }
+        pls.colorbar( colorbar_width, colorbar_height,
+            PL_COLORBAR_SHADE | PL_COLORBAR_SHADE_LABEL, 0,
+            0.005, 0.0, 0.0375, 0.875, 0, 1, 1, 0.0, 0.0,
+            cont_color, cont_width,
+            label_opts, labels,
+            axis_opts,
+            axis_ticks, axis_subticks,
+            num_values, values );
+
+        // Reset text and tick sizes
+        pls.schr( 0.0, 1.0 );
+        pls.smaj( 0.0, 1.0 );
+        pls.smin( 0.0, 1.0 );
+
 // Now we can draw the perimeter.  (If do before, shade stuff may overlap.)
         for ( i = 0; i < PERIMETERPTS; i++ )
         {
-            t     = ( 2. * Math.PI / ( PERIMETERPTS - 1 ) ) * (double) i;
+            t     = ( 2. * Math.PI / ( PERIMETERPTS - 1 ) ) * i;
             px[i] = Math.cos( t );
             py[i] = Math.sin( t );
         }
