@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x21.java 11301 2010-11-02 17:21:08Z airwin $
+// $Id: x21.java 12329 2013-05-02 22:44:50Z airwin $
 //--------------------------------------------------------------------------
 //
 //--------------------------------------------------------------------------
@@ -29,6 +29,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.lang.Math;
 
@@ -134,6 +135,7 @@ class x21 {
         double x[], y[], z[], clev[];
         double xg[], yg[], zg[][];
         double xg0[][], yg0[][];
+        double xx[], yy[];
         double zmin, zmax, lzm[], lzM[];
         int    i, j, k;
         int    alg;
@@ -153,20 +155,24 @@ class x21 {
 
         // Parse and process command line arguments.
         // pls.MergeOpts(options, "x22c options", NULL);
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         opt[2] = wmin;
-        opt[3] = (double) knn_order;
+        opt[3] = knn_order;
         opt[4] = threshold;
 
         // Initialize PLplot.
         pls.init();
 
+        cmap1_init();
+
         pls.seed( 5489 );
 
-        x = new double[pts];
-        y = new double[pts];
-        z = new double[pts];
+        x  = new double[pts];
+        y  = new double[pts];
+        z  = new double[pts];
+        xx = new double[1];
+        yy = new double[1];
 
         create_data( x, y, z ); // the sampled data
         zmin = z[0];
@@ -203,8 +209,24 @@ class x21 {
         pls.env( xm, xM, ym, yM, 2, 0 );
         pls.col0( 15 );
         pls.lab( "X", "Y", "The original data sampling" );
-        pls.col0( 2 );
-        pls.poin( x, y, 5 );
+        for ( i = 0; i < pts; i++ )
+        {
+            pls.col1( ( z[i] - zmin ) / ( zmax - zmin ) );
+            // The following plstring call should be the the equivalent of
+            // plpoin( 1, &x[i], &y[i], 5 ); Use plstring because it is
+            // not deprecated like plpoin and has much more powerful
+            // capabilities.  N.B. symbol 141 works for Hershey devices
+            // (e.g., -dev xwin) only if plfontld( 0 ) has been called
+            // while symbol 727 works only if plfontld( 1 ) has been
+            // called.  The latter is the default which is why we use 727
+            // here to represent a centred X (multiplication) symbol.
+            // This dependence on plfontld is one of the limitations of
+            // the Hershey escapes for PLplot, but the upside is you get
+            // reasonable results for both Hershey and Unicode devices.
+            xx[0] = x[i];
+            yy[0] = y[i];
+            pls.string( xx, yy, "#(727)" );
+        }
         pls.adv( 0 );
 
         pls.ssub( 3, 2 );
@@ -227,8 +249,8 @@ class x21 {
                 // regions, a weighted average over the neighbors is done.
                 //
 
-                if ( alg == PLStream.GRID_CSA || alg == PLStream.GRID_DTLI ||
-                     alg == PLStream.GRID_NNLI || alg == PLStream.GRID_NNI )
+                if ( alg == GRID_CSA || alg == GRID_DTLI ||
+                     alg == GRID_NNLI || alg == GRID_NNI )
                 {
                     int    ii, jj;
                     double dist, d;
@@ -283,7 +305,7 @@ class x21 {
                     pls.col0( 15 );
                     pls.lab( "X", "Y", title[alg - 1] );
                     pls.shades( zg, xm, xM, ym, yM,
-                        clev, 1, 0, 1, true, xg0, yg0 );
+                        clev, 1., 0, 1., true, xg0, yg0 );
                     pls.col0( 2 );
                 }
                 else
@@ -291,7 +313,6 @@ class x21 {
                     for ( i = 0; i < nl; i++ )
                         clev[i] = lzm[0] + ( lzM[0] - lzm[0] ) / ( nl - 1 ) * i;
 
-                    cmap1_init();
                     pls.vpor( 0.0, 1.0, 0.0, 0.9 );
                     pls.wind( -1.1, 0.75, -0.65, 1.20 );
                     //
@@ -309,8 +330,8 @@ class x21 {
                         "bcdfntu", "Z", 0.5, 0 );
                     pls.col0( 15 );
                     pls.lab( "", "", title[alg - 1] );
-                    pls.plot3dc( xg, yg, zg, PLStream.DRAW_LINEXY |
-                        PLStream.MAG_COLOR | PLStream.BASE_CONT,
+                    pls.plot3dc( xg, yg, zg, DRAW_LINEXY |
+                        MAG_COLOR | BASE_CONT,
                         clev );
                 }
             }
