@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x22.java 11301 2010-11-02 17:21:08Z airwin $
+// $Id: x22.java 12832 2013-12-09 14:39:59Z andrewross $
 //    Simple vector plot example
 //--------------------------------------------------------------------------
 //
@@ -29,9 +29,22 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 import java.lang.Math;
 
+class Transform implements PLCallbackCT {
+    public void coordTransform( double x, double y, double[] xt, double[] yt, Object data )
+    {
+        double xmax;
+
+        xmax = 10.0;
+
+        xt[0] = x;
+        yt[0] = y / 4.0 * ( 3 - Math.cos( Math.PI * x / xmax ) );
+    }
+}
+
 class x22 {
     double MIN( double x, double y ) { return ( x < y ? x : y ); }
     double MAX( double x, double y ) { return ( x > y ? x : y ); }
@@ -42,7 +55,7 @@ class x22 {
     double[][] v  = null;
     double[][] xg = null;
     double[][] yg = null;
-    int nx, ny;
+    int nx, ny, nc, nseg;
 
     // Vector plot of the circulation about the origin
     void circulation()
@@ -83,7 +96,7 @@ class x22 {
     }
 
     // Vector plot of flow through a constricted pipe
-    void constriction()
+    void constriction( int astyle )
     {
         int    i, j;
         double dx, dy, x, y;
@@ -111,7 +124,7 @@ class x22 {
                 if ( Math.abs( y ) < b )
                 {
                     dbdx = ymax / 4.0 * Math.sin( Math.PI * x / xmax ) *
-                           y / b;
+                           Math.PI / xmax * y / b;
                     u[i][j] = Q * ymax / b;
                     v[i][j] = dbdx * u[i][j];
                 }
@@ -124,12 +137,70 @@ class x22 {
         }
 
         pls.env( xmin, xmax, ymin, ymax, 0, 0 );
-        pls.lab( "(x)", "(y)", "#frPLplot Example 22 - constriction" );
+        pls.lab( "(x)", "(y)", "#frPLplot Example 22 - constriction (arrow style " + astyle + ")" );
         pls.col0( 2 );
-        pls.vect( u, v, -0.5, xg, yg );
+        pls.vect( u, v, -1.0, xg, yg );
         pls.col0( 1 );
     }
 
+//
+// Vector plot of flow through a constricted pipe
+// with a coordinate transform
+//
+    void constriction2( )
+    {
+        int       i, j;
+        double    dx, dy, x, y;
+        double    xmin, xmax, ymin, ymax;
+        double    Q, b, dbdx;
+        double[] clev = new double[nc];
+        Transform transform = new Transform();
+
+        dx = 1.0;
+        dy = 1.0;
+
+        xmin = -nx / 2 * dx;
+        xmax = nx / 2 * dx;
+        ymin = -ny / 2 * dy;
+        ymax = ny / 2 * dy;
+
+        pls.stransform( transform, xmax );
+
+        Q = 2.0;
+        for ( i = 0; i < nx; i++ )
+        {
+            x = ( i - nx / 2 + 0.5 ) * dx;
+            for ( j = 0; j < ny; j++ )
+            {
+                y        = ( j - ny / 2 + 0.5 ) * dy;
+                xg[i][j] = x;
+                yg[i][j] = y;
+                b        = ymax / 4.0 * ( 3 - Math.cos( Math.PI * x / xmax ) );
+                u[i][j]  = Q * ymax / b;
+                v[i][j]  = 0.0;
+            }
+        }
+
+        for ( i = 0; i < nc; i++ )
+        {
+            clev[i] = Q + i * Q / ( nc - 1 );
+        }
+
+        pls.env( xmin, xmax, ymin, ymax, 0, 0 );
+        pls.lab( "(x)", "(y)", "#frPLplot Example 22 - constriction with plstransform" );
+        pls.col0( 2 );
+        pls.shades( u, xmin + dx / 2, xmax - dx / 2,
+            ymin + dy / 2, ymax - dy / 2,
+            clev, 0, 1, 1.0, 0, xg, yg );
+        pls.vect( u, v, -1.0, xg, yg );
+        // Plot edges using plpath (which accounts for coordinate transformation) rather than plline
+        pls.path( nseg, xmin, ymax, xmax, ymax );
+        pls.path( nseg, xmin, ymin, xmax, ymin );
+        pls.col0( 1 );
+
+        pls.stransform( null, null );
+    }
+
     // Vector plot of the gradient of a shielded potential (see example 9)
     void potential()
     {
@@ -159,7 +230,7 @@ class x22 {
         // Charge 2 is placed at (d1, -d1), with image charge at (d2, -d2).
         // Also put in smoothing term at small distances.
 
-        rmax = (double) nr;
+        rmax = nr;
 
         eps = 2.;
 
@@ -177,10 +248,10 @@ class x22 {
 
         for ( i = 0; i < nr; i++ )
         {
-            r = 0.5 + (double) i;
+            r = 0.5 + i;
             for ( j = 0; j < ntheta; j++ )
             {
-                theta    = 2. * Math.PI / ( ntheta - 1 ) * ( 0.5 + (double) j );
+                theta    = 2. * Math.PI / ( ntheta - 1 ) * ( 0.5 + j );
                 x        = r * Math.cos( theta );
                 y        = r * Math.sin( theta );
                 xg[i][j] = x;
@@ -204,10 +275,10 @@ class x22 {
         pls.env( xmaxmin[1], xmaxmin[0], ymaxmin[1], ymaxmin[0], 0, 0 );
         pls.lab( "(x)", "(y)", "#frPLplot Example 22 - potential gradient vector plot" );
         // Plot contours of the potential
-        dz = ( zmaxmin[0] - zmaxmin[1] ) / (double) nlevel;
+        dz = ( zmaxmin[0] - zmaxmin[1] ) / nlevel;
         for ( i = 0; i < nlevel; i++ )
         {
-            clevel[i] = zmaxmin[1] + ( (double) i + 0.5 ) * dz;
+            clevel[i] = zmaxmin[1] + ( i + 0.5 ) * dz;
         }
         pls.col0( 3 );
         pls.lsty( 2 );
@@ -223,7 +294,7 @@ class x22 {
         // Plot the perimeter of the cylinder
         for ( i = 0; i < nper; i++ )
         {
-            theta = ( 2. * Math.PI / ( nper - 1 ) ) * (double) i;
+            theta = ( 2. * Math.PI / ( nper - 1 ) ) * i;
             px[i] = rmax * Math.cos( theta );
             py[i] = rmax * Math.sin( theta );
         }
@@ -261,14 +332,16 @@ class x22 {
 
         // Parse and process command line arguments
 
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         // Initialize plplot
 
         pls.init();
 
-        nx = 20;
-        ny = 20;
+        nx   = 20;
+        ny   = 20;
+        nc   = 11;
+        nseg = 20;
 
         // Allocate arrays
         u  = new double[nx][ny];
@@ -283,13 +356,17 @@ class x22 {
         // Set arrow style using arrow_x and arrow_y then
         // plot uMath.sing these arrows.
         pls.svect( arrow_x, arrow_y, fill );
-        constriction();
+        constriction( 1 );
 
         // Set arrow style using arrow2_x and arrow2_y then
         // plot using these filled arrows.
         fill = true;
         pls.svect( arrow2_x, arrow2_y, fill );
-        constriction();
+        constriction( 2 );
+
+        constriction2();
+
+        pls.svect( null, null, false );
 
         potential();
 
