@@ -1,5 +1,5 @@
 //--------------------------------------------------------------------------
-// $Id: x24.java 11680 2011-03-27 17:57:51Z airwin $
+// $Id: x24.java 12240 2012-10-04 22:10:12Z andrewross $
 //  Unicode Pace Flag
 //--------------------------------------------------------------------------
 //
@@ -39,6 +39,7 @@
 package plplot.examples;
 
 import plplot.core.*;
+import static plplot.core.plplotjavacConstants.*;
 
 class x24 {
     PLStream pls = new PLStream();
@@ -114,7 +115,7 @@ class x24 {
     {
         int i, j;
 
-        pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
+        pls.parseopts( args, PL_PARSE_FULL | PL_PARSE_NOPROGRAM );
 
         pls.init();
 
