@@ -1,4 +1,4 @@
---[[ $Id: x01.lua 11680 2011-03-27 17:57:51Z airwin $
+--[[ $Id: x01.lua 12288 2013-01-30 04:40:35Z airwin $
 
 	Simple line plot and multiple windows demo.
 
@@ -87,9 +87,9 @@ function plot2()
 
   -- Draw the line 
   pl.col0(3)
-  pl.wid(2)
+  pl.width(2)
   pl.line(x, y)
-  pl.wid(1)
+  pl.width(1)
 end
 
 
