@@ -1,4 +1,4 @@
---[[ $Id: x02.lua 11680 2011-03-27 17:57:51Z airwin $
+--[[ $Id: x02.lua 12288 2013-01-30 04:40:35Z airwin $
 
 	Multiple window and color map 0 demo.
 
@@ -40,14 +40,14 @@ function draw_windows(nw, cmap0_offset)
     vmin = 0.1
     vmax = 0.9
     for j = 0, 2 do
-      pl.wid(j + 1)
+      pl.width(j + 1)
       pl.vpor(vmin, vmax, vmin, vmax)
       pl.wind(0, 1, 0, 1)
       pl.box("bc", 0, 0, "bc", 0, 0)
       vmin = vmin + 0.1
       vmax = vmax - 0.1
     end
-    pl.wid(1)
+    pl.width(1)
     pl.ptex(0.5, 0.5, 1, 0, 0.5, tostring(i))
   end
 end
@@ -102,7 +102,7 @@ function demo2()
     --	saturation	[0., 1.]	magnitude
    
     -- Vary hue uniformly from left to right 
-    h = (360/10) * math.mod(i, 10)
+    h = (360/10) * (i % 10)
     
     -- Vary lightness uniformly from top to bottom, between min & max 
     l = lmin + (lmax - lmin) * math.floor(i/10)/9
