@@ -1,4 +1,4 @@
---[[ $Id: x03.lua 10613 2009-11-19 12:05:09Z andrewross $
+--[[ $Id: x03.lua 11680 2011-03-27 17:57:51Z airwin $
 
 	Polar plot demo.
 
@@ -7,7 +7,7 @@
   This file is part of PLplot.
 
   PLplot is free software you can redistribute it and/or modify
-  it under the terms of the GNU General Library Public License as published
+  it under the terms of the GNU Library General Public License as published
   by the Free Software Foundation either version 2 of the License, or
   (at your option) any later version.
 
@@ -57,7 +57,7 @@ pl.env(-1.3, 1.3, -1.3, 1.3, 1, -2)
 
 -- Draw circles for polar grid
 for i = 1, 10 do
-		pl.arc(0, 0, 0.1*i, 0.1*i, 0, 360, 0);
+		pl.arc(0, 0, 0.1*i, 0.1*i, 0, 360, 0, 0);
 end
 
 pl.col0(2)
