@@ -1,4 +1,4 @@
---[[ $Id: x11.lua 11680 2011-03-27 17:57:51Z airwin $
+--[[ $Id: x11.lua 12167 2012-02-16 20:24:20Z airwin $
 
 	Mesh plot demo.
 
@@ -44,7 +44,7 @@ title = {
 
 -- return single bit (for OR)
 function bit(x,b)
-	return (math.mod(x, 2^b) - math.mod(x,2^(b-1)) > 0)
+  return ((x % 2^b) - (x % 2^(b-1)) > 0)
 end
 
 -- logic OR for number values
