@@ -1,4 +1,4 @@
---[[ $Id: x13.lua 11680 2011-03-27 17:57:51Z airwin $
+--[[ $Id: x13.lua 12167 2012-02-16 20:24:20Z airwin $
 
 	Pie chart demo.
 
@@ -71,7 +71,7 @@ for i = 1, 5 do
       thetasave=theta
 	end
 	pl.col0(i)
-	pl.psty(math.mod((i + 2), 8) + 1)
+	pl.psty(((i + 2) % 8) + 1)
 	pl.fill(x, y)
 	pl.col0(1)
 	pl.line(x, y)
