@@ -1,4 +1,4 @@
---[[ $Id: x19.lua 11680 2011-03-27 17:57:51Z airwin $
+--[[ $Id: x19.lua 12532 2013-09-26 15:18:37Z andrewross $
 
 	Illustrates backdrop plotting of world, US maps.
 	Contributed by Wesley Ebisuzaki.
@@ -125,8 +125,8 @@ pl.init()
 -- Cartesian plots 
 -- Most of world 
 
-minx = 190
-maxx = 190+360
+minx = -170
+maxx = minx+360
 
 -- Setup a custom latitude and longitude-based scaling function.
 pl.slabelfunc("geolocation_labeler");
