@@ -1,4 +1,4 @@
---[[ $Id: x21.lua 11680 2011-03-27 17:57:51Z airwin $
+--[[ $Id: x21.lua 12331 2013-05-03 02:41:21Z airwin $
 	Grid data demo
 
    Copyright (C) 200  Werner Smekal
@@ -30,7 +30,7 @@ dofile("plplot_examples.lua")
 
 -- return single bit (for OR)
 function bit(x,b)
-	return (math.mod(x, 2^b) - math.mod(x,2^(b-1)) > 0)
+  return ((x % 2^b) - (x % 2^(b-1)) > 0)
 end
 
 -- logic OR for number values
@@ -128,6 +128,8 @@ opt = { 0, 0, wmin, knn_order, threshold, 0 }
 -- Initialize plplot 
 pl.init()
 
+cmap1_init()
+
 -- Initialise random number generator 
 pl.seed(5489)
 
@@ -141,13 +143,19 @@ end
 
 xg, yg = create_grid(xp, yp) -- grid the data at 
 clev = {}
+xx = {}
+yy = {}
 
 pl.col0(1)
 pl.env(xm, xM, ym, yM, 2, 0)
 pl.col0(15)
 pl.lab("X", "Y", "The original data sampling")
-pl.col0(2)
-pl.poin(x, y, 5)
+for i=1, pts do
+  pl.col1( (z[i]-zmin)/(zmax-zmin) )
+  xx[1] = x[i]
+  yy[1] = y[i]
+  pl.string( xx, yy, "#(727)" )
+end
 pl.adv(0)
 
 pl.ssub(3, 2)
@@ -224,14 +232,13 @@ for k = 1, 2 do
       pl.env0(xm, xM, ym, yM, 2, 0)
       pl.col0(15)
       pl.lab("X", "Y", title[alg])
-      pl.shades(zg, xm, xM, ym, yM, clev, 1, 0, 1, 1)
+      pl.shades(zg, xm, xM, ym, yM, clev, 1., 0, 1., 1)
       pl.col0(2)
     else 
       for i = 1, nl do
         clev[i] = lzm + (lzM-lzm)/(nl-1)*(i-1)
       end
 
-      cmap1_init()
       pl.vpor(0, 1, 0, 0.9)
       pl.wind(-1.1, 0.75, -0.65, 1.20)
       
