@@ -1,6 +1,6 @@
 --[[ -*- coding: utf-8 -*-
    
-   $Id: x26.lua 11717 2011-04-21 00:47:06Z airwin $
+   $Id: x26.lua 12331 2013-05-03 02:41:21Z airwin $
 
    Multi-lingual version of the first page of example 4.
 
@@ -76,7 +76,7 @@ line_label = { "-20 dB/decade", "-20 dB/десяток" }
 
 -- return single bit (for OR)
 function bit(x,b)
-  return (math.mod(x, 2^b) - math.mod(x,2^(b-1)) > 0)
+  return ((x % 2^b) - (x % 2^(b-1)) > 0)
 end
 
 -- logic OR for number values
@@ -177,10 +177,10 @@ function plot1(type, x_label, y_label, alty_label, title_label, line_label, lege
   box_colors[1] = 0
   box_patterns[1] = 0
   box_scales[1] = 0
-  box_line_widths[1] = 0
+  box_line_widths[1] = 0.
   line_colors[1] = 2
   line_styles[1] = 1
-  line_widths[1] = 1
+  line_widths[1] = 1.
   -- unused arbitrary data
   symbol_colors[1]  = 0
   symbol_scales[1]  = 0
@@ -196,10 +196,10 @@ function plot1(type, x_label, y_label, alty_label, title_label, line_label, lege
     box_colors[2] = 0
     box_patterns[2] = 0
     box_scales[2] = 0
-    box_line_widths[2] = 0
+    box_line_widths[2] = 0.
     line_colors[2]    = 3
     line_styles[2]    = 1
-    line_widths[2]    = 1
+    line_widths[2]    = 1.
     symbol_colors[2]  = 3
     symbol_scales[2]  = 1.
     symbol_numbers[2] = 4
