@@ -1,4 +1,4 @@
---[[ $Id: x27.lua 11858 2011-08-05 07:45:34Z andrewross $
+--[[ $Id: x27.lua 12167 2012-02-16 20:24:20Z airwin $
 
 	Drawing "spirograph" curves - epitrochoids, cycolids, roulettes
 
@@ -34,7 +34,7 @@ function gcd (a,  b)
     b = math.floor(math.abs(b))
     while b~=0 do
         t = b
-        b = math.mod(a,b)
+        b = a % b
         a = t
     end 
     return a
