@@ -1,4 +1,4 @@
-(* $Id: x05.ml 9059 2008-12-08 20:58:53Z andrewross $
+(* $Id: x05.ml 10463 2009-09-23 20:56:58Z hezekiahcarty $
 
         Histogram demo.
 *)
@@ -15,7 +15,7 @@ let npts = 2047
 
 let () =
   (* Parse and process command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
   (* Initialize plplot *)
   plinit ();
