@@ -1,4 +1,4 @@
-(* $Id: x07.ml 9059 2008-12-08 20:58:53Z andrewross $
+(* $Id: x07.ml 10957 2010-05-01 15:31:28Z hezekiahcarty $
 
         Font demo.
 *)
@@ -6,7 +6,7 @@
 open Plplot
 
 let base =
-  [|0; 200; 500; 600; 700; 800; 900;
+  [|0; 100; 0; 100; 200; 500; 600; 700; 800; 900;
     2000; 2100; 2200; 2300; 2400; 2500; 2600; 2700; 2800; 2900|]
 
 (*--------------------------------------------------------------------------*\
@@ -15,13 +15,14 @@ let base =
 
 let () =
   (* Parse and process command line arguments *)
-  ignore (plparseopts Sys.argv [PL_PARSE_FULL]);
+  plparseopts Sys.argv [PL_PARSE_FULL];
 
   (* Initialize plplot *)
   plinit ();
 
-  plfontld 1;
-  for l = 0 to 16 do
+  plfontld 0;
+  for l = 0 to 19 do
+    if l = 2 then plfontld 1;
     pladv 0;
 
     (* Set up viewport and window *)
@@ -53,7 +54,10 @@ let () =
       done;
     done;
 
-    plmtex "t" 1.5 0.5 0.5 "PLplot Example 7 - PLSYM symbols";
+    if l < 2 then
+      plmtex "t" 1.5 0.5 0.5 "PLplot Example 7 - PLSYM symbols (compact)"
+    else
+      plmtex "t" 1.5 0.5 0.5 "PLplot Example 7 - PLSYM symbols (extended)"
   done;
   plend ();
   ()
