@@ -1,4 +1,4 @@
-(* $Id: x18.ml 10517 2009-10-06 18:45:37Z hezekiahcarty $
+(* $Id: x18.ml 11409 2011-01-01 00:26:35Z hezekiahcarty $
 
   3-d line and point plot demo.  Adapted from x08c.c.
 *)
@@ -120,7 +120,8 @@ let () =
     if opt.(k) <> 0 then
       plline3 x y z
     else
-      plpoin3 x y z 1;
+      (* U+22C5 DOT OPERATOR. *)
+      plstring3 x y z "⋅";
 
     plcol0 3;
     let title =
