@@ -70,10 +70,10 @@ let () =
   let box_colors = Array.make max_nlegend 0 in
   let box_patterns = Array.make max_nlegend 0 in
   let box_scales = Array.make max_nlegend 0.0 in
-  let box_line_widths = Array.make max_nlegend 0 in
+  let box_line_widths = Array.make max_nlegend 0.0 in
   let line_colors = Array.make max_nlegend 0 in
   let line_styles = Array.make max_nlegend 0 in
-  let line_widths = Array.make max_nlegend 0 in
+  let line_widths = Array.make max_nlegend 0.0 in
   let symbol_numbers = Array.make max_nlegend 0 in
   let symbol_colors = Array.make max_nlegend 0 in
   let symbol_scales = Array.make max_nlegend 0.0 in
@@ -102,7 +102,7 @@ let () =
   let opt_base = [PL_LEGEND_BACKGROUND; PL_LEGEND_BOUNDING_BOX] in
   opt_array.(0) <- [PL_LEGEND_LINE; PL_LEGEND_SYMBOL];
   line_styles.(0) <- 1;
-  line_widths.(0) <- 1;
+  line_widths.(0) <- 1.0;
   symbol_scales.(0) <- 1.;
   symbol_numbers.(0) <- 4;
   symbols.(0) <- "*";
@@ -149,7 +149,7 @@ let () =
   for k = 0 to nlegend - 1 do
     opt_array.(k) <- [PL_LEGEND_LINE; PL_LEGEND_SYMBOL];
     line_styles.(k) <- 1;
-    line_widths.(k) <- 1;
+    line_widths.(k) <- 1.0;
     symbol_scales.(k) <- 1.0;
     symbol_numbers.(k) <- 2;
     symbols.(k) <- "*";
@@ -308,7 +308,7 @@ let () =
     for k = 0 to !nlegend - 1 do
       opt_array.(k) <- [PL_LEGEND_LINE; PL_LEGEND_SYMBOL];
       line_styles.(k) <- 1;
-      line_widths.(k) <- 1;
+      line_widths.(k) <- 1.0;
       symbol_scales.(k) <- 1.;
       symbol_numbers.(k) <- 2;
       symbols.(k) <- "*";
@@ -377,14 +377,14 @@ let () =
   box_colors.(1) <- 2;
   box_patterns.(1) <- 0;
   box_scales.(1) <- 0.8;
-  box_line_widths.(1) <- 1;
+  box_line_widths.(1) <- 1.0;
 
   opt_array.(2) <- [PL_LEGEND_LINE];
   text.(2) <- sprintf "%s" "Line";
   text_colors.(2) <- 3;
   line_colors.(2) <- 3;
   line_styles.(2) <- 1;
-  line_widths.(2) <- 1;
+  line_widths.(2) <- 1.0;
 
   opt_array.(3) <- [PL_LEGEND_SYMBOL];
   text.(3) <- sprintf "%s" "Symbol";
@@ -399,7 +399,7 @@ let () =
   text_colors.(4) <- 5;
   line_colors.(4) <- 5;
   line_styles.(4) <- 1;
-  line_widths.(4) <- 1;
+  line_widths.(4) <- 1.0;
   symbol_colors.(4) <- 5;
   symbol_scales.(4) <- text_scale;
   symbol_numbers.(4) <- 4;
@@ -482,7 +482,7 @@ let () =
     box_colors.(i) <- i + 1;
     box_patterns.(i) <- 0;
     box_scales.(i) <- 0.8;
-    box_line_widths.(i) <- 1;
+    box_line_widths.(i) <- 1.0;
   done;
 
   let opt = opt_base in
@@ -512,7 +512,7 @@ let () =
     box_colors.(i) <- 2;
     box_patterns.(i) <- i;
     box_scales.(i) <- 0.8;
-    box_line_widths.(i) <- 1;
+    box_line_widths.(i) <- 1.0;
   done;
 
   let opt = opt_base in
@@ -539,7 +539,7 @@ let () =
     box_colors.(i) <- 2;
     box_patterns.(i) <- 3;
     box_scales.(i) <- 0.8;
-    box_line_widths.(i) <- i + 1;
+    box_line_widths.(i) <- float i +. 1.0;
   done;
 
   let opt = opt_base in
@@ -565,7 +565,7 @@ let () =
     text_colors.(i) <- i + 1;
     line_colors.(i) <- i + 1;
     line_styles.(i) <- 1;
-    line_widths.(i) <- 1;
+    line_widths.(i) <- 1.0;
   done;
 
   let opt = opt_base in
@@ -594,7 +594,7 @@ let () =
     text_colors.(i) <- 2;
     line_colors.(i) <- 2;
     line_styles.(i) <- i + 1;
-    line_widths.(i) <- 1;
+    line_widths.(i) <- 1.0;
   done;
 
   let opt = opt_base in
@@ -620,7 +620,7 @@ let () =
     text_colors.(i) <- 2;
     line_colors.(i) <- 2;
     line_styles.(i) <- 1;
-    line_widths.(i) <- i + 1;
+    line_widths.(i) <- float i +. 1.0;
   done;
 
   let opt = opt_base in
