@@ -171,9 +171,9 @@ function plot2
   ## Draw the line */
 
   plcol0(3);
-  plwid(2);
+  plwidth(2);
   plline(x', y');
-  plwid(1);
+  plwidth(1);
 
 endfunction
 
