@@ -1,4 +1,4 @@
-## $Id: x21c.m 11680 2011-03-27 17:57:51Z airwin $
+## $Id: x21c.m 12330 2013-05-03 02:02:05Z airwin $
 ##	Grid data demo
 ##
 ##  Copyright (C) 2004  Joao Cardoso
@@ -81,6 +81,8 @@ function ix21c
 
   plinit;
 
+  cmap1_init;
+
   plseed(5489);
 
   [x, y, z] = create_data(pts, xm, xM, ym, yM, randn, rosen); ## the sampled data
@@ -93,8 +95,10 @@ function ix21c
   plenv(xm, xM, ym, yM, 2, 0);
   plcol0(15);
   pllab("X", "Y", "The original data sampling");
-  plcol0(2);
-  plpoin(x, y, 5);
+  for i=1:pts
+    plcol1( ( z(i) - zmin ) / ( zmax - zmin ) );
+    plstring( x(i), y(i), "#(727)" );
+  end
   pladv(0);
 
   plssub(3,2);
@@ -163,14 +167,13 @@ function ix21c
 	plenv0(xm, xM, ym, yM, 2, 0);
 	plcol0(15);
 	pllab("X", "Y", deblank(title(alg,:)));
-	plshades(zg, xm, xM, ym, yM, clev, 1, 0, 1, 1);
+	plshades(zg, xm, xM, ym, yM, clev, 1., 0, 1., 1);
 	plcol0(2);
       else 
 
 	i=(0:nl-1)';
 	clev = lzm + (lzM-lzm)/(nl-1)*i;
 
-	cmap1_init;
 	plvpor(0.0, 1.0, 0.0, 0.9);
 	plwind(-1.1, 0.75, -0.65, 1.20);
 	##
