@@ -41,13 +41,13 @@ def main(w):
 	vmin = 0.1
 	vmax = 0.9
 	for j in range(3):
-	    w.plwid(j + 3)
+	    w.plwidth(j + 3)
 	    w.plvpor(vmin, vmax, vmin, vmax)
 	    w.plwind(0.0, 1.0, 0.0, 1.0)
 	    w.plbox("bc", 0.0, 0, "bc", 0.0, 0)
 	    vmin = vmin + 0.1
 	    vmax = vmax - 0.1
-	    w.plwid(1)
+	    w.plwidth(1)
 	    w.plptex(0.5, 0.5, 1.0, 0.0, 0.5, `i`)
 
     # Now finish up.
