@@ -1,4 +1,4 @@
-# $Id: xw19.py 11680 2011-03-27 17:57:51Z airwin $
+# $Id: xw19.py 12532 2013-09-26 15:18:37Z andrewross $
 
 #  Copyright (C) Wesley Ebisuzaki
 #  Copyright (C) 2009 Andrew Ross
@@ -100,8 +100,8 @@ def main():
     # Cartesian plots 
     # Most of world
 
-    minx = 190
-    maxx = 190+360
+    minx = -170
+    maxx = minx+360
 
     # Setup a custom latitude and longitude-based scaling function.
     plslabelfunc(geolocation_labeler, None)
