@@ -1,4 +1,4 @@
-# $Id: xw21.py 11680 2011-03-27 17:57:51Z airwin $
+# $Id: xw21.py 12323 2013-05-02 17:41:54Z airwin $
 
 #  Copyright (C) 2007, 2008 Andrew Ross
 
@@ -70,6 +70,7 @@ def main():
     opt[3] = knn_order
     opt[4] = threshold
  
+    cmap1_init()
     plseed(5489)
 
     # Create the sampled data
@@ -100,12 +101,18 @@ def main():
     xg = xm + (xM-xm)*arange(xp)/(xp-1.)
     yg = ym + (yM-ym)*arange(yp)/(yp-1.)
 
+    xx = zeros(1)
+    yy = zeros(1)
+
     plcol0(1)
     plenv(xm,xM,ym,yM,2,0)
     plcol0(15)
     pllab('X','Y','The original data sampling')
-    plcol0(2)
-    plpoin(x,y,5)
+    for i in range(pts):
+        plcol1( ( z[i] - zmin )/( zmax - zmin ) )
+        xx[0] = x[i]
+        yy[0] = y[i]
+        plstring( xx, yy, '#(727)' )
     pladv(0)
 
     plssub(3,2)
@@ -113,8 +120,7 @@ def main():
     for k in range(2):
         pladv(0)
         for alg in range(1,7):
-            zg = reshape(zeros(xp*yp),(xp,yp))
-            plgriddata(x, y, z, xg, yg, zg, alg, opt[alg-1])
+            zg = plgriddata(x, y, z, xg, yg, alg, opt[alg-1])
 
             if alg == GRID_CSA or alg == GRID_DTLI or alg == GRID_NNLI or alg == GRID_NNI:
                 for i in range(xp):
@@ -154,11 +160,10 @@ def main():
                 plenv0(xm,xM,ym,yM,2,0)
                 plcol0(15)
                 pllab('X','Y',title[alg-1])
-                plshades(zg, xm, xM, ym, yM, clev, 1, 1, None, None)
+                plshades(zg, xm, xM, ym, yM, clev, 1., 1, None, None)
                 plcol0(2)
             else:
                 clev = lzm + (lzM-lzm)*arange(nl)/(nl-1)
-                cmap1_init()
                 plvpor(0.0, 1.0, 0.0, 0.9)
                 plwind(-1.1, 0.75, -0.65, 1.20)
                 plw3d(1.0, 1.0, 1.0, xm, xM, ym, yM, lzm, lzM, 30.0, -40.0)
