@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x01.tcl 11572 2011-02-21 07:39:43Z arjenmarkus $
+# $Id: x01.tcl 12288 2013-01-30 04:40:35Z airwin $
 #----------------------------------------------------------------------------
 
 proc x01 {{w loopback}} {
@@ -111,9 +111,9 @@ proc plot2 {w} {
     }
 
     $w cmd plcol0 3
-    $w cmd plwid 2
+    $w cmd plwidth 2
     $w cmd plline 100 x1 y1
-    $w cmd plwid 1
+    $w cmd plwidth 1
 }
 
 # This is supposed to work just like the plot3() in x01c.c
