@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x02.tcl 9917 2009-05-05 11:35:31Z andrewross $
+# $Id: x02.tcl 12288 2013-01-30 04:40:35Z airwin $
 #----------------------------------------------------------------------------
 
 proc x02 {{w loopback}} {
@@ -124,14 +124,14 @@ proc x02_draw_windows { w nw {cmap0_offset 0} } {
 	set vmin 0.1
 	set vmax 0.9
 	for {set j 0} {$j <= 2} {incr j} {
-	    $w cmd plwid [expr $j+1]
+	    $w cmd plwidth [expr $j+1]
 	    $w cmd plvpor $vmin $vmax $vmin $vmax
 	    $w cmd plwind 0.0 1.0 0.0 1.0
 	    $w cmd plbox "bc" 0.0 0 "bc" 0.0 0
 	    set vmin [expr $vmin+0.1]
 	    set vmax [expr $vmax-0.1]
 	}
-	$w cmd plwid 1
+	$w cmd plwidth 1
 	$w cmd plptex 0.5 0.5 1.0 0.0 0.5 $i
     }
 
