@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x05.tcl 8674 2008-08-19 10:54:16Z andrewross $
+# $Id: x05.tcl 11572 2011-02-21 07:39:43Z arjenmarkus $
 #----------------------------------------------------------------------------
 
 proc x05 {{w loopback}} {
@@ -8,7 +8,7 @@ proc x05 {{w loopback}} {
 
 # Fill up data points
 
-    set delta [expr 2.0 * 3.14159265358979323846 / $npts]
+    set delta [expr 2.0 * $::PLPLOT::PL_PI / $npts]
     for {set i 0} {$i < $npts} {incr i} {
 	data $i = [expr sin($i * $delta)]
     }
