@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x10.tcl 3399 2001-12-27 18:11:59Z airwin $
+# $Id: x10.tcl 8674 2008-08-19 10:54:16Z andrewross $
 #----------------------------------------------------------------------------
 
 proc x10 {{w loopback}} {
@@ -12,5 +12,5 @@ proc x10 {{w loopback}} {
   $w cmd plbox bc 0.0 0 bc 0.0 0
   $w cmd plptex 0.5 0.5 1.0 0.0 0.5 "BOX at (50,150,50,100)"
 # Restore defaults
-  $w cmd plcol0 1
+  # $w cmd plcol0 1
 }
