@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x16.tcl 11572 2011-02-21 07:39:43Z arjenmarkus $
+# $Id: x16.tcl 12431 2013-07-19 09:53:51Z arjenmarkus $
 #----------------------------------------------------------------------------
 
 # plshades demo, using color fill.
@@ -10,7 +10,7 @@ proc x16 {{w loopback}} {
     set nx 35
     set ny 46
 
-    set fill_width 2; set cont_color 0; set cont_width 0
+    set fill_width 2.; set cont_color 0; set cont_width 0.
 
     matrix clevel f $ns
     matrix shedge f [expr $ns+1]
@@ -21,6 +21,14 @@ proc x16 {{w loopback}} {
     matrix zz f $nx $ny
     matrix ww f $nx $ny
 
+# Colorbar - note: single values, as we have only one bar
+    set n_axis_opts    1
+    set axis_opts      "bcvtm"
+    set axis_ticks     0.0
+    set axis_subticks  0
+    set label_opts     $::PLPLOT::PL_COLORBAR_LABEL_BOTTOM
+    set labels         "Magnitude"
+
 # Set up data array
 
     for {set i 0} {$i < $nx} {incr i} {
@@ -91,6 +99,29 @@ proc x16 {{w loopback}} {
       shedge $fill_width $cont_color $cont_width \
       1 "NULL"
 
+    # Colorbar:
+    # We draw only one bar, so use single values, not lists
+    #
+    # Smaller text
+    $w cmd plschr 0.0 0.75
+    # Small ticks on the vertical axis
+    $w cmd plsmaj 0.0 0.5
+    $w cmd plsmin 0.0 0.5
+
+    $w cmd plcolorbar \
+        [expr {$::PLPLOT::PL_COLORBAR_SHADE | $::PLPLOT::PL_COLORBAR_SHADE_LABEL}] 0 \
+        0.005 0.0 0.0375 0.875 0 1 1 0.0 0.0 \
+        $cont_color $cont_width \
+        $label_opts $labels \
+        $axis_opts \
+        $axis_ticks $axis_subticks \
+        shedge
+
+    # Reset text and tick sizes
+    $w cmd plschr 0.0 1.0
+    $w cmd plsmaj 0.0 1.0
+    $w cmd plsmin 0.0 1.0
+
     $w cmd plcol0 1
     $w cmd plbox "bcnst" 0.0 0 "bcnstv" 0.0 0
     $w cmd plcol0 2
@@ -114,6 +145,29 @@ proc x16 {{w loopback}} {
       shedge $fill_width $cont_color $cont_width \
       1 pltr1 xg1 yg1
 
+    # Colorbar:
+    # We draw only one bar, so use single values, not lists
+    #
+    # Smaller text
+    $w cmd plschr 0.0 0.75
+    # Small ticks on the vertical axis
+    $w cmd plsmaj 0.0 0.5
+    $w cmd plsmin 0.0 0.5
+
+    $w cmd plcolorbar \
+        [expr {$::PLPLOT::PL_COLORBAR_SHADE | $::PLPLOT::PL_COLORBAR_SHADE_LABEL}] 0 \
+        0.005 0.0 0.0375 0.875 0 1 1 0.0 0.0 \
+        $cont_color $cont_width \
+        $label_opts $labels \
+        $axis_opts \
+        $axis_ticks $axis_subticks \
+        shedge
+
+    # Reset text and tick sizes
+    $w cmd plschr 0.0 1.0
+    $w cmd plsmaj 0.0 1.0
+    $w cmd plsmin 0.0 1.0
+
     $w cmd plcol0 1
     $w cmd plbox "bcnst" 0.0 0 "bcnstv" 0.0 0
     $w cmd plcol0 2
@@ -137,6 +191,29 @@ proc x16 {{w loopback}} {
       shedge $fill_width $cont_color $cont_width \
       0 pltr2 xg2 yg2
 
+    # Colorbar:
+    # We draw only one bar, so use single values, not lists
+    #
+    # Smaller text
+    $w cmd plschr 0.0 0.75
+    # Small ticks on the vertical axis
+    $w cmd plsmaj 0.0 0.5
+    $w cmd plsmin 0.0 0.5
+
+    $w cmd plcolorbar \
+        [expr {$::PLPLOT::PL_COLORBAR_SHADE | $::PLPLOT::PL_COLORBAR_SHADE_LABEL}] 0 \
+        0.005 0.0 0.0375 0.875 0 1 1 0.0 0.0 \
+        $cont_color $cont_width \
+        $label_opts $labels \
+        $axis_opts \
+        $axis_ticks $axis_subticks \
+        shedge
+
+    # Reset text and tick sizes
+    $w cmd plschr 0.0 1.0
+    $w cmd plsmaj 0.0 1.0
+    $w cmd plsmin 0.0 1.0
+
     $w cmd plcol0 1
     $w cmd plbox "bcnst" 0.0 0 "bcnstv" 0.0 0
     $w cmd plcol0 2
@@ -159,6 +236,29 @@ proc x16 {{w loopback}} {
       shedge $fill_width 2 3 \
       0 pltr2 xg2 yg2
 
+    # Colorbar:
+    # We draw only one bar, so use single values, not lists
+    #
+    # Smaller text
+    $w cmd plschr 0.0 0.75
+    # Small ticks on the vertical axis
+    $w cmd plsmaj 0.0 0.5
+    $w cmd plsmin 0.0 0.5
+
+    $w cmd plcolorbar \
+        [expr {$::PLPLOT::PL_COLORBAR_SHADE | $::PLPLOT::PL_COLORBAR_SHADE_LABEL}] 0 \
+        0.005 0.0 0.0375 0.875 0 1 1 0.0 0.0 \
+        2 3.0 \
+        $label_opts $labels \
+        $axis_opts \
+        $axis_ticks $axis_subticks \
+        shedge
+
+    # Reset text and tick sizes
+    $w cmd plschr 0.0 1.0
+    $w cmd plsmaj 0.0 1.0
+    $w cmd plsmin 0.0 1.0
+
     $w cmd plcol0 1
     $w cmd plbox "bcnst" 0.0 0 "bcnstv" 0.0 0
     $w cmd plcol0 2
@@ -214,6 +314,29 @@ proc x16 {{w loopback}} {
       shedge $fill_width $cont_color $cont_width \
       0 pltr2 xg yg $wrap
 
+    # Colorbar:
+    # We draw only one bar, so use single values, not lists
+    #
+    # Smaller text
+    $w cmd plschr 0.0 0.75
+    # Small ticks on the vertical axis
+    $w cmd plsmaj 0.0 0.5
+    $w cmd plsmin 0.0 0.5
+
+    $w cmd plcolorbar \
+        [expr {$::PLPLOT::PL_COLORBAR_SHADE | $::PLPLOT::PL_COLORBAR_SHADE_LABEL}] 0 \
+        0.005 0.0 0.0375 0.875 0 1 1 0.0 0.0 \
+        $cont_color $cont_width \
+        $label_opts $labels \
+        $axis_opts \
+        $axis_ticks $axis_subticks \
+        shedge
+
+    # Reset text and tick sizes
+    $w cmd plschr 0.0 1.0
+    $w cmd plsmaj 0.0 1.0
+    $w cmd plsmin 0.0 1.0
+
 # Hold perimeter
     matrix px f 100; matrix py f 100
 
