@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x18.tcl 8674 2008-08-19 10:54:16Z andrewross $
+# $Id: x18.tcl 11603 2011-03-06 03:38:38Z airwin $
 #----------------------------------------------------------------------------
 
 proc x18 {{w loopback}} {
@@ -9,7 +9,6 @@ proc x18 {{w loopback}} {
     matrix az  f 4 = {30.0, 40.0, 50.0, 60.0}
 
     set npts 1000
-    set pi 3.14159265358979323846
 
     for {set k 0} {$k < 4} {incr k} {
 	test_poly $w $k
@@ -22,15 +21,15 @@ proc x18 {{w loopback}} {
 # From the mind of a sick and twisted physicist...
 
     for {set i 0} {$i < $npts} {incr i} {
-	z $i = [expr -1. + 2. * $i / $npts]
+	z $i = [expr {-1. + 2. * $i / $npts}]
 
-# Pick one ... 
+# Pick one ...
 
 #	r    = 1. - ( (float) i / (float) NPTS );
 	set r [z $i]
 
-	x $i = [expr $r * cos( 2. * $pi * 6. * $i / $npts )]
-	y $i = [expr $r * sin( 2. * $pi * 6. * $i / $npts )]
+	x $i = [expr {$r * cos( 2. * $::PLPLOT::PL_PI * 6. * $i / $npts )}]
+	y $i = [expr {$r * sin( 2. * $::PLPLOT::PL_PI * 6. * $i / $npts )}]
     }
 
     for {set k 0} {$k < 4} {incr k} {
@@ -48,7 +47,8 @@ proc x18 {{w loopback}} {
 	if {[opt $k]} {
 	    $w cmd plline3 $npts x y z
 	} else {
-	    $w cmd plpoin3 $npts x y z 1
+	    # U+22C5 DOT OPERATOR.
+	    $w cmd plstring3 $npts x y z "⋅" 
 	}
 
 	$w cmd plcol0 3
@@ -67,7 +67,7 @@ proc test_poly {{w loopback} k} {
     matrix draw2 i 4 = { 0, 1, 0, 1 }
     matrix draw3 i 4 = { 1, 1, 0, 0 }
 
-    set pi 3.14159265358979323846; set two_pi [expr 2. * $pi]
+    set pi $::PLPLOT::PL_PI; set two_pi [expr {2. * $pi}]
 
     matrix x f 5
     matrix y f 5
@@ -94,25 +94,25 @@ proc test_poly {{w loopback} k} {
 
     for {set i 0} {$i < 20} {incr i} {
 	for {set j 0} {$j < 20} {incr j} {
-	    x 0 = [expr sin( $pi * $j / 20.1 ) * cos( $two_pi * $i / 20 )]
-	    y 0 = [expr sin( $pi * $j / 20.1 ) * sin( $two_pi * $i / 20 )]
-	    z 0 = [expr cos( $pi * $j / 20.1 )]
+	    x 0 = [expr {sin( $pi * $j / 20.1 ) * cos( $two_pi * $i / 20 )}]
+	    y 0 = [expr {sin( $pi * $j / 20.1 ) * sin( $two_pi * $i / 20 )}]
+	    z 0 = [expr {cos( $pi * $j / 20.1 )}]
 
-	    x 1 = [expr sin( $pi * ($j+1) / 20.1 ) * cos( $two_pi * $i / 20 )]
-	    y 1 = [expr sin( $pi * ($j+1) / 20.1 ) * sin( $two_pi * $i / 20 )]
-	    z 1 = [expr cos( $pi * ($j+1) / 20.1 )]
+	    x 1 = [expr {sin( $pi * ($j+1) / 20.1 ) * cos( $two_pi * $i / 20 )}]
+	    y 1 = [expr {sin( $pi * ($j+1) / 20.1 ) * sin( $two_pi * $i / 20 )}]
+	    z 1 = [expr {cos( $pi * ($j+1) / 20.1 )}]
 
-	    x 2 = [expr sin($pi * ($j+1) / 20.1) * cos($two_pi * ($i+1) / 20)]
-	    y 2 = [expr sin($pi * ($j+1) / 20.1) * sin($two_pi * ($i+1) / 20)]
-	    z 2 = [expr cos($pi * ($j+1) / 20.1)]
+	    x 2 = [expr {sin($pi * ($j+1) / 20.1) * cos($two_pi * ($i+1) / 20)}]
+	    y 2 = [expr {sin($pi * ($j+1) / 20.1) * sin($two_pi * ($i+1) / 20)}]
+	    z 2 = [expr {cos($pi * ($j+1) / 20.1)}]
 
-	    x 3 = [expr sin( $pi * $j / 20.1 ) * cos( $two_pi * ($i+1) / 20 )]
-	    y 3 = [expr sin( $pi * $j / 20.1 ) * sin( $two_pi * ($i+1) / 20 )]
-	    z 3 = [expr cos( $pi * $j / 20.1 )]
+	    x 3 = [expr {sin( $pi * $j / 20.1 ) * cos( $two_pi * ($i+1) / 20 )}]
+	    y 3 = [expr {sin( $pi * $j / 20.1 ) * sin( $two_pi * ($i+1) / 20 )}]
+	    z 3 = [expr {cos( $pi * $j / 20.1 )}]
 
-	    x 4 = [expr sin( $pi * $j / 20.1 ) * cos( $two_pi * $i / 20 )]
-	    y 4 = [expr sin( $pi * $j / 20.1 ) * sin( $two_pi * $i / 20 )]
-	    z 4 = [expr cos( $pi * $j / 20.1 )]
+	    x 4 = [expr {sin( $pi * $j / 20.1 ) * cos( $two_pi * $i / 20 )}]
+	    y 4 = [expr {sin( $pi * $j / 20.1 ) * sin( $two_pi * $i / 20 )}]
+	    z 4 = [expr {cos( $pi * $j / 20.1 )}]
 
 	    $w cmd plpoly3 5 x y z draw$k 1
 	}
