@@ -1,4 +1,4 @@
-// $Id: xtk02.c 11760 2011-06-01 19:29:11Z airwin $
+// $Id: xtk02.c 12077 2011-11-30 22:04:42Z andrewross $
 //
 // Copyright (C) 2004  Joao Cardoso
 //
@@ -21,10 +21,13 @@
 
 #include "pltk.h"
 #include <math.h>
+#include <string.h>
 
 static int
 AppInit( Tcl_Interp *interp );
 
+int stuff( tclMatrix *pm, Tcl_Interp *interp, int argc, const char *argv[] );
+
 //--------------------------------------------------------------------------
 // A pithy little proc to show off how to install and use a tclMatrix
 // extension subcommand. This example is silly--only intended to show
@@ -34,7 +37,7 @@ AppInit( Tcl_Interp *interp );
 //--------------------------------------------------------------------------
 
 int stuff( tclMatrix *pm, Tcl_Interp *interp,
-           int argc, const char *argv[] )
+           int PL_UNUSED( argc ), const char * PL_UNUSED( argv [] ) )
 {
     int   i;
     PLFLT x, y;
@@ -49,7 +52,7 @@ int stuff( tclMatrix *pm, Tcl_Interp *interp,
         pm->fdata[i] = y;
     }
 
-    interp->result = "Things are cool in gumbyville.";
+    Tcl_SetResult( interp, (char *) "Things are cool in gumbyville.", TCL_STATIC );
     return TCL_OK;
 }
 
@@ -116,9 +119,9 @@ int   myplotCmd( ClientData, Tcl_Interp *, int, char ** );
 static int
 AppInit( Tcl_Interp *interp )
 {
-    Tk_Window main;
+    Tk_Window mainWin;
 
-    main = Tk_MainWindow( interp );
+    mainWin = Tk_MainWindow( interp );
 
 //
 // Call the init procedures for included packages.  Each call should
@@ -142,17 +145,17 @@ AppInit( Tcl_Interp *interp )
 //
 
     Tcl_CreateCommand( interp, "myplot", (Tcl_CmdProc *) myplotCmd,
-        (ClientData) main, (Tcl_CmdDeleteProc *) NULL );
+        (ClientData) mainWin, (Tcl_CmdDeleteProc *) NULL );
 
     Tcl_MatrixInstallXtnsn( "stuff", stuff );
 
     return TCL_OK;
 }
 
-void myplot1();
-void myplot2();
-void myplot3();
-void myplot4();
+void myplot1( void );
+void myplot2( void );
+void myplot3( void );
+void myplot4( void );
 
 // Plots several simple functions
 // Note the compiler should automatically convert all non-pointer arguments
@@ -332,7 +335,7 @@ plot3( void )
     plline( 101, x, y );
 }
 
-int   myplotCmd( ClientData cd, Tcl_Interp *interp, int argc, char **argv )
+int   myplotCmd( ClientData PL_UNUSED( cd ), Tcl_Interp *PL_UNUSED( interp ), int PL_UNUSED( argc ), char **argv )
 {
     if ( !strcmp( argv[1], "1" ) )
         myplot1();
