@@ -1,4 +1,4 @@
-// $Id: plcore.h 11269 2010-10-22 00:25:36Z airwin $
+// $Id: plcore.h 12275 2012-11-17 22:49:34Z hbabcock $
 //
 //      Contains declarations for core plplot data structures.  This file
 //      should be included only by plcore.c.
@@ -50,7 +50,7 @@ typedef void ( *PLDispatchInit )( PLDispatchTable *pdt );
 
 // Static function prototypes
 
-static char     *utf8_to_ucs4( const char *ptr, PLUNICODE *unichar );
+static const char     *utf8_to_ucs4( const char *ptr, PLUNICODE *unichar );
 static void     grline( short *, short *, PLINT );
 static void     grpolyline( short *, short *, PLINT );
 static void     grfill( short *, short *, PLINT );
@@ -285,6 +285,9 @@ static PLDispatchInit  static_device_initializers[] = {
 #if defined ( PLD_pscairo ) && !defined ( ENABLE_DYNDRIVERS )
     plD_dispatch_init_pscairo,
 #endif
+#if defined ( PLD_epscairo ) && !defined ( ENABLE_DYNDRIVERS )
+    plD_dispatch_init_epscairo,
+#endif
 #if defined ( PLD_svgcairo ) && !defined ( ENABLE_DYNDRIVERS )
     plD_dispatch_init_svgcairo,
 #endif
@@ -362,8 +365,9 @@ typedef struct
 
 static PLLoadableDevice *loadable_device_list;
 static PLLoadableDriver *loadable_driver_list;
-#endif
 
 static int nloadabledrivers = 0;
 
+#endif
+
 #endif  // __PLCORE_H__
