@@ -1,4 +1,4 @@
-// $Id: pldebug.h 11269 2010-10-22 00:25:36Z airwin $
+// $Id: pldebug.h 11998 2011-10-21 12:34:16Z andrewross $
 //
 //  Copyright (C) 1995 by Maurice J. LeBrun
 //
@@ -85,6 +85,9 @@ pldebug( const char *label, ... )
         if ( plsc->termin )
             c_plgra();
     }
+#else
+    // Avoid warning about unused parameter
+    (void) label;
 #endif  // DEBUG
 }
 #endif  // NEED_PLDEBUG
