@@ -1,4 +1,4 @@
-// $Id: plfreetype.h 11269 2010-10-22 00:25:36Z airwin $
+// $Id: plfreetype.h 12334 2013-05-04 16:43:33Z airwin $
 //
 //    Header file for Support routines for freetype font engine
 //
@@ -28,12 +28,13 @@
 #ifndef __PLFREETY_H__
 #define __PLFREETY_H__
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include FT_GLYPH_H
 #include FT_OUTLINE_H
+#include FT_MODULE_H
 
 #define FT_Data    _FT_Data_
 
