@@ -1,4 +1,4 @@
-// $Id: plplot.h 11887 2011-08-16 19:49:14Z hbabcock $
+// $Id: plplot.h 12968 2014-01-29 01:42:57Z airwin $
 //
 //  Macros and prototypes for the PLplot package.  This header file must
 //  be included by all user codes.
@@ -114,15 +114,22 @@
 #endif
 #endif
 
-// A wrapper used in some header files so they can be compiled with cc
-
-#define PLARGS( a )    a
-
 //--------------------------------------------------------------------------
 // dll functions
 //--------------------------------------------------------------------------
 #include "pldll.h"
 
+// Macro to mark function parameters as unused.
+// For gcc this uses the unused attribute to remove compiler warnings.
+// For all compilers the parameter name is also mangled to prevent
+// accidental use.
+#ifdef PL_UNUSED
+#elif defined ( __GNUC__ )
+# define PL_UNUSED( x )    UNUSED_ ## x __attribute__( ( unused ) )
+#else
+# define PL_UNUSED( x )    UNUSED_ ## x
+#endif
+
 //--------------------------------------------------------------------------
 // Base types for PLplot
 //
@@ -243,6 +250,9 @@ typedef void*    PLPointer;
 #define PLTEXT_FONTCHANGE        0      // font change in the text stream
 #define PLTEXT_SUPERSCRIPT       1      // superscript in the text stream
 #define PLTEXT_SUBSCRIPT         2      // subscript in the text stream
+#define PLTEXT_BACKCHAR          3      // back-char in the text stream
+#define PLTEXT_OVERLINE          4      // toggle overline in the text stream
+#define PLTEXT_UNDERLINE         5      // toggle underline in the text stream
 
 // image operations
 #define ZEROW2B                  1
@@ -321,7 +331,7 @@ typedef void*    PLPointer;
 // Obsolete names
 
 #define plParseInternalOpts( a, b, c )    c_plparseopts( a, b, c )
-#define plSetInternalOpt( a, b )          plSetOpt( a, b )
+#define plSetInternalOpt( a, b )          c_plsetopt( a, b )
 
 #endif  // PL_DEPRECATED
 
@@ -390,8 +400,8 @@ typedef struct
 
 typedef struct
 {
-    PLFLT *f;
-    PLINT nx, ny, nz;
+    const PLFLT *f;
+    PLINT       nx, ny, nz;
 } PLfGrid;
 
 //
@@ -459,7 +469,7 @@ typedef struct
     PLFLT s;                    // saturation
     PLFLT p;                    // position
     PLFLT a;                    // alpha (or transparency)
-    int   rev;                  // if set, interpolate through h=0
+    int   alt_hue_path;         // if set, interpolate through h=0
 } PLControlPt;
 
 // A PLBufferingCB is a control block for interacting with devices
@@ -636,7 +646,9 @@ typedef plf2ops_t * PLF2OPS;
 #define    plgyax                   c_plgyax
 #define    plgzax                   c_plgzax
 #define    plhist                   c_plhist
+#ifdef PL_DEPRECATED
 #define    plhls                    c_plhls
+#endif
 #define    plhlsrgb                 c_plhlsrgb
 #define    plimage                  c_plimage
 #define    plimagefr                c_plimagefr
@@ -670,8 +682,10 @@ typedef plf2ops_t * PLF2OPS;
 #define    plptex3                  c_plptex3
 #define    plrandd                  c_plrandd
 #define    plreplot                 c_plreplot
+#ifdef PL_DEPRECATED
 #define    plrgb                    c_plrgb
 #define    plrgb1                   c_plrgb1
+#endif
 #define    plrgbhls                 c_plrgbhls
 #define    plschr                   c_plschr
 #define    plscmap0                 c_plscmap0
@@ -745,7 +759,10 @@ typedef plf2ops_t * PLF2OPS;
 #define    plvpor                   c_plvpor
 #define    plvsta                   c_plvsta
 #define    plw3d                    c_plw3d
+#ifdef PL_DEPRECATED
 #define    plwid                    c_plwid
+#endif
+#define    plwidth                  c_plwidth
 #define    plwind                   c_plwind
 #define    plxormod                 c_plxormod
 
@@ -759,15 +776,17 @@ typedef plf2ops_t * PLF2OPS;
 
 #ifdef PL_DEPRECATED
 
-#define    plclr           pleop
-#define    plpage          plbop
-#define    plcol           plcol0
-#define    plcontf         plfcont
-#define    Alloc2dGrid     plAlloc2dGrid
-#define    Free2dGrid      plFree2dGrid
-#define    MinMax2dGrid    plMinMax2dGrid
-#define    plP_gvpd        plgvpd
-#define    plP_gvpw        plgvpw
+#define    plclr      pleop
+#define    plpage     plbop
+#define    plcol      plcol0
+#define    plcontf    plfcont
+// Comment out these as they can upset the C++ bindings since the C++
+// bindings use the function names without the pl prefix.
+//#define    Alloc2dGrid     plAlloc2dGrid
+//#define    Free2dGrid      plFree2dGrid
+//#define    MinMax2dGrid    plMinMax2dGrid
+#define    plP_gvpd    plgvpd
+#define    plP_gvpw    plgvpw
 #define    plotsh3d( x, y, z, nx, ny, opt )    plsurf3d( x, y, z, nx, ny, opt, NULL, 0 )
 
 #endif // PL_DEPRECATED
@@ -817,10 +836,10 @@ c_plaxes( PLFLT x0, PLFLT y0, const char *xopt, PLFLT xtick, PLINT nxsub,
 // Plot a histogram using x to store data values and y to store frequencies
 
 // Flags for plbin() - opt argument
-#define PL_BIN_DEFAULT     0
-#define PL_BIN_CENTRED     1
-#define PL_BIN_NOEXPAND    2
-#define PL_BIN_NOEMPTY     4
+#define PL_BIN_DEFAULT     0x0
+#define PL_BIN_CENTRED     0x1
+#define PL_BIN_NOEXPAND    0x2
+#define PL_BIN_NOEMPTY     0x4
 
 PLDLLIMPEXP void
 c_plbin( PLINT nbin, const PLFLT *x, const PLFLT *y, PLINT opt );
@@ -843,9 +862,9 @@ c_plbox( const char *xopt, PLFLT xtick, PLINT nxsub,
 // This is the 3-d analogue of plbox().
 
 PLDLLIMPEXP void
-c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
-          const char *yopt, const char *ylabel, PLFLT ytick, PLINT nsuby,
-          const char *zopt, const char *zlabel, PLFLT ztick, PLINT nsubz );
+c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nxsub,
+          const char *yopt, const char *ylabel, PLFLT ytick, PLINT nysub,
+          const char *zopt, const char *zlabel, PLFLT ztick, PLINT nzsub );
 
 // Calculate world coordinates and subpage from relative device coordinates.
 
@@ -877,7 +896,7 @@ c_plconfigtime( PLFLT scale, PLFLT offset1, PLFLT offset2, PLINT ccontrol, PLBOO
 //
 
 PLDLLIMPEXP void
-c_plcont( const PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
+c_plcont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
           PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data );
@@ -998,7 +1017,7 @@ c_plgcol0( PLINT icol0, PLINT *r, PLINT *g, PLINT *b );
 // Returns 8 bit RGB values for given color from color map 0 and alpha value
 
 PLDLLIMPEXP void
-c_plgcol0a( PLINT icol0, PLINT *r, PLINT *g, PLINT *b, PLFLT *a );
+c_plgcol0a( PLINT icol0, PLINT *r, PLINT *g, PLINT *b, PLFLT *alpha );
 
 // Returns the background color by 8 bit RGB value
 
@@ -1008,7 +1027,7 @@ c_plgcolbg( PLINT *r, PLINT *g, PLINT *b );
 // Returns the background color by 8 bit RGB value and alpha value
 
 PLDLLIMPEXP void
-c_plgcolbga( PLINT *r, PLINT *g, PLINT *b, PLFLT *a );
+c_plgcolbga( PLINT *r, PLINT *g, PLINT *b, PLFLT *alpha );
 
 // Returns the current compression setting
 
@@ -1038,12 +1057,12 @@ c_plgdiplt( PLFLT *p_xmin, PLFLT *p_ymin, PLFLT *p_xmax, PLFLT *p_ymax );
 // Get the drawing mode
 
 PLDLLIMPEXP PLINT
-c_plgdrawmode();
+c_plgdrawmode( void );
 
 // Get FCI (font characterization integer)
 
 PLDLLIMPEXP void
-c_plgfci( PLUNICODE *pfci );
+c_plgfci( PLUNICODE *p_fci );
 
 // Get family file parameters
 
@@ -1146,11 +1165,11 @@ c_plgzax( PLINT *p_digmax, PLINT *p_digits );
 
 // Flags for plhist() - opt argument; note: some flags are passed to
 // plbin() for the actual plotting
-#define PL_HIST_DEFAULT            0
-#define PL_HIST_NOSCALING          1
-#define PL_HIST_IGNORE_OUTLIERS    2
-#define PL_HIST_NOEXPAND           8
-#define PL_HIST_NOEMPTY            16
+#define PL_HIST_DEFAULT            0x00
+#define PL_HIST_NOSCALING          0x01
+#define PL_HIST_IGNORE_OUTLIERS    0x02
+#define PL_HIST_NOEXPAND           0x08
+#define PL_HIST_NOEMPTY            0x10
 
 PLDLLIMPEXP void
 c_plhist( PLINT n, const PLFLT *data, PLFLT datmin, PLFLT datmax,
@@ -1230,13 +1249,13 @@ c_pllegend( PLFLT *p_legend_width, PLFLT *p_legend_height,
             PLINT nlegend, const PLINT *opt_array,
             PLFLT text_offset, PLFLT text_scale, PLFLT text_spacing,
             PLFLT text_justification,
-            const PLINT *text_colors, const char **text,
+            const PLINT *text_colors, const char * const *text,
             const PLINT *box_colors, const PLINT *box_patterns,
-            const PLFLT *box_scales, const PLINT *box_line_widths,
+            const PLFLT *box_scales, const PLFLT *box_line_widths,
             const PLINT *line_colors, const PLINT *line_styles,
-            const PLINT *line_widths,
+            const PLFLT *line_widths,
             const PLINT *symbol_colors, const PLFLT *symbol_scales,
-            const PLINT *symbol_numbers, const char **symbols );
+            const PLINT *symbol_numbers, const char * const *symbols );
 
 // Routine for drawing continous colour legends
 PLDLLIMPEXP void
@@ -1245,10 +1264,11 @@ c_plcolorbar( PLFLT *p_colorbar_width, PLFLT *p_colorbar_height,
               PLFLT x_length, PLFLT y_length,
               PLINT bg_color, PLINT bb_color, PLINT bb_style,
               PLFLT low_cap_color, PLFLT high_cap_color,
-              PLINT cont_color, PLINT cont_width,
-              PLFLT ticks, PLINT sub_ticks,
-              const char *axis_opts, const char *label,
-              PLINT n_values, const PLFLT *values );
+              PLINT cont_color, PLFLT cont_width,
+              PLINT n_labels, const PLINT *label_opts, const char * const *labels,
+              PLINT n_axes, const char * const * axis_opts,
+              const PLFLT *ticks, const PLINT *sub_ticks,
+              const PLINT *n_values, const PLFLT * const *values );
 
 // Sets position of the light source
 PLDLLIMPEXP void
@@ -1285,7 +1305,7 @@ c_plmeridians( void ( *mapform )( PLINT, PLFLT *, PLFLT * ),
 // Plots a mesh representation of the function z[x][y].
 
 PLDLLIMPEXP void
-c_plmesh( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny, PLINT opt );
+c_plmesh( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny, PLINT opt );
 
 // Like plmesh, but uses an evaluator function to access z data from zp
 
@@ -1296,7 +1316,7 @@ plfmesh( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // Plots a mesh representation of the function z[x][y] with contour
 
 PLDLLIMPEXP void
-c_plmeshc( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny, PLINT opt,
+c_plmeshc( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny, PLINT opt,
            const PLFLT *clevel, PLINT nlevel );
 
 // Like plmeshc, but uses an evaluator function to access z data from zp
@@ -1325,7 +1345,7 @@ c_plmtex3( const char *side, PLFLT disp, PLFLT pos, PLFLT just,
 // Plots a 3-d representation of the function z[x][y].
 
 PLDLLIMPEXP void
-c_plot3d( const PLFLT *x, const PLFLT *y, const PLFLT **z,
+c_plot3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
           PLINT nx, PLINT ny, PLINT opt, PLBOOL side );
 
 // Like plot3d, but uses an evaluator function to access z data from zp
@@ -1337,7 +1357,7 @@ plfplot3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // Plots a 3-d representation of the function z[x][y] with contour.
 
 PLDLLIMPEXP void
-c_plot3dc( const PLFLT *x, const PLFLT *y, const PLFLT **z,
+c_plot3dc( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
            PLINT nx, PLINT ny, PLINT opt,
            const PLFLT *clevel, PLINT nlevel );
 
@@ -1351,10 +1371,10 @@ plfplot3dc( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // y index limits.
 
 PLDLLIMPEXP void
-c_plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT **z,
+c_plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
             PLINT nx, PLINT ny, PLINT opt,
             const PLFLT *clevel, PLINT nlevel,
-            PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax );
+            PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax );
 
 // Like plot3dcl, but uses an evaluator function to access z data from zp
 
@@ -1362,7 +1382,7 @@ PLDLLIMPEXP void
 plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
              PLINT nx, PLINT ny, PLINT opt,
              const PLFLT *clevel, PLINT nlevel,
-             PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax );
+             PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax );
 
 //
 // definitions for the opt argument in plot3dc() and plsurf3d()
@@ -1370,16 +1390,16 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // DRAW_LINEX *must* be 1 and DRAW_LINEY *must* be 2, because of legacy code!
 //
 
-#define DRAW_LINEX     ( 1 << 0 )                  // draw lines parallel to the X axis
-#define DRAW_LINEY     ( 1 << 1 )                  // draw lines parallel to the Y axis
-#define DRAW_LINEXY    ( DRAW_LINEX | DRAW_LINEY ) // draw lines parallel to both the X and Y axis
-#define MAG_COLOR      ( 1 << 2 )                  // draw the mesh with a color dependent of the magnitude
-#define BASE_CONT      ( 1 << 3 )                  // draw contour plot at bottom xy plane
-#define TOP_CONT       ( 1 << 4 )                  // draw contour plot at top xy plane
-#define SURF_CONT      ( 1 << 5 )                  // draw contour plot at surface
-#define DRAW_SIDES     ( 1 << 6 )                  // draw sides
-#define FACETED        ( 1 << 7 )                  // draw outline for each square that makes up the surface
-#define MESH           ( 1 << 8 )                  // draw mesh
+#define DRAW_LINEX     0x001  // draw lines parallel to the X axis
+#define DRAW_LINEY     0x002  // draw lines parallel to the Y axis
+#define DRAW_LINEXY    0x003  // draw lines parallel to both the X and Y axis
+#define MAG_COLOR      0x004  // draw the mesh with a color dependent of the magnitude
+#define BASE_CONT      0x008  // draw contour plot at bottom xy plane
+#define TOP_CONT       0x010  // draw contour plot at top xy plane
+#define SURF_CONT      0x020  // draw contour plot at surface
+#define DRAW_SIDES     0x040  // draw sides
+#define FACETED        0x080  // draw outline for each square that makes up the surface
+#define MESH           0x100  // draw mesh
 
 //
 //  valid options for plot3dc():
@@ -1467,7 +1487,7 @@ c_plscmap0( const PLINT *r, const PLINT *g, const PLINT *b, PLINT ncol0 );
 // Set color map 0 colors by 8 bit RGB values and alpha values
 
 PLDLLIMPEXP void
-c_plscmap0a( const PLINT *r, const PLINT *g, const PLINT *b, const PLFLT *a, PLINT ncol0 );
+c_plscmap0a( const PLINT *r, const PLINT *g, const PLINT *b, const PLFLT *alpha, PLINT ncol0 );
 
 // Set number of colors in cmap 0
 
@@ -1482,14 +1502,14 @@ c_plscmap1( const PLINT *r, const PLINT *g, const PLINT *b, PLINT ncol1 );
 // Set color map 1 colors by 8 bit RGB and alpha values
 
 PLDLLIMPEXP void
-c_plscmap1a( const PLINT *r, const PLINT *g, const PLINT *b, const PLFLT *a, PLINT ncol1 );
+c_plscmap1a( const PLINT *r, const PLINT *g, const PLINT *b, const PLFLT *alpha, PLINT ncol1 );
 
 // Set color map 1 colors using a piece-wise linear relationship between
 // intensity [0,1] (cmap 1 index) and position in HLS or RGB color space.
 
 PLDLLIMPEXP void
 c_plscmap1l( PLBOOL itype, PLINT npts, const PLFLT *intensity,
-             const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLBOOL *rev );
+             const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLBOOL *alt_hue_path );
 
 // Set color map 1 colors using a piece-wise linear relationship between
 // intensity [0,1] (cmap 1 index) and position in HLS or RGB color space.
@@ -1497,7 +1517,7 @@ c_plscmap1l( PLBOOL itype, PLINT npts, const PLFLT *intensity,
 
 PLDLLIMPEXP void
 c_plscmap1la( PLBOOL itype, PLINT npts, const PLFLT *intensity,
-              const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLFLT *a, const PLBOOL *rev );
+              const PLFLT *coord1, const PLFLT *coord2, const PLFLT *coord3, const PLFLT *alpha, const PLBOOL *alt_hue_path );
 
 // Set number of colors in cmap 1
 
@@ -1522,7 +1542,7 @@ c_plscol0( PLINT icol0, PLINT r, PLINT g, PLINT b );
 // Set a given color from color map 0 by 8 bit RGB value
 
 PLDLLIMPEXP void
-c_plscol0a( PLINT icol0, PLINT r, PLINT g, PLINT b, PLFLT a );
+c_plscol0a( PLINT icol0, PLINT r, PLINT g, PLINT b, PLFLT alpha );
 
 // Set the background color by 8 bit RGB value
 
@@ -1532,7 +1552,7 @@ c_plscolbg( PLINT r, PLINT g, PLINT b );
 // Set the background color by 8 bit RGB value and alpha value
 
 PLDLLIMPEXP void
-c_plscolbga( PLINT r, PLINT g, PLINT b, PLFLT a );
+c_plscolbga( PLINT r, PLINT g, PLINT b, PLFLT alpha );
 
 // Used to globally turn color output on/off
 
@@ -1579,7 +1599,7 @@ c_plsdiplz( PLFLT xmin, PLFLT ymin, PLFLT xmax, PLFLT ymax );
 // Set seed for internal random number generator
 
 PLDLLIMPEXP void
-c_plseed( unsigned int s );
+c_plseed( unsigned int seed );
 
 // Set the escape character for text strings.
 
@@ -1609,32 +1629,32 @@ c_plsfont( PLINT family, PLINT style, PLINT weight );
 // Shade region.
 
 PLDLLIMPEXP void
-c_plshade( const PLFLT **a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
-           PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
+c_plshade( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+           PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
            PLFLT shade_min, PLFLT shade_max,
-           PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-           PLINT min_color, PLINT min_width,
-           PLINT max_color, PLINT max_width,
+           PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+           PLINT min_color, PLFLT min_width,
+           PLINT max_color, PLFLT max_width,
            void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLBOOL rectangular,
            void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
            PLPointer pltr_data );
 
 PLDLLIMPEXP void
 c_plshade1( const PLFLT *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
-            PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
+            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
             PLFLT shade_min, PLFLT shade_max,
-            PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-            PLINT min_color, PLINT min_width,
-            PLINT max_color, PLINT max_width,
+            PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+            PLINT min_color, PLFLT min_width,
+            PLINT max_color, PLFLT max_width,
             void ( *fill )( const PLINT, const PLFLT *, const PLFLT * ), PLBOOL rectangular,
             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
             PLPointer pltr_data );
 
 PLDLLIMPEXP void
-c_plshades( const PLFLT **a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+c_plshades( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
             PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-            const PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-            PLINT cont_color, PLINT cont_width,
+            const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+            PLINT cont_color, PLFLT cont_width,
             void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLBOOL rectangular,
             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
             PLPointer pltr_data );
@@ -1643,8 +1663,8 @@ PLDLLIMPEXP void
 plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
            PLINT ( *defined )( PLFLT, PLFLT ),
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-           const PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-           PLINT cont_color, PLINT cont_width,
+           const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+           PLINT cont_color, PLFLT cont_width,
            void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
            void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
            PLPointer pltr_data );
@@ -1657,9 +1677,9 @@ plfshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
           PLINT nx, PLINT ny,
           PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
           PLFLT shade_min, PLFLT shade_max,
-          PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-          PLINT min_color, PLINT min_width,
-          PLINT max_color, PLINT max_width,
+          PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+          PLINT min_color, PLFLT min_width,
+          PLINT max_color, PLFLT max_width,
           void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLBOOL rectangular,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data );
@@ -1669,9 +1689,9 @@ plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
            PLINT ( *defined )( PLFLT, PLFLT ),
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
            PLFLT shade_min, PLFLT shade_max,
-           PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-           PLINT min_color, PLINT min_width,
-           PLINT max_color, PLINT max_width,
+           PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+           PLINT min_color, PLFLT min_width,
+           PLINT max_color, PLFLT max_width,
            void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
            void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
            PLPointer pltr_data );
@@ -1804,7 +1824,7 @@ c_plstripd( PLINT id );
 // plots a 2d image (or a matrix too large for plshade() )
 
 PLDLLIMPEXP void
-c_plimagefr( const PLFLT **idata, PLINT nx, PLINT ny,
+c_plimagefr( const PLFLT * const *idata, PLINT nx, PLINT ny,
              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
              PLFLT valuemin, PLFLT valuemax,
              void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
@@ -1826,7 +1846,7 @@ plfimagefr( PLF2OPS idataops, PLPointer idatap, PLINT nx, PLINT ny,
 // automatically scaled
 
 PLDLLIMPEXP void
-c_plimage( const PLFLT **idata, PLINT nx, PLINT ny,
+c_plimage( const PLFLT * const *idata, PLINT nx, PLINT ny,
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
            PLFLT Dxmin, PLFLT Dxmax, PLFLT Dymin, PLFLT Dymax );
 
@@ -1848,7 +1868,7 @@ c_plstyl( PLINT nms, const PLINT *mark, const PLINT *space );
 // Plots the 3d surface representation of the function z[x][y].
 
 PLDLLIMPEXP void
-c_plsurf3d( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny,
+c_plsurf3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny,
             PLINT opt, const PLFLT *clevel, PLINT nlevel );
 
 // Like plsurf3d, but uses an evaluator function to access z data from zp
@@ -1861,17 +1881,18 @@ plfsurf3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // index limits.
 
 PLDLLIMPEXP void
-c_plsurf3dl( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny,
+c_plsurf3dl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny,
              PLINT opt, const PLFLT *clevel, PLINT nlevel,
-             PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax );
+             PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax );
 
 // Like plsurf3dl, but uses an evaluator function to access z data from zp
 
 PLDLLIMPEXP void
 plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
             PLINT opt, const PLFLT *clevel, PLINT nlevel,
-            PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT * indexymax );
+            PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax );
 
+// Set arrow style for vector plots.
 PLDLLIMPEXP void
 c_plsvect( const PLFLT *arrowx, const PLFLT *arrowy, PLINT npts, PLBOOL fill );
 
@@ -1927,7 +1948,7 @@ c_plvasp( PLFLT aspect );
 // simple arrow plotter.
 
 PLDLLIMPEXP void
-c_plvect( const PLFLT **u, const PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
+c_plvect( const PLFLT * const *u, const PLFLT * const *v, PLINT nx, PLINT ny, PLFLT scale,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data );
 
@@ -1959,14 +1980,21 @@ c_plvsta( void );
 // Set up a window for three-dimensional plotting.
 
 PLDLLIMPEXP void
-c_plw3d( PLFLT basex, PLFLT basey, PLFLT height, PLFLT xmin0,
-         PLFLT xmax0, PLFLT ymin0, PLFLT ymax0, PLFLT zmin0,
-         PLFLT zmax0, PLFLT alt, PLFLT az );
+c_plw3d( PLFLT basex, PLFLT basey, PLFLT height, PLFLT xmin,
+         PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin,
+         PLFLT zmax, PLFLT alt, PLFLT az );
+
+#ifdef PL_DEPRECATED
+// Set pen width with deprecated integer width
+
+PLDLLIMPEXP void
+c_plwid( PLINT width );
+#endif
 
 // Set pen width.
 
 PLDLLIMPEXP void
-c_plwid( PLINT width );
+c_plwidth( PLFLT width );
 
 // Set up world coordinates of the viewport boundaries (2d plots).
 
@@ -2068,7 +2096,7 @@ pltr2f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data );
 //
 
 PLDLLIMPEXP PLF2OPS
-plf2ops_c();
+plf2ops_c( void );
 
 //
 // Returns a pointer to a plf2ops_t stucture with pointers to functions for accessing 2-D data
@@ -2077,7 +2105,7 @@ plf2ops_c();
 //
 
 PLDLLIMPEXP PLF2OPS
-plf2ops_grid_c();
+plf2ops_grid_c( void );
 
 //
 // Returns a pointer to a plf2ops_t stucture with pointers to functions for
@@ -2089,7 +2117,7 @@ plf2ops_grid_c();
 //
 
 PLDLLIMPEXP PLF2OPS
-plf2ops_grid_row_major();
+plf2ops_grid_row_major( void );
 
 //
 // Returns a pointer to a plf2ops_t stucture with pointers to functions for
@@ -2101,7 +2129,7 @@ plf2ops_grid_row_major();
 //
 
 PLDLLIMPEXP PLF2OPS
-plf2ops_grid_col_major();
+plf2ops_grid_col_major( void );
 
 
 // Function evaluators (Should these be deprecated in favor of plf2ops?)
@@ -2265,7 +2293,7 @@ plFree2dGrid( PLFLT **f, PLINT nx, PLINT ny );
 // Find the maximum and minimum of a 2d matrix allocated with plAllc2dGrid().
 
 PLDLLIMPEXP void
-plMinMax2dGrid( const PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmax, PLFLT *fmin );
+plMinMax2dGrid( const PLFLT * const *f, PLINT nx, PLINT ny, PLFLT *fmax, PLFLT *fmin );
 
 // Wait for graphics input event and translate to world coordinates
 
