@@ -1,4 +1,4 @@
-// $Id: plplotP.h 11849 2011-08-03 23:11:30Z hezekiahcarty $
+// $Id: plplotP.h 12831 2013-12-09 14:35:42Z andrewross $
 //
 //  Internal (private) macros and prototypes for the PLplot package.  This
 //  header file must be included before all others, including system header
@@ -252,22 +252,25 @@ int plsnscanf( const char *buffer, int n, const char *format, ... );
 #  endif
 #endif
 #if defined ( PL__HAVE_ISINF )
-#  define isinf     _isinf
+#  define isinf       _isinf
+#endif
+#if defined ( PL_HAVE_FINITE )
+#  define isfinite    finite
 #endif
 #if defined ( PL__HAVE_FINITE )
-#  define finite    _finite
+#  define isfinite    _finite
 #endif
 
 // Note these replacements follow the old BSD convention and not
 // C99. In particular isinf does not distinguish +/- inf.
 #if !defined ( PL_HAVE_ISNAN )
-#  define isnan( x )     ( ( x ) != ( x ) )
+#  define isnan( x )       ( ( x ) != ( x ) )
 #endif
 #if !defined ( PL_HAVE_ISINF )
-#  define isinf( x )     ( !isnan( x ) && isnan( x - x ) )
+#  define isinf( x )       ( !isnan( x ) && isnan( x - x ) )
 #endif
-#if !defined ( PL_HAVE_FINITE )
-#  define finite( x )    ( !isnan( x - x ) )
+#if !defined ( PL_HAVE_ISFINITE )
+#  define isfinite( x )    ( !isnan( x - x ) )
 #endif
 
 // Check if C99 HUGE_VAL macro is available - if not then
@@ -721,7 +724,7 @@ typedef struct cont_level
 } CONT_LEVEL;
 
 void
-cont_store( const PLFLT **f, PLINT nx, PLINT ny,
+cont_store( const PLFLT * const *f, PLINT nx, PLINT ny,
             PLINT kx, PLINT lx, PLINT ky, PLINT ly,
             const PLFLT *clevel, PLINT nlevel,
             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
@@ -795,7 +798,7 @@ plP_setpxl( PLFLT xpmm0, PLFLT ypmm0 );
 // Get background parameters (including line width) for 3d plot.
 
 void
-plP_gzback( PLINT **zbf, PLINT **zbc, PLFLT **zbt, PLINT **zbw );
+plP_gzback( PLINT **zbf, PLINT **zbc, PLFLT **zbt, PLFLT **zbw );
 
 // Move to physical coordinates (x,y).
 
@@ -845,7 +848,7 @@ plP_gprec( PLINT *p_setp, PLINT *p_prec );
 // Get the date / time format for numeric labels
 
 const char *
-plP_gtimefmt();
+plP_gtimefmt( void );
 
 // Computes the length of a string in mm, including escape sequences.
 
@@ -1117,7 +1120,7 @@ void
 grimage( short *x, short *y, unsigned short *z, PLINT nx, PLINT ny );
 
 PLDLLIMPEXP int
-plInBuildTree();
+plInBuildTree( void );
 
 void
 plimageslow( PLFLT *idata, PLINT nx, PLINT ny,
@@ -1153,19 +1156,19 @@ plhershey2unicode( int in );
 // struct used for FCI to FontName lookups.
 typedef struct
 {
-    PLUNICODE     fci;
-    unsigned char *pfont;
+    PLUNICODE           fci;
+    const unsigned char *pfont;
 } FCI_to_FontName_Table;
 
 // Internal function to obtain a pointer to a valid font name.
-PLDLLIMPEXP char *
+PLDLLIMPEXP const char *
 plP_FCI2FontName( PLUNICODE fci,
                   const FCI_to_FontName_Table lookup[], const int nlookup );
 
 
 // Internal function to free memory from driver options
 void
-plP_FreeDrvOpts();
+plP_FreeDrvOpts( void );
 
 // Convert a ucs4 unichar to utf8 char string
 PLDLLIMPEXP int
@@ -1190,14 +1193,22 @@ plio_fread( void *, size_t, size_t, FILE * );
 void
 plio_fgets( char *, int, FILE * );
 
+// Draws a tick parallel to x, using world coordinates
+void
+plwxtik( PLFLT x, PLFLT y, PLBOOL minor, PLBOOL invert );
+
+// Draws a tick parallel to y, using world coordinates
+void
+plwytik( PLFLT x, PLFLT y, PLBOOL minor, PLBOOL invert );
+
 // get drivers directory
 
 #ifdef ENABLE_DYNDRIVERS
-PLDLLIMPEXP char*
+PLDLLIMPEXP const char*
 plGetDrvDir( void );
 #endif
 
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 PLDLLIMPEXP void
 plD_FreeType_init( PLStream * );
 
@@ -1216,6 +1227,10 @@ pl_set_extended_cmap0( PLStream *, int, int );
 PLDLLIMPEXP FILE *
 pl_create_tempfile( char **fname );
 
+// Create a temporary fifo securely
+PLDLLIMPEXP char *
+pl_create_tempfifo( const char **p_fifoname, const char **p_dirname );
+
 #ifdef __cplusplus
 }
 #endif
