@@ -1,4 +1,4 @@
-// $Id: plstrm.h 11774 2011-06-20 22:09:33Z airwin $
+// $Id: plstrm.h 12288 2013-01-30 04:40:35Z airwin $
 //
 //	Contains declarations for PLStream and PLDev structs.
 //	Also prototypes for stream & device utility functions.
@@ -530,10 +530,10 @@ typedef struct
 {
 // Misc control information
 
-    PLINT      ipls, level, verbose, debug, initialized, dev_initialized;
+    PLINT ipls, level, verbose, debug, initialized, dev_initialized;
     //CONSTANT SOVERSION FIX
     //    PLBOOL     stream_closed;
-    const char *program;
+    char  *program;
 
 // Plot-wide coordinate transform
 
@@ -554,7 +554,7 @@ typedef struct
 
 // Variables governing pen width
 
-    PLINT width;
+    PLFLT width;
     PLINT widthset, widthlock;
 
 // Variables governing arrow
@@ -774,31 +774,31 @@ typedef struct
     // transformation between broken-down and continuous time used in
     // the qsastime library.
 
-    QSASConfig *qsasconfig;
+    QSASConfig  *qsasconfig;
 
     // Gradient section.
-    PLINT      dev_gradient;
-    PLINT      ngradient;
-    PLINT      *xgradient, *ygradient;
+    PLINT       dev_gradient;
+    PLINT       ngradient;
+    PLINT       *xgradient, *ygradient;
     // The next three variables define the polygon boundary used
     // in the software fallback for the gradient.
-    PLINT      n_polygon;
-    PLFLT      *x_polygon, *y_polygon;
+    PLINT       n_polygon;
+    const PLFLT *x_polygon, *y_polygon;
 
     //CONSTANT SOVERSION FIX
-    PLBOOL     stream_closed;
-    PLINT      line_style;
-    PLINT      dev_mem_alpha;
-    PLINT      has_string_length;
-    PLFLT      string_length;
-    PLINT      get_string_length;
-    PLINT      dev_eofill;
+    PLBOOL      stream_closed;
+    PLINT       line_style;
+    PLINT       dev_mem_alpha;
+    PLINT       has_string_length;
+    PLFLT       string_length;
+    PLINT       get_string_length;
+    PLINT       dev_eofill;
 
     // Drawing mode section
-    PLINT      dev_modeset;
+    PLINT       dev_modeset;
 
     // Calculate bounding-box limits rather than plot box?
-    PLBOOL     if_boxbb;
+    PLBOOL      if_boxbb;
     // Bounding box limits in mm for box including decorations
     // (inverted tick marks and numerical tick labels if either is
     // present).
