@@ -132,7 +132,9 @@ struct csa
     int nppc;                   // average number of points per square
 };
 
-static void csa_quit( char* format, ... )
+void csa_setnppc( csa* a, double nppc );
+
+static void csa_quit( const char* format, ... )
 {
     va_list args;
 
@@ -155,26 +157,26 @@ static void csa_quit( char* format, ... )
 //
 static void* alloc2d( int n1, int n2, size_t unitsize )
 {
-    unsigned int size;
-    char         * p;
-    char         ** pp;
-    int          i;
+    size_t size;
+    char   * p;
+    char   ** pp;
+    int    i;
 
     assert( n1 > 0 );
     assert( n2 > 0 );
     assert( (double) n1 * (double) n2 <= (double) UINT_MAX );
 
-    size = n1 * n2;
+    size = (size_t) ( n1 * n2 );
     if ( ( p = calloc( size, unitsize ) ) == NULL )
         csa_quit( "alloc2d(): %s\n", strerror( errno ) );
 
     assert( (double) n2 * (double) sizeof ( void* ) <= (double) UINT_MAX );
 
-    size = n2 * sizeof ( void* );
+    size = (size_t) n2 * sizeof ( void* );
     if ( ( pp = malloc( size ) ) == NULL )
         csa_quit( "alloc2d(): %s\n", strerror( errno ) );
     for ( i = 0; i < n2; i++ )
-        pp[i] = &p[i * n1 * unitsize];
+        pp[i] = &p[(size_t) ( i * n1 ) * unitsize];
 
     return pp;
 }
@@ -226,7 +228,7 @@ static void triangle_addpoint( triangle* t, point* p )
         }
         else
         {
-            t->points      = realloc( t->points, t->nallocated * 2 * sizeof ( point* ) );
+            t->points      = realloc( t->points, (size_t) ( t->nallocated * 2 ) * sizeof ( point* ) );
             t->nallocated *= 2;
         }
     }
@@ -337,7 +339,7 @@ static void square_addpoint( square* s, point* p )
         }
         else
         {
-            s->points      = realloc( s->points, s->nallocated * 2 * sizeof ( point* ) );
+            s->points      = realloc( s->points, (size_t) ( s->nallocated * 2 ) * sizeof ( point* ) );
             s->nallocated *= 2;
         }
     }
@@ -407,7 +409,7 @@ void csa_addpoints( csa* a, int n, point points[] )
         na *= 2;
     if ( na != a->nallocated )
     {
-        a->points     = realloc( a->points, na * sizeof ( point* ) );
+        a->points     = realloc( a->points, (size_t) na * sizeof ( point* ) );
         a->nallocated = na;
     }
 
@@ -534,7 +536,7 @@ static void csa_squarize( csa* a )
     // will be calculated directy (by least squares method), without using
     // C1 smoothness conditions.
     //
-    a->pt = malloc( ( a->ni / 2 + 1 ) * a->nj * sizeof ( triangle* ) );
+    a->pt = malloc( (size_t) ( ( a->ni / 2 + 1 ) * a->nj ) * sizeof ( triangle* ) );
     for ( j = 0, ii = 0, nadj = 0; j < a->nj; ++j )
     {
         for ( i = 0; i < a->ni; ++i )
@@ -623,7 +625,7 @@ static void getsquares( csa* a, triangle* t, int* n, square*** squares )
         jmax = a->nj - 1;
 
     *n           = 0;
-    ( *squares ) = malloc( ( imax - imin + 1 ) * ( jmax - jmin + 1 ) * sizeof ( square* ) );
+    ( *squares ) = malloc( (size_t) ( ( imax - imin + 1 ) * ( jmax - jmin + 1 ) ) * sizeof ( square* ) );
 
     for ( j = jmin; j <= jmax; ++j )
     {
@@ -670,10 +672,11 @@ static void thindata( triangle* t, int npmax )
 
     for ( ii = 0; ii < t->npoints; ++ii )
     {
+        square* s;
         point * p = t->points[ii];
-        int   i   = (int) floor( ( p->x - xmin ) / h );
-        int   j   = (int) floor( ( p->y - ymin ) / h );
-        square* s = squares[j][i];
+        i = (int) floor( ( p->x - xmin ) / h );
+        j = (int) floor( ( p->y - ymin ) / h );
+        s = squares[j][i];
 
         if ( s->npoints == 0 )
             square_addpoint( s, p );
@@ -830,7 +833,7 @@ static void svd( double** a, int n, int m, double* w, double** v )
 
     assert( m > 0 && n > 0 );
 
-    rv1 = malloc( n * sizeof ( double ) );
+    rv1 = malloc( (size_t) n * sizeof ( double ) );
 
     //
     // householder reduction to bidiagonal form
@@ -1040,8 +1043,8 @@ static void svd( double** a, int n, int m, double* w, double** v )
                     s    = -f * h;
                     for ( j = 0; j < m; j++ )
                     {
-                        double y = a[j][l1];
-                        double z = a[j][i];
+                        y = a[j][l1];
+                        z = a[j][i];
 
                         a[j][l1] = y * c + z * s;
                         a[j][i]  = z * c - y * s;
@@ -1202,7 +1205,7 @@ static void csa_findprimarycoeffs( csa* a )
         triangle* t       = a->pt[i];
         int     npoints   = t->npoints;
         point   ** points = t->points;
-        double  * z       = malloc( npoints * sizeof ( double ) );
+        double  * z       = malloc( (size_t) npoints * sizeof ( double ) );
         int     q         = n2q( t->npoints );
         int     ok        = 1;
         double  b[10];
