@@ -6,40 +6,40 @@
 #include "defines.h"
 #include "cd.h"
 
-/* cdtest.c: test program for the cgmdraw module.
- *
- *      Written by G. Edward Johnson <mailto:lorax@nist.gov>
- *      Date: April 1996
- *      Copyright: cd software produced by NIST, an agency of the
- *      U.S. government, is by statute not subject to copyright
- *      in the United States. Recipients of this software assume all
- *      responsibilities associated with its operation, modification
- *      and maintenance.
- *
- */
+// cdtest.c: test program for the cgmdraw module.
+//
+//      Written by G. Edward Johnson <mailto:lorax@nist.gov>
+//      Date: April 1996
+//      Copyright: cd software produced by NIST, an agency of the
+//      U.S. government, is by statute not subject to copyright
+//      in the United States. Recipients of this software assume all
+//      responsibilities associated with its operation, modification
+//      and maintenance.
+//
+//
 
 
 int main()
 {
     cdImagePtr myimage;
 
-    /* Color indexes */
+    // Color indexes
     int     white;
     int     blue;
     int     red;
     int     green;
     int     black;
     int     lavender;
-    /* points for polygons and polylines */
+    // points for polygons and polylines
     cdPoint points[15];
-    /* output file */
+    // output file
     FILE    *outf;
 
 
-/* create an image, 1000 by 1000 pixels */
+// create an image, 1000 by 1000 pixels
     myimage = cdImageCreate( 1000, 1000 );
 
-/* Allocate the background color */
+// Allocate the background color
     white = cdImageColorAllocate( myimage, 255, 255, 255 );
     red   = cdImageColorAllocate( myimage, 255, 0, 0 );
     green = cdImageColorAllocate( myimage, 0, 255, 0 );
@@ -101,7 +101,7 @@ int main()
         fprintf( stderr, "cdLine Unsuccessful\n" );
     }
 
-/* Now, build a rectangle */
+// Now, build a rectangle
     if ( cdSetShapeFillAttrib( myimage, 3, blue, 6 ) )
     {
         fprintf( stderr, "cdSetShapeFillAttrib Successful\n" );
@@ -131,7 +131,7 @@ int main()
 
 
 
-/* now check out each of the line styles in order */
+// now check out each of the line styles in order
 
     if ( cdSetLineAttrib( myimage, 5, 4, green ) )
     {
@@ -220,7 +220,7 @@ int main()
         fprintf( stderr, "cdLine Unsuccessful\n" );
     }
 
-/* now make a circle */
+// now make a circle
     if ( cdSetShapeFillAttrib( myimage, 1, -1, 6 ) )
     {
         fprintf( stderr, "cdSetShapeFillAttrib Successful\n" );
@@ -248,7 +248,7 @@ int main()
         fprintf( stderr, "cdCircle Unsuccessful\n" );
     }
 
-/* how about a Circular Arc now */
+// how about a Circular Arc now
     if ( cdArc3Pt( myimage, 550, 500, 600, 600, 650, 550 ) )
     {
         fprintf( stderr, "cdArc3Pt Successful\n" );
@@ -258,7 +258,7 @@ int main()
         fprintf( stderr, "cdArc3Pt Unsuccessful\n" );
     }
 
-/* now draw a closed Circular Arc */
+// now draw a closed Circular Arc
     if ( cdArc3PtClose( myimage, 550, 200, 600, 300, 650, 250, 0 ) )
     {
         fprintf( stderr, "cdArc3PtClose Successful\n" );
@@ -268,7 +268,7 @@ int main()
         fprintf( stderr, "cdArc3PtClose Unsuccessful\n" );
     }
 
-/* and now for an ellipse */
+// and now for an ellipse
     if ( cdSetShapeEdgeAttrib( myimage, 1, 2, green, 1 ) )
     {
         fprintf( stderr, "cdSetShapeEdgeAttrib Successful\n" );
@@ -288,8 +288,8 @@ int main()
     }
 
 
-/* Now, the harder ones.  First lets try the polygon stuff */
-/* a polygon with 7 or less points */
+// Now, the harder ones.  First lets try the polygon stuff
+// a polygon with 7 or less points
 
     points[0].x = 700;
     points[0].y = 700;
@@ -307,7 +307,7 @@ int main()
         fprintf( stderr, "cdPolygon Unsuccessful\n" );
     }
 
-/* Here's a tough one, a polygon with more than seven points */
+// Here's a tough one, a polygon with more than seven points
 
     points[0].x  = 800;
     points[0].y  = 700;
@@ -341,29 +341,29 @@ int main()
         fprintf( stderr, "cdPolygon Unsuccessful\n" );
     }
 
-/* Now for a polygon set, two polygons (both triangles) the first one
- * with an invisible edge closing it. */
+// Now for a polygon set, two polygons (both triangles) the first one
+// with an invisible edge closing it.
 
-    points[0].x = 500;  /* start of first polygon */
+    points[0].x = 500;  // start of first polygon
     points[0].y = 350;
-    points[0].e = 1;    /* edge out is visible */
+    points[0].e = 1;    // edge out is visible
     points[1].x = 575;
     points[1].y = 350;
     points[1].e = 1;
     points[2].x = 575;
     points[2].y = 430;
-    points[2].e = 3;    /* close polygon with visible edge */
-    points[3].x = 600;  /* start of second polygon */
+    points[2].e = 3;    // close polygon with visible edge
+    points[3].x = 600;  // start of second polygon
     points[3].y = 350;
-    points[3].e = 0;    /* edge out is invisible */
+    points[3].e = 0;    // edge out is invisible
     points[4].x = 700;
     points[4].y = 350;
     points[4].e = 1;
     points[5].x = 650;
     points[5].y = 475;
-    points[5].e = 2;    /* close polygone with an invisible edge */
+    points[5].e = 2;    // close polygone with an invisible edge
 
-/* make the edges wider so it is easier to see if they are there */
+// make the edges wider so it is easier to see if they are there
     if ( cdSetEdgeWidth( myimage, 3 ) )
     {
         fprintf( stderr, "cdSetEdgeWidth Successful\n" );
@@ -372,7 +372,7 @@ int main()
     {
         fprintf( stderr, "cdSetEdgeWidth Unsuccessful\n" );
     }
-    if ( cdPolygonSet( myimage, points, 6 ) ) /* draw the polygonset */
+    if ( cdPolygonSet( myimage, points, 6 ) ) // draw the polygonset
     {
         fprintf( stderr, "cdPolygonSet Successful\n" );
     }
@@ -381,7 +381,7 @@ int main()
         fprintf( stderr, "cdPolygonSet Unsuccessful\n" );
     }
 
-/* now for poly lines, just like polygons (except they're lines) */
+// now for poly lines, just like polygons (except they're lines)
 
     if ( cdSetLineAttrib( myimage, 1, 1, red ) )
     {
@@ -424,8 +424,8 @@ int main()
     }
 
 
-/* Markers */
-/* set the attributes */
+// Markers
+// set the attributes
     if ( cdSetMarkerAttrib( myimage, 1, 1, green ) )
     {
         fprintf( stderr, "cdSetMarkerAttrib Successful\n" );
@@ -435,7 +435,7 @@ int main()
         fprintf( stderr, "cdSetMarkerAttrib Unsuccessful\n" );
     }
 
-/* now plot the marker */
+// now plot the marker
 
     if ( cdMarker( myimage, 900, 500 ) )
     {
@@ -449,7 +449,7 @@ int main()
 
     if ( cdSetMarkerAttrib( myimage, 5, 3, black ) )
     {
-/* set the marker type to cross */
+// set the marker type to cross
         fprintf( stderr, "cdSetMarkerAttrib Successful\n" );
     }
     else
@@ -457,7 +457,7 @@ int main()
         fprintf( stderr, "cdSetMarkerAttrib Unsuccessful\n" );
     }
 
-/* a Poly Marker,  two markers in different places */
+// a Poly Marker,  two markers in different places
     points[0].x = 715;
     points[0].y = 785;
     points[1].x = 735;
@@ -473,7 +473,7 @@ int main()
     }
 
 
-/* Hey, things are going so well, lets do some text */
+// Hey, things are going so well, lets do some text
     lavender = cdImageColorAllocate( myimage, 204, 102, 255 );
 
     if ( cdSetTextAttrib( myimage, 1, lavender, 50 ) )
@@ -494,7 +494,7 @@ int main()
         fprintf( stderr, "cdText Unsuccessful\n" );
     }
 
-/* More text.  This time test TextPath and TextOrient */
+// More text.  This time test TextPath and TextOrient
     if ( cdSetTextPath( myimage, 3 ) )
     {
         fprintf( stderr, "cdSetTextPath Successful\n" );
@@ -573,7 +573,8 @@ int main()
 
 
     outf = fopen( "cdout.cgm", "wb" );
-    if ( !outf ) return 1;
+    if ( !outf )
+        return 1;
     cdImageCgm( myimage, outf );
     fclose( outf );
     outf = 0;
