@@ -6,7 +6,7 @@
 # /tmp/plplot-dist-prep
 
 # Copyright (C) 2003, 2004  Rafael Laboissiere
-# Copyright (C) 2006 Alan W. Irwin
+# Copyright (C) 2006, 2013 Alan W. Irwin
 #
 # This file is part of PLplot.
 #
@@ -24,22 +24,16 @@
 # along with PLplot; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-# $Id: make_tarball.sh 11680 2011-03-27 17:57:51Z airwin $
+# $Id: make_tarball.sh 12554 2013-09-30 07:01:15Z airwin $
 
 usage () {
   local prog=`basename $0`
-  echo "Usage: $prog -t tagname [-n] [-w URL] \\"
+  echo "Usage: $prog [-n] \\"
   echo "          [-c [-i prefix] [-o cmake options]] \\"
   echo "       $prog -d"
   echo "       $prog -h"
   echo
-  echo "Option -t is mandatory and is used for specifying the subdirectory"
-  echo "  of the svn URL.  By default the svn URL points to the tags"
-  echo "  subdirectory so normally the -t option is a version tag"
-  echo "  (e.g., v5_7_4) used for the _already committed_ tags subdirectory"
-  echo "  of the release existing at the SourceForge svn repository."
   echo "Option -n prevents pre-building anything including the DocBook manual."
-  echo "Option -w sets the svn repository URL."
   echo "When option -c is given, the generated tarball is"
   echo "  unpacked, configured with cmake and built with make, and"
   echo "  the ctest (build-tree tests) is run afterward."
@@ -57,7 +51,6 @@ usage () {
 }
 
 DOC_ARG=${DOC_ARG:--DBUILD_DOC=ON}
-SVN_URL=${SVN_URL:-https://plplot.svn.sourceforge.net/svnroot/plplot/tags}
 # Just easier to always keep this temporary directory in the same location
 SVNTMPDIR=/tmp/plplot-dist-prep
 
@@ -83,7 +76,7 @@ PREBUILD_ARG="-DPREBUILD_DIST=ON"
 PREBUILT_DOC_ARG="-DPREBUILT_DOC=ON"
 do_prebuild_dist=yes
 
-while getopts "cdhi:no:t:u:w:" option
+while getopts "cdhi:no:u:" option
 do
   case $option in
     c) do_check=yes ;;
@@ -92,29 +85,36 @@ do
     i) test -n "$OPTARG" || usage 1 ; prefix=$OPTARG ;;
     n) DOC_ARG=;PREBUILD_ARG=;PREBUILT_DOC_ARG=;do_prebuild_dist=no ;;
     o) config_opt="$config_opt $OPTARG" ;;
-    t) test -n "$OPTARG" || usage 1 ; TAG=$OPTARG ;;
-    w) test -n "$OPTARG" || usage 1 ; SVN_URL=$OPTARG ;;
     *) usage 1 ;;
   esac
 done
 
-test -n "$TAG" || usage 1
-
 cleanup ( ) {
     rm -rf $SVNTMPDIR
 }
 
-#trap "cleanup" 0 HUP INT QUIT PIPE TERM
+# Find absolute PATH of script without using readlink (since readlink is
+# not available on all platforms).  Followed advice at
+# http://fritzthomas.com/open-source/linux/551-how-to-get-absolute-path-within-shell-script-part2/
+ORIGINAL_PATH="$(pwd)"
+cd "$(dirname $0)"
+# Absolute Path of the script
+SCRIPT_PATH="$(pwd)"
+cd "${ORIGINAL_PATH}"
+
+# Assumption: top-level source tree is parent directory of where script
+# is located.
+SOURCE_TREE="$(dirname ${SCRIPT_PATH})"
 
 cleanup
 mkdir $SVNTMPDIR
 cd $SVNTMPDIR
-svn export $SVN_URL/$TAG plplot \
+svn export $SOURCE_TREE plplot \
   && mkdir build_dir \
   && cd build_dir \
   && cmake -DCMAKE_VERBOSE_MAKEFILE=ON \
      ${PREBUILD_ARG} ${DOC_ARG} -DBUILD_DOX_DOC=ON \
-     -DWWW_USER:STRING=${WWW_USER} ../plplot >& cmake.out \
+     ../plplot >& cmake.out \
   && echo "Making distribution." \
   && (if [ "$do_prebuild_dist" = "yes" ] ; then
         make ${make_opt} prebuild_dist >& make_prebuild_dist.out
@@ -131,7 +131,7 @@ svn export $SVN_URL/$TAG plplot \
   && ( cd ctest_build_dir \
        && cmake ${config_opt} -DCMAKE_INSTALL_PREFIX:PATH=${prefix} \
           -DCMAKE_VERBOSE_MAKEFILE=ON ${PREBUILT_DOC_ARG} -DBUILD_DOX_DOC=ON \
-	  -DWWW_USER:STRING=${WWW_USER} -DBUILD_TEST=ON \
+	  -DBUILD_TEST=ON \
 	  ../plplot >& cmake.out \
        && make ${make_opt} >& make.out \
        && ctest >& ctest.out \
