@@ -1,10 +1,10 @@
 #!/bin/bash
 
-# $Id: style_source.sh 11795 2011-07-06 02:28:50Z airwin $
+# $Id: style_source.sh 12914 2013-12-29 20:11:07Z airwin $
 
 # This script will run uncrustify on all source files registered in
 # the lists below (and scripts/convert_comment.py on all C source
-# files registerd below) and summarize which uncrustified or
+# files registered below) and summarize which uncrustified or
 # comment-converted files would be different.  (convert_comment.py
 # converts /* ... */ style comments to the c99-acceptable // form of
 # comments because uncrustify does not (yet) have that configuration
@@ -37,7 +37,7 @@ Usage: ./style_source.sh [OPTIONS]
 
 Options:
    [--diff [diff options]]  Show detailed style differences in source code
-                            with optional concatanated diff options headed
+                            with optional concatenated diff options headed
                             by a single hyphen.  If no diff options are
                             specified, then -auw is used by default.
    [--nodiff]               Summarize style differences in source code (default).
@@ -49,158 +49,6 @@ Options:
    exit $1
 }
 
-# Figure out what script options were specified by the user.
-# Defaults
-export diff=OFF
-export apply=OFF
-export diff_options="-auw"
-
-while test $# -gt 0; do
-
-    case $1 in
-	--diff)
-	    diff=ON
-	    case $2 in
-		-[^-]*)
-		    diff_options=$2
-		    shift
-		    ;;
-	    esac
-	    ;;
-	--nodiff)
-	    diff=OFF
-	    ;;
-	--apply)
-	    apply=ON
-	    ;;
-	--noapply)
-	    apply=OFF
-	    ;;
-	--help)
-            usage 0 1>&2
-            ;;
-	*)
-            usage 1 1>&2
-            ;;
-    esac
-    shift
-done
-
-allowed_version=0.58
-version=$(uncrustify --version)
-if [ "$version" != "uncrustify $allowed_version" ] ; then
-    echo "
-Detected uncrustify version = '$version'.
-This script only works with uncrustify $allowed_version."
-    exit 1
-fi
-
-if [ ! -f src/plcore.c ] ; then 
-    echo "This script can only be run from PLplot top-level source tree."
-    exit 1
-fi
-
-if [ "$apply" = "ON" ] ; then
-    echo '
-The --apply option is POWERFUL and will replace _all_ files mentioned in
-previous runs of style_source.sh with their uncrustified versions.
-'
-    ANSWER=
-    while [ "$ANSWER" != "yes" -a "$ANSWER" != "no" ] ; do
-	echo -n "Continue (yes/no)? "
-	read ANSWER
-    done
-    if [ "$ANSWER" = "no" ] ; then
-	echo "Immediate exit specified!"
-	exit
-    fi
-fi
-
-export csource_LIST
-# Top level directory.
-csource_LIST="config.h.cmake"
-
-# src directory
-csource_LIST="$csource_LIST src/*.[ch]"
-
-# All C source (i.e., exclude qt.h) in include directory.
-csource_LIST="$csource_LIST $(ls include/*.h include/*.h.in include/*.h.cmake |grep -v qt.h)" 
-
-# Every subdirectory of lib.
-csource_LIST="$csource_LIST lib/*/*.[ch] lib/qsastime/qsastimeP.h.in"
-
-# C part of drivers.
-csource_LIST="$csource_LIST drivers/*.c"
-
-# C part of examples.
-csource_LIST="$csource_LIST examples/c/*.[ch] examples/tk/*.c"
-
-# C source in fonts.
-csource_LIST="$csource_LIST fonts/*.c"
-
-# C source in utils.
-csource_LIST="$csource_LIST utils/*.c"
-
-csource_LIST="$csource_LIST bindings/tcl/*.[ch] bindings/f95/*.c bindings/f95/plstubs.h bindings/gnome2/*/*.c bindings/ocaml/plplot_impl.c bindings/ocaml/plcairo/plcairo_impl.c bindings/python/plplot_widgetmodule.c bindings/f77/*.c bindings/f77/plstubs.h bindings/tk/*.[ch] bindings/tk-x-plat/*.[ch] bindings/octave/plplot_octave.h.in bindings/octave/plplot_octave_rej.h bindings/octave/massage.c"
-
-export cppsource_LIST
-
-# C++ part of bindings/c++
-cppsource_LIST="bindings/c++/plstream.cc  bindings/c++/plstream.h"
-
-# C++ part of include. 
-cppsource_LIST="$cppsource_LIST include/qt.h"
-
-# C++ part of drivers.
-cppsource_LIST="$cppsource_LIST drivers/wxwidgets.h drivers/*.cpp drivers/*.cc" 
-
-# C++ part of examples.
-cppsource_LIST="$cppsource_LIST examples/c++/*.cc examples/c++/*.cpp examples/c++/*.h"
-
-# C++ source in bindings.
-cppsource_LIST="$cppsource_LIST bindings/qt_gui/plqt.cpp bindings/wxwidgets/wxPLplotstream.cpp bindings/wxwidgets/wxPLplotwindow.cpp bindings/wxwidgets/wxPLplotwindow.h bindings/wxwidgets/wxPLplotstream.h.in"
-
-export javasource_LIST
-
-# Java part of bindings/java
-javasource_LIST="bindings/java/*.java bindings/java/*.java.in"
-
-# Java part of examples/java
-javasource_LIST="$javasource_LIST examples/java/*.java"
-
-export dsource_LIST
-
-# D part of bindings/d
-dsource_LIST="bindings/d/*.d"
-
-# D part of examples/d
-dsource_LIST="$dsource_LIST examples/d/*.d"
-
-export swig_csource_LIST
-
-# API description for Swig being sure to ignore the generated file,
-# bindings/swig-support/swig_documentation.i
-swig_csource_LIST=bindings/swig-support/plplotcapi.i
-
-# Use specific names here for each C-like file controlling specific
-# language bindings since some files (e.g., bindings/python/fragments.i)
-# are copied from swig itself so don't mess with them.  Also, ignore octave
-# since that C++-like file goes under swig_cppsource_LIST.
-swig_csource_LIST="$swig_csource_LIST bindings/java/plplotjavac.i"
-swig_csource_LIST="$swig_csource_LIST bindings/lua/plplotluac.i"
-swig_csource_LIST="$swig_csource_LIST bindings/python/plplotcmodule.i"
-
-export swig_cppsource_LIST
-swig_cppsource_LIST=bindings/octave/plplot_octave.i
-
-# Check that source file lists actually refer to files.
-for source in $csource_LIST $cppsource_LIST $javasource_LIST $dsource_LIST $swig_csource_LIST $swig_cppsource_LIST; do
-    if [ ! -f $source ] ; then
-	echo $source is not a regular file so this script will not work without further editing.
-	exit 1
-    fi
-done
-
 transform_source()
 {
     # $1 is a list of source files of a particular language.
@@ -262,7 +110,24 @@ transform_source()
     # quotes) after the $c_command to correct introduced swig styling
     # errors (if in fact you are styling swig source).
 
+    # N.B. for the --apply option, transform_source is called twice;
+    # once with apply=OFF and once with it on.  For the first call
+    # with apply=OFF the logic below lists all files (and diffs all
+    # files if that option is used) that will be changed.  For the
+    # second call with apply=ON, the logic below changes the source
+    # files and then lists (and diffs if that option is set) any
+    # remaining changes that still have to be done. (On rare
+    # occasions, uncrustify has to be applied iteratively.)
+
     for language_source in $1 ; do
+	if [ "$apply" = "ON" ] ; then
+	    $u_command < $language_source | $c_command | eval $s_command | \
+		cmp --quiet $language_source -
+	    if [ "$?" -ne 0 ] ; then
+		$u_command < $language_source | $c_command | eval $s_command >| /tmp/temporary.file
+		mv -f /tmp/temporary.file $language_source
+	    fi
+	fi
 	$u_command < $language_source | $c_command | eval $s_command | \
 	    cmp --quiet $language_source -
 	if [ "$?" -ne 0 ] ; then
@@ -271,15 +136,171 @@ transform_source()
 		$u_command < $language_source | $c_command | eval $s_command | \
 		diff $diff_options $language_source -
 	    fi
-
-	    if [ "$apply" = "ON" ] ; then
-		$u_command < $language_source | $c_command | eval $s_command >| /tmp/temporary.file
-		mv -f /tmp/temporary.file $language_source
-	    fi
 	fi
     done
 }
 
+# Figure out what script options were specified by the user.
+# Defaults
+export diff=OFF
+export apply=OFF
+export diff_options="-auw"
+
+while test $# -gt 0; do
+
+    case $1 in
+	--diff)
+	    diff=ON
+	    case $2 in
+		-[^-]*)
+		    diff_options=$2
+		    shift
+		    ;;
+	    esac
+	    ;;
+	--nodiff)
+	    diff=OFF
+	    ;;
+	--apply)
+	    apply=ON
+	    ;;
+	--noapply)
+	    apply=OFF
+	    ;;
+	--help)
+            usage 0 1>&2
+            ;;
+	*)
+            usage 1 1>&2
+            ;;
+    esac
+    shift
+done
+
+allowed_version=0.58
+version=$(uncrustify --version)
+if [ "$version" != "uncrustify $allowed_version" ] ; then
+    echo "
+Detected uncrustify version = '$version'.
+This script only works with uncrustify $allowed_version."
+    exit 1
+fi
+
+if [ ! -f src/plcore.c ] ; then 
+    echo "This script can only be run from PLplot top-level source tree."
+    exit 1
+fi
+
+export csource_LIST
+# Top level directory.
+csource_LIST="plplot_config.h.in"
+
+# src directory
+csource_LIST="$csource_LIST src/*.[ch]"
+
+# All C source (i.e., exclude qt.h) in include directory.
+csource_LIST="$csource_LIST $(ls include/*.h include/*.h.in |grep -v qt.h)" 
+
+# Every subdirectory of lib.
+csource_LIST="$csource_LIST lib/*/*.[ch] lib/qsastime/qsastimeP.h.in"
+
+# C part of drivers.
+csource_LIST="$csource_LIST drivers/*.c"
+
+# C part of examples.
+csource_LIST="$csource_LIST examples/c/*.[ch] examples/tk/*.c"
+
+# C source in fonts.
+csource_LIST="$csource_LIST fonts/*.c"
+
+# C source in utils.
+csource_LIST="$csource_LIST utils/*.c"
+
+csource_LIST="$csource_LIST bindings/tcl/*.[ch] bindings/f95/*.c bindings/f95/plstubs.h bindings/gnome2/*/*.c bindings/ocaml/plplot_impl.c bindings/ocaml/plcairo/plcairo_impl.c bindings/python/plplot_widgetmodule.c bindings/tk/*.[ch] bindings/tk-x-plat/*.[ch] bindings/octave/plplot_octave.h.in bindings/octave/plplot_octave_rej.h bindings/octave/massage.c"
+
+export cppsource_LIST
+
+# C++ part of bindings/c++
+cppsource_LIST="bindings/c++/plstream.cc  bindings/c++/plstream.h"
+
+# C++ part of include. 
+cppsource_LIST="$cppsource_LIST include/qt.h"
+
+# C++ part of drivers.
+cppsource_LIST="$cppsource_LIST drivers/wxwidgets.h drivers/*.cpp drivers/*.cc" 
+
+# C++ part of examples.
+cppsource_LIST="$cppsource_LIST examples/c++/*.cc examples/c++/*.cpp examples/c++/*.h"
+
+# C++ source in bindings.
+cppsource_LIST="$cppsource_LIST bindings/qt_gui/plqt.cpp bindings/wxwidgets/wxPLplotstream.cpp bindings/wxwidgets/wxPLplotwindow.cpp bindings/wxwidgets/wxPLplotwindow.h bindings/wxwidgets/wxPLplotstream.h.in"
+
+export javasource_LIST
+
+# Java part of bindings/java
+javasource_LIST="bindings/java/*.java bindings/java/*.java.in"
+
+# Java part of examples/java
+javasource_LIST="$javasource_LIST examples/java/*.java"
+
+export dsource_LIST
+
+# D part of bindings/d
+dsource_LIST="bindings/d/*.d"
+
+# D part of examples/d
+dsource_LIST="$dsource_LIST examples/d/*.d"
+
+export swig_csource_LIST
+
+# API description for Swig being sure to ignore the generated file,
+# bindings/swig-support/swig_documentation.i
+swig_csource_LIST=bindings/swig-support/plplotcapi.i
+
+# Use specific names here for each C-like file controlling specific
+# language bindings since some files (e.g., bindings/python/fragments.i)
+# are copied from swig itself so don't mess with them.  Also, ignore octave
+# since that C++-like file goes under swig_cppsource_LIST.
+swig_csource_LIST="$swig_csource_LIST bindings/java/plplotjavac.i"
+swig_csource_LIST="$swig_csource_LIST bindings/lua/plplotluac.i"
+swig_csource_LIST="$swig_csource_LIST bindings/python/plplotcmodule.i"
+
+export swig_cppsource_LIST
+swig_cppsource_LIST=bindings/octave/plplot_octave.i
+
+# Check that source file lists actually refer to files.
+for source in $csource_LIST $cppsource_LIST $javasource_LIST $dsource_LIST $swig_csource_LIST $swig_cppsource_LIST; do
+    if [ ! -f $source ] ; then
+	echo $source is not a regular file so this script will not work without further editing.
+	exit 1
+    fi
+done
+
+if [ "$apply" = "ON" ] ; then
+    apply=OFF
+    # Should be the exact same transform_source commands as below.
+    transform_source "$csource_LIST" C "comments"
+    transform_source "$cppsource_LIST" CPP "comments"
+    transform_source "$javasource_LIST" JAVA "comments"
+    transform_source "$dsource_LIST" D "comments"
+    transform_source "$swig_csource_LIST" C "comments" "swig"
+    transform_source "$swig_cppsource_LIST" CPP "comments" "swig"
+    apply=ON
+    echo '
+The --apply option is POWERFUL and will replace _all_ files mentioned above
+(if any) with their styled versions.
+'
+    ANSWER=
+    while [ "$ANSWER" != "yes" -a "$ANSWER" != "no" ] ; do
+	echo -n "Continue (yes/no)? "
+	read ANSWER
+    done
+    if [ "$ANSWER" = "no" ] ; then
+	echo "Immediate exit specified!"
+	exit
+    fi
+fi
+
 transform_source "$csource_LIST" C "comments"
 transform_source "$cppsource_LIST" CPP "comments"
 transform_source "$javasource_LIST" JAVA "comments"
