@@ -1,4 +1,4 @@
-// $Id: pdfutils.c 11680 2011-03-27 17:57:51Z airwin $
+// xId: pdfutils.c 11966 2011-10-14 07:10:05Z andrewross $
 //
 //  pdf_utils.c
 //
@@ -28,14 +28,16 @@
 //
 //--------------------------------------------------------------------------
 //
-//  These functions do the low-level reading/writing of portable data files.
-//  Data can be written to/read from either a file handle or memory buffer.
-//
+
+//! @file
+//!  These functions do the low-level reading/writing of portable data files.
+//!  Data can be written to/read from either a file handle or memory buffer.
+//!
 
 #define NEED_PLDEBUG
 #include "plplotP.h"
 
-static void print_ieeef( void *, void * );
+static void print_ieeef( float *, U_LONG * );
 static int  pdf_wrx( const U_CHAR *x, long nitems, PDFstrm *pdfs );
 
 static int debug = 0;
@@ -43,7 +45,11 @@ static int debug = 0;
 //--------------------------------------------------------------------------
 // void pdf_set (string, value)
 //
-// Set an option.  Pretty sparse right now but you never know.
+//! Set an option.  Pretty sparse right now but you never know.
+//!
+//! @param option The option string.
+//! @param value The value to set it to.
+//!
 //--------------------------------------------------------------------------
 
 void
@@ -56,8 +62,12 @@ pdf_set( char *option, int value )
 //--------------------------------------------------------------------------
 // pdf_fopen()
 //
-// Initializes a PDFstrm for a file oriented device.
-// Used exactly like fopen().
+//! Initializes a PDFstrm for a file oriented device.
+//! Used exactly like fopen().
+//!
+//! @param filename The filename of the file to open.
+//! @param mode File access mode, as would be used by fopen.
+//!
 //--------------------------------------------------------------------------
 
 PDFstrm *
@@ -128,12 +138,18 @@ pdf_fopen( const char *filename, const char *mode )
 //--------------------------------------------------------------------------
 // pdf_bopen()
 //
-// Initializes a PDFstrm for reading/writing to a memory buffer.
-// If buffer is NULL, a standard buffer is allocated.
+//! Initializes a PDFstrm for reading/writing to a memory buffer.
+//! If buffer is NULL, a standard buffer is allocated.
+//!
+//! @param buffer User allocated memory, can be NULL.
+//! @param bufmax Size of buffer, or the desired buffer.
+//!
+//! @returns A PDFstrm structure.
+//!
 //--------------------------------------------------------------------------
 
 PDFstrm *
-pdf_bopen( U_CHAR *buffer, long bufmax )
+pdf_bopen( U_CHAR *buffer, size_t bufmax )
 {
     PDFstrm *pdfs;
 
@@ -176,8 +192,12 @@ pdf_bopen( U_CHAR *buffer, long bufmax )
 //--------------------------------------------------------------------------
 // pdf_finit()
 //
-// Initializes a PDFstrm for a file oriented device.
-// Like pdf_fopen() but an existing file handle is specified.
+//! Initializes a PDFstrm for a file oriented device.
+//! Like pdf_fopen() but an existing file handle is specified.
+//!
+//! @param file A open file handle.
+//!
+//! @returns A PDFstrm structure.
 //--------------------------------------------------------------------------
 
 PDFstrm *
@@ -205,8 +225,13 @@ pdf_finit( FILE *file )
 //--------------------------------------------------------------------------
 // pdf_close()
 //
-// Closes a PDFstrm.
-// Used exactly like fclose().
+//! Closes a PDFstrm.
+//! Used exactly like fclose().
+//!
+//! @param pdfs The file stream to close.
+//!
+//! @returns 0
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -238,7 +263,13 @@ pdf_close( PDFstrm *pdfs )
 //--------------------------------------------------------------------------
 // int pdf_putc()
 //
-// Writes a single character.
+//! Writes a single character.
+//!
+//! @param c The character to write.
+//! @param pdfs The stream to write it to.
+//!
+//! @returns The character written or EOF.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -270,7 +301,7 @@ pdf_putc( int c, PDFstrm *pdfs )
                 plexit( "pdf_putc: Insufficient memory" );
             }
         }
-        pdfs->buffer[pdfs->bp++] = c;
+        pdfs->buffer[pdfs->bp++] = (unsigned char) c;
         result = c;
     }
     else
@@ -282,7 +313,12 @@ pdf_putc( int c, PDFstrm *pdfs )
 //--------------------------------------------------------------------------
 // int pdf_getc()
 //
-// Reads a single character.
+//! Reads a single character.
+//!
+//! @param pdfs The stream to read the character from.
+//!
+//! @return The character read or EOF.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -316,7 +352,13 @@ pdf_getc( PDFstrm *pdfs )
 //--------------------------------------------------------------------------
 // int pdf_ungetc()
 //
-// Push back the last command read.
+//! Push back the last command read.
+//!
+//! @param c The character to pushback.
+//! @param pdfs The stream to push it back into.
+//!
+//! @returns The character pushed back, or EOF.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -342,7 +384,7 @@ pdf_ungetc( int c, PDFstrm *pdfs )
     {
         if ( pdfs->bp > 0 )
         {
-            pdfs->buffer[--pdfs->bp] = c;
+            pdfs->buffer[--pdfs->bp] = (unsigned char) c;
             result = c;
         }
     }
@@ -355,7 +397,14 @@ pdf_ungetc( int c, PDFstrm *pdfs )
 //--------------------------------------------------------------------------
 // int pdf_wrx()
 //
-// Writes a record.
+//! Writes a record.
+//!
+//! @param x The data to write.
+//! @param nitems The length of x.
+//! @param pdfs The stream to write it to.
+//!
+//! @returns The number of bytes actually written.
+//!
 //--------------------------------------------------------------------------
 
 static int
@@ -365,8 +414,8 @@ pdf_wrx( const U_CHAR *x, long nitems, PDFstrm *pdfs )
 
     if ( pdfs->file != NULL )
     {
-        result    = fwrite( x, 1, nitems, pdfs->file );
-        pdfs->bp += nitems;
+        result    = (int) fwrite( x, 1, (size_t) nitems, pdfs->file );
+        pdfs->bp += (size_t) nitems;
 #ifdef PLPLOT_USE_TCL_CHANNELS
     }
     else if ( pdfs->tclChan != NULL )
@@ -401,7 +450,14 @@ pdf_wrx( const U_CHAR *x, long nitems, PDFstrm *pdfs )
 //--------------------------------------------------------------------------
 // int pdf_rdx()
 //
-// Reads a record.
+//! Reads a record.
+//!
+//! @param x Storage for the data to read.
+//! @param nitems The length of the x.
+//! @param pdfs The stream to read it from.
+//!
+//! @returns The number of bytes read.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -411,8 +467,8 @@ pdf_rdx( U_CHAR *x, long nitems, PDFstrm *pdfs )
 
     if ( pdfs->file != NULL )
     {
-        result    = fread( x, 1, nitems, pdfs->file );
-        pdfs->bp += nitems;
+        result    = (int) fread( x, 1, (size_t) nitems, pdfs->file );
+        pdfs->bp += (size_t) nitems;
 #ifdef PLPLOT_USE_TCL_CHANNELS
     }
     else if ( pdfs->tclChan != NULL )
@@ -438,13 +494,19 @@ pdf_rdx( U_CHAR *x, long nitems, PDFstrm *pdfs )
 //--------------------------------------------------------------------------
 // pdf_wr_header()
 //
-// Writes a header string.  Input string must be NULL-terminated.  The
-// written string is terminated by a new-line, not a NULL.  This is done
-// so you can type e.g. "% strings <file> | head" and get sensible output.
+//! Writes a header string.  Input string must be NULL-terminated.  The
+//! written string is terminated by a new-line, not a NULL.  This is done
+//! so you can type e.g. "% strings <file> | head" and get sensible output.
+//!
+//! @param pdfs The stream to which to write the header.
+//! @param header The header.
+//!
+//! @returns 0 if there was no error.
+//!
 //--------------------------------------------------------------------------
 
 int
-pdf_wr_header( PDFstrm *pdfs, char *header )
+pdf_wr_header( PDFstrm *pdfs, const char *header )
 {
     int i;
 
@@ -466,8 +528,14 @@ pdf_wr_header( PDFstrm *pdfs, char *header )
 //--------------------------------------------------------------------------
 // int pdf_rd_header
 //
-// Reads a newline-terminated header string from PDFstrm *pdfs, and
-// converts to a usual NULL-terminated string.  80 chars maximum assumed.
+//! Reads a newline-terminated header string from PDFstrm *pdfs, and
+//! converts to a usual NULL-terminated string.  80 chars maximum assumed.
+//!
+//! @param pdfs The stream to read the header from.
+//! @param header Pre-allocated storage for the header.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -482,7 +550,7 @@ pdf_rd_header( PDFstrm *pdfs, char *header )
         if ( ( c = pdf_getc( pdfs ) ) == EOF )
             return PDF_RDERR;
 
-        header[i] = c;
+        header[i] = (char) c;
         if ( header[i] == '\n' )
             break;
     }
@@ -493,7 +561,13 @@ pdf_rd_header( PDFstrm *pdfs, char *header )
 //--------------------------------------------------------------------------
 // pdf_wr_string()
 //
-// Writes a null-terminated string.
+//! Writes a null-terminated string.
+//!
+//! @param pdfs The stream to write the string to.
+//! @param string The string to write.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -515,8 +589,15 @@ pdf_wr_string( PDFstrm *pdfs, const char *string )
 //--------------------------------------------------------------------------
 // int pdf_rd_string
 //
-// Reads a null-terminated string from PDFstrm *pdfs.
-// A max of nmax chars are read.
+//! Reads a null-terminated string from PDFstrm *pdfs.
+//! A max of nmax chars are read.
+//!
+//! @param pdfs The stream to read the string from.
+//! @param string Pre-allocated storage for the string.
+//! @param nmax The size of string.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -531,7 +612,7 @@ pdf_rd_string( PDFstrm *pdfs, char *string, int nmax )
         if ( ( c = pdf_getc( pdfs ) ) == EOF )
             return PDF_RDERR;
 
-        string[i] = c;
+        string[i] = (char) c;
         if ( c == '\0' )
             break;
     }
@@ -542,7 +623,13 @@ pdf_rd_string( PDFstrm *pdfs, char *string, int nmax )
 //--------------------------------------------------------------------------
 // int pdf_wr_1byte()
 //
-// Writes a U_CHAR as a single byte.
+//! Writes a U_CHAR as a single byte.
+//!
+//! @param pdfs The stream to write the byte too.
+//! @param s The byte to write.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -560,7 +647,13 @@ pdf_wr_1byte( PDFstrm *pdfs, U_CHAR s )
 //--------------------------------------------------------------------------
 // int pdf_rd_1byte()
 //
-// Reads a single byte, storing into a U_CHAR.
+//! Reads a single byte, storing into a U_CHAR.
+//!
+//! @param pdfs The stream to read the byte from.
+//! @param ps Storage for the byte.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -578,7 +671,13 @@ pdf_rd_1byte( PDFstrm *pdfs, U_CHAR *ps )
 //--------------------------------------------------------------------------
 // pdf_wr_2bytes()
 //
-// Writes a U_SHORT as two single bytes, low end first.
+//! Writes a U_SHORT as two single bytes, low end first.
+//!
+//! @param pdfs The stream to write the two bytes to.
+//! @param s The two bytes to write.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -598,20 +697,29 @@ pdf_wr_2bytes( PDFstrm *pdfs, U_SHORT s )
 //--------------------------------------------------------------------------
 // pdf_rd_2bytes()
 //
-// Reads a U_SHORT from two single bytes, low end first.
+//! Reads a U_SHORT from two single bytes, low end first.
+//!
+//! @param pdfs The stream to read the two bytes from.
+//! @param ps Pre-allocated storage for the two bytes.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
 pdf_rd_2bytes( PDFstrm *pdfs, U_SHORT *ps )
 {
-    U_CHAR x[2];
+    U_CHAR  x[2];
+    U_SHORT xs;
 
     if ( !pdf_rdx( x, 2, pdfs ) )
         return PDF_RDERR;
 
     *ps  = 0;
-    *ps |= (U_LONG) x[0];
-    *ps |= (U_LONG) x[1] << 8;
+    xs   = (U_SHORT) x[0];
+    *ps |= xs;
+    xs   = (U_SHORT) ( (U_SHORT) x[1] << 8 );
+    *ps |= xs;
 
     return 0;
 }
@@ -619,7 +727,14 @@ pdf_rd_2bytes( PDFstrm *pdfs, U_SHORT *ps )
 //--------------------------------------------------------------------------
 // pdf_wr_2nbytes()
 //
-// Writes n U_SHORT's as 2n single bytes, low end first.
+//! Writes n U_SHORT's as 2n single bytes, low end first.
+//!
+//! @param pdfs The stream to write the shorts to.
+//! @param s An array of shorts.
+//! @param n Size of s.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -642,14 +757,22 @@ pdf_wr_2nbytes( PDFstrm *pdfs, U_SHORT *s, PLINT n )
 //--------------------------------------------------------------------------
 // pdf_rd_2nbytes()
 //
-// Reads n U_SHORT's from 2n single bytes, low end first.
+//! Reads n U_SHORT's from 2n single bytes, low end first.
+//!
+//! @param pdfs The stream to read the shorts from.
+//! @param s Pre-allocated storage for the shorts.
+//! @param n Size of s.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
 pdf_rd_2nbytes( PDFstrm *pdfs, U_SHORT *s, PLINT n )
 {
-    PLINT  i;
-    U_CHAR x[2];
+    PLINT   i;
+    U_CHAR  x[2];
+    U_SHORT xs;
 
     for ( i = 0; i < n; i++ )
     {
@@ -657,8 +780,10 @@ pdf_rd_2nbytes( PDFstrm *pdfs, U_SHORT *s, PLINT n )
             return PDF_RDERR;
 
         s[i]  = 0;
-        s[i] |= (U_SHORT) x[0];
-        s[i] |= (U_SHORT) x[1] << 8;
+        xs    = (U_SHORT) x[0];
+        s[i] |= xs;
+        xs    = (U_SHORT) ( (U_SHORT) x[1] << 8 );
+        s[i] |= xs;
     }
     return 0;
 }
@@ -666,7 +791,13 @@ pdf_rd_2nbytes( PDFstrm *pdfs, U_SHORT *s, PLINT n )
 //--------------------------------------------------------------------------
 // pdf_wr_4bytes()
 //
-// Writes an unsigned long as four single bytes, low end first.
+//! Writes an unsigned long as four single bytes, low end first.
+//!
+//! @param pdfs The stream to write the unsigned long to.
+//! @param s The unsigned long to write.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -688,7 +819,13 @@ pdf_wr_4bytes( PDFstrm *pdfs, U_LONG s )
 //--------------------------------------------------------------------------
 // pdf_rd_4bytes()
 //
-// Reads an unsigned long from 4 single bytes, low end first.
+//! Reads an unsigned long from 4 single bytes, low end first.
+//!
+//! @param pdfs The stream to read the unsigned long from.
+//! @param ps Pre-allocated storage for the unsigned long.
+//!
+//! @returns 0 is successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -766,16 +903,23 @@ pdf_rd_4bytes( PDFstrm *pdfs, U_LONG *ps )
 //--------------------------------------------------------------------------
 // int pdf_wr_ieeef()
 //
-// Writes a float in IEEE single precision (32 bit) format.
+//! Writes a float in IEEE single precision (32 bit) format.
+//!
+//! @param pdfs The stream to write the float to.
+//! @param f The float.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
 pdf_wr_ieeef( PDFstrm *pdfs, float f )
 {
-    double fdbl, fmant, f_new;
-    float  fsgl, f_tmp;
-    int    istat, exp, e_new, e_off, bias = 127;
-    U_LONG value, s_ieee, e_ieee, f_ieee;
+    double    fdbl, fmant, f_new;
+    float     fsgl, f_tmp;
+    int       istat, ex, e_new, e_off;
+    const int bias = 127;
+    U_LONG    value, s_ieee, e_ieee, f_ieee;
 
     if ( f == 0.0 )
     {
@@ -784,7 +928,7 @@ pdf_wr_ieeef( PDFstrm *pdfs, float f )
     }
     fdbl  = f;
     fsgl  = (float) fdbl;
-    fmant = frexp( fdbl, &exp );
+    fmant = frexp( fdbl, &ex );
 
     if ( fmant < 0 )
         s_ieee = 1;
@@ -793,7 +937,7 @@ pdf_wr_ieeef( PDFstrm *pdfs, float f )
 
     fmant = fabs( fmant );
     f_new = 2 * fmant;
-    e_new = exp - 1;
+    e_new = ex - 1;
 
     if ( e_new < 1 - bias )
     {
@@ -803,7 +947,7 @@ pdf_wr_ieeef( PDFstrm *pdfs, float f )
     }
     else
     {
-        e_ieee = e_new + bias;
+        e_ieee = (U_LONG) ( e_new + bias );
         f_tmp  = (float) ( f_new - 1 );
     }
     f_ieee = (U_LONG) ( f_tmp * 8388608 );         // multiply by 2^23
@@ -835,7 +979,13 @@ pdf_wr_ieeef( PDFstrm *pdfs, float f )
 //--------------------------------------------------------------------------
 // int pdf_rd_ieeef()
 //
-// Reads a float from a IEEE single precision (32 bit) format.
+//! Reads a float from a IEEE single precision (32 bit) format.
+//!
+//! @param pdfs The stream to read the float from.
+//! @param pf Pre-allocated storage for the float.
+//!
+//! @returns 0 if successful.
+//!
 //--------------------------------------------------------------------------
 
 int
@@ -843,7 +993,7 @@ pdf_rd_ieeef( PDFstrm *pdfs, float *pf )
 {
     double f_new, f_tmp;
     float  fsgl;
-    int    istat, exp, bias = 127;
+    int    istat, ex, bias = 127;
     U_LONG value, s_ieee, e_ieee, f_ieee;
 
     if ( ( istat = pdf_rd_4bytes( pdfs, &value ) ) )
@@ -857,16 +1007,16 @@ pdf_rd_ieeef( PDFstrm *pdfs, float *pf )
 
     if ( e_ieee == 0 )
     {
-        exp   = 1 - bias;
+        ex    = 1 - bias;
         f_new = f_tmp;
     }
     else
     {
-        exp   = (int) e_ieee - bias;
+        ex    = (int) e_ieee - bias;
         f_new = 1.0 + f_tmp;
     }
 
-    fsgl = (float) ( f_new * pow( 2.0, (double) exp ) );
+    fsgl = (float) ( f_new * pow( 2.0, (double) ex ) );
     if ( s_ieee == 1 )
         fsgl = -fsgl;
 
@@ -884,17 +1034,21 @@ pdf_rd_ieeef( PDFstrm *pdfs, float *pf )
 //--------------------------------------------------------------------------
 // print_ieeef()
 //
-// Prints binary representation for numbers pointed to by arguments.
-// The first argument is the original float, the second is the
-// IEEE representation.  They should be the same on any machine that
-// uses IEEE floats.
+//! Prints binary representation for numbers pointed to by arguments.
+//! The first argument is the original float, the second is the
+//! IEEE representation.  They should be the same on any machine that
+//! uses IEEE floats.
+//!
+//! @param vx The original float?
+//! @param vy The IEEE representation?
+//!
 //--------------------------------------------------------------------------
 
 static void
-print_ieeef( void *vx, void *vy )
+print_ieeef( float *vx, U_LONG *vy )
 {
     int    i;
-    U_LONG f, *x = (U_LONG *) vx, *y = (U_LONG *) vy;
+    U_LONG f, *x = (U_LONG *) vx, *y = vy;
     char   bitrep[33];
 
     bitrep[32] = '\0';
@@ -929,16 +1083,21 @@ print_ieeef( void *vx, void *vy )
 //--------------------------------------------------------------------------
 // plAlloc2dGrid()
 //
-// Allocates a block of memory for use as a 2-d grid of PLFLT's.
-// Resulting array can be indexed as f[i][j] anywhere.  This is to be used
-// instead of PLFLT f[nx][ny], which is less useful.  Note that this type
-// of allocation is required by the PLplot functions which take a 2-d
-// grids of PLFLT's as an argument, such as plcont() and plot3d().
-// Example usage:
-//
-//   PLFLT **z;
-//
-//   Alloc2dGrid(&z, XPTS, YPTS);
+//! Allocates a block of memory for use as a 2-d grid of PLFLT's.
+//! Resulting array can be indexed as f[i][j] anywhere.  This is to be used
+//! instead of PLFLT f[nx][ny], which is less useful.  Note that this type
+//! of allocation is required by the PLplot functions which take a 2-d
+//! grids of PLFLT's as an argument, such as plcont() and plot3d().
+//! Example usage:
+//!
+//!   PLFLT **z;
+//!
+//!   Alloc2dGrid(&z, XPTS, YPTS);
+//!
+//! @param f Location of the storage (address of a **).
+//! @param nx Size of the grid in x.
+//! @param ny Size of the grid in y.
+//!
 //--------------------------------------------------------------------------
 
 void
@@ -946,12 +1105,12 @@ plAlloc2dGrid( PLFLT ***f, PLINT nx, PLINT ny )
 {
     PLINT i;
 
-    if ( ( *f = (PLFLT **) calloc( nx, sizeof ( PLFLT * ) ) ) == NULL )
+    if ( ( *f = (PLFLT **) calloc( (size_t) nx, sizeof ( PLFLT * ) ) ) == NULL )
         plexit( "Memory allocation error in \"plAlloc2dGrid\"" );
 
     for ( i = 0; i < nx; i++ )
     {
-        if ( ( ( *f )[i] = (PLFLT *) calloc( ny, sizeof ( PLFLT ) ) ) == NULL )
+        if ( ( ( *f )[i] = (PLFLT *) calloc( (size_t) ny, sizeof ( PLFLT ) ) ) == NULL )
             plexit( "Memory allocation error in \"plAlloc2dGrid\"" );
     }
 }
@@ -959,11 +1118,15 @@ plAlloc2dGrid( PLFLT ***f, PLINT nx, PLINT ny )
 //--------------------------------------------------------------------------
 // Free2dGrid()
 //
-// Frees a block of memory allocated with Alloc2dGrid().
+//! Frees a block of memory allocated with Alloc2dGrid().
+//!
+//! @param f The [][] to the storage.
+//! @param nx Size of the grid in x.
+//! @param PL_UNUSED( ny) Not used.
 //--------------------------------------------------------------------------
 
 void
-plFree2dGrid( PLFLT **f, PLINT nx, PLINT ny )
+plFree2dGrid( PLFLT **f, PLINT nx, PLINT PL_UNUSED( ny ) )
 {
     PLINT i;
 
@@ -976,17 +1139,24 @@ plFree2dGrid( PLFLT **f, PLINT nx, PLINT ny )
 //--------------------------------------------------------------------------
 // MinMax2dGrid()
 //
-// Finds the maximum and minimum of a 2d matrix allocated with plAllc2dGrid().
-// NaN and +/- infinity values are ignored.
+//! Finds the maximum and minimum of a 2d matrix allocated with plAllc2dGrid().
+//! NaN and +/- infinity values are ignored.
+//!
+//! param f 2d matrix pointer.
+//! param nx Size of the grid in x.
+//! param ny Size of the grid in y.
+//! param fnmax Maximum value in the matrix.
+//! param fnmin Minimum value in the matrix.
+//!
 //--------------------------------------------------------------------------
 
 void
-plMinMax2dGrid( const PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmax, PLFLT *fmin )
+plMinMax2dGrid( const PLFLT * const*f, PLINT nx, PLINT ny, PLFLT *fnmax, PLFLT *fnmin )
 {
     int   i, j;
     PLFLT m, M;
 
-    if ( !finite( f[0][0] ) )
+    if ( !isfinite( f[0][0] ) )
     {
         M = -HUGE_VAL;
         m = HUGE_VAL;
@@ -998,7 +1168,7 @@ plMinMax2dGrid( const PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmax, PLFLT *fmin )
     {
         for ( j = 0; j < ny; j++ )
         {
-            if ( !finite( f[i][j] ) )
+            if ( !isfinite( f[i][j] ) )
                 continue;
             if ( f[i][j] > M )
                 M = f[i][j];
@@ -1006,6 +1176,6 @@ plMinMax2dGrid( const PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmax, PLFLT *fmin )
                 m = f[i][j];
         }
     }
-    *fmax = M;
-    *fmin = m;
+    *fnmax = M;
+    *fnmin = m;
 }
