@@ -1,4 +1,4 @@
-// $Id: plbox.c 11811 2011-07-12 05:48:39Z airwin $
+// $Id: plbox.c 12950 2014-01-22 20:22:02Z airwin $
 //
 //      Routines for drawing axes & box around the current viewport.
 //
@@ -65,6 +65,18 @@ grid_box( const char *xopt, PLFLT xtick1, PLINT nxsub1,
 static void
 label_box( const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1 );
 
+static void
+plP_default_label_log( PLINT axis, PLFLT value, char *string, PLINT len, void *data );
+
+static void
+plP_default_label_log_fixed( PLINT axis, PLFLT value, char *string, PLINT len, void *data );
+
+static void
+plP_default_label( PLINT axis, PLFLT value, char *string, PLINT len, void *data );
+
+static const char *
+plgesc_string( void );
+
 //--------------------------------------------------------------------------
 // void plbox()
 //
@@ -127,7 +139,7 @@ c_plaxes( PLFLT x0, PLFLT y0,
           const char *yopt, PLFLT ytick, PLINT nysub )
 {
     PLBOOL lax, lbx, lcx, ldx, lgx, lix, llx, lsx, ltx, lux, lwx, lxx;
-    PLBOOL lay, lBy, lby, lCy, lcy, ldy, lgy, liy, lly, lsy, lty, luy, lwy, lxy;
+    PLBOOL lay, lby, lcy, ldy, lgy, liy, lly, lsy, lty, luy, lwy, lxy;
     PLINT  xmajor, xminor, ymajor, yminor;
     PLINT  i, i1x, i2x, i3x, i4x, i1y, i2y, i3y, i4y;
     PLINT  nxsub1, nysub1;
@@ -446,7 +458,7 @@ c_plaxes( PLFLT x0, PLFLT y0,
                 if ( ldy )
                 {
                     pldtfac( vpwymi, vpwyma, &factor, &tstart );
-                    tp = ytick1 * ( floor( ( vpwymi - tstart ) / ytick1 ) + 1 ) + tstart;
+                    tp = ytick1 * ( floor( ( vpwyma - tstart ) / ytick1 ) + 1 ) + tstart;
                 }
                 else
                     tp = ytick1 * ( floor( vpwyma / ytick1 ) + 1 );
@@ -581,15 +593,16 @@ c_plaxes( PLFLT x0, PLFLT y0,
 //--------------------------------------------------------------------------
 
 void
-c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
-          const char *yopt, const char *ylabel, PLFLT ytick, PLINT nsuby,
-          const char *zopt, const char *zlabel, PLFLT ztick, PLINT nsubz )
+c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nxsub,
+          const char *yopt, const char *ylabel, PLFLT ytick, PLINT nysub,
+          const char *zopt, const char *zlabel, PLFLT ztick, PLINT nzsub )
 {
     PLFLT dx, dy, tx, ty, ux, uy;
     PLFLT xmin, xmax, ymin, ymax, zmin, zmax, zscale;
     PLFLT cxx, cxy, cyx, cyy, cyz;
     PLINT ln;
-    PLINT *zbflg, *zbcol, *zbwidth;
+    PLINT *zbflg, *zbcol;
+    PLFLT *zbwidth;
     PLFLT *zbtck;
     PLINT xdigmax, xdigits;
     PLINT ydigmax, ydigits;
@@ -633,26 +646,26 @@ c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
         ux = plP_w3wcx( xmax, ymin, zmin );
         uy = plP_w3wcy( xmax, ymin, zmin );
         plxybx( xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
-            xmin, xmax, xtick, nsubx, 0, &xdigits );
+            xmin, xmax, xtick, nxsub, 0, &xdigits );
 
         dx = ux - tx;
         dy = uy - ty;
         plzbx( zopt, zlabel, 1, dx, dy, ux, uy,
-            plP_w3wcy( xmax, ymin, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmax, ymin, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
 
         tx = plP_w3wcx( xmin, ymax, zmin );
         ty = plP_w3wcy( xmin, ymax, zmin );
         ux = plP_w3wcx( xmin, ymin, zmin );
         uy = plP_w3wcy( xmin, ymin, zmin );
         plxybx( yopt, ylabel, PL_Y_AXIS, tx, ty, ux, uy,
-            ymax, ymin, ytick, nsuby, ln, &ydigits );
+            ymax, ymin, ytick, nysub, ln, &ydigits );
 
         dx = ux - tx;
         dy = uy - ty;
 // restore zdigits to initial value for second call
         zdigits = zdigmax;
         plzbx( zopt, zlabel, 0, dx, dy, tx, ty,
-            plP_w3wcy( xmin, ymax, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmin, ymax, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
     }
     else if ( cxx <= 0.0 && cxy <= 0.0 )
     {
@@ -662,26 +675,26 @@ c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
         ux = plP_w3wcx( xmin, ymin, zmin );
         uy = plP_w3wcy( xmin, ymin, zmin );
         plxybx( yopt, ylabel, PL_Y_AXIS, tx, ty, ux, uy,
-            ymax, ymin, ytick, nsuby, 0, &ydigits );
+            ymax, ymin, ytick, nysub, 0, &ydigits );
 
         dx = ux - tx;
         dy = uy - ty;
         plzbx( zopt, zlabel, 1, dx, dy, ux, uy,
-            plP_w3wcy( xmin, ymin, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmin, ymin, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
 
         tx = plP_w3wcx( xmax, ymax, zmin );
         ty = plP_w3wcy( xmax, ymax, zmin );
         ux = plP_w3wcx( xmin, ymax, zmin );
         uy = plP_w3wcy( xmin, ymax, zmin );
         plxybx( xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
-            xmax, xmin, xtick, nsubx, ln, &xdigits );
+            xmax, xmin, xtick, nxsub, ln, &xdigits );
 
         dx = ux - tx;
         dy = uy - ty;
 // restore zdigits to initial value for second call
         zdigits = zdigmax;
         plzbx( zopt, zlabel, 0, dx, dy, tx, ty,
-            plP_w3wcy( xmax, ymax, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmax, ymax, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
     }
     else if ( cxx <= 0.0 && cxy >= 0.0 )
     {
@@ -691,26 +704,26 @@ c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
         ux = plP_w3wcx( xmin, ymax, zmin );
         uy = plP_w3wcy( xmin, ymax, zmin );
         plxybx( xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
-            xmax, xmin, xtick, nsubx, 0, &xdigits );
+            xmax, xmin, xtick, nxsub, 0, &xdigits );
 
         dx = ux - tx;
         dy = uy - ty;
         plzbx( zopt, zlabel, 1, dx, dy, ux, uy,
-            plP_w3wcy( xmin, ymax, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmin, ymax, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
 
         tx = plP_w3wcx( xmax, ymin, zmin );
         ty = plP_w3wcy( xmax, ymin, zmin );
         ux = plP_w3wcx( xmax, ymax, zmin );
         uy = plP_w3wcy( xmax, ymax, zmin );
         plxybx( yopt, ylabel, PL_Y_AXIS, tx, ty, ux, uy,
-            ymin, ymax, ytick, nsuby, ln, &ydigits );
+            ymin, ymax, ytick, nysub, ln, &ydigits );
 
         dx = ux - tx;
         dy = uy - ty;
 // restore zdigits to initial value for second call
         zdigits = zdigmax;
         plzbx( zopt, zlabel, 0, dx, dy, tx, ty,
-            plP_w3wcy( xmax, ymin, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmax, ymin, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
     }
     else if ( cxx >= 0.0 && cxy >= 0.0 )
     {
@@ -720,26 +733,26 @@ c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
         ux = plP_w3wcx( xmax, ymax, zmin );
         uy = plP_w3wcy( xmax, ymax, zmin );
         plxybx( yopt, ylabel, PL_X_AXIS, tx, ty, ux, uy,
-            ymin, ymax, ytick, nsuby, 0, &ydigits );
+            ymin, ymax, ytick, nysub, 0, &ydigits );
 
         dx = ux - tx;
         dy = uy - ty;
         plzbx( zopt, zlabel, 1, dx, dy, ux, uy,
-            plP_w3wcy( xmax, ymax, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmax, ymax, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
 
         tx = plP_w3wcx( xmin, ymin, zmin );
         ty = plP_w3wcy( xmin, ymin, zmin );
         ux = plP_w3wcx( xmax, ymin, zmin );
         uy = plP_w3wcy( xmax, ymin, zmin );
         plxybx( xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
-            xmin, xmax, xtick, nsubx, ln, &xdigits );
+            xmin, xmax, xtick, nxsub, ln, &xdigits );
 
         dx = ux - tx;
         dy = uy - ty;
 // restore zdigits to initial value for second call
         zdigits = zdigmax;
         plzbx( zopt, zlabel, 0, dx, dy, tx, ty,
-            plP_w3wcy( xmin, ymin, zmax ), zmin, zmax, ztick, nsubz, &zdigits );
+            plP_w3wcy( xmin, ymin, zmax ), zmin, zmax, ztick, nzsub, &zdigits );
     }
     plsxax( xdigmax, xdigits );
     plsyax( ydigmax, ydigits );
@@ -773,7 +786,7 @@ c_plbox3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 static void
 plxybx( const char *opt, const char *label, PLINT axis, PLFLT wx1, PLFLT wy1,
         PLFLT wx2, PLFLT wy2, PLFLT vmin_in, PLFLT vmax_in,
-        PLFLT tick, PLINT nsub, PLINT nolast, PLINT *digits )
+        PLFLT tick, PLINT nsub, PLINT PL_UNUSED( nolast ), PLINT *digits )
 {
     static char string[STRING_LEN];
     PLINT       lb, ld, lf, li, ll, ln, ls, lt, lu, lo;
@@ -783,7 +796,8 @@ plxybx( const char *opt, const char *label, PLINT axis, PLFLT wx1, PLFLT wy1,
     PLFLT       pos, tn, tp, temp, height, tick1, vmin, vmax;
 // Note that 'tspace' is the minimim distance away (in fractional number
 // of ticks) from the boundary that an X or Y numerical label can be drawn.
-    PLFLT dwx, dwy, lambda, tcrit, tspace = 0.1;
+    PLFLT      dwx, dwy, lambda, tcrit, tspace = 0.1;
+    const char * esc_string = plgesc_string();
 
     vmin = ( vmax_in > vmin_in ) ? vmin_in : vmax_in;
     vmax = ( vmax_in > vmin_in ) ? vmax_in : vmin_in;
@@ -917,7 +931,7 @@ plxybx( const char *opt, const char *label, PLINT axis, PLFLT wx1, PLFLT wy1,
         *digits = 2;
         if ( !ll && !lo && mode )
         {
-            snprintf( string, STRING_LEN, "(x10#u%d#d)", (int) scale );
+            snprintf( string, STRING_LEN, "(x10%su%d%sd)", esc_string, (int) scale, esc_string );
             plxytx( wx1, wy1, wx2, wy2, height, 1.0, 0.5, string );
         }
     }
@@ -1010,6 +1024,7 @@ plzbx( const char *opt, const char *label, PLINT right, PLFLT dx, PLFLT dy,
     PLFLT       pos, tn, tp, temp, height, tick1;
     PLFLT       dwy, lambda, diag, major, minor, xmajor, xminor;
     PLFLT       ymajor, yminor, dxm, dym, vmin, vmax;
+    const char  * esc_string = plgesc_string();
 
     vmin = ( vmax_in > vmin_in ) ? vmin_in : vmax_in;
     vmax = ( vmax_in > vmin_in ) ? vmax_in : vmin_in;
@@ -1148,12 +1163,12 @@ plzbx( const char *opt, const char *label, PLINT right, PLFLT dx, PLFLT dy,
             if ( lm && right )
                 plztx( "v", dx, dy, wx, wy1, wy2, -0.5, pos, 0.0, string );
 
-            lstring = strlen( string );
+            lstring = (PLINT) strlen( string );
             *digits = MAX( *digits, lstring );
         }
         if ( !ll && !lo && mode )
         {
-            snprintf( string, STRING_LEN, "(x10#u%d#d)", (int) scale );
+            snprintf( string, STRING_LEN, "(x10%su%d%sd)", esc_string, (int) scale, esc_string );
             pos    = 1.15;
             height = 0.5;
             if ( ln && !right )
@@ -1249,11 +1264,12 @@ static void
 grid_box( const char *xopt, PLFLT xtick1, PLINT nxsub1,
           const char *yopt, PLFLT ytick1, PLINT nysub1 )
 {
-    PLINT lgx, lhx, llx;
-    PLINT lgy, lhy, lly;
+    PLINT lgx, lhx, llx, ldx;
+    PLINT lgy, lhy, lly, ldy;
     PLFLT vpwxmi, vpwxma, vpwymi, vpwyma;
     PLFLT vpwxmin, vpwxmax, vpwymin, vpwymax;
     PLFLT tn, temp, tcrit, tspace = 0.1;
+    PLFLT tstart, factor;
     PLINT i;
 
 // Set plot options from input
@@ -1261,10 +1277,12 @@ grid_box( const char *xopt, PLFLT xtick1, PLINT nxsub1,
     lgx = plP_stsearch( xopt, 'g' );
     lhx = plP_stsearch( xopt, 'h' );
     llx = plP_stsearch( xopt, 'l' );
+    ldx = plP_stsearch( xopt, 'd' );
 
     lgy = plP_stsearch( yopt, 'g' );
     lhy = plP_stsearch( yopt, 'h' );
     lly = plP_stsearch( yopt, 'l' );
+    ldy = plP_stsearch( yopt, 'd' );
 
     plP_xgvpw( &vpwxmin, &vpwxmax, &vpwymin, &vpwymax );
 // n.b. large change; vpwxmi always numerically less than vpwxma, and
@@ -1278,8 +1296,16 @@ grid_box( const char *xopt, PLFLT xtick1, PLINT nxsub1,
 
     if ( lgx )
     {
-        for ( tn = xtick1 * floor( vpwxmi / xtick1 );
-              tn <= vpwxma; tn += xtick1 )
+        if ( ldx )
+        {
+            pldtfac( vpwxmi, vpwxma, &factor, &tstart );
+            tn = xtick1 * ( floor( ( vpwxmi - tstart ) / xtick1 ) ) + tstart;
+        }
+        else
+        {
+            tn = xtick1 * floor( vpwxmi / xtick1 );
+        }
+        for (; tn <= vpwxma; tn += xtick1 )
         {
             if ( lhx )
             {
@@ -1316,9 +1342,16 @@ grid_box( const char *xopt, PLFLT xtick1, PLINT nxsub1,
 
     if ( lgy )
     {
-        tn = ytick1 * floor( vpwymi / ytick1 + tspace );
-        for ( tn = ytick1 * floor( vpwymi / ytick1 );
-              tn <= vpwyma; tn += ytick1 )
+        if ( ldy )
+        {
+            pldtfac( vpwymi, vpwyma, &factor, &tstart );
+            tn = ytick1 * ( floor( ( vpwymi - tstart ) / ytick1 ) ) + tstart;
+        }
+        else
+        {
+            tn = ytick1 * floor( vpwymi / ytick1 );
+        }
+        for (; tn <= vpwyma; tn += ytick1 )
         {
             if ( lhy )
             {
@@ -1366,11 +1399,22 @@ label_box( const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1 )
     PLBOOL      ldy, lfy, liy, lly, lmy, lny, lty, lvy, loy, lxy;
     PLFLT       vpwxmi, vpwxma, vpwymi, vpwyma;
     PLFLT       vpwxmin, vpwxmax, vpwymin, vpwymax;
-    PLFLT       pos, tn, tp, offset, height, just;
+    PLFLT       tn, tp, offset;
     PLFLT       factor, tstart;
-    const char  *timefmt;
+    const char  *timefmt = NULL;
     PLFLT       default_mm, char_height_mm, height_mm;
-    PLFLT       string_length_mm, pos_mm;
+    PLFLT       string_length_mm = 0.0, pos_mm = 0.0;
+
+    // Assume label data is for placement of exponents if no custom
+    // label function is provided.
+    PLBOOL custom_exponent_placement = !plsc->label_func && plsc->label_data;
+
+    // pos, height, and just are unnecessarily set to quiet
+    // -O3 -Wuninitialized warnings that are obvious false alarms from
+    // the clarity of the code associated with the true or false
+    // result for custom_exponent_placement.
+    PLFLT      pos          = 0.0, height = 0.0, just = 0.0;
+    const char * esc_string = plgesc_string();
 
     plgchr( &default_mm, &char_height_mm );
 
@@ -1498,9 +1542,7 @@ label_box( const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1 )
 
         if ( !llx && !ldx && !lox && xmode )
         {
-            // Assume label data is for placement of exponents if no custom
-            // label function is provided.
-            if ( plsc->label_data )
+            if ( custom_exponent_placement )
             {
                 height = ( (PLLabelDefaults *) plsc->label_data )->exp_label_disp;
                 pos    = ( (PLLabelDefaults *) plsc->label_data )->exp_label_pos;
@@ -1512,7 +1554,7 @@ label_box( const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1 )
                 pos    = 1.0;
                 just   = 0.5;
             }
-            snprintf( string, STRING_LEN, "(x10#u%d#d)", (int) xscale );
+            snprintf( string, STRING_LEN, "(x10%su%d%sd)", esc_string, (int) xscale, esc_string );
             if ( lnx )
             {
                 // Bottom axis exponent.
@@ -1741,69 +1783,94 @@ label_box( const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1 )
 
         if ( !lly && !ldy && !loy && ymode )
         {
-            snprintf( string, STRING_LEN, "(x10#u%d#d)", (int) yscale );
-            if ( plsc->label_data )
+            snprintf( string, STRING_LEN, "(x10%su%d%sd)", esc_string, (int) yscale, esc_string );
+            if ( custom_exponent_placement )
             {
                 height = ( (PLLabelDefaults *) plsc->label_data )->exp_label_disp;
                 pos    = ( (PLLabelDefaults *) plsc->label_data )->exp_label_pos;
                 just   = ( (PLLabelDefaults *) plsc->label_data )->exp_label_just;
             }
+            if ( lvy )
+            {
+                offset = 0.1;  // more space to clear labels in "v" mode
+            }
             else
             {
                 offset = 0.02;
-                height = 2.0;
-                // Left axis exponent
-                if ( lny )
+            }
+            // Left axis exponent
+            if ( lny )
+            {
+                if ( !custom_exponent_placement )
                 {
-                    pos  = 0.0 - offset;
-                    just = 1.0;
-                    if ( plsc->if_boxbb )
+                    height = 3.2;
+                    pos    = 1.0 + offset;
+                    just   = 0.5;
+                }
+                if ( plsc->if_boxbb )
+                {
+                    // For horizontal axes, height of zero corresponds
+                    // to character centred on edge so should add 0.5
+                    // to height to obtain bounding box edge in
+                    // direction away from edge if no exponent.  Add
+                    // an additional offset to make exponent fit.
+                    height_mm        = ( height + 1.4 ) * char_height_mm;
+                    plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
+                        plsc->ypmm + height_mm );
+                    string_length_mm = plstrl( string );
+                    pos_mm           = ( plsc->vppxmi + pos *
+                                         ( plsc->vppxma - plsc->vppxmi ) ) /
+                                       plsc->xpmm;
+                    plsc->boxbb_xmin = MIN( plsc->boxbb_xmin,
+                        pos_mm - string_length_mm );
+                }
+                else
+                {
+                    if ( lvy )
                     {
-                        // For horizontal axes, height of zero corresponds
-                        // to character centred on edge so should add 0.5
-                        // to height to obtain bounding box edge in
-                        // direction away from edge if no exponent.  Add
-                        // an additional offset to make exponent fit.
-                        height_mm        = ( height + 1.4 ) * char_height_mm;
-                        plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
-                            plsc->ypmm + height_mm );
-                        string_length_mm = plstrl( string );
-                        pos_mm           = ( plsc->vppxmi + pos *
-                                             ( plsc->vppxma - plsc->vppxmi ) ) /
-                                           plsc->xpmm;
-                        plsc->boxbb_xmin = MIN( plsc->boxbb_xmin,
-                            pos_mm - string_length_mm );
+                        plmtex( "lv", height, pos, just, string );
                     }
                     else
                     {
-                        plmtex( "t", height, pos, just, string );
+                        plmtex( "l", height, pos, just, string );
                     }
                 }
-                // Right axis exponent.
-                if ( lmy )
+            }
+            // Right axis exponent.
+            if ( lmy )
+            {
+                if ( !custom_exponent_placement )
                 {
-                    pos  = 1.0 + offset;
-                    just = 0.0;
-                    if ( plsc->if_boxbb )
+                    height = 3.4;   // Extra space for superscript
+                    pos    = 1.0 + offset;
+                    just   = 0.5;
+                }
+                if ( plsc->if_boxbb )
+                {
+                    // For horizontal axes, height of zero corresponds
+                    // to character centred on edge so should add 0.5
+                    // to height to obtain bounding box edge in
+                    // direction away from edge if no exponent.  Add
+                    // an additional offset to make exponent fit.
+                    height_mm        = ( height + 1.4 ) * char_height_mm;
+                    plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
+                        plsc->ypmm + height_mm );
+                    string_length_mm = plstrl( string );
+                    pos_mm           = ( plsc->vppxmi + pos *
+                                         ( plsc->vppxma - plsc->vppxmi ) ) /
+                                       plsc->xpmm;
+                    plsc->boxbb_xmax = MAX( plsc->boxbb_xmin,
+                        pos_mm + string_length_mm );
+                }
+                else
+                {
+                    if ( lvy )
                     {
-                        // For horizontal axes, height of zero corresponds
-                        // to character centred on edge so should add 0.5
-                        // to height to obtain bounding box edge in
-                        // direction away from edge if no exponent.  Add
-                        // an additional offset to make exponent fit.
-                        height_mm        = ( height + 1.4 ) * char_height_mm;
-                        plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
-                            plsc->ypmm + height_mm );
-                        string_length_mm = plstrl( string );
-                        pos_mm           = ( plsc->vppxmi + pos *
-                                             ( plsc->vppxma - plsc->vppxmi ) ) /
-                                           plsc->xpmm;
-                        plsc->boxbb_xmax = MAX( plsc->boxbb_xmin,
-                            pos_mm + string_length_mm );
+                        plmtex( "rv", height, pos, just, string );
                     }
                     else
                     {
-                        plmtex( "t", height, pos, just, string );
+                        plmtex( "r", height, pos, just, string );
                     }
                 }
             }
@@ -1825,8 +1892,7 @@ label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const c
     PLBOOL      ldy, lfy, liy, lly, lmy, lny, lty, lvy, loy, lxy;
     PLFLT       vpwxmi, vpwxma, vpwymi, vpwyma;
     PLFLT       vpwxmin, vpwxmax, vpwymin, vpwymax;
-    PLFLT       pos, tn, offset, height, just;
-    PLFLT       factor, tstart;
+    PLFLT       tn, offset;
     const char  *timefmt;
     PLINT       i;
     PLINT       xdigmax, xdigits, xdigmax_old, xdigits_old;
@@ -1834,7 +1900,18 @@ label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const c
     PLINT       lxmin, lxmax, lymin, lymax;
     PLINT       pxmin, pxmax, pymin, pymax;
     PLFLT       default_mm, char_height_mm, height_mm;
-    PLFLT       string_length_mm, pos_mm;
+    PLFLT       string_length_mm = 0.0, pos_mm = 0.0;
+
+    // Assume label data is for placement of exponents if no custom
+    // label function is provided.
+    PLBOOL custom_exponent_placement = !plsc->label_func && plsc->label_data;
+
+    // pos, height, and just are unnecessarily set to quiet
+    // -O3 -Wuninitialized warnings that are obvious false alarms from
+    // the clarity of the code associated with the true or false
+    // result for custom_exponent_placement.
+    PLFLT      pos          = 0.0, height = 0.0, just = 0.0;
+    const char * esc_string = plgesc_string();
 
     plgchr( &default_mm, &char_height_mm );
 
@@ -2016,9 +2093,7 @@ label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const c
 
         if ( !llx && !ldx && !lox && xmode )
         {
-            // Assume label data is for placement of exponents if no custom
-            // label function is provided.
-            if ( plsc->label_data )
+            if ( custom_exponent_placement )
             {
                 height = ( (PLLabelDefaults *) plsc->label_data )->exp_label_disp;
                 pos    = ( (PLLabelDefaults *) plsc->label_data )->exp_label_pos;
@@ -2030,7 +2105,7 @@ label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const c
                 pos    = 1.0;
                 just   = 0.5;
             }
-            snprintf( string, STRING_LEN, "(x10#u%d#d)", (int) xscale );
+            snprintf( string, STRING_LEN, "(x10%su%d%sd)", esc_string, (int) xscale, esc_string );
             if ( lnx )
             {
                 // Bottom axis exponent.
@@ -2273,69 +2348,94 @@ label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const c
 
         if ( !lly && !ldy && !loy && ymode )
         {
-            snprintf( string, STRING_LEN, "(x10#u%d#d)", (int) yscale );
-            if ( plsc->label_data )
+            snprintf( string, STRING_LEN, "(x10%su%d%sd)", esc_string, (int) yscale, esc_string );
+            if ( custom_exponent_placement )
             {
                 height = ( (PLLabelDefaults *) plsc->label_data )->exp_label_disp;
                 pos    = ( (PLLabelDefaults *) plsc->label_data )->exp_label_pos;
                 just   = ( (PLLabelDefaults *) plsc->label_data )->exp_label_just;
             }
+            if ( lvy )
+            {
+                offset = 0.1;  // more space to clear labels in "v" mode
+            }
             else
             {
                 offset = 0.02;
-                height = 2.0;
-                // Left axis exponent.
-                if ( lny )
+            }
+            // Left axis exponent.
+            if ( lny )
+            {
+                if ( !custom_exponent_placement )
                 {
-                    pos  = 0.0 - offset;
-                    just = 1.0;
-                    if ( plsc->if_boxbb )
+                    height = 3.2;
+                    pos    = 1.0 + offset;
+                    just   = 0.5;
+                }
+                if ( plsc->if_boxbb )
+                {
+                    // For horizontal axes, height of zero corresponds
+                    // to character centred on edge so should add 0.5
+                    // to height to obtain bounding box edge in
+                    // direction away from edge if no exponent.  Add
+                    // an additional offset to make exponent fit.
+                    height_mm        = ( height + 1.4 ) * char_height_mm;
+                    plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
+                        plsc->ypmm + height_mm );
+                    string_length_mm = plstrl( string );
+                    pos_mm           = ( plsc->vppxmi + pos *
+                                         ( plsc->vppxma - plsc->vppxmi ) ) /
+                                       plsc->xpmm;
+                    plsc->boxbb_xmin = MIN( plsc->boxbb_xmin,
+                        pos_mm - string_length_mm );
+                }
+                else
+                {
+                    if ( lvy )
                     {
-                        // For horizontal axes, height of zero corresponds
-                        // to character centred on edge so should add 0.5
-                        // to height to obtain bounding box edge in
-                        // direction away from edge if no exponent.  Add
-                        // an additional offset to make exponent fit.
-                        height_mm        = ( height + 1.4 ) * char_height_mm;
-                        plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
-                            plsc->ypmm + height_mm );
-                        string_length_mm = plstrl( string );
-                        pos_mm           = ( plsc->vppxmi + pos *
-                                             ( plsc->vppxma - plsc->vppxmi ) ) /
-                                           plsc->xpmm;
-                        plsc->boxbb_xmin = MIN( plsc->boxbb_xmin,
-                            pos_mm - string_length_mm );
+                        plmtex( "lv", height, pos, just, string );
                     }
                     else
                     {
-                        plmtex( "t", height, pos, just, string );
+                        plmtex( "l", height, pos, just, string );
                     }
                 }
-                // Right axis exponent.
-                if ( lmy )
+            }
+            // Right axis exponent.
+            if ( lmy )
+            {
+                if ( !custom_exponent_placement )
                 {
-                    pos  = 1.0 + offset;
-                    just = 0.0;
-                    if ( plsc->if_boxbb )
+                    height = 3.4;   // Extra space for superscript
+                    pos    = 1.0 + offset;
+                    just   = 0.5;
+                }
+                if ( plsc->if_boxbb )
+                {
+                    // For horizontal axes, height of zero corresponds
+                    // to character centred on edge so should add 0.5
+                    // to height to obtain bounding box edge in
+                    // direction away from edge if no exponent.  Add
+                    // an additional offset to make exponent fit.
+                    height_mm        = ( height + 1.4 ) * char_height_mm;
+                    plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
+                        plsc->ypmm + height_mm );
+                    string_length_mm = plstrl( string );
+                    pos_mm           = ( plsc->vppxmi + pos *
+                                         ( plsc->vppxma - plsc->vppxmi ) ) /
+                                       plsc->xpmm;
+                    plsc->boxbb_xmax = MAX( plsc->boxbb_xmin,
+                        pos_mm + string_length_mm );
+                }
+                else
+                {
+                    if ( lvy )
                     {
-                        // For horizontal axes, height of zero corresponds
-                        // to character centred on edge so should add 0.5
-                        // to height to obtain bounding box edge in
-                        // direction away from edge if no exponent.  Add
-                        // an additional offset to make exponent fit.
-                        height_mm        = ( height + 1.4 ) * char_height_mm;
-                        plsc->boxbb_ymax = MAX( plsc->boxbb_ymax, plsc->vppyma /
-                            plsc->ypmm + height_mm );
-                        string_length_mm = plstrl( string );
-                        pos_mm           = ( plsc->vppxmi + pos *
-                                             ( plsc->vppxma - plsc->vppxmi ) ) /
-                                           plsc->xpmm;
-                        plsc->boxbb_xmax = MAX( plsc->boxbb_xmin,
-                            pos_mm + string_length_mm );
+                        plmtex( "rv", height, pos, just, string );
                     }
                     else
                     {
-                        plmtex( "t", height, pos, just, string );
+                        plmtex( "r", height, pos, just, string );
                     }
                 }
             }
@@ -2361,13 +2461,14 @@ label_box_custom( const char *xopt, PLINT n_xticks, const PLFLT *xticks, const c
 // potential exposure in the PLplot API.
 //
 //--------------------------------------------------------------------------
-void plP_default_label_log( PLINT axis, PLFLT value, char *string, PLINT len, void *data )
+void plP_default_label_log( PLINT PL_UNUSED( axis ), PLFLT value, char *string, PLINT len, void * PL_UNUSED( data ) )
 {
+    const char * esc_string = plgesc_string();
     // Exponential, i.e. 10^-1, 10^0, 10^1, etc
-    snprintf( string, len, "10#u%d", (int) ROUND( value ) );
+    snprintf( string, (size_t) len, "10%su%d", esc_string, (int) ROUND( value ) );
 }
 
-void plP_default_label_log_fixed( PLINT axis, PLFLT value, char *string, PLINT len, void *data )
+void plP_default_label_log_fixed( PLINT PL_UNUSED( axis ), PLFLT value, char *string, PLINT len, void * PL_UNUSED( data ) )
 {
     // Fixed point, i.e. .1, 1, 10, etc
 
@@ -2378,15 +2479,15 @@ void plP_default_label_log_fixed( PLINT axis, PLFLT value, char *string, PLINT l
     {
         char form[FORMAT_LEN];
         snprintf( form, FORMAT_LEN, "%%.%df", ABS( exponent ) );
-        snprintf( string, len, form, value );
+        snprintf( string, (size_t) len, form, value );
     }
     else
     {
-        snprintf( string, len, "%d", (int) value );
+        snprintf( string, (size_t) len, "%d", (int) value );
     }
 }
 
-void plP_default_label( PLINT axis, PLFLT value, char *string, PLINT len, void *data )
+void plP_default_label( PLINT PL_UNUSED( axis ), PLFLT value, char *string, PLINT len, void *data )
 {
     PLINT  scale, prec;
     PLINT  setpre, precis;
@@ -2411,7 +2512,7 @@ void plP_default_label( PLINT axis, PLFLT value, char *string, PLINT len, void *
 
     snprintf( form, FORMAT_LEN, "%%.%df", (int) prec );
     snprintf( temp, TEMP_LEN, form, value );
-    strncpy( string, temp, len - 1 );
+    strncpy( string, temp, (size_t) ( len - 1 ) );
     string[len - 1] = '\0';
 }
 
@@ -2445,6 +2546,7 @@ static void
 plform( PLINT axis, PLFLT value, PLINT scale, PLINT prec, char *string, PLINT len, PLBOOL ll, PLBOOL lf, PLBOOL lo )
 {
     // Check to see if a custom labeling function is defined.  If not,
+    // use default.
     if ( lo && plsc->label_func )
     {
         ( *plsc->label_func )( axis, value, string, len, plsc->label_data );
@@ -2508,3 +2610,50 @@ c_plslabelfunc( void ( *label_func )( PLINT, PLFLT, char *, PLINT, PLPointer ),
     plsc->label_func = label_func;
     plsc->label_data = label_data;
 }
+
+static const char *
+plgesc_string( void )
+{
+    static const char *esc_strings = { "!\0#\0$\0%\0&\0*\0@\0^\0~\0" };
+    int d;
+    // Follow plgesc logic here which is to set the default escape
+    // if plsc->esc is in its initial state.
+    if ( plsc->esc == '\0' )
+        plsc->esc = '#';
+
+    switch ( plsc->esc )
+    {
+    case '!':
+        d = 0;
+        break;
+    case '#':
+        d = 1;
+        break;
+    case '$':
+        d = 2;
+        break;
+    case '%':
+        d = 3;
+        break;
+    case '&':
+        d = 4;
+        break;
+    case '*':
+        d = 5;
+        break;
+    case '@':
+        d = 6;
+        break;
+    case '^':
+        d = 7;
+        break;
+    case '~':
+        d = 8;
+        break;
+    default:
+        plwarn( "plgesc_string: Invalid escape character, assuming '#' instead" );
+        d = 1;
+        break;
+    }
+    return &( esc_strings[d * 2] );
+}
