@@ -1,4 +1,4 @@
-// $Id: plcont.c 11759 2011-06-01 17:41:34Z airwin $
+// $Id: plcont.c 12095 2011-12-03 08:56:15Z andrewross $
 //
 //      Contour plotter.
 //
@@ -105,7 +105,7 @@ static CONT_LINE  *currline;
 static int        cont3d = 0;
 
 static CONT_LINE *
-alloc_line( CONT_LEVEL *node )
+alloc_line( void )
 {
     CONT_LINE *line;
 
@@ -139,7 +139,7 @@ alloc_level( PLFLT level )
     }
     node->level = level;
     node->next  = NULL;
-    node->line  = alloc_line( node );
+    node->line  = alloc_line( );
 
     return node;
 }
@@ -148,9 +148,9 @@ static void
 realloc_line( CONT_LINE *line )
 {
     if ( ( ( line->x = (PLFLT *) realloc( line->x,
-                 ( line->npts + LINE_ITEMS ) * sizeof ( PLFLT ) ) ) == NULL ) ||
+                 (size_t) ( line->npts + LINE_ITEMS ) * sizeof ( PLFLT ) ) ) == NULL ) ||
          ( ( line->y = (PLFLT *) realloc( line->y,
-                 ( line->npts + LINE_ITEMS ) * sizeof ( PLFLT ) ) ) == NULL ) )
+                 (size_t) ( line->npts + LINE_ITEMS ) * sizeof ( PLFLT ) ) ) == NULL ) )
         plexit( "realloc_line: Insufficient memory" );
 }
 
@@ -236,7 +236,7 @@ cont_mv_store( PLFLT xx, PLFLT yy )
     {
         if ( currline->npts != 0 ) // not an empty list, allocate new
         {
-            currline->next = alloc_line( currlev );
+            currline->next = alloc_line( );
             currline       = currline->next;
         }
 
@@ -368,9 +368,9 @@ static void plfloatlabel( PLFLT value, char *string, PLINT len )
         mant = (int) ( mant * pow( 10.0, prec - 1 ) + 0.5 * mant / fabs( mant ) ) / pow( 10.0, prec - 1 );
 
     snprintf( form, FORM_LEN, "%%.%df", prec - 1 );
-    snprintf( string, len, form, mant );
+    snprintf( string, (size_t) len, form, mant );
     snprintf( tmpstring, TMPSTRING_LEN, "#(229)10#u%d", exponent );
-    strncat( string, tmpstring, len - strlen( string ) - 1 );
+    strncat( string, tmpstring, (size_t) len - strlen( string ) - 1 );
 
     if ( abs( exponent ) < limexp || value == 0.0 )
     {
@@ -385,7 +385,7 @@ static void plfloatlabel( PLFLT value, char *string, PLINT len )
             prec = 0;
 
         snprintf( form, FORM_LEN, "%%.%df", (int) prec );
-        snprintf( string, len, form, value );
+        snprintf( string, (size_t) len, form, value );
     }
 }
 
@@ -489,7 +489,7 @@ plf2evalr( PLINT ix, PLINT iy, PLPointer plf2eval_data )
 //--------------------------------------------------------------------------
 
 void
-cont_store( const PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
+cont_store( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
             PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
             PLPointer pltr_data,
@@ -512,7 +512,7 @@ cont_store( const PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
 //--------------------------------------------------------------------------
 
 void
-c_plcont( const PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
+c_plcont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
           PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data )
@@ -567,14 +567,14 @@ plfcont( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
         return;
     }
 
-    if ( ( ipts = (PLINT **) malloc( nx * sizeof ( PLINT * ) ) ) == NULL )
+    if ( ( ipts = (PLINT **) malloc( (size_t) nx * sizeof ( PLINT * ) ) ) == NULL )
     {
         plexit( "plfcont: Insufficient memory" );
     }
 
     for ( i = 0; i < nx; i++ )
     {
-        if ( ( ipts[i] = (PLINT *) malloc( ny * sizeof ( PLINT * ) ) ) == NULL )
+        if ( ( ipts[i] = (PLINT *) malloc( (size_t) ny * sizeof ( PLINT * ) ) ) == NULL )
         {
             plexit( "plfcont: Insufficient memory" );
         }
@@ -865,7 +865,7 @@ pldrawcn( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 //--------------------------------------------------------------------------
 
 void
-pltr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data )
+pltr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer PL_UNUSED( pltr_data ) )
 {
     *tx = x;
     *ty = y;
