@@ -1,4 +1,4 @@
-// $Id: pldeprecated.c 11682 2011-03-31 02:55:49Z airwin $
+// $Id: pldeprecated.c 12953 2014-01-22 23:18:38Z airwin $
 //
 //  Copyright (C) 2005  Alan W. Irwin
 //
@@ -25,11 +25,10 @@
 //  is explicitly commented.
 //
 
-#ifdef PL_DEPRECATED
-
-#define NEED_PLDEBUG
 #include "plplotP.h"
 
+#ifdef PL_DEPRECATED
+
 // The following functions have been removed from plplot ahead of the 5.9.8
 // release. They have long been advertised as deprecated.
 //   plParseOpts
@@ -44,6 +43,9 @@
 //   plrgb1
 //   plhls
 
+// The following function was formally deprecated in 5.9.10.
+//   plwid
+
 //--------------------------------------------------------------------------
 // plrgb()
 //
@@ -122,5 +124,18 @@ c_plhls( PLFLT h, PLFLT l, PLFLT s )
     plrgb( r, g, b );
 }
 
+//--------------------------------------------------------------------------
+// void plwid()
+//
+// Set pen width using a deprecated integer width value rather than
+// the recommended plwidth call with floating-point width value.
+//--------------------------------------------------------------------------
+
+void
+c_plwid( PLINT width )
+{
+    plwarn( "plwid: function deprecated. Use plwidth instead" );
+    plwidth( (PLFLT) width );
+}
 
 #endif // PL_DEPRECATED
