@@ -1,4 +1,4 @@
-// $Id: pldtik.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: pldtik.c 12625 2013-10-24 18:54:19Z airwin $
 //
 //      Determines tick spacing and mode (fixed or floating) of
 //      numeric axis labels.
@@ -39,7 +39,8 @@ pldtik( PLFLT vmin, PLFLT vmax, PLFLT *tick, PLINT *nsubt, PLBOOL ld )
 {
     PLFLT t1, t2, tick_reasonable;
     PLINT np, ns;
-    PLFLT factor;
+    // Unnecessarily set factor to quiet -O3 -Wuninitialized warnings.
+    PLFLT factor = 0.0;
 
 
     if ( ld )
