@@ -1,8 +1,8 @@
-// $Id: plfreetype.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: plfreetype.c 12661 2013-11-05 16:24:11Z airwin $
 //
 // Copyright (C) 2002, 2004, 2005  Andrew Roach
 // Copyright (C) 2002  Maurice LeBrun
-// Copyright (C) 2002, 2004, 2005  Alan W. Irwin
+// Copyright (C) 2002-2012  Alan W. Irwin
 // Copyright (C) 2003, 2004  Joao Cardoso
 // Copyright (C) 2003, 2004, 2005  Rafael Laboissiere
 // Copyright (C) 2004  Andrew Ross
@@ -91,7 +91,7 @@ int access( char *filename, int flag )
 #include "plDevs.h"
 #include "plplotP.h"
 #include "drivers.h"
-#ifdef HAVE_FREETYPE
+#ifdef PL_HAVE_FREETYPE
 #include "plfreetype.h"
 #include "plfci-truetype.h"
 
@@ -136,7 +136,7 @@ void plD_render_freetype_sym( PLStream *pls, EscText *args );
 
 //  Private prototypes for use in this file only
 
-static void FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot, int x, int y, short colour );
+static void FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot, int x, int y );
 static void FT_SetFace( PLStream *pls, PLUNICODE fci );
 static PLFLT CalculateIncrement( int bg, int fg, int levels );
 
@@ -148,7 +148,7 @@ static PLFLT CalculateIncrement( int bg, int fg, int levels );
 //
 
 static void FT_WriteStrW( PLStream *pls, const PLUNICODE  *text, short len, int x, int y );
-static void FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy );
+static void FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy, int *overyy, int *underyy );
 
 //--------------------------------------------------------------------------
 // FT_StrX_YW()
@@ -161,12 +161,12 @@ static void FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx
 //--------------------------------------------------------------------------
 
 void
-FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy )
+FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy, int *overyy, int *underyy )
 {
     FT_Data   *FT = (FT_Data *) pls->FT;
     short     i   = 0;
-    FT_Vector akerning;
-    int       x = 0, y = 0;
+    FT_Vector akerning, adjust;
+    int       x = 0, y = 0, startingy;
     char      esc;
 
     plgesc( &esc );
@@ -178,22 +178,45 @@ FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy )
 // and this is the best thing I could think of.
 //
 
-    y -= FT->face->size->metrics.height;
+    y        -= (int) FT->face->size->metrics.height;
+    startingy = y;
+    *yy       = y; //note height is negative!
+    *overyy   = 0;
+    *underyy  = 0;
+    adjust.x  = 0;
+    adjust.y  = 0;
 
 // walk through the text character by character
     for ( i = 0; i < len; i++ )
     {
-        if ( ( text[i] == esc ) && ( text[i - 1] != esc ) )
+        if ( ( text[i] == (PLUNICODE) esc ) && ( text[i - 1] != (PLUNICODE) esc ) )
         {
-            if ( text[i + 1] == esc )
+            if ( text[i + 1] == (PLUNICODE) esc )
                 continue;
 
             switch ( text[i + 1] )
             {
             case 'u': // super script
+            case 'U': // super script
+                adjust.y = FT->face->size->metrics.height / 2;
+                adjust.x = 0;
+                FT_Vector_Transform( &adjust, &FT->matrix );
+                x += (int) adjust.x;
+                y -= (int) adjust.y;
+                //calculate excess height from superscripts, this will need changing if scale of sub/superscripts changes
+                *overyy = y - startingy < *overyy ? y - startingy : *overyy;
+                i++;
+                break;
+
             case 'd': // subscript
-            case 'U':
-            case 'D':
+            case 'D': // subscript
+                adjust.y = -FT->face->size->metrics.height / 2;
+                adjust.x = 0;
+                FT_Vector_Transform( &adjust, &FT->matrix );
+                x += (int) adjust.x;
+                y -= (int) adjust.y;
+                //calculate excess depth from subscripts, this will need changing if scale of sub/superscripts changes
+                *underyy = startingy - y < *underyy ? startingy - y : *underyy;
                 i++;
                 break;
             }
@@ -202,6 +225,7 @@ FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy )
         {
             // FCI in text stream; change font accordingly.
             FT_SetFace( pls, text[i] );
+            *yy = (int) ( FT->face->size->metrics.height > -*yy  ? -FT->face->size->metrics.height : *yy );
         }
         else
         {
@@ -213,7 +237,7 @@ FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy )
                     text[i],
                     ft_kerning_default,
                     &akerning );
-                x += ( akerning.x >> 6 );        // add (or subtract) the kerning
+                x += (int) ( akerning.x >> 6 );        // add (or subtract) the kerning
             }
 
             //
@@ -234,8 +258,8 @@ FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy )
             // Y is negative because freetype does things upside down
             //
 
-            x += ( FT->face->glyph->advance.x );
-            y -= ( FT->face->glyph->advance.y );
+            x += (int) ( FT->face->glyph->advance.x );
+            y -= (int) ( FT->face->glyph->advance.y );
         }
     }
 
@@ -250,7 +274,6 @@ FT_StrX_YW( PLStream *pls, const PLUNICODE *text, short len, int *xx, int *yy )
 //yy=y>> 6;
 //xx=x>> 6;
 //
-    *yy = y;
     *xx = x;
 }
 
@@ -304,8 +327,8 @@ FT_WriteStrW( PLStream *pls, const PLUNICODE *text, short len, int x, int y )
     adjust.x = 0;
     adjust.y = 0;
     FT_Vector_Transform( &adjust, &FT->matrix );
-    x += adjust.x;
-    y -= adjust.y;
+    x += (int) adjust.x;
+    y -= (int) adjust.y;
 
 // (RL, on 2005-01-25) The computation of cumulated glyph width within
 // the text is done now with full precision, using 26.6 Freetype
@@ -324,9 +347,9 @@ FT_WriteStrW( PLStream *pls, const PLUNICODE *text, short len, int x, int y )
 
     for ( i = 0; i < len; i++ )
     {
-        if ( ( text[i] == esc ) && ( text[i - 1] != esc ) )
+        if ( ( text[i] == (PLUNICODE) esc ) && ( text[i - 1] != (PLUNICODE) esc ) )
         {
-            if ( text[i + 1] == esc )
+            if ( text[i + 1] == (PLUNICODE) esc )
                 continue;
 
             switch ( text[i + 1] )
@@ -345,8 +368,8 @@ FT_WriteStrW( PLStream *pls, const PLUNICODE *text, short len, int x, int y )
                 adjust.y = FT->face->size->metrics.height / 2;
                 adjust.x = 0;
                 FT_Vector_Transform( &adjust, &FT->matrix );
-                x += adjust.x;
-                y -= adjust.y;
+                x += (int) adjust.x;
+                y -= (int) adjust.y;
                 i++;
                 break;
 
@@ -355,8 +378,8 @@ FT_WriteStrW( PLStream *pls, const PLUNICODE *text, short len, int x, int y )
                 adjust.y = -FT->face->size->metrics.height / 2;
                 adjust.x = 0;
                 FT_Vector_Transform( &adjust, &FT->matrix );
-                x += adjust.x;
-                y -= adjust.y;
+                x += (int) adjust.x;
+                y -= (int) adjust.y;
                 i++;
                 break;
             }
@@ -377,17 +400,17 @@ FT_WriteStrW( PLStream *pls, const PLUNICODE *text, short len, int x, int y )
                     text[last_char],
                     text[i],
                     ft_kerning_default, &akerning );
-                x += akerning.x;        // add (or subtract) the kerning
-                y -= akerning.y;        // Do I need this in case of rotation ?
+                x += (int) akerning.x;        // add (or subtract) the kerning
+                y -= (int) akerning.y;        // Do I need this in case of rotation ?
             }
 
 
             FT_Load_Char( FT->face, text[i], ( FT->smooth_text == 0 ) ? FT_LOAD_MONOCHROME + FT_LOAD_RENDER : FT_LOAD_RENDER | FT_LOAD_FORCE_AUTOHINT );
             FT_PlotChar( pls, FT, FT->face->glyph,
-                ROUND( x / 64.0 ), ROUND( y / 64.0 ), 2 );          // render the text
+                ROUND( x / 64.0 ), ROUND( y / 64.0 ) );          // render the text
 
-            x += FT->face->glyph->advance.x;
-            y -= FT->face->glyph->advance.y;
+            x += (int) FT->face->glyph->advance.x;
+            y -= (int) FT->face->glyph->advance.y;
 
             last_char = i;
         }
@@ -403,14 +426,15 @@ FT_WriteStrW( PLStream *pls, const PLUNICODE *text, short len, int x, int y )
 
 void
 FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
-             int x, int y, short colour )
+             int x, int y )
 {
     unsigned char bittest;
     short         i, k, j;
     int           n = slot->bitmap.pitch;
     int           current_pixel_colour;
     int           R, G, B;
-    PLFLT         alpha_a, alpha_b;
+    PLFLT         alpha_a;
+    //PLFLT         alpha_b;
     int           xx;
     short         imin, imax, kmin, kmax;
 
@@ -433,33 +457,33 @@ FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
 
     if ( FT->scale != 0.0 )    // scale was set
     {
-        clipxmin = clipxmin / FT->scale;
-        clipxmax = clipxmax / FT->scale;
+        clipxmin = (PLINT) ( clipxmin / FT->scale );
+        clipxmax = (PLINT) ( clipxmax / FT->scale );
         if ( FT->invert_y == 1 )
         {
-            clipymin = FT->ymax - ( clipymin / FT->scale );
-            clipymax = FT->ymax - ( clipymax / FT->scale );
+            clipymin = (PLINT) ( FT->ymax - ( clipymin / FT->scale ) );
+            clipymax = (PLINT) ( FT->ymax - ( clipymax / FT->scale ) );
         }
         else
         {
-            clipymin = clipymin / FT->scale;
-            clipymax = clipymax / FT->scale;
+            clipymin = (PLINT) ( clipymin / FT->scale );
+            clipymax = (PLINT) ( clipymax / FT->scale );
         }
     }
     else
     {
-        clipxmin = clipxmin / FT->scalex;
-        clipxmax = clipxmax / FT->scalex;
+        clipxmin = (PLINT) ( clipxmin / FT->scalex );
+        clipxmax = (PLINT) ( clipxmax / FT->scalex );
 
         if ( FT->invert_y == 1 )
         {
-            clipymin = FT->ymax - ( clipymin / FT->scaley );
-            clipymax = FT->ymax - ( clipymax / FT->scaley );
+            clipymin = (PLINT) ( FT->ymax - ( clipymin / FT->scaley ) );
+            clipymax = (PLINT) ( FT->ymax - ( clipymax / FT->scaley ) );
         }
         else
         {
-            clipymin = clipymin / FT->scaley;
-            clipymax = clipymax / FT->scaley;
+            clipymin = (PLINT) ( clipymin / FT->scaley );
+            clipymax = (PLINT) ( clipymax / FT->scaley );
         }
     }
     if ( clipxmin > clipxmax )
@@ -484,8 +508,8 @@ FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
         x += slot->bitmap_left;
         y -= slot->bitmap_top;
 
-        imin = MAX( 0, clipymin - y );
-        imax = MIN( slot->bitmap.rows, clipymax - y );
+        imin = (short) MAX( 0, clipymin - y );
+        imax = (short) MIN( slot->bitmap.rows, clipymax - y );
         for ( i = imin; i < imax; i++ )
         {
             for ( k = 0; k < n; k++ )
@@ -512,10 +536,10 @@ FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
         x += slot->bitmap_left;
         y -= slot->bitmap_top;
 
-        imin = MAX( 0, clipymin - y );
-        imax = MIN( slot->bitmap.rows, clipymax - y );
-        kmin = MAX( 0, clipxmin - x );
-        kmax = MIN( slot->bitmap.width, clipxmax - x );
+        imin = (short) MAX( 0, clipymin - y );
+        imax = (short) MIN( slot->bitmap.rows, clipymax - y );
+        kmin = (short) MAX( 0, clipxmin - x );
+        kmax = (short) MIN( slot->bitmap.width, clipxmax - x );
         for ( i = imin; i < imax; i++ )
         {
             for ( k = kmin; k < kmax; k++ )
@@ -540,9 +564,9 @@ FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
                             alpha_a = (float) FT->shade / 255.0;
 
                             // alpha_b=1.0-alpha_a;
-                            // R=(plsc->cmap0[pls->icol0].r*alpha_a)+(R*alpha_b);
-                            // G=(plsc->cmap0[pls->icol0].g*alpha_a)+(G*alpha_b);
-                            // B=(plsc->cmap0[pls->icol0].b*alpha_a)+(B*alpha_b);
+                            // R=(plsc->curcolor.r*alpha_a)+(R*alpha_b);
+                            // G=(plsc->curcolor.g*alpha_a)+(G*alpha_b);
+                            // B=(plsc->curcolor.b*alpha_a)+(B*alpha_b);
                             //
 
                             //  This next bit of code is, I *think*, computationally
@@ -554,9 +578,9 @@ FT_PlotChar( PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
                             //  Is one faster than the other so that you'd ever notice ?
                             //
 
-                            R = ( ( ( plsc->cmap0[pls->icol0].r - R ) * alpha_a ) + R );
-                            G = ( ( ( plsc->cmap0[pls->icol0].g - G ) * alpha_a ) + G );
-                            B = ( ( ( plsc->cmap0[pls->icol0].b - B ) * alpha_a ) + B );
+                            R = (int) ( ( ( plsc->curcolor.r - R ) * alpha_a ) + R );
+                            G = (int) ( ( ( plsc->curcolor.g - G ) * alpha_a ) + G );
+                            B = (int) ( ( ( plsc->curcolor.b - B ) * alpha_a ) + B );
 
                             FT->set_pixel( pls, x + k, y + i, RGB( R > 255 ? 255 : R, G > 255 ? 255 : G, B > 255 ? 255 : B ) );
                         }
@@ -659,15 +683,16 @@ void plD_FreeType_init( PLStream *pls )
 
 #if defined ( MSDOS ) || defined ( WIN32 )
 
-//
-// Work out if we have Win95+ or Win3.?... sort of.
-// Actually, this just tries to find the place where the fonts live by looking
-// for arial, which should be on all windows machines.
-// At present, it only looks in two places, on one drive. I might change this
-// soon.
-//
-    if ( WINDIR_PATH == NULL )
+// First check for a user customised location and if
+// the fonts aren't found there try the default Windows
+// locations
+    if ( ( a = getenv( "PLPLOT_FREETYPE_FONT_DIR" ) ) != NULL )
+        strncpy( font_dir, a, PLPLOT_MAX_PATH - 1 );
+    else if ( strlen( PL_FREETYPE_FONT_DIR ) > 0 )
+        strncpy( font_dir, PL_FREETYPE_FONT_DIR, PLPLOT_MAX_PATH - 1 );
+    else if ( WINDIR_PATH == NULL )
     {
+        //try to guess the font location by looking for arial font on C:
         if ( access( "c:\\windows\\fonts\\arial.ttf", F_OK ) == 0 )
         {
             strcpy( font_dir, "c:/windows/fonts/" );
@@ -681,6 +706,7 @@ void plD_FreeType_init( PLStream *pls )
     }
     else
     {
+        //Try to guess the font location by looking for Arial font in the Windows Path
         strncat( WINDIR_PATH, "\\fonts\\arial.ttf", PLPLOT_MAX_PATH - 1 - strlen( WINDIR_PATH ) );
         if ( access( WINDIR_PATH, F_OK ) == 0 )
         {
@@ -693,6 +719,7 @@ void plD_FreeType_init( PLStream *pls )
         else
             plwarn( "Could not find font path; I sure hope you have defined fonts manually !" );
     }
+    font_dir[PLPLOT_MAX_PATH - 1] = '\0';
 
     if ( pls->debug )
         fprintf( stderr, "%s\n", font_dir );
@@ -749,7 +776,7 @@ void plD_FreeType_init( PLStream *pls )
         else
         {
             strncpy( FT->font_name[i], font_dir, PLPLOT_MAX_PATH - 1 );
-            strncat( FT->font_name[i], (char *) TrueTypeLookup[i].pfont, PLPLOT_MAX_PATH - 1 - strlen( FT->font_name[i] ) );
+            strncat( FT->font_name[i], (const char *) TrueTypeLookup[i].pfont, PLPLOT_MAX_PATH - 1 - strlen( FT->font_name[i] ) );
         }
         FT->font_name[i][PLPLOT_MAX_PATH - 1] = '\0';
 
@@ -768,8 +795,11 @@ void plD_FreeType_init( PLStream *pls )
                 fclose( infile );
             }
         }
-        FontLookup[i].fci   = TrueTypeLookup[i].fci;
-        FontLookup[i].pfont = (unsigned char *) FT->font_name[i];
+        FontLookup[i].fci = TrueTypeLookup[i].fci;
+        if ( FT->font_name[i][0] == '\0' )
+            FontLookup[i].pfont = NULL;
+        else
+            FontLookup[i].pfont = (unsigned char *) FT->font_name[i];
     }
 //
 // Next, we check to see if -drvopt has been used on the command line to
@@ -796,7 +826,7 @@ void FT_SetFace( PLStream *pls, PLUNICODE fci )
 
     if ( fci != FT->fci )
     {
-        char *font_name = plP_FCI2FontName( fci, FontLookup, N_TrueTypeLookup );
+        const char *font_name = plP_FCI2FontName( fci, FontLookup, N_TrueTypeLookup );
         if ( font_name == NULL )
         {
             if ( FT->fci == PL_FCI_IMPOSSIBLE )
@@ -819,11 +849,16 @@ void FT_SetFace( PLStream *pls, PLUNICODE fci )
                 if ( FT_New_Face( FT->library, font_name, 0, &FT->face ) )
                     plexit( "FT_SetFace: Error loading a font in freetype" );
             }
+
+            //check if the charmap was loaded correctly - freetype only checks for a unicode charmap
+            //if it is not set then use the first found charmap in the font
+            if ( FT->face->charmap == NULL )
+                FT_Select_Charmap( FT->face, FT->face->charmaps[0]->encoding );
         }
     }
     FT_Set_Char_Size( FT->face, 0,
-        font_size * 64 / TEXT_SCALING_FACTOR, pls->xdpi,
-        pls->ydpi );
+        (FT_F26Dot6) ( font_size * 64 / TEXT_SCALING_FACTOR ), (FT_UInt) pls->xdpi,
+        (FT_UInt) pls->ydpi );
 }
 
 //--------------------------------------------------------------------------
@@ -838,11 +873,14 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 {
     FT_Data   *FT = (FT_Data *) pls->FT;
     int       x, y;
-    int       w  = 0, h = 0;
+    int       w  = 0, h = 0, overh = 0, underh = 0;
     PLFLT     *t = args->xform;
     FT_Matrix matrix;
     PLFLT     angle = PI * pls->diorot / 2;
-//
+    PLUNICODE *line = args->unicode_array;
+    int       linelen;
+    int       prevlineheights = 0;
+
 // Used later in a commented out section (See Rotate The Page), if that
 // section will never be used again, remove these as well.
 //      PLINT clxmin, clxmax, clymin, clymax;
@@ -853,7 +891,7 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
     FT_Fixed  height;
     PLFLT     height_factor;
 
-    if ( ( args->string != NULL ) || ( args->unicode_array_len > 0 ) )
+    if ( ( args->unicode_array_len > 0 ) )
     {
 //
 //   Work out if either the font size, the font face or the
@@ -875,6 +913,15 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 
 
 
+//
+// Split the text into lines based on the newline character
+//
+        while ( line < args->unicode_array + args->unicode_array_len )
+        {
+            linelen = 0;
+            while ( line[linelen] != '\n' && line + linelen < args->unicode_array + args->unicode_array_len )
+                ++linelen;
+
 //
 //  Now we work out how long the text is (for justification etc...) and how
 //  high the text is. This is done on UN-TRANSFORMED text, since we will
@@ -883,15 +930,15 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 //  that calculates the text size.
 //
 
-        FT->matrix.xx = 0x10000;
-        FT->matrix.xy = 0x00000;
-        FT->matrix.yx = 0x00000;
-        FT->matrix.yy = 0x10000;
+            FT->matrix.xx = 0x10000;
+            FT->matrix.xy = 0x00000;
+            FT->matrix.yx = 0x00000;
+            FT->matrix.yy = 0x10000;
 
-        FT_Vector_Transform( &FT->pos, &FT->matrix );
-        FT_Set_Transform( FT->face, &FT->matrix, &FT->pos );
+            FT_Vector_Transform( &FT->pos, &FT->matrix );
+            FT_Set_Transform( FT->face, &FT->matrix, &FT->pos );
 
-        FT_StrX_YW( pls, args->unicode_array, args->unicode_array_len, &w, &h );
+            FT_StrX_YW( pls, line, (short) linelen, &w, &h, &overh, &underh );
 
 //
 //      Set up the transformation Matrix
@@ -916,20 +963,20 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 // always a negative quantity.
 //
 
-        height_factor = (PLFLT) ( FT->face->ascender - FT->face->descender )
-                        / FT->face->ascender;
-        height = (FT_Fixed) ( 0x10000 * height_factor );
+            height_factor = (PLFLT) ( FT->face->ascender - FT->face->descender )
+                            / FT->face->ascender;
+            height = (FT_Fixed) ( 0x10000 * height_factor );
 
 #ifdef DJGPP
-        FT->matrix.xx = height * t[0];
-        FT->matrix.xy = height * t[2];
-        FT->matrix.yx = height * t[1];
-        FT->matrix.yy = height * t[3];
+            FT->matrix.xx = (FT_Fixed) ( (PLFLT) height * t[0] );
+            FT->matrix.xy = (FT_Fixed) ( (PLFLT) height * t[2] );
+            FT->matrix.yx = (FT_Fixed) ( (PLFLT) height * t[1] );
+            FT->matrix.yy = (FT_Fixed) ( (PLFLT) height * t[3] );
 #else
-        FT->matrix.xx = height * t[0];
-        FT->matrix.xy = height * t[1];
-        FT->matrix.yx = height * t[2];
-        FT->matrix.yy = height * t[3];
+            FT->matrix.xx = (FT_Fixed) ( (PLFLT) height * t[0] );
+            FT->matrix.xy = (FT_Fixed) ( (PLFLT) height * t[1] );
+            FT->matrix.yx = (FT_Fixed) ( (PLFLT) height * t[2] );
+            FT->matrix.yy = (FT_Fixed) ( (PLFLT) height * t[3] );
 #endif
 
 
@@ -940,22 +987,22 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 //  will use freetypes matrix math stuff to do this for us.
 //
 
-        Cos_A = cos( angle );
-        Sin_A = sin( angle );
+            Cos_A = cos( angle );
+            Sin_A = sin( angle );
 
-        matrix.xx = (FT_Fixed) 0x10000 * Cos_A;
+            matrix.xx = (FT_Fixed) ( (PLFLT) 0x10000 * Cos_A );
 
 #ifdef DJGPP
-        matrix.xy = (FT_Fixed) 0x10000 * Sin_A * -1;
-        matrix.yx = (FT_Fixed) 0x10000 * Sin_A;
+            matrix.xy = (FT_Fixed) ( (PLFLT) 0x10000 * Sin_A * -1.0 );
+            matrix.yx = (FT_Fixed) ( (PLFLT) 0x10000 * Sin_A );
 #else
-        matrix.xy = (FT_Fixed) 0x10000 * Sin_A;
-        matrix.yx = (FT_Fixed) 0x10000 * Sin_A * -1;
+            matrix.xy = (FT_Fixed) ( (PLFLT) 0x10000 * Sin_A );
+            matrix.yx = (FT_Fixed) ( (PLFLT) 0x10000 * Sin_A * -1.0 );
 #endif
 
-        matrix.yy = (FT_Fixed) 0x10000 * Cos_A;
+            matrix.yy = (FT_Fixed) ( (PLFLT) 0x10000 * Cos_A );
 
-        FT_Matrix_Multiply( &matrix, &FT->matrix );
+            FT_Matrix_Multiply( &matrix, &FT->matrix );
 
 
 //       Calculate a Vector from the matrix
@@ -967,7 +1014,7 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 //
 
 
-        FT_Vector_Transform( &FT->pos, &FT->matrix );
+            FT_Vector_Transform( &FT->pos, &FT->matrix );
 
 
 //    Transform the font face
@@ -979,7 +1026,7 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 // it is asked for.
 //
 
-        FT_Set_Transform( FT->face, &FT->matrix, &FT->pos );
+            FT_Set_Transform( FT->face, &FT->matrix, &FT->pos );
 
 
 //                            Rotate the Page
@@ -995,51 +1042,51 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 //   Convert into normal coordinates from virtual coordinates
 //
 
-        if ( FT->scale != 0.0 ) // scale was set
-        {
-            x = args->x / FT->scale;
+            if ( FT->scale != 0.0 )             // scale was set
+            {
+                x = (int) ( args->x / FT->scale );
 
-            if ( FT->invert_y == 1 )
-                y = FT->ymax - ( args->y / FT->scale );
+                if ( FT->invert_y == 1 )
+                    y = (int) ( FT->ymax - ( args->y / FT->scale ) );
+                else
+                    y = (int) ( args->y / FT->scale );
+            }
             else
-                y = args->y / FT->scale;
-        }
-        else
-        {
-            x = args->x / FT->scalex;
+            {
+                x = (int) ( args->x / FT->scalex );
 
-            if ( FT->invert_y == 1 )
-                y = FT->ymax - ( args->y / FT->scaley );
-            else
-                y = args->y / FT->scaley;
-        }
+                if ( FT->invert_y == 1 )
+                    y = (int) ( FT->ymax - ( args->y / FT->scaley ) );
+                else
+                    y = (int) ( args->y / FT->scaley );
+            }
 
-        //          Adjust for the justification and character height
-        //
-        //  Eeeksss... this wasn't a nice bit of code to work out, let me tell you.
-        //  I could not work out an entirely satisfactory solution that made
-        //  logical sense, so came up with an "illogical" one as well.
-        //  The logical one works fine for text in the normal "portrait"
-        //  orientation, and does so for reasons you might expect it to work; But
-        //  for all other orientations, the text's base line is either a little
-        //  high, or a little low. This is because of the way the base-line pos
-        //  is calculated from the decender height. The "dodgie" way of calculating
-        //  the position is to use the character height here, then adjust for the
-        //  decender height by a three-fold factor later on. That approach seems to
-        //  work a little better for rotated pages, but why it should be so, I
-        //  don't understand. You can compile in or out which way you want it by
-        //  defining "DODGIE_DECENDER_HACK".
-        //
-        //  note: the logic of the page rotation coming up next is that we pump in
-        //  the justification factor and then use freetype to rotate and transform
-        //  the values, which we then use to change the plotting location.
-        //
+            //          Adjust for the justification and character height
+            //
+            //  Eeeksss... this wasn't a nice bit of code to work out, let me tell you.
+            //  I could not work out an entirely satisfactory solution that made
+            //  logical sense, so came up with an "illogical" one as well.
+            //  The logical one works fine for text in the normal "portrait"
+            //  orientation, and does so for reasons you might expect it to work; But
+            //  for all other orientations, the text's base line is either a little
+            //  high, or a little low. This is because of the way the base-line pos
+            //  is calculated from the decender height. The "dodgie" way of calculating
+            //  the position is to use the character height here, then adjust for the
+            //  decender height by a three-fold factor later on. That approach seems to
+            //  work a little better for rotated pages, but why it should be so, I
+            //  don't understand. You can compile in or out which way you want it by
+            //  defining "DODGIE_DECENDER_HACK".
+            //
+            //  note: the logic of the page rotation coming up next is that we pump in
+            //  the justification factor and then use freetype to rotate and transform
+            //  the values, which we then use to change the plotting location.
+            //
 
 
 #ifdef DODGIE_DECENDER_HACK
-        adjust.y = h;
+            adjust.y = h;
 #else
-        adjust.y = 0;
+            adjust.y = 0;
 #endif
 
 // (RL, on 2005-01-24) The code below uses floating point and division
@@ -1060,14 +1107,14 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 // only one glyph in the string in this case, we are okay here).
 //
 
-        if ( ( args->unicode_array_len == 2 )
-             && ( args->unicode_array[0] == ( PL_FCI_MARK | 0x004 ) ) )
-        {
-            adjust.x = args->just * ROUND( FT->face->glyph->metrics.width / 64.0 );
-            adjust.y = (FT_Pos) ROUND( FT->face->glyph->metrics.height / 128.0 );
-        }
-        else
-        {
+            if ( ( args->unicode_array_len == 2 )
+                 && ( args->unicode_array[0] == ( PL_FCI_MARK | 0x004 ) ) )
+            {
+                adjust.x = (FT_Pos) ( args->just * ROUND( (PLFLT) FT->face->glyph->metrics.width / 64.0 ) );
+                adjust.y = (FT_Pos) ROUND( (PLFLT) FT->face->glyph->metrics.height / 128.0 );
+            }
+            else
+            {
 // (RL, on 2005-01-21) The vertical adjustment is set below, making
 // the DODGIE conditional moot.  I use the value of h as return by FT_StrX_YW,
 // which should correspond to the total height of the text being
@@ -1077,17 +1124,24 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 // height_factor below.
 //
 
-            adjust.y = (FT_Pos)
-                       ROUND( FT->face->size->metrics.height / height_factor / 128.0 );
-            adjust.x = (FT_Pos) ( args->just * ROUND( w / 64.0 ) );
+                adjust.y = (FT_Pos)
+                           ROUND( (PLFLT) FT->face->size->metrics.height / height_factor / 128.0 - ( prevlineheights + overh ) / 64.0 );
+                adjust.x = (FT_Pos) ( args->just * ROUND( w / 64.0 ) );
+            }
+
+            FT_Vector_Transform( &adjust, &FT->matrix );             // was /&matrix); -  was I using the wrong matrix all this time ?
+
+            x -= (int) adjust.x;
+            y += (int) adjust.y;
+
+            FT_WriteStrW( pls, line, (short) linelen, x, y );             // write it out
+
+//
+// Move to the next line
+//
+            line            += linelen + 1;
+            prevlineheights += h + overh + underh;
         }
-
-        FT_Vector_Transform( &adjust, &FT->matrix ); // was /&matrix); -  was I using the wrong matrix all this time ?
-
-        x -= adjust.x;
-        y += adjust.y;
-
-        FT_WriteStrW( pls, args->unicode_array, args->unicode_array_len, x, y ); // write it out
     }
     else
     {
@@ -1106,7 +1160,7 @@ void plD_render_freetype_text( PLStream *pls, EscText *args )
 void plD_FreeType_Destroy( PLStream *pls )
 {
     FT_Data *FT = (FT_Data *) pls->FT;
-    extern int FT_Done_Library( FT_Library library );
+    //extern int FT_Done_Library( FT_Library library );
 
     if ( FT )
     {
@@ -1176,9 +1230,9 @@ void pl_set_extended_cmap0( PLStream *pls, int ncol0_width, int ncol0_org )
 
         for ( j = 0, k = ncol0_org + i - 1; j < ncol0_width; j++, k += ( ncol0_org - 1 ) )
         {
-            r -= r_inc;
-            g -= g_inc;
-            b -= b_inc;
+            r -= (int) r_inc;
+            g -= (int) g_inc;
+            b -= (int) b_inc;
             if ( ( r < 0 ) || ( g < 0 ) || ( b < 0 ) )
                 plscol0( k, 0, 0, 0 );
             else
@@ -1209,21 +1263,21 @@ void plD_render_freetype_sym( PLStream *pls, EscText *args )
 
     if ( FT->scale != 0.0 )    // scale was set
     {
-        x = args->x / FT->scale;
+        x = (int) ( args->x / FT->scale );
 
         if ( FT->invert_y == 1 )
-            y = FT->ymax - ( args->y / FT->scale );
+            y = (int) ( FT->ymax - ( args->y / FT->scale ) );
         else
-            y = args->y / FT->scale;
+            y = (int) ( args->y / FT->scale );
     }
     else
     {
-        x = args->x / FT->scalex;
+        x = (int) ( args->x / FT->scalex );
 
         if ( FT->invert_y == 1 )
-            y = FT->ymax - ( args->y / FT->scaley );
+            y = (int) ( FT->ymax - ( args->y / FT->scaley ) );
         else
-            y = args->y / FT->scaley;
+            y = (int) ( args->y / FT->scaley );
     }
 
 
@@ -1251,8 +1305,8 @@ void plD_render_freetype_sym( PLStream *pls, EscText *args )
 
     adjust.x = 0;
     FT_Vector_Transform( &adjust, &FT->matrix );
-    x += adjust.x;
-    y -= adjust.y;
+    x += (int) adjust.x;
+    y -= (int) adjust.y;
 
     plgfci( &fci );
     FT_SetFace( pls, fci );
@@ -1270,8 +1324,8 @@ void plD_render_freetype_sym( PLStream *pls, EscText *args )
 // but it is as good a way as I can think of.
 //
 
-    x -= ( FT->face->glyph->advance.x >> 6 ) / 2;
-    FT_PlotChar( pls, FT, FT->face->glyph, x, y, pls->icol0 ); // render the text
+    x -= (int) ( ( FT->face->glyph->advance.x >> 6 ) / 2 );
+    FT_PlotChar( pls, FT, FT->face->glyph, x, y ); // render the text
 }
 
 
