@@ -1,4 +1,4 @@
-// $Id: plgradient.c 11738 2011-05-01 19:14:40Z airwin $
+// $Id: plgradient.c 12095 2011-12-03 08:56:15Z andrewross $
 //
 //      Implement linear gradients for PLplot.
 //
@@ -77,7 +77,7 @@ c_plgradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
     else
     {
       #define NGRAD    2
-        int   i, irot_min, irot_max;
+        int   i, irot_min;
         PLINT _xpoly[PL_MAXPOLY], _ypoly[PL_MAXPOLY];
         PLINT *xpoly, *ypoly;
         PLINT xgrad[NGRAD], ygrad[NGRAD], clpxmi, clpxma, clpymi, clpyma;
@@ -92,7 +92,6 @@ c_plgradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
         xrot_min = xrot;
         xrot_max = xrot;
         irot_min = 0;
-        irot_max = 0;
         for ( i = 1; i < n; i++ )
         {
             xrot = x[i] * cosangle + y[i] * sinangle;
@@ -104,7 +103,6 @@ c_plgradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
             else if ( xrot > xrot_max )
             {
                 xrot_max = xrot;
-                irot_max = i;
             }
         }
         // xrot_min and xrot_max are the minimum and maximum rotated x
@@ -131,8 +129,8 @@ c_plgradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
         npts = n;
         if ( n > PL_MAXPOLY - 1 )
         {
-            xpoly = (PLINT *) malloc( ( n + 1 ) * sizeof ( PLINT ) );
-            ypoly = (PLINT *) malloc( ( n + 1 ) * sizeof ( PLINT ) );
+            xpoly = (PLINT *) malloc( (size_t) ( n + 1 ) * sizeof ( PLINT ) );
+            ypoly = (PLINT *) malloc( (size_t) ( n + 1 ) * sizeof ( PLINT ) );
 
             if ( ( xpoly == NULL ) || ( ypoly == NULL ) )
             {
@@ -195,8 +193,8 @@ plgradient_soft( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
 
     // Define polygon boundary so it is accessible from gradient_defined.
     plsc->n_polygon = n;
-    plsc->x_polygon = (PLFLT *) x;
-    plsc->y_polygon = (PLFLT *) y;
+    plsc->x_polygon = x;
+    plsc->y_polygon = y;
 
     // Find x and y range of polygon.
     xmin = x[0];
@@ -255,7 +253,7 @@ plgradient_soft( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
     for ( i = 0; i < NEDGE; i++ )
         edge[i] = (PLFLT) i / (PLFLT) ( NEDGE - 1 );
 
-    plshades( (const PLFLT **) z, NX, NY, gradient_defined, xmin, xmax, ymin, ymax,
+    plshades( (const PLFLT * const *) z, NX, NY, gradient_defined, xmin, xmax, ymin, ymax,
         edge, NEDGE, 0, 0, 0, plfill, 1, NULL, NULL );
     free( (void *) edge );
     plFree2dGrid( z, NX, NY );
