@@ -1,6 +1,6 @@
 //
 // plgridd.c: Plot grids data from irregularly sampled data.
-// $Id: plgridd.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: plgridd.c 11973 2011-10-17 21:16:39Z andrewross $
 //
 // Copyright (C) 2004  Joao Cardoso
 // Copyright (C) 2004  Alan W. Irwin
@@ -62,7 +62,7 @@ grid_csa( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
 static void
 grid_nni( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
           const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy,
-          PLF2OPS zops, PLPointer zgp, PLFLT wmin );
+          PLF2OPS zops, PLPointer zgp, PLFLT wtmin );
 
 static void
 grid_dtli( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
@@ -214,19 +214,19 @@ grid_csa( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
           const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy,
           PLF2OPS zops, PLPointer zgp )
 {
-    PLFLT *xt, *yt, *zt;
-    point *pin, *pgrid, *pt;
-    csa   * a = NULL;
-    int   i, j, nptsg;
+    const PLFLT *xt, *yt, *zt;
+    point       *pin, *pgrid, *pt;
+    csa         * a = NULL;
+    int         i, j, nptsg;
 
-    if ( ( pin = (point *) malloc( npts * sizeof ( point ) ) ) == NULL )
+    if ( ( pin = (point *) malloc( (size_t) npts * sizeof ( point ) ) ) == NULL )
     {
         plexit( "grid_csa: Insufficient memory" );
     }
 
-    xt = (PLFLT *) x;
-    yt = (PLFLT *) y;
-    zt = (PLFLT *) z;
+    xt = x;
+    yt = y;
+    zt = z;
     pt = pin;
     for ( i = 0; i < npts; i++ )
     {
@@ -237,16 +237,16 @@ grid_csa( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
     }
 
     nptsg = nptsx * nptsy;
-    if ( ( pgrid = (point *) malloc( nptsg * sizeof ( point ) ) ) == NULL )
+    if ( ( pgrid = (point *) malloc( (size_t) nptsg * sizeof ( point ) ) ) == NULL )
     {
         plexit( "grid_csa: Insufficient memory" );
     }
 
-    yt = (PLFLT *) yg;
+    yt = yg;
     pt = pgrid;
     for ( j = 0; j < nptsy; j++ )
     {
-        xt = (PLFLT *) xg;
+        xt = xg;
         for ( i = 0; i < nptsx; i++ )
         {
             pt->x = (double) *xt++;
@@ -573,9 +573,9 @@ static void
 grid_dtli( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
            const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp )
 {
-    point *pin, *pgrid, *pt;
-    PLFLT *xt, *yt, *zt;
-    int   i, j, nptsg;
+    point       *pin, *pgrid, *pt;
+    const PLFLT *xt, *yt, *zt;
+    int         i, j, nptsg;
 
     if ( sizeof ( realT ) != sizeof ( double ) )
     {
@@ -583,14 +583,14 @@ grid_dtli( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
         return;
     }
 
-    if ( ( pin = (point *) malloc( npts * sizeof ( point ) ) ) == NULL )
+    if ( ( pin = (point *) malloc( (size_t) npts * sizeof ( point ) ) ) == NULL )
     {
         plexit( "grid_dtli: Insufficient memory" );
     }
 
-    xt = (PLFLT *) x;
-    yt = (PLFLT *) y;
-    zt = (PLFLT *) z;
+    xt = x;
+    yt = y;
+    zt = z;
     pt = pin;
     for ( i = 0; i < npts; i++ )
     {
@@ -602,16 +602,16 @@ grid_dtli( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
 
     nptsg = nptsx * nptsy;
 
-    if ( ( pgrid = (point *) malloc( nptsg * sizeof ( point ) ) ) == NULL )
+    if ( ( pgrid = (point *) malloc( (size_t) nptsg * sizeof ( point ) ) ) == NULL )
     {
         plexit( "grid_dtli: Insufficient memory" );
     }
 
-    yt = (PLFLT *) yg;
+    yt = yg;
     pt = pgrid;
     for ( j = 0; j < nptsy; j++ )
     {
-        xt = (PLFLT *) xg;
+        xt = xg;
         for ( i = 0; i < nptsx; i++ )
         {
             pt->x = (double) *xt++;
@@ -645,11 +645,11 @@ grid_dtli( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
 static void
 grid_nni( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
           const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp,
-          PLFLT wmin )
+          PLFLT wtmin )
 {
-    PLFLT *xt, *yt, *zt;
-    point *pin, *pgrid, *pt;
-    int   i, j, nptsg;
+    const PLFLT *xt, *yt, *zt;
+    point       *pin, *pgrid, *pt;
+    int         i, j, nptsg;
     nn_rule = NON_SIBSONIAN;
 
     if ( sizeof ( realT ) != sizeof ( double ) )
@@ -658,20 +658,20 @@ grid_nni( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
         return;
     }
 
-    if ( wmin == 0. ) // only accept weights greater than wmin
+    if ( wtmin == 0. ) // only accept weights greater than wtmin
     {
-        plwarn( "plgriddata(): GRID_NNI: wmin must be specified with 'data' arg. Using -PLFLT_MAX" );
-        wmin = -PLFLT_MAX;
+        plwarn( "plgriddata(): GRID_NNI: wtmin must be specified with 'data' arg. Using -PLFLT_MAX" );
+        wtmin = -PLFLT_MAX;
     }
 
-    if ( ( pin = (point *) malloc( npts * sizeof ( point ) ) ) == NULL )
+    if ( ( pin = (point *) malloc( (size_t) npts * sizeof ( point ) ) ) == NULL )
     {
         plexit( "plgridata: Insufficient memory" );
     }
 
-    xt = (PLFLT *) x;
-    yt = (PLFLT *) y;
-    zt = (PLFLT *) z;
+    xt = x;
+    yt = y;
+    zt = z;
     pt = pin;
     for ( i = 0; i < npts; i++ )
     {
@@ -683,16 +683,16 @@ grid_nni( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
 
     nptsg = nptsx * nptsy;
 
-    if ( ( pgrid = (point *) malloc( nptsg * sizeof ( point ) ) ) == NULL )
+    if ( ( pgrid = (point *) malloc( (size_t) nptsg * sizeof ( point ) ) ) == NULL )
     {
         plexit( "plgridata: Insufficient memory" );
     }
 
-    yt = (PLFLT *) yg;
+    yt = yg;
     pt = pgrid;
     for ( j = 0; j < nptsy; j++ )
     {
-        xt = (PLFLT *) xg;
+        xt = xg;
         for ( i = 0; i < nptsx; i++ )
         {
             pt->x = (double) *xt++;
@@ -702,7 +702,7 @@ grid_nni( const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts,
         yt++;
     }
 
-    nnpi_interpolate_points( npts, pin, wmin, nptsg, pgrid );
+    nnpi_interpolate_points( npts, pin, wtmin, nptsg, pgrid );
     for ( i = 0; i < nptsx; i++ )
     {
         for ( j = 0; j < nptsy; j++ )
