@@ -56,23 +56,26 @@ RestoreWrite2BufferPixmap()
     plP_esc( PLESC_IMAGEOPS, &op );
 }
 
-void
-disabledisplay()
-{
-    PLINT op = ZEROW2D;
-
-    plP_esc( PLESC_IMAGEOPS, &op );
-}
-
-void
-enabledisplay()
-{
-    PLINT op = ONEW2D;
-
-    plP_esc( PLESC_IMAGEOPS, &op );
-    plP_esc( PLESC_EXPOSE, NULL );
-}
-
+//
+// Unused functions - comment out
+//
+//void
+//disabledisplay()
+//{
+//    PLINT op = ZEROW2D;
+//
+//    plP_esc( PLESC_IMAGEOPS, &op );
+//}
+//
+//void
+//enabledisplay()
+//{
+//    PLINT op = ONEW2D;
+//
+//    plP_esc( PLESC_IMAGEOPS, &op );
+//    plP_esc( PLESC_EXPOSE, NULL );
+//}
+//
 
 
 //
@@ -188,7 +191,7 @@ grimage( short *x, short *y, unsigned short *z, PLINT nx, PLINT ny )
 //
 //--------------------------------------------------------------------------
 void
-c_plimagefr( const PLFLT **idata, PLINT nx, PLINT ny,
+c_plimagefr( const PLFLT * const *idata, PLINT nx, PLINT ny,
              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
              PLFLT valuemin, PLFLT valuemax,
              void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
@@ -230,7 +233,7 @@ plfimagefr( PLF2OPS idataops, PLPointer idatap, PLINT nx, PLINT ny,
         return;
     }
 
-    if ( ( z = (PLFLT *) malloc( ny * nx * sizeof ( PLFLT ) ) ) == NULL )
+    if ( ( z = (PLFLT *) malloc( (size_t) ( ny * nx ) * sizeof ( PLFLT ) ) ) == NULL )
     {
         plexit( "plimagefr: Insufficient memory" );
     }
@@ -327,7 +330,7 @@ plfimagefr( PLF2OPS idataops, PLPointer idatap, PLINT nx, PLINT ny,
 //
 //--------------------------------------------------------------------------
 void
-c_plimage( const PLFLT **idata, PLINT nx, PLINT ny,
+c_plimage( const PLFLT * const *idata, PLINT nx, PLINT ny,
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
            PLFLT Dxmin, PLFLT Dxmax, PLFLT Dymin, PLFLT Dymax )
 {
