@@ -1,4 +1,4 @@
-// $Id: plot3d.c 11760 2011-06-01 19:29:11Z airwin $
+// $Id: plot3d.c 12962 2014-01-27 08:07:41Z airwin $
 //
 //! @file
 //!
@@ -34,8 +34,8 @@
 static PLINT pl3mode = 0;       // 0 3d solid; 1 mesh plot
 static PLINT pl3upv  = 1;       // 1 update view; 0 no update
 
-static PLINT zbflg = 0, zbcol, zbwidth;
-static PLFLT zbtck;
+static PLINT zbflg = 0, zbcol;
+static PLFLT zbtck, zbwidth;
 
 static PLINT *oldhiview = NULL;
 static PLINT *oldloview = NULL;
@@ -57,9 +57,9 @@ static PLFLT fc_minz, fc_maxz;
 
 static void plgrid3( PLFLT );
 static void plnxtv( PLINT *, PLINT *, PLFLT*, PLINT, PLINT );
-static void plside3( PLFLT *, PLFLT *, PLF2OPS, PLPointer, PLINT, PLINT, PLINT );
+static void plside3( const PLFLT *, const PLFLT *, PLF2OPS, PLPointer, PLINT, PLINT, PLINT );
 static void plt3zz( PLINT, PLINT, PLINT, PLINT,
-                    PLINT, PLINT *, PLFLT *, PLFLT *, PLF2OPS, PLPointer,
+                    PLINT, PLINT *, const PLFLT *, const PLFLT *, PLF2OPS, PLPointer,
                     PLINT, PLINT, PLINT *, PLINT *, PLFLT* );
 static void plnxtvhi( PLINT *, PLINT *, PLFLT*, PLINT, PLINT );
 static void plnxtvlo( PLINT *, PLINT *, PLFLT*, PLINT, PLINT );
@@ -69,18 +69,18 @@ static void savehipoint( PLINT, PLINT );
 static void savelopoint( PLINT, PLINT );
 static void swaphiview( void );
 static void swaploview( void );
-static void myexit( char * );
-static void myabort( char * );
+static void myexit( const char * );
+static void myabort( const char * );
 static void freework( void );
 static int  plabv( PLINT, PLINT, PLINT, PLINT, PLINT, PLINT );
 static void pl3cut( PLINT, PLINT, PLINT, PLINT, PLINT,
                     PLINT, PLINT, PLINT, PLINT *, PLINT * );
 static PLFLT plGetAngleToLight( PLFLT* x, PLFLT* y, PLFLT* z );
 static void plP_draw3d( PLINT x, PLINT y, PLFLT *c, PLINT j, PLINT move );
-static void plxyindexlimits( PLINT instart, PLINT inn,
-                             PLINT *inarray_min, PLINT *inarray_max,
-                             PLINT *outstart, PLINT *outn, PLINT outnmax,
-                             PLINT *outarray_min, PLINT *outarray_max );
+//static void plxyindexlimits( PLINT instart, PLINT inn,
+//                             PLINT *inarray_min, PLINT *inarray_max,
+//                             PLINT *outstart, PLINT *outn, PLINT outnmax,
+//                             PLINT *outarray_min, PLINT *outarray_max );
 
 
 // #define MJL_HACK 1
@@ -115,7 +115,7 @@ c_pllightsource( PLFLT x, PLFLT y, PLFLT z )
 //--------------------------------------------------------------------------
 
 void
-c_plmesh( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny, PLINT opt )
+c_plmesh( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny, PLINT opt )
 {
     plfplot3dc( x, y, plf2ops_c(), (PLPointer) z, nx, ny, opt | MESH, NULL, 0 );
 }
@@ -147,7 +147,7 @@ plfmesh( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 //--------------------------------------------------------------------------
 
 void
-c_plmeshc( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny, PLINT opt,
+c_plmeshc( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny, PLINT opt,
            const PLFLT *clevel, PLINT nlevel )
 {
     plfplot3dc( x, y, plf2ops_c(), (PLPointer) z, nx, ny, opt | MESH, clevel, nlevel );
@@ -167,14 +167,14 @@ plP_clip_poly( int Ni, PLFLT *Vi[3], int axis, PLFLT dir, PLFLT offset )
 {
     int   anyout = 0;
     PLFLT _in[PL_MAXPOLY], _T[3][PL_MAXPOLY];
-    PLFLT *in, *T[3], *TT;
+    PLFLT *in, *T[3], *TT = NULL;
     int   No = 0;
     int   i, j, k;
 
     if ( Ni > PL_MAXPOLY )
     {
-        in = (PLFLT *) malloc( sizeof ( PLFLT ) * Ni );
-        TT = (PLFLT *) malloc( 3 * sizeof ( PLFLT ) * Ni );
+        in = (PLFLT *) malloc( sizeof ( PLFLT ) * (size_t) Ni );
+        TT = (PLFLT *) malloc( 3 * sizeof ( PLFLT ) * (size_t) Ni );
 
         if ( in == NULL || TT == NULL )
         {
@@ -297,8 +297,8 @@ shade_triangle( PLFLT x0, PLFLT y0, PLFLT z0,
 
         for ( i = 0; i < n; i++ )
         {
-            u[i] = plP_wcpcx( plP_w3wcx( x[i], y[i], z[i] ) );
-            v[i] = plP_wcpcy( plP_w3wcy( x[i], y[i], z[i] ) );
+            u[i] = (short) plP_wcpcx( plP_w3wcx( x[i], y[i], z[i] ) );
+            v[i] = (short) plP_wcpcy( plP_w3wcy( x[i], y[i], z[i] ) );
         }
         u[n] = u[0];
         v[n] = v[0];
@@ -323,7 +323,7 @@ shade_triangle( PLFLT x0, PLFLT y0, PLFLT z0,
 //--------------------------------------------------------------------------
 
 void
-c_plsurf3d( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny,
+c_plsurf3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny,
             PLINT opt, const PLFLT *clevel, PLINT nlevel )
 {
     plfsurf3d( x, y, plf2ops_c(), (PLPointer) z, nx, ny,
@@ -335,8 +335,8 @@ plfsurf3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
            PLINT nx, PLINT ny, PLINT opt, const PLFLT *clevel, PLINT nlevel )
 {
     PLINT i;
-    PLINT *indexymin = (PLINT *) malloc( (size_t) ( nx * sizeof ( PLINT ) ) );
-    PLINT *indexymax = (PLINT *) malloc( (size_t) ( nx * sizeof ( PLINT ) ) );
+    PLINT *indexymin = (PLINT *) malloc( (size_t) nx * sizeof ( PLINT ) );
+    PLINT *indexymax = (PLINT *) malloc( (size_t) nx * sizeof ( PLINT ) );
 
     if ( !indexymin || !indexymax )
         plexit( "plsurf3d: Out of memory." );
@@ -353,7 +353,7 @@ plfsurf3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 
 //--------------------------------------------------------------------------
 // void plsurf3dl(x, y, z, nx, ny, opt, clevel, nlevel,
-// ixstart, ixn, indexymin, indexymax)
+// indexxmin, indexxmax, indexymin, indexymax)
 //
 // Plots the 3-d surface representation of the function z[x][y].
 // The x values are stored as x[0..nx-1], the y values as y[0..ny-1],
@@ -374,7 +374,7 @@ plfsurf3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 //
 // indexymin and indexymax are arrays which specify the y index range
 // (following the convention that the upper range limit is one more than
-// actual index limit) for an x index range of ixstart, ixn.
+// actual index limit) for an x index range of indexxmin, indexxmax.
 // This code is a complete departure from the approach taken in the old version
 // of this routine. Formerly to code attempted to use the logic for the hidden
 // line algorithm to draw the hidden surface. This was really hard. This code
@@ -386,18 +386,18 @@ plfsurf3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 //--------------------------------------------------------------------------
 
 void
-c_plsurf3dl( const PLFLT *x, const PLFLT *y, const PLFLT **z, PLINT nx, PLINT ny,
+c_plsurf3dl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z, PLINT nx, PLINT ny,
              PLINT opt, const PLFLT *clevel, PLINT nlevel,
-             PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax )
+             PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax )
 {
     plfsurf3dl( x, y, plf2ops_c(), (PLPointer) z, nx, ny,
-        opt, clevel, nlevel, ixstart, ixn, indexymin, indexymax );
+        opt, clevel, nlevel, indexxmin, indexxmax, indexymin, indexymax );
 }
 
 void
 plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
             PLINT opt, const PLFLT *clevel, PLINT nlevel,
-            PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax )
+            PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax )
 {
     PLFLT      cxx, cxy, cyx, cyy, cyz;
     PLINT      i, j, k;
@@ -412,7 +412,8 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
     CONT_LEVEL *cont, *clev;
     CONT_LINE  *cline;
     int        ct, ix, iy, iftriangle;
-    PLINT      color = plsc->icol0, width = plsc->width;
+    PLINT      color = plsc->icol0;
+    PLFLT      width = plsc->width;
     PLFLT      ( *getz )( PLPointer, PLINT, PLINT ) = zops->get;
 
     if ( plsc->level < 3 )
@@ -553,7 +554,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
         bx[2] = ( ixOrigin != ixmin && ixSlow == 0 ) || ixSlow > 0 ? xmax : xmin;
         by[2] = ( iyOrigin != iymin && iySlow == 0 ) || iySlow > 0 ? ymax : ymin;
 
-        plwid( zbwidth );
+        plwidth( zbwidth );
         plcol0( zbcol );
         for ( tp = tick * floor( zmin / tick ) + tick; tp <= zmax; tp += tick )
         {
@@ -565,7 +566,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
         by[0] = by[1];
         bz[0] = zmin;
         plline3( 2, bx, by, bz );
-        plwid( width );
+        plwidth( width );
         plcol0( color );
     }
 
@@ -582,8 +583,8 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
         int      np = NPTS;
         PLFLT    **zstore;
         PLcGrid2 cgrid2;
-        PLFLT    *zz = (PLFLT *) malloc( NPTS * sizeof ( PLFLT ) );
-        if ( zz == NULL )
+        PLFLT    *zzloc = (PLFLT *) malloc( (size_t) NPTS * sizeof ( PLFLT ) );
+        if ( zzloc == NULL )
             plexit( "plsurf3dl: Insufficient memory" );
 
         // get the contour lines
@@ -595,7 +596,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
         plAlloc2dGrid( &cgrid2.yg, nx, ny );
         plAlloc2dGrid( &zstore, nx, ny );
 
-        for ( i = ixstart; i < ixn; i++ )
+        for ( i = indexxmin; i < indexxmax; i++ )
         {
             for ( j = 0; j < indexymin[i]; j++ )
             {
@@ -617,7 +618,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
             }
         }
         // Fill cont structure with contours.
-        cont_store( (const PLFLT **) zstore, nx, ny, ixstart + 1, ixn, 1, ny,
+        cont_store( (const PLFLT * const *) zstore, nx, ny, indexxmin + 1, indexxmax, 1, ny,
             clevel, nlevel, pltr2, (void *) &cgrid2, &cont );
 
         // Free the 2D input arrays to cont_store since not needed any more.
@@ -635,17 +636,17 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
                 if ( cline->npts > np )
                 {
                     np = cline->npts;
-                    if ( ( zz = (PLFLT *) realloc( zz, np * sizeof ( PLFLT ) ) ) == NULL )
+                    if ( ( zzloc = (PLFLT *) realloc( zzloc, (size_t) np * sizeof ( PLFLT ) ) ) == NULL )
                     {
                         plexit( "plsurf3dl: Insufficient memory" );
                     }
                 }
                 for ( j = 0; j < cline->npts; j++ )
-                    zz[j] = plsc->ranmi;
+                    zzloc[j] = plsc->ranmi;
                 if ( cline->npts > 0 )
                 {
                     plcol1( ( clev->level - fc_minz ) / ( fc_maxz - fc_minz ) );
-                    plline3( cline->npts, cline->x, cline->y, zz );
+                    plline3( cline->npts, cline->x, cline->y, zzloc );
                 }
                 cline = cline->next;
             }
@@ -655,7 +656,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
         while ( clev != NULL );
 
         cont_clean_store( cont ); // now release the memory
-        free( zz );
+        free( zzloc );
     }
 
     // Now we can iterate over the grid drawing the quads
@@ -682,7 +683,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
                     ix = ixFast * ( iFast + i ) + ixSlow * ( iSlow + j ) + ixOrigin;
                     iy = iyFast * ( iFast + i ) + iySlow * ( iSlow + j ) + iyOrigin;
 
-                    if ( ixstart <= ix && ix < ixn &&
+                    if ( indexxmin <= ix && ix < indexxmax &&
                          indexymin[ix] <= iy && iy < indexymax[ix] )
                     {
                         xm += px[2 * i + j] = x[ix];
@@ -777,13 +778,11 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
     {
         plcol0( 0 );
         plfplot3dcl( x, y, zops, zp, nx, ny, MESH | DRAW_LINEXY, NULL, 0,
-            ixstart, ixn, indexymin, indexymax );
+            indexxmin, indexxmax, indexymin, indexymax );
     }
 
     if ( opt & DRAW_SIDES ) // the sides look ugly !!!
     {                       // draw one more row with all the Z's set to zmin
-        PLFLT zscale, zmin, zmax;
-
         plP_grange( &zscale, &zmin, &zmax );
 
         iSlow      = nSlow - 1;
@@ -794,7 +793,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
             {
                 ix = ixFast * ( iFast + i ) + ixSlow * iSlow + ixOrigin;
                 iy = iyFast * ( iFast + i ) + iySlow * iSlow + iyOrigin;
-                if ( ixstart <= ix && ix < ixn &&
+                if ( indexxmin <= ix && ix < indexxmax &&
                      indexymin[ix] <= iy && iy < indexymax[ix] )
                 {
                     px[2 * i] = x[ix];
@@ -823,7 +822,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
             {
                 ix = ixFast * iFast + ixSlow * ( iSlow + i ) + ixOrigin;
                 iy = iyFast * iFast + iySlow * ( iSlow + i ) + iyOrigin;
-                if ( ixstart <= ix && ix < ixn &&
+                if ( indexxmin <= ix && ix < indexxmax &&
                      indexymin[ix] <= iy && iy < indexymax[ix] )
                 {
                     px[2 * i] = x[ix];
@@ -856,7 +855,7 @@ plfsurf3dl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx
 //--------------------------------------------------------------------------
 
 void
-c_plot3d( const PLFLT *x, const PLFLT *y, const PLFLT **z,
+c_plot3d( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
           PLINT nx, PLINT ny, PLINT opt, PLBOOL side )
 {
     plfplot3dc( x, y, plf2ops_c(), (PLPointer) z, nx, ny, opt | ( side != 0 ? DRAW_SIDES : 0 ), NULL, 0 );
@@ -879,7 +878,7 @@ plfplot3d( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 //--------------------------------------------------------------------------
 
 void
-c_plot3dc( const PLFLT *x, const PLFLT *y, const PLFLT **z,
+c_plot3dc( const PLFLT *x, const PLFLT *y, const PLFLT * const*z,
            PLINT nx, PLINT ny, PLINT opt,
            const PLFLT *clevel, PLINT nlevel )
 {
@@ -895,7 +894,7 @@ plfplot3dc( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 
 //--------------------------------------------------------------------------
 // void plot3dcl(x, y, z, nx, ny, opt, clevel, nlevel,
-//       ixstart, ixn, indexymin, indexymax)
+//       indexxmin, indexxmax, indexymin, indexymax)
 //
 // Plots a 3-d representation of the function z[x][y]. The x values
 // are stored as x[0..nx-1], the y values as y[0..ny-1], and the z
@@ -913,17 +912,17 @@ plfplot3dc( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // or any bitwise combination, e.g. "MAG_COLOR | DRAW_LINEX"
 // indexymin and indexymax are arrays which specify the y index limits
 // (following the convention that the upper range limit is one more than
-// actual index limit) for an x index range of ixstart, ixn.
+// actual index limit) for an x index range of indexxmin, indexxmax.
 //--------------------------------------------------------------------------
 
 void
-c_plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT **z,
+c_plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
             PLINT nx, PLINT ny, PLINT opt,
             const PLFLT *clevel, PLINT nlevel,
-            PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax )
+            PLINT indexxmin, PLINT indexxmax, const PLINT *indexymin, const PLINT *indexymax )
 {
     plfplot3dcl( x, y, plf2ops_c(), (PLPointer) z, nx, ny,
-        opt, clevel, nlevel, ixstart, ixn, indexymin, indexymax );
+        opt, clevel, nlevel, indexxmin, indexxmax, indexymin, indexymax );
 }
 
 //--------------------------------------------------------------------------
@@ -958,29 +957,29 @@ c_plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT **z,
 //! or any bitwise OR'd combination, e.g. "MAG_COLOR | DRAW_LINEX"
 //! @param clevel z values at which to draw contours
 //! @param nlevel Number of values in clevels
-//! @param ixstart Index of first x coordinate to include in plot
-//! @param ixn Number of x coordinates to include in plot
-//! @param indexymin Array which specifies the min y index for each x
-//! index in range ixstart, ixn.
-//! @param indexymax Array which specifies the max y index for each x
-//! coordinate (following the convention that the upper range limit is one more
-//! than actual index limit) for an x index range of ixstart, ixn.
+//! @param PL_UNUSED( indexxmin ) Not used.
+//! @param PL_UNUSED( indexxmax ) Not used.
+//! @param PL_UNUSED( indexymin ) Not used.
+//! @param PL_UNUSED( indexymax ) Not used.
+//!
 //--------------------------------------------------------------------------
 
 void
 plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
              PLINT nx, PLINT ny, PLINT opt,
              const PLFLT *clevel, PLINT nlevel,
-             PLINT ixstart, PLINT ixn, const PLINT *indexymin, const PLINT *indexymax )
+             PLINT PL_UNUSED( indexxmin ), PLINT PL_UNUSED( indexxmax ), const PLINT * PL_UNUSED( indexymin ), const PLINT * PL_UNUSED( indexymax ) )
 {
     PLFLT cxx, cxy, cyx, cyy, cyz;
-    PLINT init, i, ix, iy, color, width;
+    PLINT init, ix, iy, color;
+    PLFLT width;
     PLFLT xmin, xmax, ymin, ymax, zmin, zmax, zscale;
     PLINT ixmin   = 0, ixmax = nx - 1, iymin = 0, iymax = ny - 1;
     PLINT clipped = 0, base_cont = 0, side = 0;
     PLFLT ( *getz )( PLPointer, PLINT, PLINT ) = zops->get;
-    PLFLT *_x, *_y, **_z;
-    PLFLT *x_modified, *y_modified;
+    PLFLT *_x = NULL, *_y = NULL, **_z = NULL;
+    const PLFLT *x_modified, *y_modified;
+    int i;
 
     pl3mode = 0;
 
@@ -1065,7 +1064,7 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
         int _nx = ixmax - ixmin + 1;
         int _ny = iymax - iymin + 1;
         PLFLT ty0, ty1, tx0, tx1;
-        int i, j;
+        int j;
 
         if ( _nx <= 1 || _ny <= 1 )
         {
@@ -1074,9 +1073,9 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
         }
 
         // allocate storage for new versions of the input vectors
-        if ( ( ( _x = (PLFLT *) malloc( _nx * sizeof ( PLFLT ) ) ) == NULL ) ||
-             ( ( _y = (PLFLT *) malloc( _ny * sizeof ( PLFLT ) ) ) == NULL ) ||
-             ( ( _z = (PLFLT **) malloc( _nx * sizeof ( PLFLT* ) ) ) == NULL ) )
+        if ( ( ( _x = (PLFLT *) malloc( (size_t) _nx * sizeof ( PLFLT ) ) ) == NULL ) ||
+             ( ( _y = (PLFLT *) malloc( (size_t) _ny * sizeof ( PLFLT ) ) ) == NULL ) ||
+             ( ( _z = (PLFLT **) malloc( (size_t) _nx * sizeof ( PLFLT* ) ) ) == NULL ) )
         {
             plexit( "c_plot3dcl: Insufficient memory" );
         }
@@ -1096,7 +1095,7 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
         // copy the data array so we can interpolate around the edges
         for ( i = 0; i < _nx; i++ )
         {
-            if ( ( _z[i] = (PLFLT *) malloc( _ny * sizeof ( PLFLT ) ) ) == NULL )
+            if ( ( _z[i] = (PLFLT *) malloc( (size_t) _ny * sizeof ( PLFLT ) ) ) == NULL )
             {
                 plexit( "c_plot3dcl: Insufficient memory" );
             }
@@ -1148,13 +1147,13 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
         nx   = _nx;
         ny   = _ny;
         // Do not want to modify input x and y (const modifier)
-        x_modified = _x;
-        y_modified = _y;
+        x_modified = (const PLFLT *) _x;
+        y_modified = (const PLFLT *) _y;
     }
     else
     {
-        x_modified = (PLFLT *) x;
-        y_modified = (PLFLT *) y;
+        x_modified = x;
+        y_modified = y;
     }
 
     // From here on must use x_modified and y_modified rather than
@@ -1191,7 +1190,7 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 
     if ( opt & MAG_COLOR )    // If enabled, use magnitude colored wireframe
     {
-        if ( ( ctmp = (PLFLT *) malloc( (size_t) ( 2 * MAX( nx, ny ) * sizeof ( PLFLT ) ) ) ) == NULL )
+        if ( ( ctmp = (PLFLT *) malloc( (size_t) ( 2 * MAX( nx, ny ) ) * sizeof ( PLFLT ) ) ) == NULL )
         {
             plexit( "c_plot3dcl: Insufficient memory" );
         }
@@ -1204,8 +1203,8 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 
     // Allocate work arrays
 
-    utmp = (PLINT *) malloc( (size_t) ( 2 * MAX( nx, ny ) * sizeof ( PLINT ) ) );
-    vtmp = (PLINT *) malloc( (size_t) ( 2 * MAX( nx, ny ) * sizeof ( PLINT ) ) );
+    utmp = (PLINT *) malloc( (size_t) ( 2 * MAX( nx, ny ) ) * sizeof ( PLINT ) );
+    vtmp = (PLINT *) malloc( (size_t) ( 2 * MAX( nx, ny ) ) * sizeof ( PLINT ) );
 
     if ( !utmp || !vtmp )
         myexit( "plot3dcl: Out of memory." );
@@ -1294,8 +1293,8 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
         CONT_LEVEL *cont, *clev;
         CONT_LINE *cline;
 
-        PLINT *uu = (PLINT *) malloc( NPTS * sizeof ( PLINT ) );
-        PLINT *vv = (PLINT *) malloc( NPTS * sizeof ( PLINT ) );
+        PLINT *uu = (PLINT *) malloc( (size_t) NPTS * sizeof ( PLINT ) );
+        PLINT *vv = (PLINT *) malloc( (size_t) NPTS * sizeof ( PLINT ) );
         // prepare cont_store input
         PLFLT **zstore;
         PLcGrid2 cgrid2;
@@ -1324,7 +1323,7 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
         pl3upv = 0;
 
         // Fill cont structure with contours.
-        cont_store( (const PLFLT **) zstore, nx, ny, 1, nx, 1, ny,
+        cont_store( (const PLFLT * const *) zstore, nx, ny, 1, nx, 1, ny,
             clevel, nlevel, pltr2, (void *) &cgrid2, &cont );
 
         // Free the 2D input arrays to cont_store since not needed any more.
@@ -1339,13 +1338,13 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
             cline = clev->line;
             do  // there are several lines that make up each contour
             {
-                int cx, i, k, l, m, start, end;
+                int cx, k, l, m, start, end;
                 PLFLT tx, ty;
                 if ( cline->npts > np )
                 {
                     np = cline->npts;
-                    if ( ( ( uu = (PLINT *) realloc( uu, np * sizeof ( PLINT ) ) ) == NULL ) ||
-                         ( ( vv = (PLINT *) realloc( vv, np * sizeof ( PLINT ) ) ) == NULL ) )
+                    if ( ( ( uu = (PLINT *) realloc( uu, (size_t) np * sizeof ( PLINT ) ) ) == NULL ) ||
+                         ( ( vv = (PLINT *) realloc( vv, (size_t) np * sizeof ( PLINT ) ) ) == NULL ) )
                     {
                         plexit( "c_plot3dcl: Insufficient memory" );
                     }
@@ -1433,10 +1432,10 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
     {
         color = plsc->icol0;
         width = plsc->width;
-        plwid( zbwidth );
+        plwidth( zbwidth );
         plcol0( zbcol );
         plgrid3( zbtck );
-        plwid( width );
+        plwidth( width );
         plcol0( color );
     }
 
@@ -1471,74 +1470,74 @@ plfplot3dcl( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp,
 // inarray_min array has a maximum or inarray_max array has a minimum.
 //--------------------------------------------------------------------------
 
-static void
-plxyindexlimits( PLINT instart, PLINT inn,
-                 PLINT *inarray_min, PLINT *inarray_max,
-                 PLINT *outstart, PLINT *outn, PLINT outnmax,
-                 PLINT *outarray_min, PLINT *outarray_max )
-{
-    PLINT i, j;
-    if ( inn < 0 )
-    {
-        myabort( "plxyindexlimits: Must have instart >= 0" );
-        return;
-    }
-    if ( inn - instart <= 0 )
-    {
-        myabort( "plxyindexlimits: Must have at least 1 defined point" );
-        return;
-    }
-    *outstart = inarray_min[instart];
-    *outn     = inarray_max[instart];
-    for ( i = instart; i < inn; i++ )
-    {
-        *outstart = MIN( *outstart, inarray_min[i] );
-        *outn     = MAX( *outn, inarray_max[i] );
-        if ( i + 2 < inn )
-        {
-            if ( inarray_min[i] < inarray_min[i + 1] &&
-                 inarray_min[i + 1] > inarray_min[i + 2] )
-            {
-                myabort( "plxyindexlimits: inarray_min must not have a maximum" );
-                return;
-            }
-            if ( inarray_max[i] > inarray_max[i + 1] &&
-                 inarray_max[i + 1] < inarray_max[i + 2] )
-            {
-                myabort( "plxyindexlimits: inarray_max must not have a minimum" );
-                return;
-            }
-        }
-    }
-    if ( *outstart < 0 )
-    {
-        myabort( "plxyindexlimits: Must have all elements of inarray_min >= 0" );
-        return;
-    }
-    if ( *outn > outnmax )
-    {
-        myabort( "plxyindexlimits: Must have all elements of inarray_max <= outnmax" );
-        return;
-    }
-    for ( j = *outstart; j < *outn; j++ )
-    {
-        i = instart;
-        // Find first valid i for this j.
-        while ( i < inn && !( inarray_min[i] <= j && j < inarray_max[i] ) )
-            i++;
-        if ( i < inn )
-            outarray_min[j] = i;
-        else
-        {
-            myabort( "plxyindexlimits: bad logic; invalid i should never happen" );
-            return;
-        }
-        // Find next invalid i for this j.
-        while ( i < inn && ( inarray_min[i] <= j && j < inarray_max[i] ) )
-            i++;
-        outarray_max[j] = i;
-    }
-}
+//static void
+//plxyindexlimits( PLINT instart, PLINT inn,
+//                 PLINT *inarray_min, PLINT *inarray_max,
+//                 PLINT *outstart, PLINT *outn, PLINT outnmax,
+//                 PLINT *outarray_min, PLINT *outarray_max )
+//{
+//    PLINT i, j;
+//    if ( inn < 0 )
+//    {
+//        myabort( "plxyindexlimits: Must have instart >= 0" );
+//        return;
+//    }
+//    if ( inn - instart <= 0 )
+//    {
+//        myabort( "plxyindexlimits: Must have at least 1 defined point" );
+//        return;
+//    }
+//    *outstart = inarray_min[instart];
+//    *outn     = inarray_max[instart];
+//    for ( i = instart; i < inn; i++ )
+//    {
+//        *outstart = MIN( *outstart, inarray_min[i] );
+//        *outn     = MAX( *outn, inarray_max[i] );
+//        if ( i + 2 < inn )
+//        {
+//            if ( inarray_min[i] < inarray_min[i + 1] &&
+//                 inarray_min[i + 1] > inarray_min[i + 2] )
+//            {
+//                myabort( "plxyindexlimits: inarray_min must not have a maximum" );
+//                return;
+//            }
+//            if ( inarray_max[i] > inarray_max[i + 1] &&
+//                 inarray_max[i + 1] < inarray_max[i + 2] )
+//            {
+//                myabort( "plxyindexlimits: inarray_max must not have a minimum" );
+//                return;
+//            }
+//        }
+//    }
+//    if ( *outstart < 0 )
+//    {
+//        myabort( "plxyindexlimits: Must have all elements of inarray_min >= 0" );
+//        return;
+//    }
+//    if ( *outn > outnmax )
+//    {
+//        myabort( "plxyindexlimits: Must have all elements of inarray_max <= outnmax" );
+//        return;
+//    }
+//    for ( j = *outstart; j < *outn; j++ )
+//    {
+//        i = instart;
+//        // Find first valid i for this j.
+//        while ( i < inn && !( inarray_min[i] <= j && j < inarray_max[i] ) )
+//            i++;
+//        if ( i < inn )
+//            outarray_min[j] = i;
+//        else
+//        {
+//            myabort( "plxyindexlimits: bad logic; invalid i should never happen" );
+//            return;
+//        }
+//        // Find next invalid i for this j.
+//        while ( i < inn && ( inarray_min[i] <= j && j < inarray_max[i] ) )
+//            i++;
+//        outarray_max[j] = i;
+//    }
+//}
 
 //--------------------------------------------------------------------------
 // void plP_gzback()
@@ -1547,7 +1546,7 @@ plxyindexlimits( PLINT instart, PLINT inn,
 //--------------------------------------------------------------------------
 
 void
-plP_gzback( PLINT **zbf, PLINT **zbc, PLFLT **zbt, PLINT **zbw )
+plP_gzback( PLINT **zbf, PLINT **zbc, PLFLT **zbt, PLFLT **zbw )
 {
     *zbf = &zbflg;
     *zbc = &zbcol;
@@ -1619,7 +1618,7 @@ plGetAngleToLight( PLFLT* x, PLFLT* y, PLFLT* z )
 
 static void
 plt3zz( PLINT x0, PLINT y0, PLINT dx, PLINT dy, PLINT flag, PLINT *init,
-        PLFLT *x, PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
+        const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
         PLINT *u, PLINT *v, PLFLT* c )
 {
     PLINT n = 0;
@@ -1701,7 +1700,7 @@ plt3zz( PLINT x0, PLINT y0, PLINT dx, PLINT dy, PLINT flag, PLINT *init,
 //--------------------------------------------------------------------------
 
 static void
-plside3( PLFLT *x, PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny, PLINT opt )
+plside3( const PLFLT *x, const PLFLT *y, PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny, PLINT opt )
 {
     PLINT i;
     PLFLT cxx, cxy, cyx, cyy, cyz;
@@ -1966,7 +1965,7 @@ plnxtvhi( PLINT *u, PLINT *v, PLFLT* c, PLINT n, PLINT init )
     if ( init == 1 )
     {
         int i;
-        oldhiview = (PLINT *) malloc( (size_t) ( 2 * n * sizeof ( PLINT ) ) );
+        oldhiview = (PLINT *) malloc( (size_t) ( 2 * n ) * sizeof ( PLINT ) );
         if ( !oldhiview )
             myexit( "plnxtvhi: Out of memory." );
 
@@ -2004,12 +2003,12 @@ plnxtvhi( PLINT *u, PLINT *v, PLFLT* c, PLINT n, PLINT init )
         {
             newhiview =
                 (PLINT *) realloc( (void *) newhiview,
-                    (size_t) ( newhisize * sizeof ( PLINT ) ) );
+                    (size_t) newhisize * sizeof ( PLINT ) );
         }
         else
         {
             newhiview =
-                (PLINT *) malloc( (size_t) ( newhisize * sizeof ( PLINT ) ) );
+                (PLINT *) malloc( (size_t) newhisize * sizeof ( PLINT ) );
         }
         if ( !newhiview )
             myexit( "plnxtvhi: Out of memory." );
@@ -2285,7 +2284,7 @@ plnxtvlo( PLINT *u, PLINT *v, PLFLT*c, PLINT n, PLINT init )
     //
     if ( init == 1 )
     {
-        oldloview = (PLINT *) malloc( (size_t) ( 2 * n * sizeof ( PLINT ) ) );
+        oldloview = (PLINT *) malloc( (size_t) ( 2 * n ) * sizeof ( PLINT ) );
         if ( !oldloview )
             myexit( "\nplnxtvlo: Out of memory." );
 
@@ -2325,12 +2324,12 @@ plnxtvlo( PLINT *u, PLINT *v, PLFLT*c, PLINT n, PLINT init )
         {
             newloview =
                 (PLINT *) realloc( (void *) newloview,
-                    (size_t) ( newlosize * sizeof ( PLINT ) ) );
+                    (size_t) newlosize * sizeof ( PLINT ) );
         }
         else
         {
             newloview =
-                (PLINT *) malloc( (size_t) ( newlosize * sizeof ( PLINT ) ) );
+                (PLINT *) malloc( (size_t) newlosize * sizeof ( PLINT ) );
         }
         if ( !newloview )
             myexit( "plnxtvlo: Out of memory." );
@@ -2551,7 +2550,7 @@ savehipoint( PLINT px, PLINT py )
     {
         newhisize += 2 * BINC;
         newhiview  = (PLINT *) realloc( (void *) newhiview,
-            (size_t) ( newhisize * sizeof ( PLINT ) ) );
+            (size_t) newhisize * sizeof ( PLINT ) );
         if ( !newhiview )
             myexit( "savehipoint: Out of memory." );
     }
@@ -2572,7 +2571,7 @@ savelopoint( PLINT px, PLINT py )
     {
         newlosize += 2 * BINC;
         newloview  = (PLINT *) realloc( (void *) newloview,
-            (size_t) ( newlosize * sizeof ( PLINT ) ) );
+            (size_t) newlosize * sizeof ( PLINT ) );
         if ( !newloview )
             myexit( "savelopoint: Out of memory." );
     }
@@ -2644,7 +2643,7 @@ freework( void )
 //--------------------------------------------------------------------------
 
 static void
-myexit( char *msg )
+myexit( const char *msg )
 {
     freework();
     plexit( msg );
@@ -2658,7 +2657,7 @@ myexit( char *msg )
 //--------------------------------------------------------------------------
 
 static void
-myabort( char *msg )
+myabort( const char *msg )
 {
     freework();
     plabort( msg );
