@@ -1,4 +1,4 @@
-// $Id: plsdef.c 11680 2011-03-27 17:57:51Z airwin $
+// $Id: plsdef.c 11973 2011-10-17 21:16:39Z andrewross $
 //
 //      Routines to set various plplot parameters, such as char height,
 //      symbol size, tick length, line and fill patterns, etc.
@@ -191,7 +191,7 @@ static struct pattern
 // Set defining parameters for pattern fill
 
 static void
-spat( PLINT inc[], PLINT del[], PLINT nlin );
+spat( const PLINT inc[], const PLINT del[], PLINT nlin );
 
 //--------------------------------------------------------------------------
 // void plschr()
@@ -307,7 +307,7 @@ c_plpat( PLINT nlin, const PLINT *inc, const PLINT *del )
             return;
         }
     }
-    spat( (PLINT *) inc, (PLINT *) del, nlin );
+    spat( inc, del, nlin );
 }
 
 //--------------------------------------------------------------------------
@@ -353,7 +353,7 @@ c_plpsty( PLINT patt )
 //--------------------------------------------------------------------------
 
 static void
-spat( PLINT inc[], PLINT del[], PLINT nlin )
+spat( const PLINT inc[], const PLINT del[], PLINT nlin )
 {
     PLINT i;
 
