@@ -1,4 +1,4 @@
-// $Id: plshade.c 11759 2011-06-01 17:41:34Z airwin $
+// $Id: plshade.c 12312 2013-05-01 01:11:41Z hezekiahcarty $
 //
 //      Functions to shade regions on the basis of value.
 //      Can be used to shade contour plots or alone.
@@ -30,8 +30,8 @@
 // void plshade(PLFLT *a, PLINT nx, PLINT ny, char *defined,
 //	PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
 //      PLFLT shade_min, PLFLT shade_max,
-//      PLINT sh_color, PLINT sh_width, PLINT min_color, PLINT min_width,
-//      PLINT max_color, PLINT max_width, void (*fill)(), PLINT
+//      PLINT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width,
+//      PLINT max_color, PLFLT max_width, void (*fill)(), PLINT
 //      rectangular, ...)
 //
 // arguments:
@@ -68,11 +68,11 @@
 // Defines the interval to be shaded. If shade_max <= shade_min, plshade
 // does nothing.
 //
-//	PLINT sh_cmap, PLFLT sh_color, PLINT sh_width
+//	PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width
 //
 // Defines color map, color map index, and width used by the fill pattern.
 //
-//      PLINT min_color, min_width, max_color, max_width
+//      PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width
 //
 // Defines pen color, width used by the boundary of shaded region. The min
 // values are used for the shade_min boundary, and the max values are used
@@ -124,10 +124,6 @@
 #include "plplotP.h"
 #include <float.h>
 
-#define MISSING_MIN_DEF      (PLFLT) 1.0
-#define MISSING_MAX_DEF      (PLFLT) -1.0
-
-
 #define NEG                  1
 #define POS                  8
 #define OK                   0
@@ -142,7 +138,7 @@ static PLFLT sh_max, sh_min;
 static int   min_points, max_points, n_point;
 static int   min_pts[4], max_pts[4];
 static PLINT pen_col_min, pen_col_max;
-static PLINT pen_wd_min, pen_wd_max;
+static PLFLT pen_wd_min, pen_wd_max;
 static PLFLT int_val;
 
 // Function prototypes
@@ -183,13 +179,12 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
              PLFLT ( *c2eval )( PLINT, PLINT, PLPointer ),
              PLPointer c2eval_data,
              PLINT ( *defined )( PLFLT, PLFLT ),
-             PLFLT missing_min, PLFLT missing_max,
              PLINT nx, PLINT ny,
              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
              PLFLT shade_min, PLFLT shade_max,
-             PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-             PLINT min_color, PLINT min_width,
-             PLINT max_color, PLINT max_width,
+             PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+             PLINT min_color, PLFLT min_width,
+             PLINT max_color, PLFLT max_width,
              void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
              void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
              PLPointer pltr_data );
@@ -207,15 +202,15 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 // (if cont_color <= 0 or cont_width <=0, no such contours are drawn).
 //--------------------------------------------------------------------------
 
-void c_plshades( const PLFLT **a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+void c_plshades( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                 const PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-                 PLINT cont_color, PLINT cont_width,
+                 const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+                 PLINT cont_color, PLFLT cont_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data )
 {
-    plfshades( plf2ops_c(), a, nx, ny, defined,
+    plfshades( plf2ops_c(), (PLPointer) a, nx, ny, defined,
         xmin, xmax, ymin, ymax,
         clevel, nlevel, fill_width,
         cont_color, cont_width,
@@ -240,15 +235,15 @@ void
 plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
            PLINT ( *defined )( PLFLT, PLFLT ),
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-           const PLFLT *clevel, PLINT nlevel, PLINT fill_width,
-           PLINT cont_color, PLINT cont_width,
+           const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+           PLINT cont_color, PLFLT cont_width,
            void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
            void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
            PLPointer pltr_data )
 {
     PLFLT shade_min, shade_max, shade_color;
-    PLINT i, init_color, init_width;
-    PLFLT color_min, color_max, color_range;
+    PLINT i, init_color;
+    PLFLT init_width, color_min, color_max, color_range;
 
     // Color range to use
     color_min   = plsc->cmap1_min;
@@ -277,7 +272,7 @@ plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
         init_color = plsc->icol0;
         init_width = plsc->width;
         plcol0( cont_color );
-        plwid( cont_width );
+        plwidth( cont_width );
         if ( pltr )
         {
             plfcont( zops->f2eval, zp, nx, ny, 1, nx, 1, ny, clevel, nlevel, pltr, pltr_data );
@@ -293,13 +288,13 @@ plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
             PLFLT   *x, *y;
             cgrid1.nx = nx;
             cgrid1.ny = ny;
-            x         = (PLFLT *) malloc( nx * sizeof ( PLFLT ) );
+            x         = (PLFLT *) malloc( (size_t) nx * sizeof ( PLFLT ) );
             if ( x == NULL )
                 plexit( "plfshades: Out of memory for x" );
             cgrid1.xg = x;
             for ( i = 0; i < nx; i++ )
                 cgrid1.xg[i] = xmin + ( xmax - xmin ) * (float) i / (float) ( nx - 1 );
-            y = (PLFLT *) malloc( ny * sizeof ( PLFLT ) );
+            y = (PLFLT *) malloc( (size_t) ny * sizeof ( PLFLT ) );
             if ( y == NULL )
                 plexit( "plfshades: Out of memory for y" );
             cgrid1.yg = y;
@@ -311,7 +306,7 @@ plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
             free( y );
         }
         plcol0( init_color );
-        plwid( init_width );
+        plwidth( init_width );
     }
 }
 
@@ -323,12 +318,12 @@ plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
 // via a (PLFLT **), and is column-dominant (normal C ordering).
 //--------------------------------------------------------------------------
 
-void c_plshade( const PLFLT **a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+void c_plshade( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
                 PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                 PLFLT shade_min, PLFLT shade_max,
-                PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                PLINT min_color, PLINT min_width,
-                PLINT max_color, PLINT max_width,
+                PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                PLINT min_color, PLFLT min_width,
+                PLINT max_color, PLFLT max_width,
                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                 PLPointer pltr_data )
@@ -336,7 +331,7 @@ void c_plshade( const PLFLT **a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT,
     plshade_int( plf2eval1, (PLPointer) a,
         NULL, NULL,
 //	     plc2eval, (PLPointer) &cgrid,
-        defined, MISSING_MIN_DEF, MISSING_MAX_DEF, nx, ny, xmin,
+        defined, nx, ny, xmin,
         xmax, ymin, ymax, shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
@@ -354,23 +349,23 @@ void c_plshade( const PLFLT **a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT,
 void c_plshade1( const PLFLT *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                  PLFLT shade_min, PLFLT shade_max,
-                 PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-                 PLINT min_color, PLINT min_width,
-                 PLINT max_color, PLINT max_width,
+                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+                 PLINT min_color, PLFLT min_width,
+                 PLINT max_color, PLFLT max_width,
                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
                  PLPointer pltr_data )
 {
     PLfGrid grid;
 
-    grid.f  = (PLFLT *) a;
+    grid.f  = a;
     grid.nx = nx;
     grid.ny = ny;
 
     plshade_int( plf2eval, ( PLPointer ) & grid,
         NULL, NULL,
 //	     plc2eval, (PLPointer) &cgrid,
-        defined, MISSING_MIN_DEF, MISSING_MAX_DEF, nx, ny, xmin,
+        defined, nx, ny, xmin,
         xmax, ymin, ymax, shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
@@ -392,15 +387,15 @@ plfshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
           PLINT nx, PLINT ny,
           PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
           PLFLT shade_min, PLFLT shade_max,
-          PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-          PLINT min_color, PLINT min_width,
-          PLINT max_color, PLINT max_width,
+          PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+          PLINT min_color, PLFLT min_width,
+          PLINT max_color, PLFLT max_width,
           void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data )
 {
     plshade_int( f2eval, f2eval_data, c2eval, c2eval_data,
-        NULL, MISSING_MIN_DEF, MISSING_MAX_DEF,
+        NULL,
         nx, ny, xmin, xmax, ymin, ymax,
         shade_min, shade_max, sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
@@ -423,9 +418,9 @@ plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
            PLINT ( *defined )( PLFLT, PLFLT ),
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
            PLFLT shade_min, PLFLT shade_max,
-           PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-           PLINT min_color, PLINT min_width,
-           PLINT max_color, PLINT max_width,
+           PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+           PLINT min_color, PLFLT min_width,
+           PLINT max_color, PLFLT max_width,
            void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
            void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
            PLPointer pltr_data )
@@ -433,7 +428,7 @@ plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
     plshade_int( zops->f2eval, zp,
         NULL, NULL,
 //	     plc2eval, (PLPointer) &cgrid,
-        defined, MISSING_MIN_DEF, MISSING_MAX_DEF, nx, ny, xmin,
+        defined, nx, ny, xmin,
         xmax, ymin, ymax, shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
@@ -451,19 +446,10 @@ plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
 //
 // 4/95
 //
-// new: missing_min, missing_max
-//
-//     if data <= missing_max and data >= missing_min
-//       then the data will beconsidered to be missing
-//     this allows 2nd way to set undefined points (good for ftn)
-//     if missing feature is not used, set missing_max < missing_min
-//
 // parameters:
 //
 // f2eval, f2eval_data:  data to plot
-// c2eval, c2eval_data:  defined mask (not implimented)
 // defined: defined mask (old API - implimented)
-// missing_min, missing_max: yet another way to set data to undefined
 // nx, ny: array dimensions
 // xmin, xmax, ymin, ymax: grid coordinates
 // shade_min, shade_max: shade region with values between ...
@@ -482,26 +468,27 @@ plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
 static void
 plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
              PLPointer f2eval_data,
-             PLFLT ( *c2eval )( PLINT, PLINT, PLPointer ),
-             PLPointer c2eval_data,
+             PLFLT ( * c2eval )( PLINT, PLINT, PLPointer ), // unused, but macro doesn't work
+             PLPointer PL_UNUSED( c2eval_data ),
              PLINT ( *defined )( PLFLT, PLFLT ),
-             PLFLT missing_min, PLFLT missing_max,
              PLINT nx, PLINT ny,
              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
              PLFLT shade_min, PLFLT shade_max,
-             PLINT sh_cmap, PLFLT sh_color, PLINT sh_width,
-             PLINT min_color, PLINT min_width,
-             PLINT max_color, PLINT max_width,
+             PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+             PLINT min_color, PLFLT min_width,
+             PLINT max_color, PLFLT max_width,
              void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
              void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
              PLPointer pltr_data )
 {
-    PLINT init_width, n, slope = 0, ix, iy;
+    PLINT n, slope = 0, ix, iy;
     int   count, i, j, nxny;
     PLFLT *a, *a0, *a1, dx, dy;
-    PLFLT x[8], y[8], xp[2], tx, ty;
+    PLFLT x[8], y[8], xp[2], tx, ty, init_width;
     int   *c, *c0, *c1;
 
+    (void) c2eval;   // Cast to void to silence compiler warning about unused parameter
+
     if ( plsc->level < 3 )
     {
         plabort( "plfshade: window must be set up first" );
@@ -533,7 +520,7 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
     pen_wd_max = max_width;
 
     plstyl( (PLINT) 0, NULL, NULL );
-    plwid( sh_width );
+    plwidth( sh_width );
     if ( fill != NULL )
     {
         switch ( sh_cmap )
@@ -552,7 +539,7 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
     // alloc space for value array, and initialize
     // This is only a temporary kludge
     nxny = nx * ny;
-    if ( ( a = (PLFLT *) malloc( nxny * sizeof ( PLFLT ) ) ) == NULL )
+    if ( ( a = (PLFLT *) malloc( (size_t) nxny * sizeof ( PLFLT ) ) ) == NULL )
     {
         plabort( "plfshade: unable to allocate memory for value array" );
         return;
@@ -564,7 +551,7 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 
     // alloc space for condition codes
 
-    if ( ( c = (int *) malloc( nxny * sizeof ( int ) ) ) == NULL )
+    if ( ( c = (int *) malloc( (size_t) nxny * sizeof ( int ) ) ) == NULL )
     {
         plabort( "plfshade: unable to allocate memory for condition codes" );
         free( a );
@@ -801,7 +788,7 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 
             if ( fill != NULL )
             {
-                plwid( sh_width );
+                plwidth( sh_width );
                 if ( sh_cmap == 0 )
                     plcol0( (PLINT) sh_color );
                 else if ( sh_cmap == 1 )
@@ -817,7 +804,7 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 
     free( c );
     free( a );
-    plwid( init_width );
+    plwidth( init_width );
 }
 
 //--------------------------------------------------------------------------
@@ -835,6 +822,8 @@ set_cond( register int *cond, register PLFLT *a, register PLINT n )
             *cond++ = NEG;
         else if ( *a > sh_max )
             *cond++ = POS;
+        else if ( isnan( *a ) ) //check for nans and set cond to undefined
+            *cond++ = UNDEF;
         else
             *cond++ = OK;
         a++;
@@ -1007,9 +996,9 @@ exfill( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
 
         // Slightly less than 2 n points are required for xx, yy, but
         // allocate room for 2 n to be safe.
-        if ( ( xx = (PLFLT *) malloc( 2 * n * sizeof ( PLFLT ) ) ) == NULL )
+        if ( ( xx = (PLFLT *) malloc( 2 * (size_t) n * sizeof ( PLFLT ) ) ) == NULL )
             plexit( "exfill: out of memory for xx" );
-        if ( ( yy = (PLFLT *) malloc( 2 * n * sizeof ( PLFLT ) ) ) == NULL )
+        if ( ( yy = (PLFLT *) malloc( 2 * (size_t) n * sizeof ( PLFLT ) ) ) == NULL )
             plexit( "exfill: out of memory for yy." );
 
         for ( i = 0; i < n; i++ )
@@ -1177,7 +1166,7 @@ draw_boundary( PLINT slope, PLFLT *x, PLFLT *y )
     if ( pen_col_min != 0 && pen_wd_min != 0 && min_points != 0 )
     {
         plcol0( pen_col_min );
-        plwid( pen_wd_min );
+        plwidth( pen_wd_min );
         if ( min_points == 4 && slope == 0 )
         {
             // swap points 1 and 3
@@ -1195,7 +1184,7 @@ draw_boundary( PLINT slope, PLFLT *x, PLFLT *y )
     if ( pen_col_max != 0 && pen_wd_max != 0 && max_points != 0 )
     {
         plcol0( pen_col_max );
-        plwid( pen_wd_max );
+        plwidth( pen_wd_max );
         if ( max_points == 4 && slope == 0 )
         {
             // swap points 1 and 3
@@ -1251,7 +1240,7 @@ draw_boundary( PLINT slope, PLFLT *x, PLFLT *y )
 #define RATIO_SQ          6.0
 
 static PLINT
-plctest( PLFLT *x, PLFLT level )
+plctest( PLFLT *x, PLFLT PL_UNUSED( level ) )
 {
     int    i, j;
     double t[4], sorted[4], temp;
