@@ -1,4 +1,4 @@
-// $Id: plstdio.c 11257 2010-10-11 22:34:18Z airwin $
+// $Id: plstdio.c 12831 2013-12-09 14:35:42Z andrewross $
 //
 // Standardized I/O handler for PLplot.
 //
@@ -23,15 +23,16 @@
 //
 //
 
-#define NEED_PLDEBUG
 #include "plplotP.h"
 
 #if defined ( MSDOS ) || defined ( WIN32 )
 #include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
 #endif
 
+// This is needed for mode flags for mkfifo as well sa for MSDOS / WIN32
+#include <sys/stat.h>
+
 // For Visual C++ 2005 and later mktemp() and open() are deprecated (see
 // http://msdn.microsoft.com/en-us/library/ms235413.aspx and
 // http://msdn.microsoft.com/en-us/library/ms235491.aspx). mktemp()
@@ -54,8 +55,6 @@
 void
 plio_fwrite( void *buf, size_t size, size_t nmemb, FILE *stream )
 {
-    size_t bytes;
-
     dbug_enter( "plio_fwrite" );
 
     // Exit if there is nothing to write
@@ -65,7 +64,7 @@ plio_fwrite( void *buf, size_t size, size_t nmemb, FILE *stream )
     // Clear the error flag for this steam
     clearerr( stream );
 
-    bytes = fwrite( buf, size, nmemb, stream );
+    fwrite( buf, size, nmemb, stream );
 
     if ( ferror( stream ) )
     {
@@ -77,7 +76,7 @@ plio_fwrite( void *buf, size_t size, size_t nmemb, FILE *stream )
 }
 
 //
-// plio_read()
+// plio_fread()
 //
 // Read from stream into buf.  Like plio_write(), this function will
 // handle any I/O error conditions.
@@ -93,7 +92,7 @@ plio_fread( void *buf, size_t size, size_t nmemb, FILE *stream )
     // If the buffer has a size of zero, we should complain
     if ( size == 0 || nmemb == 0 )
     {
-        plwarn( "Zero length buffer size in plio_read, returning" );
+        plwarn( "Zero length buffer size in plio_fread, returning" );
         return;
     }
 
@@ -102,7 +101,7 @@ plio_fread( void *buf, size_t size, size_t nmemb, FILE *stream )
 
     bytes = fread( buf, size, nmemb, stream );
 
-    if ( ferror( stream ) )
+    if ( ( bytes < nmemb ) && ferror( stream ) )
     {
         // The read resulted in an error
         plabort( "Error reading from file" );
@@ -173,11 +172,13 @@ plio_fgets( char *buf, int size, FILE *stream )
 FILE *
 pl_create_tempfile( char **fname )
 {
-    int        flags;
     FILE       *fd;
-    char       *tmpdir;
+    const char *tmpdir;
     char       *template;
     const char *tmpname = "plplot_XXXXXX";
+#if !defined PL_HAVE_MKSTEMP
+    int        flags;
+#endif
 
 #if defined ( MSDOS ) || defined ( WIN32 )
     tmpdir = getenv( "TEMP" );
@@ -255,3 +256,90 @@ pl_create_tempfile( char **fname )
     return fd;
 }
 
+//
+// pl_create_tempfifo()
+//
+// Securely create a temporary fifo and return the file name.
+// This only works on POSIX compliant platforms at the moment.
+// It creates a secure directory first using mkdtemp, then
+// creates the named fifo in this directory. The combination of
+// a private directory and mkfifo failing if the file name already exists
+// makes this secure against race conditions / DoS attacks. This function
+// includes additional functionality over mkdtemp in that it honours the
+// TMP / TMPDIR / TEMP environment variables.
+//
+// The function returns the file name of the fifo.
+//
+char *
+pl_create_tempfifo( const char **p_fifoname, const char **p_dirname )
+{
+#if !defined PL_HAVE_MKDTEMP || !defined PL_HAVE_MKFIFO
+    plwarn( "Creating fifos not supported on this platform" );
+    return NULL;
+#else
+    const char *tmpdir;
+    char       *template;
+    char       *dirname;
+    const char *tmpname  = "plplot_dir_XXXXXX";
+    const char *fifoname = "plplot_fifo";
+
+#if defined ( MSDOS ) || defined ( WIN32 )
+    tmpdir = getenv( "TEMP" );
+#else
+    tmpdir = getenv( "TMPDIR" );
+#endif
+
+// The P_TMPDIR macro is defined in stdio.h on many UNIX systems - try that
+#ifdef P_TMPDIR
+    if ( tmpdir == NULL )
+        tmpdir = P_TMPDIR;
+#endif
+
+    if ( tmpdir == NULL )
+    {
+#if defined ( MSDOS ) || defined ( WIN32 )
+        tmpdir = "c:\\windows\\Temp";
+#else
+        tmpdir = "/tmp";
+#endif
+    }
+
+    // N.B. Malloc ensures template is long enough so strcpy and strcat are safe here
+    dirname = (char *) malloc( sizeof ( char ) * ( strlen( tmpdir ) + strlen( tmpname ) + 2 ) );
+    strcpy( dirname, tmpdir );
+#if defined ( MSDOS ) || defined ( WIN32 )
+    strcat( dirname, "\\" );
+#else
+    strcat( dirname, "/" );
+#endif
+    strcat( dirname, tmpname );
+    // Create the temporary directory
+    dirname    = mkdtemp( dirname );
+    *p_dirname = dirname;
+
+    // Now create the fifo in the directory
+    template = (char *) malloc( sizeof ( char ) * ( strlen( tmpdir ) + strlen( tmpname ) + strlen( fifoname ) + 4 ) );
+    strcpy( template, dirname );
+#if defined ( MSDOS ) || defined ( WIN32 )
+    strcat( template, "\\" );
+#else
+    strcat( template, "/" );
+#endif
+    strcat( template, fifoname );
+    *p_fifoname = template;
+
+    // Check that mkfifo succeeds safely
+    if ( mkfifo( template, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH ) < 0 )
+    {
+        plwarn( "mkfifo error" );
+        free( template );
+        *p_fifoname = NULL;
+        free( dirname );
+        *p_dirname = NULL;
+        return NULL;
+    }
+
+    return template;
+#endif
+}
+
