@@ -1,4 +1,4 @@
-// $Id: plvect.c 11759 2011-06-01 17:41:34Z airwin $
+// $Id: plvect.c 12740 2013-11-22 18:42:58Z airwin $
 //
 //      Vector plotting routines.
 //
@@ -39,15 +39,26 @@ static void plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale );
 void
 c_plsvect( const PLFLT *arrowx, const PLFLT *arrowy, PLINT npts, PLINT fill )
 {
-    int i;
+    int   i;
+    PLFLT def_arrow_x[6] = { -0.5, 0.5, 0.3, 0.5, 0.3, 0.5 };
+    PLFLT def_arrow_y[6] = { 0.0, 0.0, 0.2, 0.0, -0.2, 0.0 };
 
     if ( plsc->arrow_x )
         free_mem( plsc->arrow_x );
     if ( plsc->arrow_y )
         free_mem( plsc->arrow_y );
 
-    if ( ( ( plsc->arrow_x = (PLFLT *) malloc( npts * sizeof ( PLFLT ) ) ) == NULL ) ||
-         ( ( plsc->arrow_y = (PLFLT *) malloc( npts * sizeof ( PLFLT ) ) ) == NULL ) )
+    // Reset default arrow if null pointers are passed.
+    if ( arrowx == NULL && arrowy == NULL )
+    {
+        arrowx = def_arrow_x;
+        arrowy = def_arrow_y;
+        npts   = 6;
+        fill   = 0;
+    }
+
+    if ( ( ( plsc->arrow_x = (PLFLT *) malloc( (size_t) npts * sizeof ( PLFLT ) ) ) == NULL ) ||
+         ( ( plsc->arrow_y = (PLFLT *) malloc( (size_t) npts * sizeof ( PLFLT ) ) ) == NULL ) )
     {
         plexit( "c_plsvect: Insufficient memory" );
     }
@@ -68,7 +79,11 @@ static void
 plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
 {
     PLFLT uu, vv, px0, py0, dpx, dpy;
-    PLINT *a_x, *a_y;
+    PLFLT xt, yt;
+    // Unnecessarily initialize a_y to quiet a -O1 -Wuninitialized warning
+    // which is a false alarm.  (If something goes wrong with the
+    // a_x malloc below any further use of a_y does not occur.)
+    PLINT *a_x, *a_y = NULL;
     int   j;
 
     uu = scale * u;
@@ -77,19 +92,22 @@ plP_plotvect( PLFLT x, PLFLT y, PLFLT u, PLFLT v, PLFLT scale )
     if ( uu == 0.0 && vv == 0.0 )
         return;
 
-    if ( ( ( a_x = (PLINT *) malloc( sizeof ( PLINT ) * ( plsc->arrow_npts ) ) ) == NULL ) ||
-         ( ( a_y = (PLINT *) malloc( sizeof ( PLINT ) * ( plsc->arrow_npts ) ) ) == NULL ) )
+    if ( ( ( a_x = (PLINT *) malloc( sizeof ( PLINT ) * (size_t) ( plsc->arrow_npts ) ) ) == NULL ) ||
+         ( ( a_y = (PLINT *) malloc( sizeof ( PLINT ) * (size_t) ( plsc->arrow_npts ) ) ) == NULL ) )
     {
         plexit( "plP_plotvect: Insufficient memory" );
     }
 
-    px0 = plP_wcpcx( x );
-    py0 = plP_wcpcy( y );
+    TRANSFORM( x, y, &xt, &yt );
+    px0 = plP_wcpcx( xt );
+    py0 = plP_wcpcy( yt );
 
     pldebug( "plP_plotvect", "%f %f %d %d\n", x, y, px0, py0 );
 
-    dpx = plP_wcpcx( x + 0.5 * uu ) - px0;
-    dpy = plP_wcpcy( y + 0.5 * vv ) - py0;
+    TRANSFORM( x + 0.5 * uu, y + 0.5 * vv, &xt, &yt );
+    //printf("plvect: %f %f %f %f %f %f %f\n",scale, x,0.5*uu, y,0.5*vv, xt, yt);
+    dpx = plP_wcpcx( xt ) - px0;
+    dpy = plP_wcpcy( yt ) - py0;
 
     // transform arrow -> a
 
@@ -184,10 +202,7 @@ void plfvect( PLFLT ( *getuv )( PLINT, PLINT, PLPointer ),
                 vmax = ( v[i][j] > vmax ) ? v[i][j] : vmax;
             }
         }
-        umax   = umax / dxmin;
-        vmax   = vmax / dymin;
-        lscale = ( umax < vmax ) ? umax : vmax;
-        lscale = 1.5 / lscale;
+        lscale = 1.5 * MIN( dxmin / umax, dymin / vmax );
         if ( scale < 0.0 )
         {
             scale = -scale * lscale;
@@ -213,7 +228,7 @@ void plfvect( PLFLT ( *getuv )( PLINT, PLINT, PLPointer ),
 }
 
 void
-c_plvect( const PLFLT **u, const PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
+c_plvect( const PLFLT * const *u, const PLFLT * const *v, PLINT nx, PLINT ny, PLFLT scale,
           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
           PLPointer pltr_data )
 {
