@@ -1,4 +1,4 @@
-// $Id: plrender.c 11935 2011-09-25 16:09:38Z airwin $
+// $Id: plrender.c 12288 2013-01-30 04:40:35Z airwin $
 //
 //  Copyright 1991, 1992, 1993, 1994, 1995
 //  Geoffrey Furnish			furnish@dino.ph.utexas.edu
@@ -32,7 +32,7 @@
 //  the metafile driver, plmeta.c.
 //
 
-char ident[] = "@(#) $Id: plrender.c 11935 2011-09-25 16:09:38Z airwin $";
+char ident[] = "@(#) $Id: plrender.c 12288 2013-01-30 04:40:35Z airwin $";
 
 #define DEBUG
 #define DEBUG_ENTER
@@ -972,7 +972,7 @@ plr_state( U_CHAR op )
 
         plm_rd( pdf_rd_2bytes( pdfs, &width ) );
 
-        plwid( width );
+        plwidth( width );
         break;
     }
 
@@ -1931,7 +1931,7 @@ ReadFileHeader( void )
         if ( !strcmp( tag, "width" ) )
         {
             plm_rd( pdf_rd_1byte( pdfs, &dum_uchar ) );
-            plwid( dum_uchar );
+            plwidth( dum_uchar );
             continue;
         }
 
