@@ -34,14 +34,14 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 
 <!--
-Copyright: Darren Hester 2006, http://www.designsbydarren.com
-License: Released Under the "Creative Commons License", 
-http://creativecommons.org/licenses/by-nc/2.5/
+Copyright 2008-2010 Werner Smekal
+Copyright 2008-2011 Hazen Babcock
+Copyright 2008-2013 Alan W. Irwin
 -->
 
 <head>
   <title>PLplot Home Page - $title</title>
-	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
+	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
   <meta name="description" content="Homepage of the open source PLplot project" />
   <meta name="keywords" content="plot,library,c++,python" />
   <link rel="stylesheet" title="liquid" href="css/style_liquid.css" type="text/css" media="screen,projection" />
@@ -65,7 +65,7 @@ END;
 		echo '	<div id="menubar">';
 		echo '		<ul>';
 		echo '		  <li><a href="index.php" ' . (($item=='index') ? ('id="selected"') : ('')) .'>Home</a></li>';
-		echo '		  <li><a href="http://sourceforge.net/news/?group_id=2915" ' . (($item=='news') ? ('id="selected"') : ('')) .'>News</a></li>';
+		echo '		  <li><a href="http://sourceforge.net/p/plplot/news" ' . (($item=='news') ? ('id="selected"') : ('')) .'>News</a></li>';
 		echo '		  <li><a href="download.php" ' . (($item=='download') ? ('id="selected"') : ('')) .'>Download</a></li>';
 		echo '		  <li><a href="examples.php" ' . (($item=='examples') ? ('id="selected"') : ('')) .'>Examples</a></li>';
 		echo '		  <li><a href="documentation.php" ' . (($item=='documentation') ? ('id="selected"') : ('')) .'>Documentation</a></li>';
@@ -81,7 +81,7 @@ END;
 	function pageFooter()
 	{
 		echo '		<div id="pagefooter">';
-		echo '			<p>&copy; 2008 Plplot developer community.<br/>Design by <a href="http://DesignsByDarren.com">DesignsByDarren.com</a>, Some Rights Reserved.<br /><br/>';
+		echo '			<p>Original design by <a href="http://DesignsByDarren.com">DesignsByDarren.com</a>, Some Rights Reserved.<br/>Design modifications &copy; 2008-2013 Plplot developer community.<br /><br/>';
 		echo '			<a href="http://validator.w3.org/check?uri=referer"><img style="border:0;width:88px;height:31px" src="http://www.w3.org/Icons/valid-xhtml10" alt="Valid XHTML 1.0 Transitional" /></a>';
 		echo '      <a href="http://jigsaw.w3.org/css-validator/check?uri=referer"><img style="border:0;width:88px;height:31px" src="http://jigsaw.w3.org/css-validator/images/vcss" alt="Valid CSS!" /></a>';
 		echo '      </p>';
@@ -95,11 +95,10 @@ END;
 	//
 	function pageNews($newscount, $contentlength)
 	{
-		// Open the PLplot News RSS feed and parse it
+		// Open the PLplot News RSS feed and parse it (rss link taken from the plplot project page)
 		$feed = new SimplePie();
 		$feed->enable_cache(false);  // disable cache
-		$url = sprintf("http://sourceforge.net/export/rss2_projnews.php?group_id=2915&rss_limit=%d", $newscount);
-		$feed->set_feed_url($url);
+		$feed->set_feed_url("http://sourceforge.net/p/plplot/news/feed");
 		$feed->init();
 		$feed->handle_content_type();
 
@@ -110,10 +109,15 @@ END;
 		// show news items
 		if($feed->data) {
 			$items = $feed->get_items();
+			$i = 0;
 			foreach($items as $item) {
-				echo '<h4><a href="' . $item->get_permalink() . '">' . $item->get_title() . '</a></h4>'; 
-				echo '<p>' . _substr($item->get_content(), $contentlength) . ' ';
-				echo '<a href="' . $item->get_permalink() . '">Read more</a> (' . $item->get_date('j M Y') . ')</p>';
+				echo '<h4><a href="' . $item->get_permalink() . '">' . $item->get_title() . '</a></h4>' . "\n"; 
+				echo '<p>' . _substr(strip_tags($item->get_content()), $contentlength) . ' ';
+				echo '<a href="' . $item->get_permalink() . '">Read more</a> (' . $item->get_date('j M Y') . ')</p>' . "\n";
+				
+				$i = $i + 1;
+				if( $i >= $newscount )
+					break;
 			}
 		} else 
 			echo '<p>Could not open <a href="' . $url . '">News feed</a>!</p>';
@@ -141,14 +145,14 @@ END;
 				<li><a href="http://www.miscdebris.net/plplot_wiki">Wiki</a></li>
 				<li><a href="http://sourceforge.net/projects/plplot">SourceForge Project Page</a></li>
 				<li><a href="http://sourceforge.net/projects/plplot/support">Project Support Page</a></li>
-				<li><a href="http://sourceforge.net/mail/?group_id=2915">Mailing Lists</a></li>
-				<li><a href="http://sourceforge.net/tracker/?group_id=2915&amp;tid=102915">Bug Tracker</a></li>
+				<li><a href="http://sourceforge.net/p/plplot/mailman/">Mailing Lists</a></li>
+				<li><a href="http://sourceforge.net/p/plplot/bugs/">Bug Tracker</a></li>
 			</ul>
 			<h3>Source Code</h3>
 			<ul class="arrowlist">
-				<li><a href="http://sourceforge.net/project/showfiles.php?group_id=2915&amp;package_id=2865">Download</a></li>
-				<li><a href="http://sourceforge.net/svn/?group_id=2915">SVN Repository</a></li>
-				<li><a href="http://plplot.svn.sourceforge.net/viewvc/plplot/">Browse SVN</a></li>
+				<li><a href="http://sourceforge.net/projects/plplot/files/plplot/">Download</a></li>
+				<li><a href="http://svn.code.sf.net/p/plplot/code/trunk/">SVN Repository</a></li>
+				<li><a href="http://sourceforge.net/p/plplot/code/HEAD/tree/">Browse SVN</a></li>
 			</ul>
 
 		</div>
