@@ -39,13 +39,13 @@
 				<ul class="arrowlist">
 				  <li>Ada</li>
 				  <li>C/C++/D</li>
-				  <li>Fortran 77/90</li>
+				  <li>Fortran 95</li>
 				  <li>Java</li>
 				  <li><a href="http://common-lisp.net/project/cl-plplot/">Lisp</a></li>
 				  <li>Lua</li>
 				  <li>OCaml</li>
 				  <li>Octave</li>
-				  <li><a href="http://search.cpan.org/~dhunt/PDL-Graphics-PLplot-0.47/plplot.pd">Perl</a></li>
+				  <li><a href="http://search.cpan.org/~dhunt/PDL-Graphics-PLplot">Perl</a></li>
 				  <li>Python</li>
 				  <li>Tcl/Tk</li>
 				</ul>
